@@ -24,6 +24,7 @@
  */
 
  /*! \file analysis.cpp
+  * \brief Implementation of the analysis class.
   *
   * Contains the implementation of the analysis class.
   *
@@ -33,9 +34,9 @@
 # include <config.h>
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
+//#include <stdio.h>
+//#include <stdlib.h>
+//#include <string.h>
 
 #include "object.h"
 #include "complex.h"
@@ -46,6 +47,8 @@
 #include "ptrlist.h"
 #include "analysis.h"
 
+namespace qucs {
+
 //Constructor. Creates an unnamed instance of the analysis class.
 analysis::analysis () : object () {
   data = NULL;
@@ -158,3 +161,5 @@ void analysis::saveVariable (const char * n, nr_complex_t z, vector * f) {
   }
   d->add (z);
 }
+
+} // namespace qucs
