@@ -31,6 +31,8 @@
 #ifndef __ANALYSIS_H__
 #define __ANALYSIS_H__
 
+#include "object.h"
+
 #define SAVE_OPS 1 // save operating points
 #define SAVE_ALL 2 // also save subcircuit nodes and operating points
 #define SAVE_CVS 4 // save characteristic values
@@ -41,11 +43,13 @@
   static struct define_t anadef; \
   static struct define_t * definition (void) { return &anadef; }
 
+namespace qucs {
+
 class dataset;
 class net;
-class object;
 class environment;
 class sweep;
+class vector;
 template <class type_t> class ptrlist;
 
 /*! \enum analysis_type
@@ -62,7 +66,8 @@ enum analysis_type
     ANALYSIS_AC,
     ANALYSIS_HBALANCE,
     ANALYSIS_TRANSIENT,
-    ANALYSIS_SPARAMETER
+    ANALYSIS_SPARAMETER,
+    ANALYSIS_E_TRANSIENT
 };
 
 /*! \class analysis
@@ -140,6 +145,18 @@ public:
         return 0;
     }
 
+    /*! \fn isExternal
+    * \brief informs whether this is an external sim
+    *
+    * External simulations will be ignored by qucsator. This
+    * function is used to determine whether the analysis is
+    * external or not.
+    */
+    virtual bool isExternal (void)
+    {
+        return false;
+    }
+
     dataset * getData (void)
     {
         return data;
@@ -227,7 +244,7 @@ public:
      * Saves the given variable into the dataset associated with the
      * analysis.  Creates the dataset vector if necessary.
      */
-    void saveVariable (const char *, nr_complex_t, vector *);
+     void saveVariable (const char *, nr_complex_t, qucs::vector *);
 
     /*! \fn getProgress
      * \brief get
@@ -260,4 +277,6 @@ protected:
     bool progress;
 };
 
+} // namespace qucs
+
 #endif /* __ANALYSIS_H__ */
