@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,7 +29,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
+#include <cmath>
 #include <assert.h>
 #include <float.h>
 #include <ctype.h>
@@ -46,6 +46,8 @@
 #include "check_mdl.h"
 #include "tokens_mdl.h"
 
+using namespace qucs;
+
 // Global variables.
 dataset * mdl_result = NULL;
 struct mdl_link_t * mdl_root = NULL;
@@ -81,7 +83,7 @@ static void mdl_create_vardataset (struct mdl_point_t * point,
   // create vectors
   for (struct mdl_point_t * p = point; p != NULL; p = p->next) {
     int n = (p->y - 1) * 2 + p->x - 1;
-    v[n].add (rect (p->r, p->i));
+    v[n].add (nr_complex_t (p->r, p->i));
   }
   // go through indices
   for (int x = 1; x < dsize->x + 1; x++) {
