@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -30,7 +30,7 @@
 #include <stdlib.h>
 #include <string.h>
 #include <ctype.h>
-#include <math.h>
+#include <cmath>
 
 #include "logging.h"
 #include "complex.h"
@@ -45,12 +45,14 @@
 
 #define ZREF 50.0 /* reference impedance */
 
+using namespace qucs;
+
 strlist * touchstone_idents = NULL;
 dataset * touchstone_result = NULL;
-vector  * touchstone_vector = NULL;
+qucs::vector  * touchstone_vector = NULL;
 
 /* default touchstone options */
-struct touchstone_t touchstone_options = { 
+struct touchstone_t touchstone_options = {
   "GHz", 'S', "MA", 50.0, 1e9, 0, 0, 0 };
 
 /* available touchstone options */
@@ -61,13 +63,13 @@ static const char * touchstone_valid_options[] = {
    input and output list of vectors of this function is the
    touchstone_vector variable. */
 static void touchstone_join (void) {
-  vector * yroot, * xroot, * next = NULL;
+  qucs::vector * yroot, * xroot, * next = NULL;
   /* go through each vector */
   for (yroot = touchstone_vector; yroot != NULL; yroot = next) {
     /* go through each trailing vector */
-    next = (vector *) yroot->getNext ();
+    next = (qucs::vector *) yroot->getNext ();
     for (xroot = next; xroot != NULL; xroot = next) {
-      next = (vector *) xroot->getNext ();
+      next = (qucs::vector *) xroot->getNext ();
       /* append xroot vector to yroot vector (even no. of values) ? */
       if ((xroot->getSize () & 1) == 0) {
 	/* yes, delete the xroot vector and adjust list */
@@ -89,7 +91,7 @@ static void touchstone_join (void) {
    matrix.  The function return zero on success and non-zero
    otherwise. */
 static int touchstone_vector_check (void) {
-  vector * root = touchstone_vector, * next;
+  qucs::vector * root = touchstone_vector, * next;
   int even = 0, errors = 0, size = root->getSize (), noise = 0, lines = 1;
   nr_double_t f = real (root->get (0));
 
@@ -101,7 +103,7 @@ static int touchstone_vector_check (void) {
     even = 1;
   }
   /* first line determines the number of expected ports */
-  touchstone_options.ports = (int) sqrt ((size - 1) / 2.0);
+  touchstone_options.ports = (int) std::sqrt ((size - 1) / 2.0);
 
   /* check first frequency value */
   if (f < 0.0) {
@@ -111,10 +113,10 @@ static int touchstone_vector_check (void) {
   }
 
   /* go through each vector */
-  for (root = (vector *) root->getNext (); root != NULL; root = next) {
-    next = (vector *) root->getNext ();
+  for (root = (qucs::vector *) root->getNext (); root != NULL; root = next) {
+    next = (qucs::vector *) root->getNext ();
     nr_double_t freq = real (root->get (0));
-    
+
     /* check increasing frequency value */
     if (f >= freq) {
       if (!noise) {
@@ -214,21 +216,21 @@ static char * touchstone_create_set (int r, int c) {
 
 /* The function actually creates the resulting dataset. */
 static void touchstone_create (void) {
-  vector * f, * v, * root, * next, * nf = NULL;
+  qucs::vector * f, * v, * root, * next, * nf = NULL;
   int ports = touchstone_options.ports, n;
   nr_complex_t val;
   strlist * s;
 
   /* create dataset and frequency vector */
   touchstone_result = new dataset ();
-  f = new vector ("frequency");
+  f = new qucs::vector ("frequency");
   touchstone_result->appendDependency (f);
   s = new strlist ();
   s->add (f->getName ());
   /* create variable vectors for the resulting dataset */
   for (int r = 0; r < ports; r++) {
     for (int c = 0; c < ports; c++) {
-      v = new vector ();
+      v = new qucs::vector ();
       v->setName (touchstone_create_set (r, c));
       v->setDependencies (new strlist (*s));
       touchstone_result->appendVariable (v);
@@ -238,26 +240,26 @@ static void touchstone_create (void) {
 
   /* create noise vectors if necessary */
   if (touchstone_options.noise) {
-    nf = new vector ("nfreq");
+    nf = new qucs::vector ("nfreq");
     touchstone_result->appendDependency (nf);
     s = new strlist ();
     s->add (nf->getName ());
     /* append noise parameters to dataset */
-    v = new vector ("Fmin");
+    v = new qucs::vector ("Fmin");
     v->setDependencies (new strlist (*s));
     touchstone_result->appendVariable (v);
-    v = new vector ("Sopt");
+    v = new qucs::vector ("Sopt");
     v->setDependencies (new strlist (*s));
     touchstone_result->appendVariable (v);
-    v = new vector ("Rn");
+    v = new qucs::vector ("Rn");
     v->setDependencies (new strlist (*s));
-    touchstone_result->appendVariable (v);    
+    touchstone_result->appendVariable (v);
     delete s;
   }
 
   /* go through each vector */
   for (n = 0, root = touchstone_vector; root != NULL; root = next, n++) {
-    next = (vector *) root->getNext ();
+    next = (qucs::vector *) root->getNext ();
     // handle data lines
     if (n < touchstone_options.lines) {
       /* fill frequency vector */
@@ -274,19 +276,19 @@ static void touchstone_create (void) {
 	  }
 	  /* depending on the touchstone data format */
 	  if (!strcmp (touchstone_options.format, "RI")) {
-	    val = rect (real (root->get (pos + 0)),
+	    val = nr_complex_t (real (root->get (pos + 0)),
 			real (root->get (pos + 1)));
 	  }
 	  else if (!strcmp (touchstone_options.format, "MA")) {
-	    val = polar (real (root->get (pos + 0)),
+	    val = qucs::polar (real (root->get (pos + 0)),
 			 rad (real (root->get (pos + 1))));
 	  }
 	  else if (!strcmp (touchstone_options.format, "dB")) {
-	    val = polar (pow (10.0, real (root->get (pos + 0)) / 20.0),
+	    val = qucs::polar (std::pow (10.0, real (root->get (pos + 0)) / 20.0),
 			 rad (real (root->get (pos + 1))));
 	  }
 	  v->add (val);
-	  v = (vector *) v->getNext ();
+	  v = (qucs::vector *) v->getNext ();
 	}
       }
     }
@@ -296,14 +298,14 @@ static void touchstone_create (void) {
       nf->add (real (root->get (0)) * touchstone_options.factor);
       /* fill minimum noise figure vector */
       v = touchstone_result->findVariable ("Fmin");
-      val = pow (10.0, real (root->get (1)) / 10.0);
+      val = std::pow (10.0, real (root->get (1)) / 10.0);
       v->add (val);
       /* fill optimal noise reflexion coefficient vector */
       v = touchstone_result->findVariable ("Sopt");
-      val = polar (real (root->get (2)), rad (real (root->get (3))));
+      val = qucs::polar (real (root->get (2)), rad (real (root->get (3))));
       if (ZREF != touchstone_options.resistance) {
 	// re-normalize reflexion coefficient if necessary
-	nr_double_t r = (ZREF - touchstone_options.resistance) / 
+	nr_double_t r = (ZREF - touchstone_options.resistance) /
 	  (ZREF + touchstone_options.resistance);
 	val = (val - r) / (1.0 - r * val);
       }
@@ -320,7 +322,7 @@ static void touchstone_create (void) {
    impedance 50 Ohms. */
 static void touchstone_normalize_sp (void) {
   int ports = touchstone_options.ports;
-  vector * v = touchstone_result->getVariables ();
+  qucs::vector * v = touchstone_result->getVariables ();
   int i, j, n, len = v->getSize ();
   matrix s = matrix (ports);
 
@@ -331,7 +333,7 @@ static void touchstone_normalize_sp (void) {
     for (i = 0; i < ports; i++) {
       for (j = 0; j < ports; j++) {
 	s.set (i, j, v->get (n));
-	v = (vector *) v->getNext ();
+	v = (qucs::vector *) v->getNext ();
       }
     }
     // convert the temporary matrix
@@ -341,16 +343,16 @@ static void touchstone_normalize_sp (void) {
     for (i = 0; i < ports; i++) {
       for (j = 0; j < ports; j++) {
 	v->set (s.get (i, j), n);
-	v = (vector *) v->getNext ();
+	v = (qucs::vector *) v->getNext ();
       }
-    }    
+    }
   }
 }
 
 /* The function transforms the reference impedance given in the
    touchstone file to the internal reference impedance 50 Ohms. */
 static void touchstone_normalize (void) {
-  vector * v = touchstone_result->getVariables ();
+  qucs::vector * v = touchstone_result->getVariables ();
   int ports = touchstone_options.ports;
 
   // transform S-parameters if necessary
@@ -382,16 +384,16 @@ static void touchstone_normalize (void) {
 	  *v /= touchstone_options.resistance;
 	break;
       }
-      v = (vector *) v->getNext ();
+      v = (qucs::vector *) v->getNext ();
     }
   }
 }
 
 /* Removes temporary data items from memory if necessary. */
 static void touchstone_finalize (void) {
-  vector * root, * next;
+  qucs::vector * root, * next;
   for (root = touchstone_vector; root != NULL; root = next) {
-    next = (vector *) root->getNext ();
+    next = (qucs::vector *) root->getNext ();
     delete root;
   }
   touchstone_vector = NULL;
@@ -421,7 +423,7 @@ int touchstone_check (void) {
 
   /* first checking the options */
   if (touchstone_idents->length () > 3) {
-    logprint (LOG_ERROR, "checker error, found %d options\n", 
+    logprint (LOG_ERROR, "checker error, found %d options\n",
 	      touchstone_idents->length ());
     errors++;
   }
@@ -434,7 +436,7 @@ int touchstone_check (void) {
   for (i = 0; i < touchstone_idents->length (); i++) {
     char * str = touchstone_idents->get (i);
     if ((n = touchstone_idents->contains (str)) != 1) {
-      logprint (LOG_ERROR, "checker error, option `%s' occurred %dx\n", 
+      logprint (LOG_ERROR, "checker error, option `%s' occurred %dx\n",
 		str, n);
       errors++;
     }
@@ -469,7 +471,7 @@ int touchstone_check (void) {
     errors += touchstone_vector_check ();
 
     /* check validity of ports and parameters */
-    if ((touchstone_options.parameter == 'G' || 
+    if ((touchstone_options.parameter == 'G' ||
 	 touchstone_options.parameter == 'H') &&
 	touchstone_options.ports != 2) {
       logprint (LOG_ERROR, "checker error, %c-parameters for %d-ports not "
