@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -46,6 +46,8 @@
 #include "characteristic.h"
 #include "component_id.h"
 
+namespace qucs {
+
 // normalising impedance
 const nr_double_t circuit::z0 = 50.0;
 
@@ -317,7 +319,7 @@ void circuit::setSubcircuit (char * n) {
 void circuit::print (void) {
   for (int i = 0; i < getSize (); i++) {
     for (int j = 0; j < getSize (); j++) {
-      logprint (LOG_STATUS, "%s S%d%d(%+.3e,%+.3e) ", getName (), i, j, 
+      logprint (LOG_STATUS, "%s S%d%d(%+.3e,%+.3e) ", getName (), i, j,
 		(double) real (getS (i, j)), (double) imag (getS (i, j)));
     }
     logprint (LOG_STATUS, "\n");
@@ -327,7 +329,7 @@ void circuit::print (void) {
 
 /* Returns the current substrate of the circuit object.  Used for
    microstrip components only. */
-substrate * circuit::getSubstrate (void) { 
+substrate * circuit::getSubstrate (void) {
   return subst;
 }
 
@@ -577,7 +579,7 @@ int circuit::hasCharacteristic (char * n) {
 }
 
 // Returns the S-parameter at the given matrix position.
-nr_complex_t circuit::getS (int x, int y) { 
+nr_complex_t circuit::getS (int x, int y) {
   return MatrixS[y + x * size];
 }
 
@@ -587,7 +589,7 @@ void circuit::setS (int x, int y, nr_complex_t z) {
 }
 
 // Returns the noise-correlation-parameter at the given matrix position.
-nr_complex_t circuit::getN (int r, int c) { 
+nr_complex_t circuit::getN (int r, int c) {
   return MatrixN[c + r * (size + nsources)];
 }
 
@@ -651,7 +653,9 @@ void circuit::setMatrixS (matrix s) {
    circuit. */
 matrix circuit::getMatrixS (void) {
   matrix res (size);
-  memcpy (res.getData (), MatrixS, sizeof (nr_complex_t) * size * size);
+  for(unsigned int i=0; i < size; ++i)
+    for(unsigned int j=0; i < size; ++j)
+      res(i,j) = MatrixS[i*size + j];
   return res;
 }
 
@@ -670,7 +674,9 @@ void circuit::setMatrixN (matrix n) {
    matrix of the circuit. */
 matrix circuit::getMatrixN (void) {
   matrix res (size);
-  memcpy (res.getData (), MatrixN, sizeof (nr_complex_t) * size * size);
+  for(unsigned int i=0; i < size; ++i)
+    for(unsigned int j=0; i < size; ++j)
+      res(i,j) = MatrixN[i*size + j];
   return res;
 }
 
@@ -689,7 +695,9 @@ void circuit::setMatrixY (matrix y) {
    circuit. */
 matrix circuit::getMatrixY (void) {
   matrix res (size);
-  memcpy (res.getData (), MatrixY, sizeof (nr_complex_t) * size * size);
+  for(unsigned int i=0; i < size; ++i)
+    for(unsigned int j=0; i < size; ++j)
+      res(i,j) = MatrixY[i*size + j];
   return res;
 }
 
@@ -861,9 +869,19 @@ void circuit::transientCapacitanceC (int qpos, int vpos,
 void circuit::initHistory (nr_double_t age) {
   nHistories = getSize () + getVoltageSources ();
   histories = new history[nHistories];
-  for (int i = 0; i < nHistories; i++) histories[i].setAge (age);
+  setHistoryAge (age);
 }
 
+// Sets the age of all circuit histories
+void circuit::setHistoryAge (nr_double_t age) {
+  for (int i = 0; i < nHistories; i++)
+  {
+    histories[i].setAge (age);
+  }
+}
+
+
+
 // The function deletes the histories for the transient analysis.
 void circuit::deleteHistory (void) {
   if (histories != NULL) {
@@ -873,6 +891,17 @@ void circuit::deleteHistory (void) {
   setHistory (false);
 }
 
+// Truncates the transient analysis history (i.e. removes values newer
+// newer than time tcut).
+void circuit::truncateHistory (nr_double_t tcut) {
+  if (histories != NULL) {
+    for (int i = 0; i < nHistories; i++)
+    {
+      histories[i].truncate (tcut);
+    }
+  }
+}
+
 // Appends a history value.
 void circuit::appendHistory (int n, nr_double_t val) {
   histories[n].append (val);
@@ -884,11 +913,28 @@ nr_double_t circuit::getHistoryAge (void) {
   return 0.0;
 }
 
+// Returns size of the history
+int circuit::getHistorySize (void) {
+  return histories[0].getSize ();
+}
+
+// Returns the time with the specified index
+nr_double_t circuit::getHistoryTFromIndex (int idx)
+{
+  return histories[0].getTfromidx (idx);
+}
+
 /* This function should be used to apply the time vector history to
    the value histories of a circuit. */
 void circuit::applyHistory (history * h) {
+
   tvector<nr_double_t> * t = h->getTvector ();
-  for (int i = 0; i < nHistories; i++) histories[i].setTvector (t);
+
+  for (int i = 0; i < nHistories; i++)
+  {
+      histories[i].setTvector (t);
+  }
+
 }
 
 // Returns voltage at the given time for the given node.
@@ -896,7 +942,14 @@ nr_double_t circuit::getV (int port, nr_double_t t) {
   return histories[port].nearest (t);
 }
 
+// Returns voltage at the given index from the history for the given node.
+nr_double_t circuit::getV (int port, int idx) {
+  return histories[port].getValfromidx (idx);
+}
+
 // Returns current at the given time for the given voltage source.
 nr_double_t circuit::getJ (int nr, nr_double_t t) {
   return histories[nr + getSize ()].nearest (t);
 }
+
+} // namespace qucs
