@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -34,7 +34,8 @@
 #define NODE_A1 0 /* cathode node */
 #define NODE_A2 1 /* anode node   */
 
-using namespace device;
+using namespace qucs;
+using namespace qucs::device;
 
 // Constructor for the diode.
 tunneldiode::tunneldiode () : circuit (2) {
@@ -55,21 +56,21 @@ void tunneldiode::calcId (nr_double_t U, nr_double_t& I, nr_double_t& G) {
   nr_double_t de   = getPropertyDouble ("de");
   nr_double_t dW   = getPropertyDouble ("dW");
 
-  U   = Wr - Q*U/dv;
+  U   = Wr - Q_e*U/dv;
   de *= kB * kelvin (getPropertyDouble ("Temp"));
 
-  nr_double_t a = M_PI_2 + atan ( U / dW );
+  nr_double_t a = M_PI_2 + qucs::atan ( U / dW );
 
   nr_double_t e = (eta - U) / de;
   nr_double_t b = e;
   if (e < 15.0)  // avoid numerical overflow
-    b = log (1.0 + exp ( e ));
+    b = qucs::log (1.0 + qucs::exp ( e ));
 
   // current
   I = b * a;
 
   // derivative
-  G = Q / dv / de / (1.0 + exp(-e)) * a - b * Q / dv / dW / (1.0 + sqr (U/dW));
+  G = Q_e / dv / de / (1.0 + qucs::exp(-e)) * a - b * Q_e / dv / dW / (1.0 + sqr (U/dW));
 }
 
 // Callback for DC analysis.
@@ -97,10 +98,10 @@ void tunneldiode::calcDC (void) {
   gd *= Gpos + Gneg;
 
   // thermal-ionic current
-  nv *= T / Q;
-  nr_double_t c = A * Iv / sinh (Vv / nv);
-  Id += c * sinh (Ud / nv);
-  gd += c * cosh (Ud / nv) / nv;
+  nv *= T / Q_e;
+  nr_double_t c = A * Iv / qucs::sinh (Vv / nv);
+  Id += c * qucs::sinh (Ud / nv);
+  gd += c * qucs::cosh (Ud / nv) / nv;
 
   nr_double_t Ieq = Id - Ud * gd;
 
@@ -137,8 +138,8 @@ void tunneldiode::calcOperatingPoints (void) {
 
   // depletion capacitance
   nr_double_t c = 1.0 + fabs(Ud) / Vj;
-  Cd = A * Cj0 / pow (c, M);
-  Qd = A * Cj0 * Vj / (1.0-M) * (1.0 - pow (c, 1.0 - M));
+  Cd = A * Cj0 / qucs::pow (c, M);
+  Qd = A * Cj0 * Vj / (1.0-M) * (1.0 - qucs::pow (c, 1.0 - M));
 
   // quantum well (diffusion) capacitance (negative because of NDR region)
   Cd -= te * gd;
@@ -159,7 +160,7 @@ void tunneldiode::initAC (void) {
 matrix tunneldiode::calcMatrixY (nr_double_t frequency) {
   nr_double_t gd = getOperatingPoint ("gd");
   nr_double_t Cd = getOperatingPoint ("Cd");
-  nr_complex_t yd = rect (gd, Cd * 2.0 * M_PI * frequency);
+  nr_complex_t yd = nr_complex_t (gd, Cd * 2.0 * M_PI * frequency);
   matrix y (2);
   y.set (NODE_A1, NODE_A1, +yd);
   y.set (NODE_A2, NODE_A2, +yd);
