@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,6 +29,8 @@
 #include "component.h"
 #include "hybrid.h"
 
+using namespace qucs;
+
 hybrid::hybrid () : circuit (4) {
   type = CIR_HYBRID;
 }
@@ -39,10 +41,10 @@ hybrid::hybrid () : circuit (4) {
 
 void hybrid::initSP (void) {
 
-  nr_complex_t p = polar (1.0, rad (getPropertyDouble ("phi")));
-  //nr_double_t  k = sqrt(1-pow((1/M_SQRT2),2));
-  nr_double_t  k = (1/M_SQRT2); //last line reduces to this for 1/sqrt(2)
-  
+  nr_complex_t p = qucs::polar (1.0, rad (getPropertyDouble ("phi")));
+  //nr_double_t  k = std::sqrt(1-pow((1/M_SQRT2),2));
+  nr_double_t  k = (1/M_SQRT2); //last line reduces to this for 1/std::sqrt(2)
+
   allocMatrixS ();
 //S11 = S22 = S33 = S44 = 0
   setS (NODE_1, NODE_1, 0.0); setS (NODE_2, NODE_2, 0.0);
@@ -50,7 +52,7 @@ void hybrid::initSP (void) {
 //S14 = S23 = S32 = S41 = 0
   setS (NODE_1, NODE_4, 0.0); setS (NODE_2, NODE_3, 0.0);
   setS (NODE_3, NODE_2, 0.0); setS (NODE_4, NODE_1, 0.0);
-//S12 = S21 = S34 = S43 = sqrt(1-k^2)
+//S12 = S21 = S34 = S43 = std::sqrt(1-k^2)
   setS (NODE_1, NODE_2, k); setS (NODE_2, NODE_1, k);
   setS (NODE_3, NODE_4, k); setS (NODE_4, NODE_3, k);
 //S13 = S31 = S24 = S42 = k*exp(j * p)
@@ -70,9 +72,9 @@ void hybrid::initAC (void) {
 
     nr_double_t  k = 1 / M_SQRT2;
     nr_complex_t y;
-    nr_complex_t A = k*k*(nr_complex_t(1,0)+polar(1.0, 2.0*rad (getPropertyDouble ("phi"))));
-    nr_double_t B  = 2 * sqrt(1-(k*k));
-    nr_complex_t C = polar (2*k, rad (getPropertyDouble ("phi")));
+    nr_complex_t A = k*k*(nr_complex_t(1,0)+qucs::polar(1.0, 2.0*rad (getPropertyDouble ("phi"))));
+    nr_double_t B  = 2 * std::sqrt(1-(k*k));
+    nr_complex_t C = qucs::polar (2*k, rad (getPropertyDouble ("phi")));
     nr_complex_t D = getPropertyDouble ("Zref") * ((A*A)-(C*C));
 
     setVoltageSources (0);
@@ -96,7 +98,7 @@ void hybrid::initAC (void) {
     setY (NODE_2, NODE_3, y); setY (NODE_3, NODE_2, y);
 
 
-    
+
 }
 
 void hybrid::initTR (void) {
