@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,6 +29,8 @@
 #include "component.h"
 #include "inductor.h"
 
+using namespace qucs;
+
 inductor::inductor () : circuit (2) {
   type = CIR_INDUCTOR;
   setISource (true);
@@ -36,7 +38,7 @@ inductor::inductor () : circuit (2) {
 
 void inductor::calcSP (nr_double_t frequency) {
   nr_double_t l = getPropertyDouble ("L") / z0;
-  nr_complex_t z = rect (0, 2.0 * M_PI * frequency * l);
+  nr_complex_t z = nr_complex_t (0, 2.0 * M_PI * frequency * l);
   setS (NODE_1, NODE_1, z / (z + 2.0));
   setS (NODE_2, NODE_2, z / (z + 2.0));
   setS (NODE_1, NODE_2, 2.0 / (z + 2.0));
@@ -44,7 +46,7 @@ void inductor::calcSP (nr_double_t frequency) {
 }
 
 void inductor::initDC (void) {
-  setVoltageSources (1);  
+  setVoltageSources (1);
   allocMatrixMNA ();
   voltageSource (VSRC_1, NODE_1, NODE_2);
 }
@@ -73,7 +75,7 @@ void inductor::calcAC (nr_double_t frequency) {
 
   // for non-zero inductance usual MNA entries
   if (l != 0.0) {
-    nr_complex_t y = rect (0, -1 / (2.0 * M_PI * frequency * l));
+    nr_complex_t y = nr_complex_t (0, -1 / (2.0 * M_PI * frequency * l));
     setY (NODE_1, NODE_1, +y); setY (NODE_2, NODE_2, +y);
     setY (NODE_1, NODE_2, -y); setY (NODE_2, NODE_1, -y);
   }
