@@ -8,16 +8,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -25,10 +25,10 @@
 
 /*!\file bondwire.cpp
    \brief Implement a bondwire model
-   
+
    Bibliography:
 
-   [1] Microwave Solid State Circuit Design, 
+   [1] Microwave Solid State Circuit Design,
        Inder Bahl and Prakash Barthia  -- 2nd edition
        2003 - Wiley interscience
        ISBN 9-471-20755-1
@@ -38,13 +38,13 @@
        online 2006/11/02
 
    [3] Physical and electrical modeling of bonding wires up to 110 GHz,
-       Descharles, C.   Algani, C.   Mercier, B.   Alquie, G. 
-       Microwave Conference, 2003. 33rd European 
+       Descharles, C.   Algani, C.   Mercier, B.   Alquie, G.
+       Microwave Conference, 2003. 33rd European
        Volume: 2,  On page(s): 639- 642 vol.2
        ISBN: 1-58053-834-7
        INSPEC Accession Number: 1262971
 */
-  
+
 
 #if HAVE_CONFIG_H
 # include <config.h>
@@ -54,6 +54,8 @@
 #include "substrate.h"
 #include "bondwire.h"
 
+using namespace qucs;
+
 bondwire::bondwire () : circuit (2) {
   type = CIR_BONDWIRE;
 }
@@ -72,8 +74,8 @@ enum bondwiremodel {
 };
 
 /*! model number to string matching table definition */
-struct modeltable_t { 
-  const char * name; 
+struct modeltable_t {
+  const char * name;
   int model;
 };
 
@@ -86,7 +88,7 @@ static const modeltable_t modeltable[] = {
 
 /*!\brief Get properties from model.
  * Get properties and fill the class.
- *  
+ *
  *  \todo check values
  */
 void bondwire::getProperties (void) {
@@ -98,7 +100,7 @@ void bondwire::getProperties (void) {
   h = getPropertyDouble ("H");
   rho = getPropertyDouble ("rho");
   mur = getPropertyDouble ("mur");
-  
+
   /* model used */
   char * Model  = getPropertyString ("Model");
   if (Model == NULL) {
@@ -111,7 +113,7 @@ void bondwire::getProperties (void) {
 	model = modeltable[i].model;
     }
 
-    if (model == -1) 
+    if (model == -1)
       /* XXXX: how to abort ? */
       logprint (LOG_ERROR, "Model %s not defined\n", Model);
   }
@@ -124,7 +126,7 @@ void bondwire::getProperties (void) {
   nr_double_t er    = subst->getPropertyDouble ("er");
   nr_double_t h     = subst->getPropertyDouble ("h");
   nr_double_t t     = subst->getPropertyDouble ("t");
-  
+
   /* Not yet used */
   (void) er;
   (void) h;
@@ -133,22 +135,22 @@ void bondwire::getProperties (void) {
 
 /*! Compute skin depth.
  * \todo Factorize the compution of skin depth in a header file.
- * 
+ *
  * \param f frequency
  * \param rho bond wire resistivity
  * \param mur relative magnetic permeabillity
  */
 static nr_double_t skindepth (const nr_double_t f,
 			      const nr_double_t rho, const nr_double_t mur) {
-  return sqrt (rho / (M_PI * f * MU0 * mur));
+  return std::sqrt (rho / (M_PI * f * MU0 * mur));
 }
 
 /*! Compute resitance of the wire.
- * Resitance of the wire is computed using classical 
+ * Resitance of the wire is computed using classical
  * tube model enhanced for case where tube is greater
  * than conductor (i.e. low frequency case).
  *
- * \todo Offer other resistance model for 
+ * \todo Offer other resistance model for
  *       instance exponential decay and bessel function exact
  *       computation.  But I do not know it is worth the effort.
  *
@@ -171,20 +173,20 @@ nr_double_t bondwire::resistance (const nr_double_t f) const {
 
 
 /*! Compute correction factor.
- *  According to [1] pp63 (2.30a-b) correction factor 
+ *  According to [1] pp63 (2.30a-b) correction factor
  *  is such as:
  *  \f[
  *   C = 0.25 \tanh \frac{4\delta}{d}
  *  \f]
  *  where \f$\delta\f$ is the well known skin depth.
- * 
+ *
  *  \param f frequency
  *  \param d bond wire diameter
- *  \param rho bond wire resistivity 
+ *  \param rho bond wire resistivity
  *  \param mur relative magnetic permeabillity
  *
  * However according to [2] it seems that the author of [1] do the
- * assumption of \f$\mu_r=1\f$ therefore rewrite the equation such as: 
+ * assumption of \f$\mu_r=1\f$ therefore rewrite the equation such as:
  *
  *  \f[
  *   C = \frac{\mu_r}{4} \tanh \frac{4\delta}{d}
@@ -194,7 +196,7 @@ nr_double_t bondwire::resistance (const nr_double_t f) const {
  *  \todo Check domain validity for round C factor.
  */
 static nr_double_t correctionfactor (const nr_double_t f,
-				     const nr_double_t d, 
+				     const nr_double_t d,
 				     const nr_double_t rho,
 				     const nr_double_t mur) {
   /* skin depth */
@@ -205,7 +207,7 @@ static nr_double_t correctionfactor (const nr_double_t f,
     if (delta / d < 1e-2)
       return delta / d;
     else
-      return (mur / 4) * tanh ((4 * delta) / d);
+      return (mur / 4) * std::tanh ((4 * delta) / d);
   }
   return mur / 4;
 }
@@ -215,32 +217,32 @@ static nr_double_t correctionfactor (const nr_double_t f,
     is such as (\f$l\f$ in micrometers):
 
    \f[
-    L = 2\times10^{-4} l \left[ 
-               \ln\left\{ \frac{2l}{d} 
+    L = 2\times10^{-4} l \left[
+               \ln\left\{ \frac{2l}{d}
 	                  + \sqrt{1 + \left(\frac{2l}{d}\right)^2} \right\}
 	       + \frac{d}{2l} - \sqrt{1+\left(\frac{d}{2l}\right)^2}
 	       + C \right]
-			  
+
    \f]
 
    According to [2] self inductance is (in H with l in m):
    \f[
-    L = \frac{\mu_0}{2\pi} l\left[ 
-               \ln\left\{ \frac{2l}{d} 
+    L = \frac{\mu_0}{2\pi} l\left[
+               \ln\left\{ \frac{2l}{d}
 	                  + \sqrt{1 + \left(\frac{2l}{d}\right)^2} \right\}
 	       + \frac{d}{2l} - \sqrt{1+\left(\frac{d}{2l}\right)^2}
 	       + \frac{\mu_r}{4} \right]
-			  
+
    \f]
 
    Finally we will use (in H with l in m):
    \f[
-    L = \frac{\mu_0}{2\pi} l\left[ 
-               \ln\left\{ \frac{2l}{d} 
+    L = \frac{\mu_0}{2\pi} l\left[
+               \ln\left\{ \frac{2l}{d}
 	                  + \sqrt{1 + \left(\frac{2l}{d}\right)^2} \right\}
 	       + \frac{d}{2l} - \sqrt{1+\left(\frac{d}{2l}\right)^2}
 	       + C \right]
-			  
+
    \f]
 
    \param f frequency
@@ -254,8 +256,8 @@ nr_double_t bondwire::Lfreespace (const nr_double_t f) const {
   nr_double_t d2l = d / (2.0 * l);
   nr_double_t tmp;
 
-  tmp = log (_2ld + sqrt (1 + _2ld * _2ld));
-  tmp += d2l - sqrt (1 + d2l * d2l);
+  tmp = std::log (_2ld + std::sqrt (1 + _2ld * _2ld));
+  tmp += d2l - std::sqrt (1 + d2l * d2l);
   tmp += correctionfactor (f, d, rho, mur);
 
   return MU0 * (M_1_PI / 2) * l * tmp;
@@ -267,23 +269,23 @@ nr_double_t bondwire::Lfreespace (const nr_double_t f) const {
    is such as (\f$l\f$ in micrometers):
 
    \f[
-    L = 2\times10^{-4} l \left[ 
-               \ln \frac{4h}{d} 
+    L = 2\times10^{-4} l \left[
+               \ln \frac{4h}{d}
 	       + \ln \frac{l+\sqrt{l^2+d^2/4}}{l+\sqrt{l^2+4h^2}}
 	       + \sqrt{1+\frac{4h^2}{l^2}} - \sqrt{1+\frac{d^2}{4l^2}}
 	       - 2 \frac{h}{l} + \frac{d}{2l}
 	       \right]
-			  
+
    \f]
 
    Finally we will use (in H with l in m):
    \f[
-    L = \frac{\mu_0}{2\pi} l \left[ 
-               \ln \frac{4h}{d} 
+    L = \frac{\mu_0}{2\pi} l \left[
+               \ln \frac{4h}{d}
 	       + \ln \frac{l+\sqrt{l^2+d^2/4}}{l+\sqrt{l^2+4h^2}}
 	       + \sqrt{1+\frac{4h^2}{l^2}} - \sqrt{1+\frac{d^2}{4l^2}}
 	       - 2 \frac{h}{l} + \frac{d}{2l}
-	       \right]			  
+	       \right]
    \f]
 
    \note Mirror is a strange model that is frequency independent.
@@ -296,17 +298,17 @@ nr_double_t bondwire::Lmirror (void) const {
   nr_double_t tmp;
 
   /* compute \$\ln \frac{l+\sqrt{l^2+d^2/4}}{l+\sqrt{l^2+4h^2}}\$ */
-  tmp  = log ((l + sqrt (l * l + d * d / 4)) / (l + sqrt (l * l + 4 * h * h)));
-  tmp += log (4 * h / d);
-  tmp += sqrt (1 + 4 * h * h / (l * l));
-  tmp -= sqrt (1 + d * d / (4 * l * l));
+  tmp  = std::log ((l + std::sqrt (l * l + d * d / 4)) / (l + std::sqrt (l * l + 4 * h * h)));
+  tmp += std::log (4 * h / d);
+  tmp += std::sqrt (1 + 4 * h * h / (l * l));
+  tmp -= std::sqrt (1 + d * d / (4 * l * l));
   tmp -= 2 * h / l;
   tmp += d / (2 * l);
 
   return  MU0 * (M_1_PI / 2) * l * tmp;
 }
-  
-  
+
+
 /*! Compute Y matrix of bond wire.
  */
 matrix bondwire::calcMatrixY (const nr_double_t f) {
@@ -329,7 +331,7 @@ matrix bondwire::calcMatrixY (const nr_double_t f) {
   Lw = L * 2 * M_PI * f;
 
   /* build Y-parameter matrix */
-  nr_complex_t yL = 1.0 / rect (R, Lw);
+  nr_complex_t yL = 1.0 / nr_complex_t (R, Lw);
 
   matrix Y (2);
   Y.set (NODE_1, NODE_1, +yL);
@@ -386,7 +388,7 @@ void bondwire::initDC (void) {
 
 /*! Initialize AC simulation. */
 void bondwire::initAC (void) {
-  getProperties (); 
+  getProperties ();
   setVoltageSources (0);
   allocMatrixMNA ();
 }
