@@ -31,6 +31,8 @@
 #include "substrate.h"
 #include "mscorner.h"
 
+using namespace qucs;
+
 mscorner::mscorner () : circuit (2) {
   type = CIR_MSCORNER;
 }
@@ -58,7 +60,7 @@ void mscorner::initCheck (void) {
   // capacitance in pF
   C = W * ((10.35 * er + 2.5) * Wh + (2.6 * er + 5.64));
   // inductivity in nH
-  L = 220.0 * h * (1.0 - 1.35 * exp (-0.18 * pow (Wh, 1.39)));
+  L = 220.0 * h * (1.0 - 1.35 * qucs::exp (-0.18 * qucs::pow (Wh, 1.39)));
 }
 
 void mscorner::initSP (void) {
@@ -80,8 +82,8 @@ matrix mscorner::calcMatrixZ (nr_double_t frequency) {
 
   // create Z-parameter matrix
   matrix z (2);
-  nr_complex_t z21 = rect (0.0, -0.5e12 / (M_PI * frequency * C));
-  nr_complex_t z11 = rect (0.0, 2e-9 * M_PI * frequency * L) + z21;
+  nr_complex_t z21 = nr_complex_t (0.0, -0.5e12 / (M_PI * frequency * C));
+  nr_complex_t z11 = nr_complex_t (0.0, 2e-9 * M_PI * frequency * L) + z21;
   z.set (0, 0, z11);
   z.set (0, 1, z21);
   z.set (1, 0, z21);
