@@ -32,6 +32,8 @@
 #include "msline.h"
 #include "msstep.h"
 
+using namespace qucs;
+
 msstep::msstep () : circuit (2) {
   type = CIR_MSSTEP;
 }
@@ -55,13 +57,13 @@ matrix msstep::calcMatrixZ (nr_double_t frequency) {
   nr_double_t t     = subst->getPropertyDouble ("t");
 
   // compute parallel capacitance
-  nr_double_t t1 = log10 (er);
+  nr_double_t t1 = std::log10 (er);
   nr_double_t t2 = W1 / W2;
-  nr_double_t Cs = sqrt (W1 * W2) *
+  nr_double_t Cs = std::sqrt (W1 * W2) *
     (t2 * (10.1 * t1 + 2.33) - 12.6 * t1 - 3.17);
 
   // compute series inductance
-  t1 = log10 (t2);
+  t1 = std::log10 (t2);
   t2 = t2 - 1;
   nr_double_t Ls = h * (t2 * (40.5 + 0.2 * t2) - 75 * t1);
 
@@ -69,21 +71,21 @@ matrix msstep::calcMatrixZ (nr_double_t frequency) {
   msline::analyseQuasiStatic (W1, h, t, er, SModel, ZlEff, ErEff, WEff);
   msline::analyseDispersion  (W1, h, er, ZlEff, ErEff, frequency, DModel,
 			      ZlEffFreq, ErEffFreq);
-  nr_double_t L1 = ZlEffFreq * sqrt (ErEffFreq) / C0;
+  nr_double_t L1 = ZlEffFreq * std::sqrt (ErEffFreq) / C0;
 
   msline::analyseQuasiStatic (W2, h, t, er, SModel, ZlEff, ErEff, WEff);
   msline::analyseDispersion  (W2, h, er, ZlEff, ErEff, frequency, DModel,
 			      ZlEffFreq, ErEffFreq);
-  nr_double_t L2 = ZlEffFreq * sqrt (ErEffFreq) / C0;
+  nr_double_t L2 = ZlEffFreq * std::sqrt (ErEffFreq) / C0;
 
   Ls /= (L1 + L2);
   L1 *= Ls;
   L2 *= Ls;
 
   // build Z-parameter matrix
-  nr_complex_t z21 = rect (0.0, -0.5e12 / (M_PI * frequency * Cs));
-  nr_complex_t z11 = rect (0.0, 2e-9 * M_PI * frequency * L1) + z21;
-  nr_complex_t z22 = rect (0.0, 2e-9 * M_PI * frequency * L2) + z21;
+  nr_complex_t z21 = nr_complex_t (0.0, -0.5e12 / (M_PI * frequency * Cs));
+  nr_complex_t z11 = nr_complex_t (0.0, 2e-9 * M_PI * frequency * L1) + z21;
+  nr_complex_t z22 = nr_complex_t (0.0, 2e-9 * M_PI * frequency * L2) + z21;
   matrix z (2);
   z.set (0, 0, z11);
   z.set (0, 1, z21);
