@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -32,7 +32,8 @@
 #include "msline.h"
 #include "mstee.h"
 
-using namespace device;
+using namespace qucs;
+using namespace qucs::device;
 
 mstee::mstee () : circuit (3) {
   lineA = lineB = line2 = NULL;
@@ -88,20 +89,20 @@ void mstee::calcSP (nr_double_t frequency) {
   line2->calcSP (frequency);
 
   // calculate S-parameters
-  nr_complex_t n1 = Ta2 * rect (1 + 1 / Tb2, Bt * z0);
-  nr_complex_t n2 = Tb2 * rect (1 + 1 / Ta2, Bt * z0);
-  nr_complex_t n3 = rect (1 / Ta2 + 1 / Tb2, Bt * z0);
+  nr_complex_t n1 = Ta2 * nr_complex_t (1 + 1 / Tb2, Bt * z0);
+  nr_complex_t n2 = Tb2 * nr_complex_t (1 + 1 / Ta2, Bt * z0);
+  nr_complex_t n3 = nr_complex_t (1 / Ta2 + 1 / Tb2, Bt * z0);
   setS (NODE_1, NODE_1, (1.0 - n1) / (1.0 + n1));
   setS (NODE_2, NODE_2, (1.0 - n2) / (1.0 + n2));
   setS (NODE_3, NODE_3, (1.0 - n3) / (1.0 + n3));
-  setS (NODE_1, NODE_3, 2.0 * sqrt (Ta2) / (1.0 + n1));
-  setS (NODE_3, NODE_1, 2.0 * sqrt (Ta2) / (1.0 + n1));
-  setS (NODE_2, NODE_3, 2.0 * sqrt (Tb2) / (1.0 + n2));
-  setS (NODE_3, NODE_2, 2.0 * sqrt (Tb2) / (1.0 + n2));
-  setS (NODE_1, NODE_2, 2.0 / (sqrt (Ta2 * Tb2) * rect (1, Bt * z0) +
-			       sqrt (Ta2 / Tb2) + sqrt (Tb2 / Ta2)));
-  setS (NODE_2, NODE_1, 2.0 / (sqrt (Ta2 * Tb2) * rect (1, Bt * z0) +
-			       sqrt (Ta2 / Tb2) + sqrt (Tb2 / Ta2)));
+  setS (NODE_1, NODE_3, 2.0 * std::sqrt (Ta2) / (1.0 + n1));
+  setS (NODE_3, NODE_1, 2.0 * std::sqrt (Ta2) / (1.0 + n1));
+  setS (NODE_2, NODE_3, 2.0 * std::sqrt (Tb2) / (1.0 + n2));
+  setS (NODE_3, NODE_2, 2.0 * std::sqrt (Tb2) / (1.0 + n2));
+  setS (NODE_1, NODE_2, 2.0 / (std::sqrt (Ta2 * Tb2) * nr_complex_t (1, Bt * z0) +
+			       std::sqrt (Ta2 / Tb2) + std::sqrt (Tb2 / Ta2)));
+  setS (NODE_2, NODE_1, 2.0 / (std::sqrt (Ta2 * Tb2) * nr_complex_t (1, Bt * z0) +
+			       std::sqrt (Ta2 / Tb2) + std::sqrt (Tb2 / Ta2)));
 }
 
 void mstee::calcPropagation (nr_double_t f) {
@@ -115,7 +116,7 @@ void mstee::calcPropagation (nr_double_t f) {
   nr_double_t Wa = getPropertyDouble ("W1");
   nr_double_t Wb = getPropertyDouble ("W2");
   nr_double_t W2 = getPropertyDouble ("W3");
-  
+
   nr_double_t Zla, Zlb, Zl2, Era, Erb, Er2;
 
   // computation of impedances and effective dielectric constants
@@ -134,17 +135,17 @@ void mstee::calcPropagation (nr_double_t f) {
   nr_double_t Da, Db, D2, fpa, fpb, lda, ldb, da, db, d2, r, q;
 
   // equivalent parallel plate line widths
-  Da = Z0 / Zla * h / sqrt (Era);
-  Db = Z0 / Zlb * h / sqrt (Erb);
-  D2 = Z0 / Zl2 * h / sqrt (Er2);
+  Da = Z0 / Zla * h / std::sqrt (Era);
+  Db = Z0 / Zlb * h / std::sqrt (Erb);
+  D2 = Z0 / Zl2 * h / std::sqrt (Er2);
 
   // first higher order mode cut-off frequencies
   fpa = 0.4e6 * Zla / h;
   fpb = 0.4e6 * Zlb / h;
 
   // effective wavelengths of quasi-TEM mode
-  lda = C0 / sqrt (Era) / f;
-  ldb = C0 / sqrt (Erb) / f;
+  lda = C0 / std::sqrt (Era) / f;
+  ldb = C0 / std::sqrt (Erb) / f;
 
   // main arm displacements
   da = 0.055 * D2 * Zla / Zl2 * (1 - 2 * Zla / Zl2 * sqr (f / fpa));
@@ -155,10 +156,10 @@ void mstee::calcPropagation (nr_double_t f) {
   Lb = 0.5 * W2 - db;
 
   // displacement and length of line in the side arm
-  r = sqrt (Zla * Zlb) / Zl2;
+  r = std::sqrt (Zla * Zlb) / Zl2;
   q = sqr (f) / fpa / fpb;
-  d2 = sqrt (Da * Db) * (0.5 - r * (0.05 + 0.7 * exp (-1.6 * r) +
-				    0.25 * r * q - 0.17 * log (r)));
+  d2 = std::sqrt (Da * Db) * (0.5 - r * (0.05 + 0.7 * std::exp (-1.6 * r) +
+				    0.25 * r * q - 0.17 * std::log (r)));
   L2 = 0.5 * MAX (Wa, Wb) - d2;
 
   // turn ratio of transformers in main arms
@@ -170,9 +171,9 @@ void mstee::calcPropagation (nr_double_t f) {
   Tb2 = MAX (Tb2, NR_TINY);
 
   // shunt susceptance
-  Bt = 5.5 * sqrt (Da * Db / lda / ldb) * (er + 2) / er /
-    Zl2 / sqrt (Ta2 * Tb2) * sqrt (da * db) / D2 *
-    (1 + 0.9 * log (r) + 4.5 * r * q - 4.4 * exp (-1.3 * r) -
+  Bt = 5.5 * std::sqrt (Da * Db / lda / ldb) * (er + 2) / er /
+    Zl2 / std::sqrt (Ta2 * Tb2) * std::sqrt (da * db) / D2 *
+    (1 + 0.9 * std::log (r) + 4.5 * r * q - 4.4 * std::exp (-1.3 * r) -
      20 * sqr (Zl2 / Z0));
 }
 
@@ -263,15 +264,15 @@ void mstee::calcAC (nr_double_t frequency) {
   line2->calcAC (frequency);
 
   // calculate Z-parameters
-  setD (VSRC_1, VSRC_1, rect (0, -1 / Ta2 / Bt));
-  setD (VSRC_1, VSRC_2, rect (0, -1 / sqrt (Ta2 * Tb2) / Bt));
-  setD (VSRC_1, VSRC_3, rect (0, -1 / sqrt (Ta2) / Bt));
-  setD (VSRC_2, VSRC_1, rect (0, -1 / sqrt (Ta2 * Tb2) / Bt));
-  setD (VSRC_2, VSRC_2, rect (0, -1 / Tb2 / Bt));
-  setD (VSRC_2, VSRC_3, rect (0, -1 / sqrt (Tb2) / Bt));
-  setD (VSRC_3, VSRC_1, rect (0, -1 / sqrt (Ta2) / Bt));
-  setD (VSRC_3, VSRC_2, rect (0, -1 / sqrt (Tb2) / Bt));
-  setD (VSRC_3, VSRC_3, rect (0, -1 / Bt));
+  setD (VSRC_1, VSRC_1, nr_complex_t (0, -1 / Ta2 / Bt));
+  setD (VSRC_1, VSRC_2, nr_complex_t (0, -1 / std::sqrt (Ta2 * Tb2) / Bt));
+  setD (VSRC_1, VSRC_3, nr_complex_t (0, -1 / std::sqrt (Ta2) / Bt));
+  setD (VSRC_2, VSRC_1, nr_complex_t (0, -1 / std::sqrt (Ta2 * Tb2) / Bt));
+  setD (VSRC_2, VSRC_2, nr_complex_t (0, -1 / Tb2 / Bt));
+  setD (VSRC_2, VSRC_3, nr_complex_t (0, -1 / std::sqrt (Tb2) / Bt));
+  setD (VSRC_3, VSRC_1, nr_complex_t (0, -1 / std::sqrt (Ta2) / Bt));
+  setD (VSRC_3, VSRC_2, nr_complex_t (0, -1 / std::sqrt (Tb2) / Bt));
+  setD (VSRC_3, VSRC_3, nr_complex_t (0, -1 / Bt));
 }
 
 void mstee::initTR (void) {
