@@ -30,6 +30,8 @@
 #include "substrate.h"
 #include "msvia.h"
 
+using namespace qucs;
+
 msvia::msvia () : circuit (2) {
   R = 0;
   Z = 0;
@@ -75,10 +77,10 @@ nr_complex_t msvia::calcImpedance (nr_double_t frequency) {
 
   // create Z-parameter
   nr_double_t fs  = M_PI * MU0 * sqr (t) / rho;
-  nr_double_t res = R * sqrt (1 + frequency * fs);
-  nr_double_t a   = sqrt (sqr (r) + sqr (h));
-  nr_double_t ind = MU0 * (h * log ((h + a) / r) + 1.5 * (r - a));
-  return Z = rect (res, frequency * ind);
+  nr_double_t res = R * std::sqrt (1 + frequency * fs);
+  nr_double_t a   = std::sqrt (sqr (r) + sqr (h));
+  nr_double_t ind = MU0 * (h * std::log ((h + a) / r) + 1.5 * (r - a));
+  return Z = nr_complex_t (res, frequency * ind);
 }
 
 nr_double_t msvia::calcResistance (void) {
