@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,6 +29,8 @@
 #include "component.h"
 #include "mutualx.h"
 
+using namespace qucs;
+
 mutualx::mutualx () : circuit () {
   type = CIR_MUTUALX;
   setVariableSized (true);
@@ -63,8 +65,8 @@ matrix mutualx::calcMatrixY (nr_double_t frequency) {
 matrix mutualx::calcMatrixZ (nr_double_t frequency) {
   int inductors = getSize () / 2;
   int r, c, state;
-  vector * L = getPropertyVector ("L");
-  vector * C = getPropertyVector ("k");
+  qucs::vector * L = getPropertyVector ("L");
+  qucs::vector * C = getPropertyVector ("k");
   nr_double_t o = 2 * M_PI * frequency;
   matrix z = matrix (inductors);
 
@@ -73,8 +75,8 @@ matrix mutualx::calcMatrixZ (nr_double_t frequency) {
     for (c = 0; c < inductors; c++, state++) {
       nr_double_t l1 = real (L->get (r));
       nr_double_t l2 = real (L->get (c));
-      nr_double_t k = real (C->get (state)) * sqrt (l1 * l2);
-      z.set (r, c, rect (0.0, k * o));
+      nr_double_t k = real (C->get (state)) * std::sqrt (l1 * l2);
+      z.set (r, c, nr_complex_t (0.0, k * o));
     }
   }
   return z;
@@ -87,8 +89,8 @@ void mutualx::initAC (void) {
 void mutualx::calcAC (nr_double_t frequency) {
   int inductors = getSize () / 2;
   int r, c, state;
-  vector * L = getPropertyVector ("L");
-  vector * C = getPropertyVector ("k");
+  qucs::vector * L = getPropertyVector ("L");
+  qucs::vector * C = getPropertyVector ("k");
   nr_double_t o = 2 * M_PI * frequency;
 
   // fill D-Matrix
@@ -96,8 +98,8 @@ void mutualx::calcAC (nr_double_t frequency) {
     for (c = 0; c < inductors; c++, state++) {
       nr_double_t l1 = real (L->get (r));
       nr_double_t l2 = real (L->get (c));
-      nr_double_t k = real (C->get (state)) * sqrt (l1 * l2);
-      setD (VSRC_1 + r, VSRC_1 + c, rect (0.0, k * o));
+      nr_double_t k = real (C->get (state)) * std::sqrt (l1 * l2);
+      setD (VSRC_1 + r, VSRC_1 + c, nr_complex_t (0.0, k * o));
     }
   }
 }
@@ -120,8 +122,8 @@ void mutualx::initTR (void) {
 void mutualx::calcTR (nr_double_t) {
   int inductors = getSize () / 2;
   int r, c, state;
-  vector * L = getPropertyVector ("L");
-  vector * C = getPropertyVector ("k");
+  qucs::vector * L = getPropertyVector ("L");
+  qucs::vector * C = getPropertyVector ("k");
 
   nr_double_t * veq = new nr_double_t[inductors * inductors];
   nr_double_t * req = new nr_double_t[inductors * inductors];
@@ -132,7 +134,7 @@ void mutualx::calcTR (nr_double_t) {
       nr_double_t l1 = real (L->get (r));
       nr_double_t l2 = real (L->get (c));
       nr_double_t i = real (getJ (VSRC_1 + c));
-      nr_double_t k = real (C->get (state)) * sqrt (l1 * l2);
+      nr_double_t k = real (C->get (state)) * std::sqrt (l1 * l2);
       setState  (2 * state, i * k);
       integrate (2 * state, k, req[state], veq[state]);
     }
