@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -33,6 +33,8 @@
 #define NODE_INP 1
 #define NODE_OUT 2
 
+using namespace qucs;
+
 opamp::opamp () : circuit (3) {
   type = CIR_OPAMP;
   setVoltageSources (1);
@@ -63,7 +65,7 @@ void opamp::calcDC (void) {
   nr_double_t g    = getPropertyDouble ("G");
   nr_double_t uMax = getPropertyDouble ("Umax");
   nr_double_t Uin  = real (getV (NODE_INP) - getV (NODE_INM));
-  nr_double_t Uout = uMax * M_2_PI * atan (Uin * g * M_PI_2 / uMax);
+  nr_double_t Uout = uMax * M_2_PI * qucs::atan (Uin * g * M_PI_2 / uMax);
   gv = g / (1 + sqr (M_PI_2 / uMax * g * Uin)) + GMin;
   setC (VSRC_1, NODE_INP, +gv);
   setC (VSRC_1, NODE_INM, -gv);
