@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,6 +29,8 @@
 #include "component.h"
 #include "twistedpair.h"
 
+using namespace qucs;
+
 twistedpair::twistedpair () : circuit (4) {
   type = CIR_TWISTEDPAIR;
 }
@@ -41,15 +43,15 @@ void twistedpair::initSP (void) {
 void twistedpair::calcSP (nr_double_t frequency) {
   calcPropagation (frequency);
 
-  nr_complex_t g = rect (alpha, beta);
+  nr_complex_t g = nr_complex_t (alpha, beta);
   nr_double_t p = 2 * z0 + zl;
   nr_double_t n = 2 * z0 - zl;
-  nr_complex_t e = exp (2.0 * g * len);
+  nr_complex_t e = qucs::exp (2.0 * g * len);
   nr_complex_t d = p * p * e - n * n;
 
   nr_complex_t s11 = zl * (p * e + n) / d;
   nr_complex_t s14 = 1.0 - s11;
-  nr_complex_t s12 = 4.0 * zl * z0 * exp (g * len) / d;
+  nr_complex_t s12 = 4.0 * zl * z0 * qucs::exp (g * len) / d;
 
   setS (NODE_1, NODE_1, +s11); setS (NODE_2, NODE_2, +s11);
   setS (NODE_3, NODE_3, +s11); setS (NODE_4, NODE_4, +s11);
@@ -118,7 +120,7 @@ nr_double_t twistedpair::calcLoss (nr_double_t frequency) {
   // calculate conductor losses
   rout = d / 2;
   if (frequency > 0.0) {
-    delta = sqrt (rho / (M_PI * frequency * MU0 * mur));
+    delta = qucs::sqrt (rho / (M_PI * frequency * MU0 * mur));
     rin = rout - delta;
     if (rin < 0.0) rin = 0.0;
   }
@@ -127,7 +129,7 @@ nr_double_t twistedpair::calcLoss (nr_double_t frequency) {
 
   // calculate dielectric losses
   l0 = C0 / frequency;
-  ad = M_PI * tand * sqrt (ereff) / l0;
+  ad = M_PI * tand * qucs::sqrt (ereff) / l0;
 
   alpha = ac + ad;
   return alpha;
@@ -137,7 +139,7 @@ nr_double_t twistedpair::calcLength (void) {
   nr_double_t l  = getPropertyDouble ("L");
   nr_double_t T  = getPropertyDouble ("T");
   nr_double_t D  = getPropertyDouble ("D");
-  len = l * T * M_PI * D * sqrt (1 + 1 / sqr (T * M_PI * D));
+  len = l * T * M_PI * D * qucs::sqrt (1 + 1 / sqr (T * M_PI * D));
   return len;
 }
 
@@ -148,12 +150,12 @@ void twistedpair::calcPropagation (nr_double_t frequency) {
   nr_double_t T  = getPropertyDouble ("T");
 
   nr_double_t q, p;
-  p = atan (T * M_PI * D);
+  p = qucs::atan (T * M_PI * D);
   q = 0.25 + 0.001 * p * p;  // soft PTFE
   q = 0.25 + 0.0004 * p * p; // usual
   ereff = 1.0 + q * (er - 1.0);
-  zl = Z0 / M_PI / sqrt (ereff) * acosh (D / d);
-  beta = 2 * M_PI * frequency / C0 * sqrt (ereff);
+  zl = Z0 / M_PI / qucs::sqrt (ereff) * qucs::acosh (D / d);
+  beta = 2 * M_PI * frequency / C0 * qucs::sqrt (ereff);
   angle = deg (p);
   alpha = calcLoss (frequency);
 }
@@ -168,7 +170,7 @@ void twistedpair::saveCharacteristics (nr_double_t) {
 void twistedpair::calcAC (nr_double_t frequency) {
   if (len != 0.0) {
     calcPropagation (frequency);
-    nr_complex_t g = rect (alpha, beta);
+    nr_complex_t g = nr_complex_t (alpha, beta);
     nr_complex_t y11 = coth (g * len) / zl;
     nr_complex_t y21 = -cosech (g * len) / zl;
     setY (NODE_1, NODE_1, +y11); setY (NODE_2, NODE_2, +y11);
@@ -195,7 +197,7 @@ void twistedpair::initTR (void) {
 
 // properties
 PROP_REQ [] = {
-  { "d", PROP_REAL, { 0.5e-3, PROP_NO_STR }, PROP_POS_RANGEX }, 
+  { "d", PROP_REAL, { 0.5e-3, PROP_NO_STR }, PROP_POS_RANGEX },
   { "D", PROP_REAL, { 0.8e-3, PROP_NO_STR }, PROP_POS_RANGEX },
   { "L", PROP_REAL, { 1500e-3, PROP_NO_STR }, PROP_NO_RANGE },
   { "T", PROP_REAL, { 100, PROP_NO_STR }, PROP_POS_RANGE },
