@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,6 +29,8 @@
 #include "component.h"
 #include "vac.h"
 
+using namespace qucs;
+
 vac::vac () : circuit (2) {
   type = CIR_VAC;
   setVSource (true);
@@ -52,7 +54,7 @@ void vac::initAC (void) {
   initDC ();
   nr_double_t a = getPropertyDouble ("U");
   nr_double_t p = getPropertyDouble ("Phase");
-  setE (VSRC_1, polar (a, rad (p)));
+  setE (VSRC_1, qucs::polar (a, rad (p)));
 }
 
 void vac::initTR (void) {
@@ -67,7 +69,7 @@ void vac::calcTR (nr_double_t t) {
   nr_double_t s = getNet()->getSrcFactor ();
   nr_double_t o = 2 * M_PI * f;
   nr_double_t T = p / f / 360;
-  nr_double_t u = s * a * exp (-(t + T) * d * f) * sin (o * t + rad (p));
+  nr_double_t u = s * a * std::exp (-(t + T) * d * f) * std::sin (o * t + rad (p));
   setE (VSRC_1, u);
 }
 
@@ -82,7 +84,7 @@ void vac::calcHB (nr_double_t frequency) {
   if (f == frequency) {
     nr_double_t a = getPropertyDouble ("U");
     nr_double_t p = getPropertyDouble ("Phase");
-    setE (VSRC_1, polar (a, rad (p)));
+    setE (VSRC_1, qucs::polar (a, rad (p)));
   }
   else {
     setE (VSRC_1, 0);
