@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,6 +29,8 @@
 #include "component.h"
 #include "vam.h"
 
+using namespace qucs;
+
 vam::vam () : circuit (3) {
   type = CIR_VAM;
   setVSource (true);
@@ -51,7 +53,7 @@ void vam::initAC (void) {
   initDC ();
   nr_double_t a = getPropertyDouble ("U");
   nr_double_t p = getPropertyDouble ("Phase");
-  setE (VSRC_1, polar (a, rad (p)));
+  setE (VSRC_1, qucs::polar (a, rad (p)));
 }
 
 void vam::initTR (void) {
@@ -63,14 +65,14 @@ void vam::calcTR (nr_double_t t) {
   nr_double_t p = getPropertyDouble ("Phase");
   nr_double_t d = getPropertyDouble ("m");
   nr_double_t a = getPropertyDouble ("U");
-  nr_double_t u = a * sin (2 * M_PI * f * t + rad (p));
+  nr_double_t u = a * std::sin (2 * M_PI * f * t + rad (p));
   setE (VSRC_1, u);
   setC (VSRC_1, NODE_3, -u * d);
 }
 
 // properties
 PROP_REQ [] = {
-  { "U", PROP_REAL, { 1, PROP_NO_STR }, PROP_NO_RANGE }, 
+  { "U", PROP_REAL, { 1, PROP_NO_STR }, PROP_NO_RANGE },
   { "f", PROP_REAL, { 1e9, PROP_NO_STR }, PROP_POS_RANGE },
   { "m", PROP_REAL, { 1, PROP_NO_STR }, PROP_RNGII (0, 1) },
   PROP_NO_PROP };
