@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,6 +29,8 @@
 #include "component.h"
 #include "vccs.h"
 
+using namespace qucs;
+
 vccs::vccs () : circuit (4) {
   type = CIR_VCCS;
 }
@@ -37,8 +39,8 @@ void vccs::calcSP (nr_double_t frequency) {
   nr_double_t g = getPropertyDouble ("G") * z0;
   nr_double_t t = getPropertyDouble ("T");
 
-  nr_complex_t z1 = polar (2.0 * g, M_PI - 2.0 * M_PI * frequency * t);
-  nr_complex_t z2 = polar (2.0 * g, - 2.0 * M_PI * frequency * t);
+  nr_complex_t z1 = qucs::polar (2.0 * g, M_PI - 2.0 * M_PI * frequency * t);
+  nr_complex_t z2 = qucs::polar (2.0 * g, - 2.0 * M_PI * frequency * t);
 
   setS (NODE_1, NODE_1, 1.0); setS (NODE_1, NODE_2, 0.0);
   setS (NODE_1, NODE_3, 0.0); setS (NODE_1, NODE_4, 0.0);
@@ -64,7 +66,7 @@ void vccs::initAC (void) {
 
 void vccs::calcAC (nr_double_t frequency) {
   nr_double_t t = getPropertyDouble ("T");
-  nr_complex_t g = polar (getPropertyDouble ("G"),
+  nr_complex_t g = qucs::polar (getPropertyDouble ("G"),
 			  - 2.0 * M_PI * frequency * t);
   setY (NODE_2, NODE_1, +g); setY (NODE_3, NODE_4, +g);
   setY (NODE_3, NODE_1, -g); setY (NODE_2, NODE_4, -g);
