@@ -5,7 +5,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  */
 
 #if HAVE_CONFIG_H
@@ -163,26 +163,7 @@
 	cy (n1,n1) += pwr*pow(_freq,-exp)/kB/T0;
 
 // derivative helper macros
-#define m00_hypot(v00,x,y)      v00 = xhypot(x,y);
-#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
-#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
-#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
-#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
-#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
-#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
-#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
-#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
-#define m00_pow(v00,x,y)        v00 = pow(x,y);
-#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
-#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
-
-#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
-#define m10_div(v10,v00,vv,x,y)
-#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
-
-#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
-#define m00_add(v00,x,y)        double v00=(x)+(y);
-
+// transcendental LRM p. 59
 #define m00_cos(v00,x)          v00 = cos(x);
 #define m10_cos(v10,v00,x)      v10 = (-sin(x));
 #define m00_sin(v00,x)          v00 = sin(x);
@@ -201,33 +182,68 @@
 #define m10_asin(v10,v00,x)     v10 = (+1.0/sqrt(1-x*x));
 #define m00_atan(v00,x)         v00 = atan(x);
 #define m10_atan(v10,v00,x)     v10 = (+1.0/(1+x*x));
+#define m00_hypot(v00,x,y)      v00 = sqrt((x)*(x)+(y)*(y));
+#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
+#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
+#define m00_atan2(v00,x,y)      v00 = atan2(x,y);
+// TODO atan2 derivatives ?
+#define m00_acosh(v00,x)        v00 = acosh(x);
+#define m10_acosh(v10,v00,x)    v10 = (1.0/(sqrt(x-1)*sqrt(x+1)));
+#define m00_asinh(v00,x)        v00 = asinh(x);
+#define m10_asinh(v10,v00,x)    v10 = (1.0/(sqrt(x*x+1)));
 #define m00_atanh(v00,x)        v00 = atanh(x);
-#define m10_atanh(v10,v00,x)    v10 = (+1.0/(1-x*x));
+#define m10_atanh(v10,v00,x)    v10 = (1.0/(1-x*x));
+
+
+// standard functions LRM p.58
 #define m00_logE(v00,x)         v00 = log(x);
 #define m10_logE(v10,v00,x)     v10 = (1.0/x);
 #define m00_log10(v00,x)        v00 = log10(x);
 #define m10_log10(v10,v00,x)    v10 = (1.0/x/M_LN10);
-#define m00_sqrt(v00,x)         v00 = sqrt(x);
-#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
-#define m00_fabs(v00,x)         v00 = fabs(x);
-#define m10_fabs(v10,v00,x)     v10 = (((x)>=0)?(+1.0):(-1.0));
-
 #define m00_exp(v00,x)          v00 = exp(x);
 #define m10_exp(v10,v00,x)      v10 = v00;
-
-#define m00_abs(v00)            ((v00)<(0)?(-(v00)):(v00))
+#define m00_sqrt(v00,x)         v00 = sqrt(x);
+#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
+#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
+#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
+#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
+#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
+#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
+#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
+#define m00_pow(v00,x,y)        v00 = pow(x,y);
+#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
+#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
+#define m00_abs(v00,x)          v00 = ((x)<(0)?(-(x)):(x));
+#define m10_abs(v10,v00,x)      v10 = (((x)>=0)?(+1.0):(-1.0));
 #define m00_floor(v00,x)        v00 = floor(x);
+#define m10_floor(v10,v00,x)    v10 = 1.0;
+
+#define m00_ceil(v00,x)         v00 = ceil(x);
+// TODO ceil derivative, needed?
+
+// analog operator, LRM p.61
 #define m00_limexp(v00,x)       v00 = ((x)<80.0?exp(x):exp(80.0)*(x-79.0));
 #define m10_limexp(v10,v00,x)   v10 = ((x)<80.0?(v00):exp(80.0));
 
+// analog kernel parameter system functions, LRM p.215
+#define m00_vt(x)               (kBoverQ*(x))
+#define m10_vt(x)               (kBoverQ)
+
+// extra functions (?)
+#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
+#define m10_div(v10,v00,vv,x,y)
+#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
+#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
+#define m00_add(v00,x,y)        double v00=(x)+(y);
+
+// second derivatives
 #define m20_logE(v00)           (-1.0/v00/v00)
 #define m20_exp(v00)            exp(v00)
 #define m20_limexp(v00)         ((v00)<80.0?exp(v00):0.0)
 #define m20_sqrt(v00)           (-0.25/(v00)/sqrt(v00))
-#define m20_fabs(v00)           0.0
+#define m20_abs(v00)           0.0
 #define m20_pow(x,y)            ((y)*((y)-1.0)*pow(x,y)/(x)/(x))
-#define m00_vt(x)               (kBoverQ*(x))
-#define m10_vt(x)               (kBoverQ)
+
 
 // simulator specific definitions
 #define _modelname              "EKV26MOS"
@@ -236,10 +252,11 @@
 #define _param_given(p)		(isPropertyGiven(p)?1:0)
 
 
-// $vt and $vt() functions 
+// $vt and $vt() functions
 #define _vt_nom                 (kBoverQ*_circuit_temp)
 
-using namespace device;
+using namespace qucs::device;
+using qucs::matrix;
 
 /* Device constructor. */
 EKV26MOS::EKV26MOS() : circuit (6)
@@ -461,14 +478,14 @@ double B;
 double A;
 {
 if
-(_param_given("nmos"))
+_param_given("nmos")
 {
 p_n_MOS=(+1);
 }
 else
 {
 if
-(_param_given("pmos"))
+_param_given("pmos")
 {
 p_n_MOS=(-1);
 }
@@ -592,7 +609,7 @@ con32=((5.0*N)*_vt_nom);
 con33=(Fc*Vj);
 #endif
 if
-((LEVEL==2))
+(LEVEL==2)
 {
 {
 double m00_pow(d00_pow0,Tratio,Ucex)
@@ -608,17 +625,17 @@ Kpa_T=(Kpa*d00_pow0);
 }
 Gammaa=(Gamma+(Agamma/con1));
 {
-double m00_pow(d00_pow0,22e-3,2)
+double m00_pow(d00_pow0,22e-3,2.0)
 C_epsilon=(4.0*d00_pow0);
 }
 xi=(0.028*((10.0*(Leff/Lk))-1.0));
 {
-double m00_pow(d00_pow0,xi,2)
+double m00_pow(d00_pow0,xi,2.0)
 double m00_sqrt(d00_sqrt1,(d00_pow0+C_epsilon))
 nnn=(1.0+(0.5*(xi+d00_sqrt1)));
 }
 {
-double m00_pow(d00_pow0,nnn,2)
+double m00_pow(d00_pow0,nnn,2.0)
 deltaV_RSCE=(((2.0*Q0)/Cox)*(1.0/d00_pow0));
 }
 con3=(((-Vto_T)-deltaV_RSCE)+Phi_T);
@@ -1032,7 +1049,7 @@ VG_VGate_Bulk=Vg_VGate_Bulk;
 #endif
 VG=Vg;
 if
-(((Vd-Vs)>=0.0))
+((Vd-Vs)>=0.0)
 {
 StoDswap=1.0;
 #if defined(_DERIVATE)
@@ -1061,7 +1078,7 @@ VS_VSource_int_Bulk=0.0;
 VS=Vd;
 }
 if
-((LEVEL==2))
+(LEVEL==2)
 {
 {
 double m00_sqrt(d00_sqrt0,Phi_T)
@@ -1082,10 +1099,10 @@ VGprime=((VG+con4)+(Gamma*d00_sqrt0));
 }
 }
 if
-((LEVEL==2))
+(LEVEL==2)
 {
 if
-((VGprime>0))
+(VGprime>0)
 {
 {
 double m00_sqrt(d00_sqrt0,(VGprime+con6))
@@ -1156,7 +1173,7 @@ Gammaprime_VGate_Bulk=(0.5*(Gamma0_VGate_Bulk+((Gamma0_VGate_Bulk*Gamma0)+(Gamma
 Gammaprime=(0.5*(Gamma0+d00_sqrt0));
 }
 if
-((VGprime>0.0))
+(VGprime>0.0)
 {
 {
 double m00_sqrt(d00_sqrt0,(VGprime+((0.25*Gammaprime)*Gammaprime)))
@@ -1196,7 +1213,7 @@ n=(1.0+(Gammaa/(2.0*d00_sqrt0)));
 else
 {
 if
-((VGprime>0))
+(VGprime>0)
 {
 {
 double m00_sqrt(d00_sqrt0,(VGprime+con8))
@@ -1286,7 +1303,7 @@ ir_VSource_int_Bulk=((T_1_VSource_int_Bulk*T_1)+(T_1*T_1_VSource_int_Bulk));
 #endif
 ir=(T_1*T_1);
 if
-((LEVEL==2))
+(LEVEL==2)
 {
 {
 double m00_sqrt(d00_sqrt0,iff)
@@ -1321,7 +1338,7 @@ Vdssprime=((Vc*(d00_sqrt2-0.5))+con15);
 {
 double m00_sqrt(d00_sqrt0,iff)
 if
-((Lambda*(d00_sqrt0>(Vdss/_vt_nom))))
+(Lambda*(d00_sqrt0>(Vdss/_vt_nom)))
 {
 {
 double m00_sqrt(d00_sqrt0,iff)
@@ -1502,10 +1519,10 @@ qI_VSource_int_Bulk=(((-nq_VSource_int_Bulk)*(((con30*(((Xf*Xf)+(Xf*Xr))+(Xr*Xr)
 #endif
 qI=((-nq)*(((con30*(((Xf*Xf)+(Xf*Xr))+(Xr*Xr)))/(Xf+Xr))-1.0));
 if
-((LEVEL==2))
+(LEVEL==2)
 {
 if
-((VGprime>0))
+(VGprime>0)
 {
 {
 double m00_sqrt(d00_sqrt0,((Vp+Phi_T)+1e-6))
@@ -1533,7 +1550,7 @@ qB=((-VGprime)/_vt_nom);
 else
 {
 if
-((VGprime>0))
+(VGprime>0)
 {
 {
 double m00_sqrt(d00_sqrt0,((Vp+Phi_T)+1e-6))
@@ -1559,19 +1576,19 @@ qB=((-VGprime)/_vt_nom);
 }
 }
 if
-((LEVEL==2))
+(LEVEL==2)
 {
 {
-double m00_fabs(d00_fabs0,(qB+(eta*qI)))
+double m00_abs(d00_abs0,(qB+(eta*qI)))
 #if defined(_DERIVATE)
-double m10_fabs(d10_fabs0,d00_fabs0,(qB+(eta*qI)))
+double m10_abs(d10_abs0,d00_abs0,(qB+(eta*qI)))
 #endif
 #if defined(_DERIVATE)
-Beta_VSource_int_Bulk=((Beta0prime_VSource_int_Bulk*(1.0+(con21*d00_fabs0))-Beta0prime*(con21*(qB_VSource_int_Bulk+(eta*qI_VSource_int_Bulk))*d10_fabs0))/(1.0+(con21*d00_fabs0))/(1.0+(con21*d00_fabs0)));
-Beta_VDrain_int_Bulk=((Beta0prime_VDrain_int_Bulk*(1.0+(con21*d00_fabs0))-Beta0prime*(con21*(qB_VDrain_int_Bulk+(eta*qI_VDrain_int_Bulk))*d10_fabs0))/(1.0+(con21*d00_fabs0))/(1.0+(con21*d00_fabs0)));
-Beta_VGate_Bulk=((Beta0prime_VGate_Bulk*(1.0+(con21*d00_fabs0))-Beta0prime*(con21*(qB_VGate_Bulk+(eta*qI_VGate_Bulk))*d10_fabs0))/(1.0+(con21*d00_fabs0))/(1.0+(con21*d00_fabs0)));
+Beta_VSource_int_Bulk=((Beta0prime_VSource_int_Bulk*(1.0+(con21*d00_abs0))-Beta0prime*(con21*(qB_VSource_int_Bulk+(eta*qI_VSource_int_Bulk))*d10_abs0))/(1.0+(con21*d00_abs0))/(1.0+(con21*d00_abs0)));
+Beta_VDrain_int_Bulk=((Beta0prime_VDrain_int_Bulk*(1.0+(con21*d00_abs0))-Beta0prime*(con21*(qB_VDrain_int_Bulk+(eta*qI_VDrain_int_Bulk))*d10_abs0))/(1.0+(con21*d00_abs0))/(1.0+(con21*d00_abs0)));
+Beta_VGate_Bulk=((Beta0prime_VGate_Bulk*(1.0+(con21*d00_abs0))-Beta0prime*(con21*(qB_VGate_Bulk+(eta*qI_VGate_Bulk))*d10_abs0))/(1.0+(con21*d00_abs0))/(1.0+(con21*d00_abs0)));
 #endif
-Beta=(Beta0prime/(1.0+(con21*d00_fabs0)));
+Beta=(Beta0prime/(1.0+(con21*d00_abs0)));
 }
 }
 else
@@ -1590,7 +1607,7 @@ Ispecific_VSource_int_Bulk=(((2.0*n_VSource_int_Bulk)*Beta)+((2.0*n)*Beta_VSourc
 #endif
 Ispecific=((((2.0*n)*Beta)*_vt_nom)*_vt_nom);
 if
-((LEVEL==2))
+(LEVEL==2)
 {
 #if defined(_DERIVATE)
 Ids_VGate_Bulk=((Ispecific_VGate_Bulk*(iff-irprime))+(Ispecific*(iff_VGate_Bulk-irprime_VGate_Bulk)));
@@ -1605,7 +1622,7 @@ Vib_VGate_Bulk=(-((Ibn*2.0)*Vdss_VGate_Bulk));
 #endif
 Vib=((VD-VS)-((Ibn*2.0)*Vdss));
 if
-((Vib>0.0))
+(Vib>0.0)
 {
 {
 double m00_exp(d00_exp0,(((-Ibb_T)*Lc)/Vib))
@@ -1640,16 +1657,16 @@ Ids_VSource_int_Bulk=((Ispecific_VSource_int_Bulk*(iff-ir))+(Ispecific*(iff_VSou
 Ids=(Ispecific*(iff-ir));
 }
 {
-double m00_fabs(d00_fabs0,qI)
+double m00_abs(d00_abs0,qI)
 #if defined(_DERIVATE)
-double m10_fabs(d10_fabs0,d00_fabs0,qI)
+double m10_abs(d10_abs0,d00_abs0,qI)
 #endif
 #if defined(_DERIVATE)
-Sthermal_VSource_int_Bulk=(((fourkt*Beta_VSource_int_Bulk)*d00_fabs0)+((fourkt*Beta)*qI_VSource_int_Bulk*d10_fabs0));
-Sthermal_VDrain_int_Bulk=(((fourkt*Beta_VDrain_int_Bulk)*d00_fabs0)+((fourkt*Beta)*qI_VDrain_int_Bulk*d10_fabs0));
-Sthermal_VGate_Bulk=(((fourkt*Beta_VGate_Bulk)*d00_fabs0)+((fourkt*Beta)*qI_VGate_Bulk*d10_fabs0));
+Sthermal_VSource_int_Bulk=(((fourkt*Beta_VSource_int_Bulk)*d00_abs0)+((fourkt*Beta)*qI_VSource_int_Bulk*d10_abs0));
+Sthermal_VDrain_int_Bulk=(((fourkt*Beta_VDrain_int_Bulk)*d00_abs0)+((fourkt*Beta)*qI_VDrain_int_Bulk*d10_abs0));
+Sthermal_VGate_Bulk=(((fourkt*Beta_VGate_Bulk)*d00_abs0)+((fourkt*Beta)*qI_VGate_Bulk*d10_abs0));
 #endif
-Sthermal=((fourkt*Beta)*d00_fabs0);
+Sthermal=((fourkt*Beta)*d00_abs0);
 }
 #if defined(_DERIVATE)
 T_1_VGate_Bulk=(-4.0*Ispecific_VGate_Bulk/Ispecific/Ispecific);
@@ -1716,7 +1733,7 @@ qgbo_VGate_Bulk=(con29*VG_VGate_Bulk);
 qgbo=(con29*VG);
 #endif
 if
-((StoDswap>0.0))
+(StoDswap>0.0)
 {
 #if defined(_DERIVATE)
 V1_VBulk_Source_int=0.0;
@@ -1815,7 +1832,7 @@ Qs2_VBulk_Source_int=((V2>=con33)?((Tt*Is1_VBulk_Source_int)+(Area3*(DP4*((F3*V2
 Qs2=((V2>=con33)?((Tt*Is1)+(Area3*(DP4*((F3*(V2-DP3))+(DP2*((V2*V2)-DP1)))))):0);
 #endif
 if
-((StoDswap>0.0))
+(StoDswap>0.0)
 {
 _load_static_residual2(Drain,Drain_int,(BP(Drain,Drain_int)/RDeff));
 #if defined(_DERIVATE)
@@ -1832,7 +1849,7 @@ _load_static_jacobian4(Drain_int,Source_int,Drain_int,Bulk,(p_n_MOS*Ids_VDrain_i
 _load_static_jacobian4(Drain_int,Source_int,Gate,Bulk,(p_n_MOS*Ids_VGate_Bulk));
 #endif
 if
-((LEVEL==2))
+(LEVEL==2)
 {
 _load_static_residual2(Drain_int,Bulk,(p_n_MOS*Idb));
 #if defined(_DERIVATE)
@@ -1941,7 +1958,7 @@ _load_static_jacobian4(Source_int,Drain_int,Drain_int,Bulk,(p_n_MOS*Ids_VDrain_i
 _load_static_jacobian4(Source_int,Drain_int,Gate,Bulk,(p_n_MOS*Ids_VGate_Bulk));
 #endif
 if
-((LEVEL==2))
+(LEVEL==2)
 {
 _load_static_residual2(Source_int,Bulk,(p_n_MOS*Idb));
 #if defined(_DERIVATE)
@@ -2045,8 +2062,8 @@ _save_whitenoise2(Drain_int,Drain,con26,"thermal");
 void EKV26MOS::calcDC (void)
 {
   // evaluate Verilog code
-  initVerilog ();		
-  calcVerilog ();		
+  initVerilog ();
+  calcVerilog ();
 
   // fill right hand side and static jacobian
   for (int i1 = 0; i1 < 6; i1++) {
@@ -2094,7 +2111,7 @@ matrix EKV26MOS::calcMatrixY (nr_double_t frequency)
 
   for (int i1 = 0; i1 < 6; i1++) {
     for (int i2 = 0; i2 < 6; i2++) {
-      y (i1,i2) = rect (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
+      y (i1,i2) = nr_complex_t (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
     }
   }
 
@@ -2110,7 +2127,7 @@ void EKV26MOS::initSP (void)
 /* Perform S-parameter calculations. */
 void EKV26MOS::calcSP (nr_double_t frequency)
 {
-  setMatrixS (ytos (calcMatrixY (frequency)));   
+  setMatrixS (ytos (calcMatrixY (frequency)));
 }
 
 /* Initialization of transient analysis. */
@@ -2174,7 +2191,7 @@ void EKV26MOS::calcTR (nr_double_t)
     if (_caps[i1][i1][i3][i4] != 0.0)
       transientCapacitanceC2V (i1, i3, i4, _caps[i1][i1][i3][i4], BP(i3,i4));
   } } }
-     
+
   // charge: 1-node, voltage: 1-node
   for (i1 = 0; i1 < 6; i1++) {
   for (i3 = 0; i3 < 6; i3++) {
@@ -2243,3 +2260,4 @@ void EKV26MOS::calcHB (int)
 }
 
 #include "EKV26MOS.defs.h"
+
