@@ -5,12 +5,17 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  */
 
+#if HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
 #include "HBT_X.analogfunction.h"
-#include <math.h>
+#include <cmath>
+
 
 /* math functions and appropriate derivatives */
 inline double _cos(double arg)             { return  cos(arg); }
@@ -31,8 +36,13 @@ inline double _asin(double arg)            { return  asin(arg); }
 inline double _d0_asin(double arg)         { return (+1.0/sqrt(1-arg*arg)); }
 inline double _atan(double arg)            { return  atan(arg); }
 inline double _d0_atan(double arg)         { return (+1.0/(1+arg*arg)); }
+inline double _acosh(double arg)           { return  acosh(arg); }
+inline double _d0_acosh(double arg)        { return (1.0/(sqrt(arg-1)*sqrt(arg+1))); }
+inline double _asinh(double arg)           { return  asinh(arg); }
+inline double _d0_asinh(double arg)        { return (1.0/(sqrt(arg*arg+1))); }
 inline double _atanh(double arg)           { return  atanh(arg); }
 inline double _d0_atanh(double arg)        { return (+1.0/(1-arg*arg)); }
+
 inline double _logE(double arg)            { return  log(arg); }
 inline double _d0_logE(double arg)         { return (1.0/arg); }
 inline double _log10(double arg)           { return  log10(arg); }
@@ -41,15 +51,22 @@ inline double _exp(double arg)             { return  exp(arg); }
 inline double _d0_exp(double arg)          { return exp(arg); }
 inline double _sqrt(double arg)            { return  sqrt(arg); }
 inline double _d0_sqrt(double arg)         { return (1.0/sqrt(arg)/2.0); }
-inline double _abs(double arg)             { return  fabs(arg); }
+
+inline double _abs(double arg)             { return std::abs(arg); }
 inline double _d0_abs(double arg)          { return (((arg)>=0)?(+1.0):(-1.0)); }
+
 inline int _floor(double arg)              { return  floor(arg); }
 inline int _d0_floor(double)               { return (1.0); }
 
+inline int _ceil(double arg)               { return  ceil(arg); }
+
 inline double _hypot(double x,double y)    { return sqrt((x)*(x)+(y)*(y)); }
 inline double _d0_hypot(double x,double y) { return (x)/sqrt((x)*(x)+(y)*(y)); }
 inline double _d1_hypot(double x,double y) { return (y)/sqrt((x)*(x)+(y)*(y)); }
 
+inline double _atan2(double x,double y)    { return atan2(x,y); }
+// TODO atan2 derivatives?
+
 inline double _max(double x,double y)      { return ((x)>(y))?(x):(y); }
 inline double _d0_max(double x,double y)   { return ((x)>(y))?1.0:0.0; }
 inline double _d1_max(double x,double y)   { return ((x)>(y))?0.0:1.0; }
@@ -79,8 +96,8 @@ double maxexp=0.0;
 double maxarg=0.0;
 {maxexp=1.0e25;
 maxarg=_logE(maxexp);
-if((x<maxarg))
-{exp_soft=_exp(x);
+if (x<maxarg)
+ {exp_soft=_exp(x);
 }else
 {exp_soft=(((x+1.0)-maxarg)*maxexp);
 }}
@@ -100,8 +117,8 @@ maxexp=1.0e25;
 {maxarg_x=_d0_logE(maxexp)*(maxexp_x);
 maxarg=_logE(maxexp);
 }
-if((x<maxarg))
-{{exp_soft_x=_d0_exp(x)*(1.0);
+if (x<maxarg)
+ {{exp_soft_x=_d0_exp(x)*(1.0);
 exp_soft=_exp(x);
 }
 }else
@@ -122,8 +139,8 @@ double Vch=0.0;
 double VF=0.0;
 {Vch=(0.1*Ud);
 VF=(0.9*Ud);
-if((U<VF))
-Vt=(U-(Vch*_logE((1.0+_exp(((U-VF)/Vch))))));
+if (U<VF)
+ Vt=(U-(Vch*_logE((1.0+_exp(((U-VF)/Vch))))));
 else
 Vt=(VF-(Vch*_logE((1.0+_exp(((VF-U)/Vch))))));
 }
@@ -148,8 +165,8 @@ Vch=(0.1*Ud);
 VF_Ud=(0.9);
 VF=(0.9*Ud);
 }
-if((U<VF))
-{Vt_U=(1.0-((Vch_U*_logE((1.0+_exp(((U-VF)/Vch)))))+(Vch*_d0_logE((1.0+_exp(((U-VF)/Vch))))*((+_d0_exp(((U-VF)/Vch))*(((1.0-VF_U)*Vch-(U-VF)*Vch_U)/(Vch*Vch)))))));
+if (U<VF)
+ {Vt_U=(1.0-((Vch_U*_logE((1.0+_exp(((U-VF)/Vch)))))+(Vch*_d0_logE((1.0+_exp(((U-VF)/Vch))))*((+_d0_exp(((U-VF)/Vch))*(((1.0-VF_U)*Vch-(U-VF)*Vch_U)/(Vch*Vch)))))));
 Vt_Ud=(-((Vch_Ud*_logE((1.0+_exp(((U-VF)/Vch)))))+(Vch*_d0_logE((1.0+_exp(((U-VF)/Vch))))*((+_d0_exp(((U-VF)/Vch))*(((-VF_Ud)*Vch-(U-VF)*Vch_Ud)/(Vch*Vch)))))));
 Vt=(U-(Vch*_logE((1.0+_exp(((U-VF)/Vch))))));
 }
@@ -181,14 +198,14 @@ VTHNOM=_vt((TNOM+273.15));
 KDURCHQ=0.861708692e-4;
 lnIs=_logE((Is*AREA));
 maxi=_logE(1e6);
-if(((maxi<(Ug/VTHNOM))&&(U<0.0)))
-{Tmax=(((Ug*VTHNOM)/((Ug-(maxi*VTHNOM))*KDURCHQ))-273.15);
+if ((maxi<(Ug/VTHNOM))&&(U<0.0))
+ {Tmax=(((Ug*VTHNOM)/((Ug-(maxi*VTHNOM))*KDURCHQ))-273.15);
 TJM=HBT_X_Vt(TJ,Tmax);
 }else
 {TJM=TJ;
 }VTHJ=_vt((TJM+273.15));
-if((Ug>0.0))
-{diode=(HBT_X_exp_soft(((((U/(N*VTHJ))+(Ug/VTHNOM))-(Ug/VTHJ))+lnIs))-HBT_X_exp_soft((((Ug/VTHNOM)-(Ug/VTHJ))+lnIs)));
+if (Ug>0.0)
+ {diode=(HBT_X_exp_soft(((((U/(N*VTHJ))+(Ug/VTHNOM))-(Ug/VTHJ))+lnIs))-HBT_X_exp_soft((((Ug/VTHNOM)-(Ug/VTHJ))+lnIs)));
 }else
 {diode=(HBT_X_exp_soft(((U/(N*VTH0))+lnIs))-(Is*AREA));
 }}
@@ -313,8 +330,8 @@ maxi_TJ=_d0_logE(1e6)*(0.0);
 maxi_TNOM=_d0_logE(1e6)*(0.0);
 maxi=_logE(1e6);
 }
-if(((maxi<(Ug/VTHNOM))&&(U<0.0)))
-{{Tmax_U=((Ug*VTHNOM_U)*((Ug-(maxi*VTHNOM))*KDURCHQ)-(Ug*VTHNOM)*(((-((maxi_U*VTHNOM)+(maxi*VTHNOM_U)))*KDURCHQ)+((Ug-(maxi*VTHNOM))*KDURCHQ_U)))/(((Ug-(maxi*VTHNOM))*KDURCHQ)*((Ug-(maxi*VTHNOM))*KDURCHQ));
+if ((maxi<(Ug/VTHNOM))&&(U<0.0))
+ {{Tmax_U=((Ug*VTHNOM_U)*((Ug-(maxi*VTHNOM))*KDURCHQ)-(Ug*VTHNOM)*(((-((maxi_U*VTHNOM)+(maxi*VTHNOM_U)))*KDURCHQ)+((Ug-(maxi*VTHNOM))*KDURCHQ_U)))/(((Ug-(maxi*VTHNOM))*KDURCHQ)*((Ug-(maxi*VTHNOM))*KDURCHQ));
 Tmax_Is=((Ug*VTHNOM_Is)*((Ug-(maxi*VTHNOM))*KDURCHQ)-(Ug*VTHNOM)*(((-((maxi_Is*VTHNOM)+(maxi*VTHNOM_Is)))*KDURCHQ)+((Ug-(maxi*VTHNOM))*KDURCHQ_Is)))/(((Ug-(maxi*VTHNOM))*KDURCHQ)*((Ug-(maxi*VTHNOM))*KDURCHQ));
 Tmax_Ug=((VTHNOM+(VTHNOM_Ug*Ug))*((Ug-(maxi*VTHNOM))*KDURCHQ)-(Ug*VTHNOM)*(((1.0-((maxi_Ug*VTHNOM)+(maxi*VTHNOM_Ug)))*KDURCHQ)+((Ug-(maxi*VTHNOM))*KDURCHQ_Ug)))/(((Ug-(maxi*VTHNOM))*KDURCHQ)*((Ug-(maxi*VTHNOM))*KDURCHQ));
 Tmax_N=((Ug*VTHNOM_N)*((Ug-(maxi*VTHNOM))*KDURCHQ)-(Ug*VTHNOM)*(((-((maxi_N*VTHNOM)+(maxi*VTHNOM_N)))*KDURCHQ)+((Ug-(maxi*VTHNOM))*KDURCHQ_N)))/(((Ug-(maxi*VTHNOM))*KDURCHQ)*((Ug-(maxi*VTHNOM))*KDURCHQ));
@@ -351,8 +368,8 @@ VTHJ_TJ=_d0_vt((TJM+273.15))*(TJM_TJ);
 VTHJ_TNOM=_d0_vt((TJM+273.15))*(TJM_TNOM);
 VTHJ=_vt((TJM+273.15));
 }
-if((Ug>0.0))
-{{diode_U=(HBT_X_d_exp_soft(((((U/(N*VTHJ))+(Ug/VTHNOM))-(Ug/VTHJ))+lnIs),(((((((N*VTHJ)-(U*(N*VTHJ_U)))/((N*VTHJ)*(N*VTHJ)))+(-(Ug*VTHNOM_U)/(VTHNOM*VTHNOM)))-(-(Ug*VTHJ_U)/(VTHJ*VTHJ)))+lnIs_U)))-HBT_X_d_exp_soft((((Ug/VTHNOM)-(Ug/VTHJ))+lnIs),((((-(Ug*VTHNOM_U)/(VTHNOM*VTHNOM))-(-(Ug*VTHJ_U)/(VTHJ*VTHJ)))+lnIs_U))));
+if (Ug>0.0)
+ {{diode_U=(HBT_X_d_exp_soft(((((U/(N*VTHJ))+(Ug/VTHNOM))-(Ug/VTHJ))+lnIs),(((((((N*VTHJ)-(U*(N*VTHJ_U)))/((N*VTHJ)*(N*VTHJ)))+(-(Ug*VTHNOM_U)/(VTHNOM*VTHNOM)))-(-(Ug*VTHJ_U)/(VTHJ*VTHJ)))+lnIs_U)))-HBT_X_d_exp_soft((((Ug/VTHNOM)-(Ug/VTHJ))+lnIs),((((-(Ug*VTHNOM_U)/(VTHNOM*VTHNOM))-(-(Ug*VTHJ_U)/(VTHJ*VTHJ)))+lnIs_U))));
 diode_Is=(HBT_X_d_exp_soft(((((U/(N*VTHJ))+(Ug/VTHNOM))-(Ug/VTHJ))+lnIs),(((((-(U*(N*VTHJ_Is))/((N*VTHJ)*(N*VTHJ)))+(-(Ug*VTHNOM_Is)/(VTHNOM*VTHNOM)))-(-(Ug*VTHJ_Is)/(VTHJ*VTHJ)))+lnIs_Is)))-HBT_X_d_exp_soft((((Ug/VTHNOM)-(Ug/VTHJ))+lnIs),((((-(Ug*VTHNOM_Is)/(VTHNOM*VTHNOM))-(-(Ug*VTHJ_Is)/(VTHJ*VTHJ)))+lnIs_Is))));
 diode_Ug=(HBT_X_d_exp_soft(((((U/(N*VTHJ))+(Ug/VTHNOM))-(Ug/VTHJ))+lnIs),(((((-(U*(N*VTHJ_Ug))/((N*VTHJ)*(N*VTHJ)))+((VTHNOM-(Ug*VTHNOM_Ug))/(VTHNOM*VTHNOM)))-((VTHJ-(Ug*VTHJ_Ug))/(VTHJ*VTHJ)))+lnIs_Ug)))-HBT_X_d_exp_soft((((Ug/VTHNOM)-(Ug/VTHJ))+lnIs),(((((VTHNOM-(Ug*VTHNOM_Ug))/(VTHNOM*VTHNOM))-((VTHJ-(Ug*VTHJ_Ug))/(VTHJ*VTHJ)))+lnIs_Ug))));
 diode_N=(HBT_X_d_exp_soft(((((U/(N*VTHJ))+(Ug/VTHNOM))-(Ug/VTHJ))+lnIs),(((((-(U*(VTHJ+(VTHJ_N*N)))/((N*VTHJ)*(N*VTHJ)))+(-(Ug*VTHNOM_N)/(VTHNOM*VTHNOM)))-(-(Ug*VTHJ_N)/(VTHJ*VTHJ)))+lnIs_N)))-HBT_X_d_exp_soft((((Ug/VTHNOM)-(Ug/VTHJ))+lnIs),((((-(Ug*VTHNOM_N)/(VTHNOM*VTHNOM))-(-(Ug*VTHJ_N)/(VTHJ*VTHJ)))+lnIs_N))));
@@ -383,21 +400,21 @@ double HBT_X_MM (double VBCI, double VCBO, double MC, double VCBLIN, double BF,
 double MM=0.0;
 double FBD=0.0;
 double vcbi=0.0;
-{if((((KC>0.0)&&(MC>0.0))&&(VCBO>0.0)))
-{vcbi=VBCI;
+{if (((KC>0.0)&&(MC>0.0))&&(VCBO>0.0))
+ {vcbi=VBCI;
 FBD=(VCBLIN/VCBO);
-if((VBCI>0.0))
-MM=1.0;
+if (VBCI>0.0)
+ MM=1.0;
 else
-if((VBCI>(-VCBLIN)))
-{if((MC==1))
-MM=(1.0/(1.0-(vcbi/(-VCBO))));
+if (VBCI>(-VCBLIN))
+ {if (MC==1)
+ MM=(1.0/(1.0-(vcbi/(-VCBO))));
 else
 MM=(1.0/(1.0-_pow((vcbi/(-VCBO)),MC)));
 }else
-if((VBCI<=(-VCBLIN)))
-{if((MC==1))
-{MM=((1.0/(1.0-FBD))-((((1.0/VCBO)*1.0)/_pow((1.0-FBD),2.0))*(vcbi+(FBD*VCBO))));
+if (VBCI<=(-VCBLIN))
+ {if (MC==1)
+ {MM=((1.0/(1.0-FBD))-((((1.0/VCBO)*1.0)/_pow((1.0-FBD),2.0))*(vcbi+(FBD*VCBO))));
 }else
 {MM=((1.0/(1.0-_pow(FBD,MC)))-((((MC/VCBO)*_pow(FBD,(MC-1.0)))/_pow((1.0-_pow(FBD,MC)),2.0))*(vcbi+(FBD*VCBO))));
 }}}else
@@ -428,8 +445,8 @@ double vcbi_MC=0.0;
 double vcbi_VCBLIN=0.0;
 double vcbi_BF=0.0;
 double vcbi_KC=0.0;
-{if((((KC>0.0)&&(MC>0.0))&&(VCBO>0.0)))
-{{vcbi_VBCI=1.0;
+{if (((KC>0.0)&&(MC>0.0))&&(VCBO>0.0))
+ {{vcbi_VBCI=1.0;
 vcbi_VCBO=0.0;
 vcbi_MC=0.0;
 vcbi_VCBLIN=0.0;
@@ -445,8 +462,8 @@ FBD_BF=0.0;
 FBD_KC=0.0;
 FBD=(VCBLIN/VCBO);
 }
-if((VBCI>0.0))
-{MM_VBCI=0.0;
+if (VBCI>0.0)
+ {MM_VBCI=0.0;
 MM_VCBO=0.0;
 MM_MC=0.0;
 MM_VCBLIN=0.0;
@@ -455,9 +472,9 @@ MM_KC=0.0;
 MM=1.0;
 }
 else
-if((VBCI>(-VCBLIN)))
-{if((MC==1))
-{MM_VBCI=(-(-vcbi_VBCI/(-VCBO))/((1.0-(vcbi/(-VCBO)))*(1.0-(vcbi/(-VCBO)))));
+if (VBCI>(-VCBLIN))
+ {if (MC==1)
+ {MM_VBCI=(-(-vcbi_VBCI/(-VCBO))/((1.0-(vcbi/(-VCBO)))*(1.0-(vcbi/(-VCBO)))));
 MM_VCBO=(-(-vcbi_VCBO/(-VCBO))/((1.0-(vcbi/(-VCBO)))*(1.0-(vcbi/(-VCBO)))));
 MM_MC=(-(-vcbi_MC/(-VCBO))/((1.0-(vcbi/(-VCBO)))*(1.0-(vcbi/(-VCBO)))));
 MM_VCBLIN=(-(-vcbi_VCBLIN/(-VCBO))/((1.0-(vcbi/(-VCBO)))*(1.0-(vcbi/(-VCBO)))));
@@ -475,9 +492,9 @@ MM_KC=(-(-_d0_pow((vcbi/(-VCBO)),MC)*(vcbi_KC/(-VCBO))+_d1_pow((vcbi/(-VCBO)),MC
 MM=(1.0/(1.0-_pow((vcbi/(-VCBO)),MC)));
 }
 }else
-if((VBCI<=(-VCBLIN)))
-{if((MC==1))
-{{MM_VBCI=((-(-FBD_VBCI)/((1.0-FBD)*(1.0-FBD)))-(((-(((1.0/VCBO)*1.0)*_d0_pow((1.0-FBD),2.0)*((-FBD_VBCI))+_d1_pow((1.0-FBD),2.0)*(0.0))/(_pow((1.0-FBD),2.0)*_pow((1.0-FBD),2.0)))*(vcbi+(FBD*VCBO)))+((((1.0/VCBO)*1.0)/_pow((1.0-FBD),2.0))*(vcbi_VBCI+FBD_VBCI*VCBO))));
+if (VBCI<=(-VCBLIN))
+ {if (MC==1)
+ {{MM_VBCI=((-(-FBD_VBCI)/((1.0-FBD)*(1.0-FBD)))-(((-(((1.0/VCBO)*1.0)*_d0_pow((1.0-FBD),2.0)*((-FBD_VBCI))+_d1_pow((1.0-FBD),2.0)*(0.0))/(_pow((1.0-FBD),2.0)*_pow((1.0-FBD),2.0)))*(vcbi+(FBD*VCBO)))+((((1.0/VCBO)*1.0)/_pow((1.0-FBD),2.0))*(vcbi_VBCI+FBD_VBCI*VCBO))));
 MM_VCBO=((-(-FBD_VCBO)/((1.0-FBD)*(1.0-FBD)))-((((-1/(VCBO*VCBO))*1.0*_pow((1.0-FBD),2.0)-((1.0/VCBO)*1.0)*_d0_pow((1.0-FBD),2.0)*((-FBD_VCBO))+_d1_pow((1.0-FBD),2.0)*(0.0))/(_pow((1.0-FBD),2.0)*_pow((1.0-FBD),2.0))*(vcbi+(FBD*VCBO)))+((((1.0/VCBO)*1.0)/_pow((1.0-FBD),2.0))*(vcbi_VCBO+(FBD_VCBO*VCBO)+FBD))));
 MM_MC=((-(-FBD_MC)/((1.0-FBD)*(1.0-FBD)))-(((-(((1.0/VCBO)*1.0)*_d0_pow((1.0-FBD),2.0)*((-FBD_MC))+_d1_pow((1.0-FBD),2.0)*(0.0))/(_pow((1.0-FBD),2.0)*_pow((1.0-FBD),2.0)))*(vcbi+(FBD*VCBO)))+((((1.0/VCBO)*1.0)/_pow((1.0-FBD),2.0))*(vcbi_MC+FBD_MC*VCBO))));
 MM_VCBLIN=((-(-FBD_VCBLIN)/((1.0-FBD)*(1.0-FBD)))-(((-(((1.0/VCBO)*1.0)*_d0_pow((1.0-FBD),2.0)*((-FBD_VCBLIN))+_d1_pow((1.0-FBD),2.0)*(0.0))/(_pow((1.0-FBD),2.0)*_pow((1.0-FBD),2.0)))*(vcbi+(FBD*VCBO)))+((((1.0/VCBO)*1.0)/_pow((1.0-FBD),2.0))*(vcbi_VCBLIN+FBD_VCBLIN*VCBO))));
@@ -519,8 +536,8 @@ double VF=0.0;
 {Vj=HBT_X_Vt(U,Ud);
 Vjo=HBT_X_Vt(0.0,Ud);
 VF=(0.9*Ud);
-if((m==1.0))
-{charge=((Area*C0)*((Ud*(_logE((1.0-(Vjo/Ud)))-_logE((1.0-(Vj/Ud)))))+((1.0/(1.0-(VF/Ud)))*((U-Vj)+Vjo))));
+if (m==1.0)
+ {charge=((Area*C0)*((Ud*(_logE((1.0-(Vjo/Ud)))-_logE((1.0-(Vj/Ud)))))+((1.0/(1.0-(VF/Ud)))*((U-Vj)+Vjo))));
 }else
 {charge=((Area*C0)*((((Ud/(1.0-m))*(_pow((1.0-(Vjo/Ud)),(1.0-m))-_pow((1.0-(Vj/Ud)),(1.0-m))))+(_pow((1.0-(VF/Ud)),(-m))*((U-Vj)+Vjo)))-(Ud*(1.0/(1.0-m)))));
 }}
@@ -573,8 +590,8 @@ VF_m=0.0;
 VF_Area=0.0;
 VF=(0.9*Ud);
 }
-if((m==1.0))
-{{charge_U=((Area*C0)*((Ud*(_d0_logE((1.0-(Vjo/Ud)))*((-Vjo_U/Ud))-_d0_logE((1.0-(Vj/Ud)))*((-Vj_U/Ud))))+(((-(-VF_U/Ud)/((1.0-(VF/Ud))*(1.0-(VF/Ud))))*((U-Vj)+Vjo))+((1.0/(1.0-(VF/Ud)))*((1.0-Vj_U)+Vjo_U)))));
+if (m==1.0)
+ {{charge_U=((Area*C0)*((Ud*(_d0_logE((1.0-(Vjo/Ud)))*((-Vjo_U/Ud))-_d0_logE((1.0-(Vj/Ud)))*((-Vj_U/Ud))))+(((-(-VF_U/Ud)/((1.0-(VF/Ud))*(1.0-(VF/Ud))))*((U-Vj)+Vjo))+((1.0/(1.0-(VF/Ud)))*((1.0-Vj_U)+Vjo_U)))));
 charge_C0=(((Area)*((Ud*(_logE((1.0-(Vjo/Ud)))-_logE((1.0-(Vj/Ud)))))+((1.0/(1.0-(VF/Ud)))*((U-Vj)+Vjo))))+((Area*C0)*((Ud*(_d0_logE((1.0-(Vjo/Ud)))*((-Vjo_C0/Ud))-_d0_logE((1.0-(Vj/Ud)))*((-Vj_C0/Ud))))+(((-(-VF_C0/Ud)/((1.0-(VF/Ud))*(1.0-(VF/Ud))))*((U-Vj)+Vjo))+((1.0/(1.0-(VF/Ud)))*((-Vj_C0)+Vjo_C0))))));
 charge_Ud=((Area*C0)*(((_logE((1.0-(Vjo/Ud)))-_logE((1.0-(Vj/Ud))))+((_d0_logE((1.0-(Vjo/Ud)))*((-((Vjo_Ud*Ud)-Vjo)/(Ud*Ud)))-_d0_logE((1.0-(Vj/Ud)))*((-((Vj_Ud*Ud)-Vj)/(Ud*Ud))))*Ud))+(((-(-((VF_Ud*Ud)-VF)/(Ud*Ud))/((1.0-(VF/Ud))*(1.0-(VF/Ud))))*((U-Vj)+Vjo))+((1.0/(1.0-(VF/Ud)))*((-Vj_Ud)+Vjo_Ud)))));
 charge_m=((Area*C0)*((Ud*(_d0_logE((1.0-(Vjo/Ud)))*((-Vjo_m/Ud))-_d0_logE((1.0-(Vj/Ud)))*((-Vj_m/Ud))))+(((-(-VF_m/Ud)/((1.0-(VF/Ud))*(1.0-(VF/Ud))))*((U-Vj)+Vjo))+((1.0/(1.0-(VF/Ud)))*((-Vj_m)+Vjo_m)))));
@@ -601,8 +618,8 @@ double HBT_X_Vceff (double U, double VCES)
 double Vceff=0.0;
 double Vth0=0.0;
 {Vth0=0.025;
-if((U<VCES))
-Vceff=(Vth0+(Vth0*_logE((1.0+_exp((((U-VCES)/Vth0)-1.0))))));
+if (U<VCES)
+ Vceff=(Vth0+(Vth0*_logE((1.0+_exp((((U-VCES)/Vth0)-1.0))))));
 else
 Vceff=((U-VCES)+(Vth0*_logE((1.0+_exp((1.0-((U-VCES)/Vth0)))))));
 }
@@ -620,8 +637,8 @@ double Vth0_VCES=0.0;
 Vth0_VCES=0.0;
 Vth0=0.025;
 }
-if((U<VCES))
-{Vceff_U=(Vth0_U+((Vth0_U*_logE((1.0+_exp((((U-VCES)/Vth0)-1.0)))))+(Vth0*_d0_logE((1.0+_exp((((U-VCES)/Vth0)-1.0))))*((+_d0_exp((((U-VCES)/Vth0)-1.0))*(((Vth0-((U-VCES)*Vth0_U))/(Vth0*Vth0))))))));
+if (U<VCES)
+ {Vceff_U=(Vth0_U+((Vth0_U*_logE((1.0+_exp((((U-VCES)/Vth0)-1.0)))))+(Vth0*_d0_logE((1.0+_exp((((U-VCES)/Vth0)-1.0))))*((+_d0_exp((((U-VCES)/Vth0)-1.0))*(((Vth0-((U-VCES)*Vth0_U))/(Vth0*Vth0))))))));
 Vceff_VCES=(Vth0_VCES+((Vth0_VCES*_logE((1.0+_exp((((U-VCES)/Vth0)-1.0)))))+(Vth0*_d0_logE((1.0+_exp((((U-VCES)/Vth0)-1.0))))*((+_d0_exp((((U-VCES)/Vth0)-1.0))*(((-1.0)*Vth0-(U-VCES)*Vth0_VCES)/(Vth0*Vth0)))))));
 Vceff=(Vth0+(Vth0*_logE((1.0+_exp((((U-VCES)/Vth0)-1.0))))));
 }
