@@ -5,7 +5,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  */
 
 #if HAVE_CONFIG_H
@@ -176,26 +176,7 @@
 	cy (n1,n1) += pwr*pow(_freq,-exp)/kB/T0;
 
 // derivative helper macros
-#define m00_hypot(v00,x,y)      v00 = xhypot(x,y);
-#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
-#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
-#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
-#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
-#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
-#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
-#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
-#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
-#define m00_pow(v00,x,y)        v00 = pow(x,y);
-#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
-#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
-
-#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
-#define m10_div(v10,v00,vv,x,y)
-#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
-
-#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
-#define m00_add(v00,x,y)        double v00=(x)+(y);
-
+// transcendental LRM p. 59
 #define m00_cos(v00,x)          v00 = cos(x);
 #define m10_cos(v10,v00,x)      v10 = (-sin(x));
 #define m00_sin(v00,x)          v00 = sin(x);
@@ -214,33 +195,68 @@
 #define m10_asin(v10,v00,x)     v10 = (+1.0/sqrt(1-x*x));
 #define m00_atan(v00,x)         v00 = atan(x);
 #define m10_atan(v10,v00,x)     v10 = (+1.0/(1+x*x));
+#define m00_hypot(v00,x,y)      v00 = sqrt((x)*(x)+(y)*(y));
+#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
+#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
+#define m00_atan2(v00,x,y)      v00 = atan2(x,y);
+// TODO atan2 derivatives ?
+#define m00_acosh(v00,x)        v00 = acosh(x);
+#define m10_acosh(v10,v00,x)    v10 = (1.0/(sqrt(x-1)*sqrt(x+1)));
+#define m00_asinh(v00,x)        v00 = asinh(x);
+#define m10_asinh(v10,v00,x)    v10 = (1.0/(sqrt(x*x+1)));
 #define m00_atanh(v00,x)        v00 = atanh(x);
-#define m10_atanh(v10,v00,x)    v10 = (+1.0/(1-x*x));
+#define m10_atanh(v10,v00,x)    v10 = (1.0/(1-x*x));
+
+
+// standard functions LRM p.58
 #define m00_logE(v00,x)         v00 = log(x);
 #define m10_logE(v10,v00,x)     v10 = (1.0/x);
 #define m00_log10(v00,x)        v00 = log10(x);
 #define m10_log10(v10,v00,x)    v10 = (1.0/x/M_LN10);
-#define m00_sqrt(v00,x)         v00 = sqrt(x);
-#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
-#define m00_fabs(v00,x)         v00 = fabs(x);
-#define m10_fabs(v10,v00,x)     v10 = (((x)>=0)?(+1.0):(-1.0));
-
 #define m00_exp(v00,x)          v00 = exp(x);
 #define m10_exp(v10,v00,x)      v10 = v00;
-
-#define m00_abs(v00)            ((v00)<(0)?(-(v00)):(v00))
+#define m00_sqrt(v00,x)         v00 = sqrt(x);
+#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
+#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
+#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
+#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
+#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
+#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
+#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
+#define m00_pow(v00,x,y)        v00 = pow(x,y);
+#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
+#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
+#define m00_abs(v00,x)          v00 = ((x)<(0)?(-(x)):(x));
+#define m10_abs(v10,v00,x)      v10 = (((x)>=0)?(+1.0):(-1.0));
 #define m00_floor(v00,x)        v00 = floor(x);
+#define m10_floor(v10,v00,x)    v10 = 1.0;
+
+#define m00_ceil(v00,x)         v00 = ceil(x);
+// TODO ceil derivative, needed?
+
+// analog operator, LRM p.61
 #define m00_limexp(v00,x)       v00 = ((x)<80.0?exp(x):exp(80.0)*(x-79.0));
 #define m10_limexp(v10,v00,x)   v10 = ((x)<80.0?(v00):exp(80.0));
 
+// analog kernel parameter system functions, LRM p.215
+#define m00_vt(x)               (kBoverQ*(x))
+#define m10_vt(x)               (kBoverQ)
+
+// extra functions (?)
+#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
+#define m10_div(v10,v00,vv,x,y)
+#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
+#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
+#define m00_add(v00,x,y)        double v00=(x)+(y);
+
+// second derivatives
 #define m20_logE(v00)           (-1.0/v00/v00)
 #define m20_exp(v00)            exp(v00)
 #define m20_limexp(v00)         ((v00)<80.0?exp(v00):0.0)
 #define m20_sqrt(v00)           (-0.25/(v00)/sqrt(v00))
-#define m20_fabs(v00)           0.0
+#define m20_abs(v00)           0.0
 #define m20_pow(x,y)            ((y)*((y)-1.0)*pow(x,y)/(x)/(x))
-#define m00_vt(x)               (kBoverQ*(x))
-#define m10_vt(x)               (kBoverQ)
+
 
 // simulator specific definitions
 #define _modelname              "HBT_X"
@@ -249,10 +265,11 @@
 #define _param_given(p)		(isPropertyGiven(p)?1:0)
 
 
-// $vt and $vt() functions 
+// $vt and $vt() functions
 #define _vt_nom                 (kBoverQ*_circuit_temp)
 
-using namespace device;
+using namespace qucs::device;
+using qucs::matrix;
 
 /* Device constructor. */
 HBT_X::HBT_X() : circuit (19)
@@ -801,7 +818,7 @@ Ic1ra_Tempti_GND=HBT_X_d_diode(vbci,(XCjc*Jsr),Vgr,nr,Area,Tj,Tnom,0.0,0.0,0.0,0
 #endif
 Ic1ra=HBT_X_diode(vbci,(XCjc*Jsr),Vgr,nr,Area,Tj,Tnom);
 if
-(((VAF>0.0)&&(VAR>0.0)))
+((VAF>0.0)&&(VAR>0.0))
 {
 #if defined(_DERIVATE)
 q1_Vbii_ei=(((HBT_X_d_charge(vbei,1.0,Vje,mje,1.0,vbei_Vbii_ei,0.0,0.0,0.0,0.0)-HBT_X_d_charge(0.0,1.0,Vje,mje,1.0,0.0,0.0,0.0,0.0,0.0))/VAR)+((HBT_X_d_charge(vbci,1.0,Vjc,mjc,1.0,0.0,0.0,0.0,0.0,0.0)-HBT_X_d_charge(0.0,1.0,Vjc,mjc,1.0,0.0,0.0,0.0,0.0,0.0))/VAF));
@@ -812,7 +829,7 @@ q1=((1.0+((HBT_X_charge(vbei,1.0,Vje,mje,1.0)-HBT_X_charge(0.0,1.0,Vje,mje,1.0))
 else
 {
 if
-(((VAF>0.0)&&(VAR==0.0)))
+((VAF>0.0)&&(VAR==0.0))
 {
 #if defined(_DERIVATE)
 q1_Vbii_ei=0.0;
@@ -823,7 +840,7 @@ q1=(1.0+((HBT_X_charge(vbci,1.0,Vjc,mjc,1.0)-HBT_X_charge(0.0,1.0,Vjc,mjc,1.0))/
 else
 {
 if
-(((VAF==0.0)&&(VAR>0.0)))
+((VAF==0.0)&&(VAR>0.0))
 {
 #if defined(_DERIVATE)
 q1_Vbii_ei=((HBT_X_d_charge(vbei,1.0,Vje,mje,1.0,vbei_Vbii_ei,0.0,0.0,0.0,0.0)-HBT_X_d_charge(0.0,1.0,Vje,mje,1.0,0.0,0.0,0.0,0.0,0.0))/VAR);
@@ -842,7 +859,7 @@ q1=1.0;
 }
 }
 if
-(((IKF>0.0)&&(IKR>0.0)))
+((IKF>0.0)&&(IKR>0.0))
 {
 #if defined(_DERIVATE)
 q2_Vbii_ei=(Ic0a_Vbii_ei/(Area*IKF));
@@ -854,7 +871,7 @@ q2=((Ic0a/(Area*IKF))+(Ic1ra/(Area*IKR)));
 else
 {
 if
-(((IKF>0.0)&&(IKR==0.0)))
+((IKF>0.0)&&(IKR==0.0))
 {
 #if defined(_DERIVATE)
 q2_Vbii_ei=(Ic0a_Vbii_ei/(Area*IKF));
@@ -866,7 +883,7 @@ q2=(Ic0a/(Area*IKF));
 else
 {
 if
-(((IKF==0.0)&&(IKR>0.0)))
+((IKF==0.0)&&(IKR>0.0))
 {
 #if defined(_DERIVATE)
 q2_Vbii_ei=0.0;
@@ -936,13 +953,13 @@ mm_Vbii_ci=HBT_X_d_MM(vbci,BVceo,Mc,Vbclin,Bf,kc,vbci_Vbii_ci,0.0,0.0,0.0,0.0,0.
 #endif
 mm=HBT_X_MM(vbci,BVceo,Mc,Vbclin,Bf,kc);
 if
-((mm>1.0))
+(mm>1.0)
 {
 if
-((kBeta>0.0))
+(kBeta>0.0)
 {
 if
-(((Bf-(kBeta*Tex))>1e-6))
+((Bf-(kBeta*Tex))>1e-6)
 {
 #if defined(_DERIVATE)
 EdBeta_Tempti_GND=((-1*(-(kBeta*Tex_Tempti_GND))/(Bf-(kBeta*Tex))/(Bf-(kBeta*Tex)))/((kc*(mm-1))+1));
@@ -971,10 +988,10 @@ EdBeta=(((1/Bf)-(kc*(mm-1)))/((kc*(mm-1))+1));
 else
 {
 if
-((kBeta>0.0))
+(kBeta>0.0)
 {
 if
-(((Bf-(kBeta*Tex))>1e-6))
+((Bf-(kBeta*Tex))>1e-6)
 {
 #if defined(_DERIVATE)
 EdBeta_Tempti_GND=(-1*(-(kBeta*Tex_Tempti_GND))/(Bf-(kBeta*Tex))/(Bf-(kBeta*Tex)));
@@ -1007,7 +1024,7 @@ Ib0_Vbii_ci=(Ic0a*EdBeta_Vbii_ci);
 #endif
 Ib0=(Ic0a*EdBeta);
 if
-((BVebo>0))
+(BVebo>0)
 {
 #if defined(_DERIVATE)
 Ib1_Vbii_ei=(Ib0_Vbii_ei-HBT_X_d_diode(((-BVebo)-vbei),Jsf,0.0,1.0,Area,0.0,0.0,(-vbei_Vbii_ei),0.0,0.0,0.0,0.0,0.0,0.0));
@@ -1026,7 +1043,7 @@ Ib1_Vbii_ci=Ib0_Vbii_ci;
 Ib1=Ib0;
 }
 if
-(((Jse>0.0)&&(ne>0)))
+((Jse>0.0)&&(ne>0))
 {
 #if defined(_DERIVATE)
 Ibdx_Vex_ei=HBT_X_d_diode(vxe,Jse,Vgb,ne,Area,Tj,Tnom,vxe_Vex_ei,0.0,0.0,0.0,0.0,0.0,0.0);
@@ -1043,7 +1060,7 @@ Ibdx_Tempti_GND=0.0;
 Ibdx=(vxe*1e-12);
 }
 if
-(((Jsee>0.0)&&(nee>0)))
+((Jsee>0.0)&&(nee>0))
 {
 #if defined(_DERIVATE)
 Ibdxx_Vexx_ei=HBT_X_d_diode(vxxe,Jsee,Vgbb,nee,Area,Tj,Tnom,vxxe_Vexx_ei,0.0,0.0,0.0,0.0,0.0,0.0);
@@ -1060,7 +1077,7 @@ Ibdxx_Tempti_GND=0.0;
 Ibdxx=(vxxe*1e-12);
 }
 if
-(((Jsc>0.0)&&(nc>0)))
+((Jsc>0.0)&&(nc>0))
 {
 #if defined(_DERIVATE)
 Icdx_Vcx_ci=HBT_X_d_diode(vxc,Jsc,Vgc,nc,Area,Tj,Tnom,vxc_Vcx_ci,0.0,0.0,0.0,0.0,0.0,0.0);
@@ -1085,7 +1102,7 @@ Ipdiss_Vbi_ci=((Ibx_Vbi_ci*vbcx)+(Ibx*vbcx_Vbi_ci));
 #endif
 Ipdiss=((((Ic1*vcei)+(Ib1*vbei))+(Ib2*vbci))+(Ibx*vbcx));
 if
-((Ipdiss<0.0))
+(Ipdiss<0.0)
 {
 #if defined(_DERIVATE)
 Ipdiss_Vbii_ei=0.0;
@@ -1101,11 +1118,11 @@ I00=(J0*Area);
 #endif
 #ifdef _DYNAMIC
 if
-(((XCjc<1.0)&&(XCjc>0.0)))
+((XCjc<1.0)&&(XCjc>0.0))
 {
 #ifdef _DYNAMIC
 if
-(((J0<=0.0)||(Ic0<0.0)))
+((J0<=0.0)||(Ic0<0.0))
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1147,7 +1164,7 @@ else
 {
 #ifdef _DYNAMIC
 if
-(((J0<0.0)||(Ic0<0.0)))
+((J0<0.0)||(Ic0<0.0))
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1188,7 +1205,7 @@ qb2med=(((1.0-d00_tanh0)*(HBT_X_charge(vbci,(Cjc-Cmin),Vjc,mjc,Area)+((((1.0-XJ0
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-(((XCjc<1.0)&&(XCjc>0.0)))
+((XCjc<1.0)&&(XCjc>0.0))
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1232,11 +1249,11 @@ qb2=(qb2med+qbtr);
 #endif
 #ifdef _DYNAMIC
 if
-(((Jk>0.0)&&(Rci0>0.0)))
+((Jk>0.0)&&(Rci0>0.0))
 {
 #ifdef _DYNAMIC
 if
-((RJk>0.0))
+(RJk>0.0)
 {
 #if defined(_DYNAMIC)
 Vlim=((Jk*Rci0)/(1.0-(Rci0/RJk)));
@@ -1259,7 +1276,7 @@ InvVpt=0.0;
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-(((((Thcs>0.0)&&(Ahc>0.0))&&(Jk>0.0))&&(Ic0>0.0)))
+((((Thcs>0.0)&&(Ahc>0.0))&&(Jk>0.0))&&(Ic0>0.0))
 {
 #if defined(_DYNAMIC)
 RCIO=(Rci0/Area);
@@ -1269,7 +1286,7 @@ AHC=(Area*Ahc);
 #endif
 #ifdef _DYNAMIC
 if
-(((Rci0<RJk)||(RJk<=0.0)))
+((Rci0<RJk)||(RJk<=0.0))
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1446,7 +1463,7 @@ _load_static_jacobian4(c,ci,c,ci,(1/(Rc/N)));
 #endif
 _save_whitenoise2(c,ci,((FOUR_K*TjK)/(Rc/N)),"thermal");
 if
-(((Jse>0.0)&&(ne>0)))
+((Jse>0.0)&&(ne>0))
 {
 _load_static_residual2(ex,bii,(BP(ex,bii)/(Rbxx/N)));
 #if defined(_DERIVATE)
@@ -1462,7 +1479,7 @@ _load_static_jacobian4(ex,bii,ex,bii,(1e-12));
 #endif
 }
 if
-(((Jsee>0.0)&&(nee>0)))
+((Jsee>0.0)&&(nee>0))
 {
 _load_static_residual2(exx,bii,(BP(exx,bii)/(Rbbxx/N)));
 #if defined(_DERIVATE)
@@ -1478,7 +1495,7 @@ _load_static_jacobian4(exx,bii,exx,bii,(1e-12));
 #endif
 }
 if
-(((Jsc>0.0)&&(nc>0)))
+((Jsc>0.0)&&(nc>0))
 {
 _load_static_residual2(cx,bii,(BP(cx,bii)/(Rcxx/N)));
 #if defined(_DERIVATE)
@@ -1541,7 +1558,7 @@ _load_static_jacobian4(t,ti,t,ti,(1e3));
 #endif
 }
 if
-((Ib0<=0))
+(Ib0<=0)
 {
 #if defined(_DERIVATE)
 Iniix_Vbii_ei=0.0;
@@ -1557,7 +1574,7 @@ Iniiix_Vbii_ci=0.0;
 Iniiix=0;
 }
 if
-(((Ib0+Ic1)<=0))
+((Ib0+Ic1)<=0)
 {
 #if defined(_DERIVATE)
 Inivx_Vbii_ei=0.0;
@@ -1569,7 +1586,7 @@ Inivx=0;
 else
 {
 if
-((Ab==2))
+(Ab==2)
 {
 #if defined(_DERIVATE)
 Iniix_Vbii_ei=Ib0_Vbii_ei;
@@ -1594,7 +1611,7 @@ Iniix=d00_pow0;
 }
 }
 if
-((Afb==2))
+(Afb==2)
 {
 #if defined(_DERIVATE)
 Iniiix_Vbii_ei=Ib0_Vbii_ei;
@@ -1619,7 +1636,7 @@ Iniiix=d00_pow0;
 }
 }
 if
-((Afe==2))
+(Afe==2)
 {
 #if defined(_DERIVATE)
 Inivx_Vbii_ei=(Ib0_Vbii_ei+Ic1_Vbii_ei);
@@ -1722,8 +1739,8 @@ _load_static_jacobian2s(e,ei,niv,((NP(nivx))/(Re/N)));
 void HBT_X::calcDC (void)
 {
   // evaluate Verilog code
-  initVerilog ();		
-  calcVerilog ();		
+  initVerilog ();
+  calcVerilog ();
 
   // fill right hand side and static jacobian
   for (int i1 = 0; i1 < 19; i1++) {
@@ -1771,7 +1788,7 @@ matrix HBT_X::calcMatrixY (nr_double_t frequency)
 
   for (int i1 = 0; i1 < 19; i1++) {
     for (int i2 = 0; i2 < 19; i2++) {
-      y (i1,i2) = rect (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
+      y (i1,i2) = nr_complex_t (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
     }
   }
 
@@ -1787,7 +1804,7 @@ void HBT_X::initSP (void)
 /* Perform S-parameter calculations. */
 void HBT_X::calcSP (nr_double_t frequency)
 {
-  setMatrixS (ytos (calcMatrixY (frequency)));   
+  setMatrixS (ytos (calcMatrixY (frequency)));
 }
 
 /* Initialization of transient analysis. */
@@ -1851,7 +1868,7 @@ void HBT_X::calcTR (nr_double_t)
     if (_caps[i1][i1][i3][i4] != 0.0)
       transientCapacitanceC2V (i1, i3, i4, _caps[i1][i1][i3][i4], BP(i3,i4));
   } } }
-     
+
   // charge: 1-node, voltage: 1-node
   for (i1 = 0; i1 < 19; i1++) {
   for (i3 = 0; i3 < 19; i3++) {
@@ -1924,3 +1941,4 @@ void HBT_X::calcHB (int)
 }
 
 #include "HBT_X.defs.h"
+
