@@ -5,7 +5,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  */
 
 #if HAVE_CONFIG_H
@@ -164,26 +164,7 @@
 	cy (n1,n1) += pwr*pow(_freq,-exp)/kB/T0;
 
 // derivative helper macros
-#define m00_hypot(v00,x,y)      v00 = xhypot(x,y);
-#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
-#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
-#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
-#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
-#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
-#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
-#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
-#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
-#define m00_pow(v00,x,y)        v00 = pow(x,y);
-#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
-#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
-
-#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
-#define m10_div(v10,v00,vv,x,y)
-#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
-
-#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
-#define m00_add(v00,x,y)        double v00=(x)+(y);
-
+// transcendental LRM p. 59
 #define m00_cos(v00,x)          v00 = cos(x);
 #define m10_cos(v10,v00,x)      v10 = (-sin(x));
 #define m00_sin(v00,x)          v00 = sin(x);
@@ -202,33 +183,68 @@
 #define m10_asin(v10,v00,x)     v10 = (+1.0/sqrt(1-x*x));
 #define m00_atan(v00,x)         v00 = atan(x);
 #define m10_atan(v10,v00,x)     v10 = (+1.0/(1+x*x));
+#define m00_hypot(v00,x,y)      v00 = sqrt((x)*(x)+(y)*(y));
+#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
+#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
+#define m00_atan2(v00,x,y)      v00 = atan2(x,y);
+// TODO atan2 derivatives ?
+#define m00_acosh(v00,x)        v00 = acosh(x);
+#define m10_acosh(v10,v00,x)    v10 = (1.0/(sqrt(x-1)*sqrt(x+1)));
+#define m00_asinh(v00,x)        v00 = asinh(x);
+#define m10_asinh(v10,v00,x)    v10 = (1.0/(sqrt(x*x+1)));
 #define m00_atanh(v00,x)        v00 = atanh(x);
-#define m10_atanh(v10,v00,x)    v10 = (+1.0/(1-x*x));
+#define m10_atanh(v10,v00,x)    v10 = (1.0/(1-x*x));
+
+
+// standard functions LRM p.58
 #define m00_logE(v00,x)         v00 = log(x);
 #define m10_logE(v10,v00,x)     v10 = (1.0/x);
 #define m00_log10(v00,x)        v00 = log10(x);
 #define m10_log10(v10,v00,x)    v10 = (1.0/x/M_LN10);
-#define m00_sqrt(v00,x)         v00 = sqrt(x);
-#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
-#define m00_fabs(v00,x)         v00 = fabs(x);
-#define m10_fabs(v10,v00,x)     v10 = (((x)>=0)?(+1.0):(-1.0));
-
 #define m00_exp(v00,x)          v00 = exp(x);
 #define m10_exp(v10,v00,x)      v10 = v00;
-
-#define m00_abs(v00)            ((v00)<(0)?(-(v00)):(v00))
+#define m00_sqrt(v00,x)         v00 = sqrt(x);
+#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
+#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
+#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
+#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
+#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
+#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
+#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
+#define m00_pow(v00,x,y)        v00 = pow(x,y);
+#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
+#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
+#define m00_abs(v00,x)          v00 = ((x)<(0)?(-(x)):(x));
+#define m10_abs(v10,v00,x)      v10 = (((x)>=0)?(+1.0):(-1.0));
 #define m00_floor(v00,x)        v00 = floor(x);
+#define m10_floor(v10,v00,x)    v10 = 1.0;
+
+#define m00_ceil(v00,x)         v00 = ceil(x);
+// TODO ceil derivative, needed?
+
+// analog operator, LRM p.61
 #define m00_limexp(v00,x)       v00 = ((x)<80.0?exp(x):exp(80.0)*(x-79.0));
 #define m10_limexp(v10,v00,x)   v10 = ((x)<80.0?(v00):exp(80.0));
 
+// analog kernel parameter system functions, LRM p.215
+#define m00_vt(x)               (kBoverQ*(x))
+#define m10_vt(x)               (kBoverQ)
+
+// extra functions (?)
+#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
+#define m10_div(v10,v00,vv,x,y)
+#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
+#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
+#define m00_add(v00,x,y)        double v00=(x)+(y);
+
+// second derivatives
 #define m20_logE(v00)           (-1.0/v00/v00)
 #define m20_exp(v00)            exp(v00)
 #define m20_limexp(v00)         ((v00)<80.0?exp(v00):0.0)
 #define m20_sqrt(v00)           (-0.25/(v00)/sqrt(v00))
-#define m20_fabs(v00)           0.0
+#define m20_abs(v00)           0.0
 #define m20_pow(x,y)            ((y)*((y)-1.0)*pow(x,y)/(x)/(x))
-#define m00_vt(x)               (kBoverQ*(x))
-#define m10_vt(x)               (kBoverQ)
+
 
 // simulator specific definitions
 #define _modelname              "MESFET"
@@ -237,10 +253,11 @@
 #define _param_given(p)		(isPropertyGiven(p)?1:0)
 
 
-// $vt and $vt() functions 
+// $vt and $vt() functions
 #define _vt_nom                 (kBoverQ*_circuit_temp)
 
-using namespace device;
+using namespace qucs::device;
+using qucs::matrix;
 
 /* Device constructor. */
 MESFET::MESFET() : circuit (7)
@@ -688,13 +705,13 @@ if
 ((LEVEL)==(1))
 {
 if
-(((BP(n2,n4)-Vto_T2)>0))
+((BP(n2,n4)-Vto_T2)>0)
 {
 {
-double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2)
+double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
 double m00_tanh(d00_tanh1,(Alpha*BP(n3,n4)))
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2)
+double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
 double m10_tanh(d10_tanh1,d00_tanh1,(Alpha*BP(n3,n4)))
 #endif
 #if defined(_DERIVATE)
@@ -731,10 +748,10 @@ Vf_Vn2_n4=((Ah)*d10_exp0*d10_logE1/Ah);
 Vf=(d00_logE1/Ah);
 }
 {
-double m00_pow(d00_pow0,Vf,2)
+double m00_pow(d00_pow0,Vf,2.0)
 double m00_tanh(d00_tanh1,(Alpha*BP(n3,n4)))
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,Vf,2)
+double m10_pow(d10_pow0,d00_pow0,Vf,2.0)
 double m10_tanh(d10_tanh1,d00_tanh1,(Alpha*BP(n3,n4)))
 #endif
 #if defined(_DERIVATE)
@@ -749,17 +766,17 @@ if
 ((LEVEL)==(3))
 {
 if
-(((BP(n2,n4)-Vto_T2)>0))
+((BP(n2,n4)-Vto_T2)>0)
 {
 if
-(((0<BP(n3,n4))&&(BP(n3,n4)<(3/Alpha))))
+((0<BP(n3,n4))&&(BP(n3,n4)<(3/Alpha)))
 {
 {
-double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2)
-double m00_pow(d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3)
+double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
+double m00_pow(d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3.0)
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2)
-double m10_pow(d10_pow1,d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3)
+double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
+double m10_pow(d10_pow1,d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3.0)
 #endif
 #if defined(_DERIVATE)
 Ids_Vn2_n4=((((Beta_T2*(1+(Lambda*BP(n3,n4))))*(d10_pow0*1.0))*(1-d00_pow1)*(1+(B*(BP(n2,n4)-Vto_T2)))-(((Beta_T2*(1+(Lambda*BP(n3,n4))))*d00_pow0)*(1-d00_pow1))*(B))/(1+(B*(BP(n2,n4)-Vto_T2)))/(1+(B*(BP(n2,n4)-Vto_T2))));
@@ -769,12 +786,12 @@ Ids=((((Beta_T2*(1+(Lambda*BP(n3,n4))))*d00_pow0)*(1-d00_pow1))/(1+(B*(BP(n2,n4)
 }
 }
 if
-((BP(n3,n4)>=(3/Alpha)))
+(BP(n3,n4)>=(3/Alpha))
 {
 {
-double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2)
+double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2)
+double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
 #endif
 #if defined(_DERIVATE)
 Ids_Vn2_n4=((((Beta_T2*(1+(Lambda*BP(n3,n4))))*(d10_pow0*1.0))*(1+(B*(BP(n2,n4)-Vto_T2)))-((Beta_T2*(1+(Lambda*BP(n3,n4))))*d00_pow0)*(B))/(1+(B*(BP(n2,n4)-Vto_T2)))/(1+(B*(BP(n2,n4)-Vto_T2))));
@@ -784,7 +801,7 @@ Ids=(((Beta_T2*(1+(Lambda*BP(n3,n4))))*d00_pow0)/(1+(B*(BP(n2,n4)-Vto_T2))));
 }
 }
 if
-((BP(n3,n4)<0))
+(BP(n3,n4)<0)
 {
 #if defined(_DERIVATE)
 Ids_Vn2_n4=0.0;
@@ -807,17 +824,17 @@ if
 ((LEVEL)==(4))
 {
 if
-(((BP(n2,n4)-Vto_T2)>0))
+((BP(n2,n4)-Vto_T2)>0)
 {
 if
-(((0<BP(n3,n4))&&(BP(n3,n4)<(3/Alpha))))
+((0<BP(n3,n4))&&(BP(n3,n4)<(3/Alpha)))
 {
 {
 double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),Qp)
-double m00_pow(d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3)
+double m00_pow(d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3.0)
 #if defined(_DERIVATE)
 double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),Qp)
-double m10_pow(d10_pow1,d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3)
+double m10_pow(d10_pow1,d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3.0)
 #endif
 #if defined(_DERIVATE)
 Ids1_Vn2_n4=(Beta_T2*(d10_pow0*1.0))*(1-d00_pow1);
@@ -832,7 +849,7 @@ Ids_Vn3_n4=((((Ids1_Vn3_n4*(1+(Lambda*BP(n3,n4))))+(Ids1*(Lambda)))*(1+((Delta*B
 Ids=((Ids1*(1+(Lambda*BP(n3,n4))))/(1+((Delta*BP(n3,n4))*Ids1)));
 }
 if
-((BP(n3,n4)>=(3/Alpha)))
+(BP(n3,n4)>=(3/Alpha))
 {
 {
 double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),Qp)
@@ -852,7 +869,7 @@ Ids_Vn3_n4=((((Ids1_Vn3_n4*(1+(Lambda*BP(n3,n4))))+(Ids1*(Lambda)))*(1+((Delta*B
 Ids=((Ids1*(1+(Lambda*BP(n3,n4))))/(1+((Delta*BP(n3,n4))*Ids1)));
 }
 if
-((BP(n3,n4)<0))
+(BP(n3,n4)<0)
 {
 #if defined(_DERIVATE)
 Ids_Vn2_n4=0.0;
@@ -875,14 +892,14 @@ if
 ((LEVEL)==(5))
 {
 if
-(((BP(n2,n4)-Vto_T2)>0))
+((BP(n2,n4)-Vto_T2)>0)
 {
 #if defined(_DERIVATE)
 Nst_Vn3_n4=(Nd);
 #endif
 Nst=(Ng+(Nd*BP(n3,n4)));
 if
-((Nst<1.0))
+(Nst<1.0)
 {
 #if defined(_DERIVATE)
 Nst_Vn3_n4=0.0;
@@ -961,7 +978,7 @@ if
 ((ILEVELS)==(1))
 {
 if
-((BP(n2,n4)>Vbi))
+(BP(n2,n4)>Vbi)
 {
 #if defined(_DERIVATE)
 Igs_Vn2_n4=(1/Rf);
@@ -981,7 +998,7 @@ if
 ((ILEVELS)==(2))
 {
 if
-((BP(n2,n4)>Vbi))
+(BP(n2,n4)>Vbi)
 {
 #if defined(_DERIVATE)
 Igs1_Vn2_n4=(1/Rf);
@@ -996,7 +1013,7 @@ Igs1_Vn2_n4=(1e-12);
 Igs1=(((-Area)*Is)+(BP(n2,n4)*1e-12));
 }
 if
-((BP(n2,n4)<(-Bv)))
+(BP(n2,n4)<(-Bv))
 {
 #if defined(_DERIVATE)
 Igs2_Vn2_n4=(1/R1);
@@ -1013,7 +1030,7 @@ if
 ((ILEVELS)==(3))
 {
 if
-((BP(n2,n4)>(((-5.0)*N)*Vt_T2)))
+(BP(n2,n4)>(((-5.0)*N)*Vt_T2))
 {
 {
 double m00_limexp(d00_limexp0,(BP(n2,n4)/(N*Vt_T2)))
@@ -1039,7 +1056,7 @@ if
 ((ILEVELS)==(4))
 {
 if
-((BP(n2,n4)>(((-5.0)*N)*Vt_T2)))
+(BP(n2,n4)>(((-5.0)*N)*Vt_T2))
 {
 {
 double m00_limexp(d00_limexp0,(BP(n2,n4)/(N*Vt_T2)))
@@ -1060,7 +1077,7 @@ Igs1_Vn2_n4=0.0;
 Igs1=0;
 }
 if
-((((-Bv)<BP(n2,n4))&&(BP(n2,n4)<(((-5.0)*N)*Vt_T2))))
+(((-Bv)<BP(n2,n4))&&(BP(n2,n4)<(((-5.0)*N)*Vt_T2)))
 {
 #if defined(_DERIVATE)
 Igs2_Vn2_n4=(1e-12);
@@ -1075,7 +1092,7 @@ Igs2_Vn2_n4=0.0;
 Igs2=0;
 }
 if
-((BP(n2,n4)==(-Bv)))
+(BP(n2,n4)==(-Bv))
 {
 Igs3=(-Ibv);
 }
@@ -1084,7 +1101,7 @@ else
 Igs3=0;
 }
 if
-((BP(n2,n4)<(-Bv)))
+(BP(n2,n4)<(-Bv))
 {
 {
 double m00_limexp(d00_limexp0,((-(Bv+BP(n2,n4)))/Vt_T2))
@@ -1124,7 +1141,7 @@ if
 ((ILEVELD)==(1))
 {
 if
-((BP(n2,n3)>Vbi))
+(BP(n2,n3)>Vbi)
 {
 #if defined(_DERIVATE)
 Igd_Vn2_n3=(1/Rf);
@@ -1144,7 +1161,7 @@ if
 ((ILEVELD)==(2))
 {
 if
-((BP(n2,n3)>Vbi))
+(BP(n2,n3)>Vbi)
 {
 #if defined(_DERIVATE)
 Igd1_Vn2_n3=(1/Rf);
@@ -1159,7 +1176,7 @@ Igd1_Vn2_n3=(1e-12);
 Igd1=(((-Area)*Is)+(BP(n2,n3)*1e-12));
 }
 if
-((BP(n2,n3)<(-Bv)))
+(BP(n2,n3)<(-Bv))
 {
 #if defined(_DERIVATE)
 Igd2_Vn2_n3=(1/R1);
@@ -1176,7 +1193,7 @@ if
 ((ILEVELD)==(3))
 {
 if
-((BP(n2,n3)>(((-5.0)*N)*Vt_T2)))
+(BP(n2,n3)>(((-5.0)*N)*Vt_T2))
 {
 {
 double m00_limexp(d00_limexp0,(BP(n2,n3)/(N*Vt_T2)))
@@ -1202,7 +1219,7 @@ if
 ((ILEVELD)==(4))
 {
 if
-((BP(n2,n3)>(((-5.0)*N)*Vt_T2)))
+(BP(n2,n3)>(((-5.0)*N)*Vt_T2))
 {
 {
 double m00_limexp(d00_limexp0,(BP(n2,n3)/(N*Vt_T2)))
@@ -1223,7 +1240,7 @@ Igd1_Vn2_n3=0.0;
 Igd1=0;
 }
 if
-((((-Bv)<BP(n2,n3))&&(BP(n2,n3)<(((-5.0)*N)*Vt_T2))))
+(((-Bv)<BP(n2,n3))&&(BP(n2,n3)<(((-5.0)*N)*Vt_T2)))
 {
 #if defined(_DERIVATE)
 Igd2_Vn2_n3=(1e-12);
@@ -1238,7 +1255,7 @@ Igd2_Vn2_n3=0.0;
 Igd2=0;
 }
 if
-((BP(n2,n3)==(-Bv)))
+(BP(n2,n3)==(-Bv))
 {
 Igd3=(-Ibv);
 }
@@ -1247,7 +1264,7 @@ else
 Igd3=0;
 }
 if
-((BP(n2,n3)<(-Bv)))
+(BP(n2,n3)<(-Bv))
 {
 {
 double m00_limexp(d00_limexp0,((-(Bv+BP(n2,n3)))/Vt_T2))
@@ -1276,7 +1293,7 @@ else
 { /* no default */ }
 #ifdef _DYNAMIC
 if
-((QLEVELS==0))
+(QLEVELS==0)
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1289,7 +1306,7 @@ Qgs=0;
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((QLEVELS==1))
+(QLEVELS==1)
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1302,11 +1319,11 @@ Qgs=((Area*Cgs)*BP(n2,n1));
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((QLEVELS==2))
+(QLEVELS==2)
 {
 #ifdef _DYNAMIC
 if
-((BP(n2,n1)<(Fc*Vbi)))
+(BP(n2,n1)<(Fc*Vbi))
 {
 #if defined(_DYNAMIC)
 {
@@ -1333,7 +1350,7 @@ Qgs1=0;
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((BP(n2,n1)>=(Fc*Vbi)))
+(BP(n2,n1)>=(Fc*Vbi))
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1363,14 +1380,14 @@ Qgs=(Qgs1+Qgs2);
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((QLEVELS==3))
+(QLEVELS==3)
 {
 #if defined(_DYNAMIC)
 {
-double m00_pow(d00_pow0,(BP(n2,n1)-BP(n2,n3)),2)
+double m00_pow(d00_pow0,(BP(n2,n1)-BP(n2,n3)),2.0)
 double m00_sqrt(d00_sqrt1,(d00_pow0+(Vdelta1*Vdelta1)))
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(BP(n2,n1)-BP(n2,n3)),2)
+double m10_pow(d10_pow0,d00_pow0,(BP(n2,n1)-BP(n2,n3)),2.0)
 double m10_sqrt(d10_sqrt1,d00_sqrt1,(d00_pow0+(Vdelta1*Vdelta1)))
 #endif
 #if defined(_DERIVATE)
@@ -1382,10 +1399,10 @@ Veff1=(0.5*((BP(n2,n1)+BP(n2,n3))+d00_sqrt1));
 #endif
 #if defined(_DYNAMIC)
 {
-double m00_pow(d00_pow0,(Veff1-Vto),2)
+double m00_pow(d00_pow0,(Veff1-Vto),2.0)
 double m00_sqrt(d00_sqrt1,(d00_pow0+(Vdelta2*Vdelta2)))
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(Veff1-Vto),2)
+double m10_pow(d10_pow0,d00_pow0,(Veff1-Vto),2.0)
 double m10_sqrt(d10_sqrt1,d00_sqrt1,(d00_pow0+(Vdelta2*Vdelta2)))
 #endif
 #if defined(_DERIVATE)
@@ -1397,7 +1414,7 @@ Vnew=(0.5*((Veff1+Vto_T2)+d00_sqrt1));
 #endif
 #ifdef _DYNAMIC
 if
-((Vnew>Vmax))
+(Vnew>Vmax)
 {
 #if defined(_DYNAMIC)
 {
@@ -1432,7 +1449,7 @@ Qgs=(((Cgs_T2*2)*Vbi)*(1-d00_sqrt0));
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((QLEVELD==0))
+(QLEVELD==0)
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1445,7 +1462,7 @@ Qgd=0;
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((QLEVELD==1))
+(QLEVELD==1)
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1458,11 +1475,11 @@ Qgd=((Area*Cgd)*BP(n2,n3));
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((QLEVELD==2))
+(QLEVELD==2)
 {
 #ifdef _DYNAMIC
 if
-((BP(n2,n3)<(Fc*Vbi)))
+(BP(n2,n3)<(Fc*Vbi))
 {
 #if defined(_DYNAMIC)
 {
@@ -1489,7 +1506,7 @@ Qgd1=0;
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((BP(n2,n3)>=(Fc*Vbi)))
+(BP(n2,n3)>=(Fc*Vbi))
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -1519,14 +1536,14 @@ Qgd=(Qgd1+Qgd2);
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((QLEVELD==3))
+(QLEVELD==3)
 {
 #if defined(_DYNAMIC)
 {
-double m00_pow(d00_pow0,(BP(n2,n1)-BP(n2,n3)),2)
+double m00_pow(d00_pow0,(BP(n2,n1)-BP(n2,n3)),2.0)
 double m00_sqrt(d00_sqrt1,(d00_pow0+(Vdelta1*Vdelta1)))
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(BP(n2,n1)-BP(n2,n3)),2)
+double m10_pow(d10_pow0,d00_pow0,(BP(n2,n1)-BP(n2,n3)),2.0)
 double m10_sqrt(d10_sqrt1,d00_sqrt1,(d00_pow0+(Vdelta1*Vdelta1)))
 #endif
 #if defined(_DERIVATE)
@@ -1634,7 +1651,7 @@ _load_static_jacobian4(n4,Source,n4,Source,((Area)/Rs_T2));
 #endif
 fourkt=((4.0*1.3806503e-23)*T2);
 if
-(((LEVEL==1)||(LEVEL==2)))
+((LEVEL==1)||(LEVEL==2))
 {
 {
 double m00_tanh(d00_tanh0,(Alpha_T2*BP(n3,n4)))
@@ -1648,7 +1665,7 @@ gm_Vn3_n4=(((((2*Beta_T2)*(BP(n2,n4)-Vto_T2))*(Lambda))*d00_tanh0)+((((2*Beta_T2
 gm=((((2*Beta_T2)*(BP(n2,n4)-Vto_T2))*(1+(Lambda*BP(n3,n4))))*d00_tanh0);
 }
 if
-((BP(n3,n4)<(3/Alpha)))
+(BP(n3,n4)<(3/Alpha))
 {
 #if defined(_DERIVATE)
 An_Vn3_n4=(-(1/(BP(n2,n4)-Vto_T2)));
@@ -1684,10 +1701,10 @@ flicker_pwr=(Kf*d00_pow0);
 _save_flickernoise2(n3,n4,flicker_pwr,1.0,"flicker");
 }
 if
-((LEVEL==3))
+(LEVEL==3)
 {
 if
-((BP(n3,n4)<(3/Alpha)))
+(BP(n3,n4)<(3/Alpha))
 {
 #if defined(_DERIVATE)
 H1_Vn3_n4=((-(-((Alpha)/3)))/(1+(B*(BP(n2,n4)-Vto_T2))));
@@ -1695,9 +1712,9 @@ H1_Vn2_n4=(-(1-(1-((Alpha*BP(n3,n4))/3)))*(B)/(1+(B*(BP(n2,n4)-Vto_T2)))/(1+(B*(
 #endif
 H1=((1-(1-((Alpha*BP(n3,n4))/3)))/(1+(B*(BP(n2,n4)-Vto_T2))));
 {
-double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2)
+double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2)
+double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
 #endif
 #if defined(_DERIVATE)
 gm_Vn2_n4=(((((2*Beta_T2))*(1+(Lambda*BP(n3,n4)))*H1)+((((2*Beta_T2)*(BP(n2,n4)-Vto_T2))*(1+(Lambda*BP(n3,n4))))*H1_Vn2_n4))+((((((Beta_T2*(1+(Lambda*BP(n3,n4))))*(d10_pow0*1.0))*B*H1)+((((Beta_T2*(1+(Lambda*BP(n3,n4))))*d00_pow0)*B)*H1_Vn2_n4))*(1+(B*(BP(n2,n4)-Vto_T2)))-((((Beta_T2*(1+(Lambda*BP(n3,n4))))*d00_pow0)*B)*H1)*(B))/(1+(B*(BP(n2,n4)-Vto_T2)))/(1+(B*(BP(n2,n4)-Vto_T2)))));
@@ -1719,11 +1736,11 @@ thermal_pwr=((((((8*1.3806503e-23)*T2)*gm)/3)*(((1+An)+(An*An))/(1+An)))*Gdsnoi)
 else
 {
 {
-double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2)
-double m00_pow(d00_pow1,(1+(B*(BP(n2,n4)-Vto_T2))),2)
+double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
+double m00_pow(d00_pow1,(1+(B*(BP(n2,n4)-Vto_T2))),2.0)
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2)
-double m10_pow(d10_pow1,d00_pow1,(1+(B*(BP(n2,n4)-Vto_T2))),2)
+double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),2.0)
+double m10_pow(d10_pow1,d00_pow1,(1+(B*(BP(n2,n4)-Vto_T2))),2.0)
 #endif
 #if defined(_DERIVATE)
 gm_Vn2_n4=(((((2*Beta_T2))*(1+(Lambda*BP(n3,n4)))*(1+(B*(BP(n2,n4)-Vto_T2)))-(((2*Beta_T2)*(BP(n2,n4)-Vto_T2))*(1+(Lambda*BP(n3,n4))))*(B))/(1+(B*(BP(n2,n4)-Vto_T2)))/(1+(B*(BP(n2,n4)-Vto_T2))))+((((Beta_T2*(1+(Lambda*BP(n3,n4))))*(d10_pow0*1.0))*B*d00_pow1-(((Beta_T2*(1+(Lambda*BP(n3,n4))))*d00_pow0)*B)*(d10_pow1*(B)))/d00_pow1/d00_pow1));
@@ -1752,17 +1769,17 @@ flicker_pwr=(Kf*d00_pow0);
 _save_flickernoise2(n3,n4,flicker_pwr,1.0,"flicker");
 }
 if
-((LEVEL==4))
+(LEVEL==4)
 {
 if
-((BP(n3,n4)<(3/Alpha)))
+(BP(n3,n4)<(3/Alpha))
 {
 {
 double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),Qp)
-double m00_pow(d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3)
+double m00_pow(d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3.0)
 #if defined(_DERIVATE)
 double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),Qp)
-double m10_pow(d10_pow1,d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3)
+double m10_pow(d10_pow1,d00_pow1,(1-((Alpha*BP(n3,n4))/3)),3.0)
 #endif
 #if defined(_DERIVATE)
 Ids1_Vn2_n4=(Beta_T2*(d10_pow0*1.0))*(1-d00_pow1);
@@ -1772,10 +1789,10 @@ Ids1=((Beta_T2*d00_pow0)*(1-d00_pow1));
 }
 {
 double m00_pow(d00_pow0,(BP(n2,n4)-Vto_T2),(Qp-1))
-double m00_pow(d00_pow1,((Alpha*BP(n3,n4))/3),3)
+double m00_pow(d00_pow1,((Alpha*BP(n3,n4))/3),3.0)
 #if defined(_DERIVATE)
 double m10_pow(d10_pow0,d00_pow0,(BP(n2,n4)-Vto_T2),(Qp-1))
-double m10_pow(d10_pow1,d00_pow1,((Alpha*BP(n3,n4))/3),3)
+double m10_pow(d10_pow1,d00_pow1,((Alpha*BP(n3,n4))/3),3.0)
 #endif
 #if defined(_DERIVATE)
 gm1_Vn2_n4=((Qp*Beta_T2)*(d10_pow0*1.0))*(1-(1-d00_pow1));
@@ -1849,17 +1866,17 @@ flicker_pwr=(Kf*d00_pow0);
 _save_flickernoise2(n3,n4,flicker_pwr,1.0,"flicker");
 }
 if
-((LEVEL==5))
+(LEVEL==5)
 {
 if
-((BP(n3,n4)<(3/Alpha)))
+(BP(n3,n4)<(3/Alpha))
 {
 #if defined(_DERIVATE)
 Nst_Vn3_n4=(Nd);
 #endif
 Nst=(Ng+(Nd*BP(n3,n4)));
 if
-((Nst<1.0))
+(Nst<1.0)
 {
 #if defined(_DERIVATE)
 Nst_Vn3_n4=0.0;
@@ -1920,9 +1937,9 @@ gm1_Vn3_n4=((((Ids1_Vn3_n4*Vg-Ids1*Vg_Vn3_n4)/Vg/Vg)*Qp*(d00_exp0+1)-((Ids1/Vg)*
 gm1=(((Ids1/Vg)*Qp)/(d00_exp0+1));
 }
 {
-double m00_pow(d00_pow0,(1+((Delta*BP(n3,n4))*Ids1)),2)
+double m00_pow(d00_pow0,(1+((Delta*BP(n3,n4))*Ids1)),2.0)
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(1+((Delta*BP(n3,n4))*Ids1)),2)
+double m10_pow(d10_pow0,d00_pow0,(1+((Delta*BP(n3,n4))*Ids1)),2.0)
 #endif
 #if defined(_DERIVATE)
 gm_Vn2_n4=((gm1_Vn2_n4*d00_pow0-gm1*(d10_pow0*((Delta*BP(n3,n4))*Ids1_Vn2_n4)))/d00_pow0/d00_pow0);
@@ -1948,7 +1965,7 @@ Nst_Vn3_n4=(Nd);
 #endif
 Nst=(Ng+(Nd*BP(n3,n4)));
 if
-((Nst<1.0))
+(Nst<1.0)
 {
 #if defined(_DERIVATE)
 Nst_Vn3_n4=0.0;
@@ -2009,9 +2026,9 @@ gm1_Vn3_n4=((((Ids1_Vn3_n4*Vg-Ids1*Vg_Vn3_n4)/Vg/Vg)*Qp*(d00_exp0+1)-((Ids1/Vg)*
 gm1=(((Ids1/Vg)*Qp)/(d00_exp0+1));
 }
 {
-double m00_pow(d00_pow0,(1+((Delta*BP(n3,n4))*Ids1)),2)
+double m00_pow(d00_pow0,(1+((Delta*BP(n3,n4))*Ids1)),2.0)
 #if defined(_DERIVATE)
-double m10_pow(d10_pow0,d00_pow0,(1+((Delta*BP(n3,n4))*Ids1)),2)
+double m10_pow(d10_pow0,d00_pow0,(1+((Delta*BP(n3,n4))*Ids1)),2.0)
 #endif
 #if defined(_DERIVATE)
 gm_Vn2_n4=((gm1_Vn2_n4*d00_pow0-gm1*(d10_pow0*((Delta*BP(n3,n4))*Ids1_Vn2_n4)))/d00_pow0/d00_pow0);
@@ -2054,8 +2071,8 @@ _save_whitenoise2(n4,Source,((Area*fourkt)/Rs_T2),"thermal");
 void MESFET::calcDC (void)
 {
   // evaluate Verilog code
-  initVerilog ();		
-  calcVerilog ();		
+  initVerilog ();
+  calcVerilog ();
 
   // fill right hand side and static jacobian
   for (int i1 = 0; i1 < 7; i1++) {
@@ -2103,7 +2120,7 @@ matrix MESFET::calcMatrixY (nr_double_t frequency)
 
   for (int i1 = 0; i1 < 7; i1++) {
     for (int i2 = 0; i2 < 7; i2++) {
-      y (i1,i2) = rect (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
+      y (i1,i2) = nr_complex_t (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
     }
   }
 
@@ -2119,7 +2136,7 @@ void MESFET::initSP (void)
 /* Perform S-parameter calculations. */
 void MESFET::calcSP (nr_double_t frequency)
 {
-  setMatrixS (ytos (calcMatrixY (frequency)));   
+  setMatrixS (ytos (calcMatrixY (frequency)));
 }
 
 /* Initialization of transient analysis. */
@@ -2183,7 +2200,7 @@ void MESFET::calcTR (nr_double_t)
     if (_caps[i1][i1][i3][i4] != 0.0)
       transientCapacitanceC2V (i1, i3, i4, _caps[i1][i1][i3][i4], BP(i3,i4));
   } } }
-     
+
   // charge: 1-node, voltage: 1-node
   for (i1 = 0; i1 < 7; i1++) {
   for (i3 = 0; i3 < 7; i3++) {
@@ -2249,3 +2266,4 @@ void MESFET::calcHB (int)
 }
 
 #include "MESFET.defs.h"
+
