@@ -5,12 +5,17 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  */
 
+#if HAVE_CONFIG_H
+# include <config.h>
+#endif
+
 #include <stdio.h>
 #include "binarytogrey4bit.analogfunction.h"
-#include <math.h>
+#include <cmath>
+
 
 /* math functions and appropriate derivatives */
 inline double _cos(double arg)             { return  cos(arg); }
@@ -31,8 +36,13 @@ inline double _asin(double arg)            { return  asin(arg); }
 inline double _d0_asin(double arg)         { return (+1.0/sqrt(1-arg*arg)); }
 inline double _atan(double arg)            { return  atan(arg); }
 inline double _d0_atan(double arg)         { return (+1.0/(1+arg*arg)); }
+inline double _acosh(double arg)           { return  acosh(arg); }
+inline double _d0_acosh(double arg)        { return (1.0/(sqrt(arg-1)*sqrt(arg+1))); }
+inline double _asinh(double arg)           { return  asinh(arg); }
+inline double _d0_asinh(double arg)        { return (1.0/(sqrt(arg*arg+1))); }
 inline double _atanh(double arg)           { return  atanh(arg); }
 inline double _d0_atanh(double arg)        { return (+1.0/(1-arg*arg)); }
+
 inline double _logE(double arg)            { return  log(arg); }
 inline double _d0_logE(double arg)         { return (1.0/arg); }
 inline double _log10(double arg)           { return  log10(arg); }
@@ -41,15 +51,22 @@ inline double _exp(double arg)             { return  exp(arg); }
 inline double _d0_exp(double arg)          { return exp(arg); }
 inline double _sqrt(double arg)            { return  sqrt(arg); }
 inline double _d0_sqrt(double arg)         { return (1.0/sqrt(arg)/2.0); }
-inline double _abs(double arg)             { return  fabs(arg); }
+
+inline double _abs(double arg)             { return std::abs(arg); }
 inline double _d0_abs(double arg)          { return (((arg)>=0)?(+1.0):(-1.0)); }
+
 inline int _floor(double arg)              { return  floor(arg); }
 inline int _d0_floor(double)               { return (1.0); }
 
+inline int _ceil(double arg)               { return  ceil(arg); }
+
 inline double _hypot(double x,double y)    { return sqrt((x)*(x)+(y)*(y)); }
 inline double _d0_hypot(double x,double y) { return (x)/sqrt((x)*(x)+(y)*(y)); }
 inline double _d1_hypot(double x,double y) { return (y)/sqrt((x)*(x)+(y)*(y)); }
 
+inline double _atan2(double x,double y)    { return atan2(x,y); }
+// TODO atan2 derivatives?
+
 inline double _max(double x,double y)      { return ((x)>(y))?(x):(y); }
 inline double _d0_max(double x,double y)   { return ((x)>(y))?1.0:0.0; }
 inline double _d1_max(double x,double y)   { return ((x)>(y))?0.0:1.0; }
