@@ -5,7 +5,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  */
 
 #if HAVE_CONFIG_H
@@ -171,26 +171,7 @@
 	cy (n1,n1) += pwr*pow(_freq,-exp)/kB/T0;
 
 // derivative helper macros
-#define m00_hypot(v00,x,y)      v00 = xhypot(x,y);
-#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
-#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
-#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
-#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
-#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
-#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
-#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
-#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
-#define m00_pow(v00,x,y)        v00 = pow(x,y);
-#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
-#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
-
-#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
-#define m10_div(v10,v00,vv,x,y)
-#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
-
-#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
-#define m00_add(v00,x,y)        double v00=(x)+(y);
-
+// transcendental LRM p. 59
 #define m00_cos(v00,x)          v00 = cos(x);
 #define m10_cos(v10,v00,x)      v10 = (-sin(x));
 #define m00_sin(v00,x)          v00 = sin(x);
@@ -209,33 +190,68 @@
 #define m10_asin(v10,v00,x)     v10 = (+1.0/sqrt(1-x*x));
 #define m00_atan(v00,x)         v00 = atan(x);
 #define m10_atan(v10,v00,x)     v10 = (+1.0/(1+x*x));
+#define m00_hypot(v00,x,y)      v00 = sqrt((x)*(x)+(y)*(y));
+#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
+#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
+#define m00_atan2(v00,x,y)      v00 = atan2(x,y);
+// TODO atan2 derivatives ?
+#define m00_acosh(v00,x)        v00 = acosh(x);
+#define m10_acosh(v10,v00,x)    v10 = (1.0/(sqrt(x-1)*sqrt(x+1)));
+#define m00_asinh(v00,x)        v00 = asinh(x);
+#define m10_asinh(v10,v00,x)    v10 = (1.0/(sqrt(x*x+1)));
 #define m00_atanh(v00,x)        v00 = atanh(x);
-#define m10_atanh(v10,v00,x)    v10 = (+1.0/(1-x*x));
+#define m10_atanh(v10,v00,x)    v10 = (1.0/(1-x*x));
+
+
+// standard functions LRM p.58
 #define m00_logE(v00,x)         v00 = log(x);
 #define m10_logE(v10,v00,x)     v10 = (1.0/x);
 #define m00_log10(v00,x)        v00 = log10(x);
 #define m10_log10(v10,v00,x)    v10 = (1.0/x/M_LN10);
-#define m00_sqrt(v00,x)         v00 = sqrt(x);
-#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
-#define m00_fabs(v00,x)         v00 = fabs(x);
-#define m10_fabs(v10,v00,x)     v10 = (((x)>=0)?(+1.0):(-1.0));
-
 #define m00_exp(v00,x)          v00 = exp(x);
 #define m10_exp(v10,v00,x)      v10 = v00;
-
-#define m00_abs(v00)            ((v00)<(0)?(-(v00)):(v00))
+#define m00_sqrt(v00,x)         v00 = sqrt(x);
+#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
+#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
+#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
+#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
+#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
+#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
+#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
+#define m00_pow(v00,x,y)        v00 = pow(x,y);
+#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
+#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
+#define m00_abs(v00,x)          v00 = ((x)<(0)?(-(x)):(x));
+#define m10_abs(v10,v00,x)      v10 = (((x)>=0)?(+1.0):(-1.0));
 #define m00_floor(v00,x)        v00 = floor(x);
+#define m10_floor(v10,v00,x)    v10 = 1.0;
+
+#define m00_ceil(v00,x)         v00 = ceil(x);
+// TODO ceil derivative, needed?
+
+// analog operator, LRM p.61
 #define m00_limexp(v00,x)       v00 = ((x)<80.0?exp(x):exp(80.0)*(x-79.0));
 #define m10_limexp(v10,v00,x)   v10 = ((x)<80.0?(v00):exp(80.0));
 
+// analog kernel parameter system functions, LRM p.215
+#define m00_vt(x)               (kBoverQ*(x))
+#define m10_vt(x)               (kBoverQ)
+
+// extra functions (?)
+#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
+#define m10_div(v10,v00,vv,x,y)
+#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
+#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
+#define m00_add(v00,x,y)        double v00=(x)+(y);
+
+// second derivatives
 #define m20_logE(v00)           (-1.0/v00/v00)
 #define m20_exp(v00)            exp(v00)
 #define m20_limexp(v00)         ((v00)<80.0?exp(v00):0.0)
 #define m20_sqrt(v00)           (-0.25/(v00)/sqrt(v00))
-#define m20_fabs(v00)           0.0
+#define m20_abs(v00)           0.0
 #define m20_pow(x,y)            ((y)*((y)-1.0)*pow(x,y)/(x)/(x))
-#define m00_vt(x)               (kBoverQ*(x))
-#define m10_vt(x)               (kBoverQ)
+
 
 // simulator specific definitions
 #define _modelname              "mod_amp"
@@ -244,10 +260,11 @@
 #define _param_given(p)		(isPropertyGiven(p)?1:0)
 
 
-// $vt and $vt() functions 
+// $vt and $vt() functions
 #define _vt_nom                 (kBoverQ*_circuit_temp)
 
-using namespace device;
+using namespace qucs::device;
+using qucs::matrix;
 
 /* Device constructor. */
 mod_amp::mod_amp() : circuit (14)
@@ -507,7 +524,7 @@ _load_static_residual1(n11,NP(n11));
 _load_static_jacobian1(n11,n11,1.0);
 #endif
 if
-((NP(n11)>Slewratepositive))
+(NP(n11)>Slewratepositive)
 {
 _load_static_residual1(n12,(-Slewratepositive));
 #if defined(_DERIVATE)
@@ -516,7 +533,7 @@ _load_static_residual1(n12,(-Slewratepositive));
 else
 {
 if
-((NP(n11)<(-Slewratenegative)))
+(NP(n11)<(-Slewratenegative))
 {
 _load_static_residual1(n12,Slewratenegative);
 #if defined(_DERIVATE)
@@ -563,7 +580,7 @@ _load_dynamic_jacobian1(n5,n5,(CP2));
 #endif
 #endif
 if
-((BP(n2,out_p)>=ILMAX))
+(BP(n2,out_p)>=ILMAX)
 {
 _load_static_residual1(n4,(-NP(n5)));
 #if defined(_DERIVATE)
@@ -582,7 +599,7 @@ _load_static_jacobian1(n4,n4,1.0);
 else
 {
 if
-((BP(n2,out_p)<=(-ILMAX)))
+(BP(n2,out_p)<=(-ILMAX))
 {
 _load_static_residual1(n4,(-NP(n5)));
 #if defined(_DERIVATE)
@@ -619,7 +636,7 @@ _load_static_residual2(n2,out_p,BP(n2,out_p));
 _load_static_jacobian4(n2,out_p,n2,out_p,1.0);
 #endif
 if
-((NP(out_p)>VLIMP))
+(NP(out_p)>VLIMP)
 {
 _load_static_residual1(out_p,((-10.0)*VLIMP));
 #if defined(_DERIVATE)
@@ -632,7 +649,7 @@ _load_static_jacobian1(out_p,out_p,(10.0));
 else
 {
 if
-((NP(out_p)<VLIMN))
+(NP(out_p)<VLIMN)
 {
 _load_static_residual1(out_p,((-10.0)*VLIMN));
 #if defined(_DERIVATE)
@@ -655,8 +672,8 @@ _load_static_jacobian1(out_p,out_p,(10.0));
 void mod_amp::calcDC (void)
 {
   // evaluate Verilog code
-  initVerilog ();		
-  calcVerilog ();		
+  initVerilog ();
+  calcVerilog ();
 
   // fill right hand side and static jacobian
   for (int i1 = 0; i1 < 14; i1++) {
@@ -704,7 +721,7 @@ matrix mod_amp::calcMatrixY (nr_double_t frequency)
 
   for (int i1 = 0; i1 < 14; i1++) {
     for (int i2 = 0; i2 < 14; i2++) {
-      y (i1,i2) = rect (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
+      y (i1,i2) = nr_complex_t (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
     }
   }
 
@@ -720,7 +737,7 @@ void mod_amp::initSP (void)
 /* Perform S-parameter calculations. */
 void mod_amp::calcSP (nr_double_t frequency)
 {
-  setMatrixS (ytos (calcMatrixY (frequency)));   
+  setMatrixS (ytos (calcMatrixY (frequency)));
 }
 
 /* Initialization of transient analysis. */
@@ -784,7 +801,7 @@ void mod_amp::calcTR (nr_double_t)
     if (_caps[i1][i1][i3][i4] != 0.0)
       transientCapacitanceC2V (i1, i3, i4, _caps[i1][i1][i3][i4], BP(i3,i4));
   } } }
-     
+
   // charge: 1-node, voltage: 1-node
   for (i1 = 0; i1 < 14; i1++) {
   for (i3 = 0; i3 < 14; i3++) {
@@ -845,3 +862,4 @@ void mod_amp::calcHB (int)
 }
 
 #include "mod_amp.defs.h"
+
