@@ -5,7 +5,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  */
 
 #if HAVE_CONFIG_H
@@ -166,26 +166,7 @@
 	cy (n1,n1) += pwr*pow(_freq,-exp)/kB/T0;
 
 // derivative helper macros
-#define m00_hypot(v00,x,y)      v00 = xhypot(x,y);
-#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
-#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
-#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
-#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
-#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
-#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
-#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
-#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
-#define m00_pow(v00,x,y)        v00 = pow(x,y);
-#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
-#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
-
-#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
-#define m10_div(v10,v00,vv,x,y)
-#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
-
-#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
-#define m00_add(v00,x,y)        double v00=(x)+(y);
-
+// transcendental LRM p. 59
 #define m00_cos(v00,x)          v00 = cos(x);
 #define m10_cos(v10,v00,x)      v10 = (-sin(x));
 #define m00_sin(v00,x)          v00 = sin(x);
@@ -204,33 +185,68 @@
 #define m10_asin(v10,v00,x)     v10 = (+1.0/sqrt(1-x*x));
 #define m00_atan(v00,x)         v00 = atan(x);
 #define m10_atan(v10,v00,x)     v10 = (+1.0/(1+x*x));
+#define m00_hypot(v00,x,y)      v00 = sqrt((x)*(x)+(y)*(y));
+#define m10_hypot(v10,v00,x,y)  v10 = (x)/(v00);
+#define m11_hypot(v11,v00,x,y)  v11 = (y)/(v00);
+#define m00_atan2(v00,x,y)      v00 = atan2(x,y);
+// TODO atan2 derivatives ?
+#define m00_acosh(v00,x)        v00 = acosh(x);
+#define m10_acosh(v10,v00,x)    v10 = (1.0/(sqrt(x-1)*sqrt(x+1)));
+#define m00_asinh(v00,x)        v00 = asinh(x);
+#define m10_asinh(v10,v00,x)    v10 = (1.0/(sqrt(x*x+1)));
 #define m00_atanh(v00,x)        v00 = atanh(x);
-#define m10_atanh(v10,v00,x)    v10 = (+1.0/(1-x*x));
+#define m10_atanh(v10,v00,x)    v10 = (1.0/(1-x*x));
+
+
+// standard functions LRM p.58
 #define m00_logE(v00,x)         v00 = log(x);
 #define m10_logE(v10,v00,x)     v10 = (1.0/x);
 #define m00_log10(v00,x)        v00 = log10(x);
 #define m10_log10(v10,v00,x)    v10 = (1.0/x/M_LN10);
-#define m00_sqrt(v00,x)         v00 = sqrt(x);
-#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
-#define m00_fabs(v00,x)         v00 = fabs(x);
-#define m10_fabs(v10,v00,x)     v10 = (((x)>=0)?(+1.0):(-1.0));
-
 #define m00_exp(v00,x)          v00 = exp(x);
 #define m10_exp(v10,v00,x)      v10 = v00;
-
-#define m00_abs(v00)            ((v00)<(0)?(-(v00)):(v00))
+#define m00_sqrt(v00,x)         v00 = sqrt(x);
+#define m10_sqrt(v10,v00,x)     v10 = (0.5/v00);
+#define m00_min(v00,x,y)        v00 = ((x)<(y))?(x):(y);
+#define m10_min(v10,v00,x,y)    v10 = ((x)<(y))?1.0:0.0;
+#define m11_min(v11,v00,x,y)    v11 = ((x)<(y))?0.0:1.0;
+#define m00_max(v00,x,y)        v00 = ((x)>(y))?(x):(y);
+#define m10_max(v10,v00,x,y)    v10 = ((x)>(y))?1.0:0.0;
+#define m11_max(v11,v00,x,y)    v11 = ((x)>(y))?0.0:1.0;
+#define m00_pow(v00,x,y)        v00 = pow(x,y);
+#define m10_pow(v10,v00,x,y)    v10 = (x==0.0)?0.0:(v00)*(y)/(x);
+#define m11_pow(v11,v00,x,y)    v11 = (x==0.0)?0.0:(log(x)*(v00));
+#define m00_abs(v00,x)          v00 = ((x)<(0)?(-(x)):(x));
+#define m10_abs(v10,v00,x)      v10 = (((x)>=0)?(+1.0):(-1.0));
 #define m00_floor(v00,x)        v00 = floor(x);
+#define m10_floor(v10,v00,x)    v10 = 1.0;
+
+#define m00_ceil(v00,x)         v00 = ceil(x);
+// TODO ceil derivative, needed?
+
+// analog operator, LRM p.61
 #define m00_limexp(v00,x)       v00 = ((x)<80.0?exp(x):exp(80.0)*(x-79.0));
 #define m10_limexp(v10,v00,x)   v10 = ((x)<80.0?(v00):exp(80.0));
 
+// analog kernel parameter system functions, LRM p.215
+#define m00_vt(x)               (kBoverQ*(x))
+#define m10_vt(x)               (kBoverQ)
+
+// extra functions (?)
+#define m00_div(v00,v10,x,y)    double v10=1/(y); double v00=(x)*v10;
+#define m10_div(v10,v00,vv,x,y)
+#define m11_div(v11,v00,vv,x,y) double v11 = -v00*vv;
+#define m00_mult(v00,v10,v11,x,y) double v10=(x); double v11=(y); double v00=v10*v11;
+#define m00_add(v00,x,y)        double v00=(x)+(y);
+
+// second derivatives
 #define m20_logE(v00)           (-1.0/v00/v00)
 #define m20_exp(v00)            exp(v00)
 #define m20_limexp(v00)         ((v00)<80.0?exp(v00):0.0)
 #define m20_sqrt(v00)           (-0.25/(v00)/sqrt(v00))
-#define m20_fabs(v00)           0.0
+#define m20_abs(v00)           0.0
 #define m20_pow(x,y)            ((y)*((y)-1.0)*pow(x,y)/(x)/(x))
-#define m00_vt(x)               (kBoverQ*(x))
-#define m10_vt(x)               (kBoverQ)
+
 
 // simulator specific definitions
 #define _modelname              "nigbt"
@@ -239,10 +255,11 @@
 #define _param_given(p)		(isPropertyGiven(p)?1:0)
 
 
-// $vt and $vt() functions 
+// $vt and $vt() functions
 #define _vt_nom                 (kBoverQ*_circuit_temp)
 
-using namespace device;
+using namespace qucs::device;
+using qucs::matrix;
 
 /* Device constructor. */
 nigbt::nigbt() : circuit (9)
@@ -792,7 +809,7 @@ Nscl=d00_max0;
 }
 #ifdef _DYNAMIC
 if
-((Vdg>(-Vtd)))
+(Vdg>(-Vtd))
 {
 #if defined(_DYNAMIC)
 {
@@ -823,7 +840,7 @@ Wgdj=0;
 #endif /* if (...) */
 #ifdef _DYNAMIC
 if
-((Vds>(-0.6)))
+(Vds>(-0.6))
 {
 #if defined(_DYNAMIC)
 {
@@ -845,7 +862,7 @@ Wdsj=0;
 }
 #endif /* if (...) */
 if
-((Vbc>(-0.6)))
+(Vbc>(-0.6))
 {
 {
 double m00_sqrt(d00_sqrt0,((((2*1.03594e-10)*(Vbc+0.6))/1.602176462e-19)/Nscl))
@@ -882,7 +899,7 @@ Qgs=(Cgs*Vgs);
 #endif
 #ifdef _DYNAMIC
 if
-((Vds>(-0.6)))
+(Vds>(-0.6))
 {
 #if defined(_DYNAMIC)
 {
@@ -943,7 +960,7 @@ Cgdj=((Agd*1.03594e-10)/(Wgdj+1e-20));
 #endif
 #ifdef _DYNAMIC
 if
-((Vds<(Vgs-Vtd)))
+(Vds<(Vgs-Vtd))
 {
 #if defined(_DYNAMIC)
 #if defined(_DERIVATE)
@@ -973,7 +990,7 @@ Mupc_Vvar_Mucinv_GND=(-1*Mucinv_Vvar_Mucinv_GND/((1/Mup)+Mucinv)/((1/Mup)+Mucinv
 #endif
 Mupc=(1/((1/Mup)+Mucinv));
 if
-((Ql>0))
+(Ql>0)
 {
 #if defined(_DERIVATE)
 Mueff_Vvar_Mucinv_GND=(Munc_Vvar_Mucinv_GND+(Mupc_Vvar_Mucinv_GND*Ql/(Ql+Qb)));
@@ -1032,7 +1049,7 @@ Tanh_Vvar_Mucinv_GND=WL2_Vvar_Mucinv_GND*d10_tanh0;
 Tanh=d00_tanh0;
 }
 if
-((WL>0))
+(WL>0)
 {
 #if defined(_DERIVATE)
 Plo_Vvar_Ql_GND=(Ql_Vvar_Ql_GND/(((1.602176462e-19*A)*L)*Tanh));
@@ -1053,7 +1070,7 @@ Plo_Vvar_Nsat_GND=0.0;
 Plo=0;
 }
 if
-((WL>0))
+(WL>0)
 {
 {
 double m00_sinh(d00_sinh0,WL2)
@@ -1082,7 +1099,7 @@ Deltap_Vvar_Nsat_GND=0.0;
 Deltap=0;
 }
 if
-((WL>0))
+(WL>0)
 {
 double Nl2;
 double Plo2;
@@ -1201,7 +1218,7 @@ Neff_Vvar_Ql_GND=0.0;
 Neff=0;
 }
 if
-((Ql<0))
+(Ql<0)
 {
 #if defined(_DERIVATE)
 Rb_Vvar_Ql_GND=0.0;
@@ -1237,7 +1254,7 @@ Vebd=((m00_vt(Tj)*d00_logE0)-((Dc/Munc)*d00_logE1));
 #endif
 #ifdef _DYNAMIC
 if
-((Ql<0))
+(Ql<0)
 {
 #if defined(_DYNAMIC)
 Vebq=Vebj;
@@ -1247,7 +1264,7 @@ else
 {
 #ifdef _DYNAMIC
 if
-((Ql>=Qbi))
+(Ql>=Qbi)
 {
 #if defined(_DYNAMIC)
 Vebq=Vebd;
@@ -1295,7 +1312,7 @@ M_Vvar_Nsat_GND=(-1*(-(d10_pow0*(-Vnrt*BVcbo_Vvar_Nsat_GND/BVcbo/BVcbo)))/(1-d00
 M=(1/(1-d00_pow0));
 }
 if
-((Rb>0))
+(Rb>0)
 {
 #if defined(_DERIVATE)
 It_VC_e=(Vae_VC_e/Rb);
@@ -1318,7 +1335,7 @@ It_Vvar_Mucinv_GND=0.0;
 It=(Vae/1e-6);
 }
 if
-((Veb>0))
+(Veb>0)
 {
 #if defined(_DERIVATE)
 Icss_VC_e=((1/(1+B))*It_VC_e);
@@ -1350,10 +1367,10 @@ Ic_Vvar_dVecdt_GND=(Ccer*dVecdt_Vvar_dVecdt_GND);
 #endif
 Ic=(Icss+(Ccer*dVecdt));
 if
-((Veb>0))
+(Veb>0)
 {
 if
-((Qb>0))
+(Qb>0)
 {
 #if defined(_DERIVATE)
 Ibss_Vvar_Ql_GND=((Ql_Vvar_Ql_GND/Tau)+((((((Ql_Vvar_Ql_GND*Ql)+(Ql*Ql_Vvar_Ql_GND))/Qb)/Qb)*4*Nscl*Nscl/Ni)/Ni)*Isne);
@@ -1382,7 +1399,7 @@ Ibss_Vvar_Nsat_GND=0.0;
 Ibss=0;
 }
 if
-((Vgs<Vt))
+(Vgs<Vt)
 {
 #if defined(_DERIVATE)
 Imos_Vb_E=0.0;
@@ -1393,7 +1410,7 @@ Imos=0;
 else
 {
 if
-((Vds>(Vth/Kf)))
+(Vds>(Vth/Kf))
 {
 #if defined(_DERIVATE)
 Imos_Vb_E=0.0;
@@ -1411,7 +1428,7 @@ Imos=(((Kf*KpT)*((Vth*Vds)-(((Kf*Vds)*Vds)/2)))/(1+(Theta*Vth)));
 }
 }
 if
-((Vbc>0))
+(Vbc>0)
 {
 {
 double m00_sqrt(d00_sqrt0,((((2*1.03594e-10)*Vbc)/1.602176462e-19)/Nscl))
@@ -1469,7 +1486,7 @@ Qmult_Ve_E=((M-1)*Qcer_Ve_E);
 Qmult=((M-1)*Qcer);
 #endif
 if
-((Deltap>0))
+(Deltap>0)
 {
 {
 double m00_pow(d00_pow0,Deltap,(2.0/3.0))
@@ -1649,8 +1666,8 @@ _load_dynamic_jacobian2p(var_dVecdt,e,E,(-Vec_Ve_E));
 void nigbt::calcDC (void)
 {
   // evaluate Verilog code
-  initVerilog ();		
-  calcVerilog ();		
+  initVerilog ();
+  calcVerilog ();
 
   // fill right hand side and static jacobian
   for (int i1 = 0; i1 < 9; i1++) {
@@ -1698,7 +1715,7 @@ matrix nigbt::calcMatrixY (nr_double_t frequency)
 
   for (int i1 = 0; i1 < 9; i1++) {
     for (int i2 = 0; i2 < 9; i2++) {
-      y (i1,i2) = rect (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
+      y (i1,i2) = nr_complex_t (_jstat[i1][i2], _jdyna[i1][i2] * 2 * M_PI * _freq);
     }
   }
 
@@ -1714,7 +1731,7 @@ void nigbt::initSP (void)
 /* Perform S-parameter calculations. */
 void nigbt::calcSP (nr_double_t frequency)
 {
-  setMatrixS (ytos (calcMatrixY (frequency)));   
+  setMatrixS (ytos (calcMatrixY (frequency)));
 }
 
 /* Initialization of transient analysis. */
@@ -1778,7 +1795,7 @@ void nigbt::calcTR (nr_double_t)
     if (_caps[i1][i1][i3][i4] != 0.0)
       transientCapacitanceC2V (i1, i3, i4, _caps[i1][i1][i3][i4], BP(i3,i4));
   } } }
-     
+
   // charge: 1-node, voltage: 1-node
   for (i1 = 0; i1 < 9; i1++) {
   for (i3 = 0; i3 < 9; i3++) {
@@ -1839,3 +1856,4 @@ void nigbt::calcHB (int)
 }
 
 #include "nigbt.defs.h"
+
