@@ -8,16 +8,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -34,6 +34,8 @@
 #include "interpolator.h"
 #include "vfile.h"
 
+using namespace qucs;
+
 // Constructor creates vfile object in memory.
 vfile::vfile () : circuit (2) {
   type = CIR_VFILE;
@@ -87,8 +89,8 @@ void vfile::prepare (void) {
 		  file);
 	return;
       }
-      vector * vs = data->getVariables();    // voltage
-      vector * ts = data->getDependencies(); // time
+      qucs::vector * vs = data->getVariables();    // voltage
+      qucs::vector * ts = data->getDependencies(); // time
       inter = new interpolator ();
       inter->rvectors (vs, ts);
       inter->prepare (interpolType, dataType);
