@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,6 +29,8 @@
 #include "component.h"
 #include "vrect.h"
 
+using namespace qucs;
+
 vrect::vrect () : circuit (2) {
   type = CIR_VRECT;
   setVSource (true);
@@ -80,7 +82,7 @@ void vrect::calcTR (nr_double_t t) {
 
   if (t > td) { // after delay
     t = t - td;
-    t = t - (th + tl) * floor (t / (th + tl));
+    t = t - (th + tl) * qucs::floor (t / (th + tl));
     if (t < tr) { // rising edge
       ut = + u / tr * t;
     }
