@@ -8,16 +8,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -30,7 +30,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
+#include <cmath>
 #include <assert.h>
 #include <float.h>
 #include <ctype.h>
@@ -358,7 +358,7 @@ vcd_create_dataset (struct vcd_vardef * var) {
   // go through all VCD sets
   for (vs = vcd_sets; vs; vs = vs->next) {
     found = 0;
-    // through all variables in the set 
+    // through all variables in the set
     for (vv = vs->variables; vv; vv = vv->next) {
       if (!strcmp (vv->code, var->code)) {
 	// found the variable in the set
