@@ -7,7 +7,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -45,6 +45,9 @@
 #include "csv_producer.h"
 #include "touchstone_producer.h"
 #include "matlab_producer.h"
+#include "dataset.h"
+
+using namespace qucs;
 
 /* structure defining a conversion */
 struct actionset_t {
