@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,76 +26,84 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_VCD_TOKENS_VCD_H_INCLUDED
+# define YY_VCD_TOKENS_VCD_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int vcd_debug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     t_END = 258,
-     t_COMMENT = 259,
-     t_DATE = 260,
-     t_ENDDEFINITIONS = 261,
-     t_SCOPE = 262,
-     t_TIMESCALE = 263,
-     t_UPSCOPE = 264,
-     t_VAR = 265,
-     t_VERSION = 266,
-     t_DUMPALL = 267,
-     t_DUMPOFF = 268,
-     t_DUMPON = 269,
-     t_DUMPVARS = 270,
-     s_MODULE = 271,
-     s_TASK = 272,
-     s_FUNCTION = 273,
-     s_FORK = 274,
-     s_BEGIN = 275,
-     ONE = 276,
-     B = 277,
-     Z = 278,
-     ZERO = 279,
-     HASHMARK = 280,
-     X = 281,
-     R = 282,
-     TEN = 283,
-     HUNDRET = 284,
-     PICO = 285,
-     MICRO = 286,
-     NANO = 287,
-     FEMTO = 288,
-     SECOND = 289,
-     MILLI = 290,
-     EVENT = 291,
-     INTEGER = 292,
-     PARAMETER = 293,
-     REAL = 294,
-     REG = 295,
-     SUPPLY0 = 296,
-     SUPPLY1 = 297,
-     TIME = 298,
-     TRI = 299,
-     TRIAND = 300,
-     TRIOR = 301,
-     TRIREG = 302,
-     TRI0 = 303,
-     TRI1 = 304,
-     WAND = 305,
-     WIRE = 306,
-     WOR = 307,
-     Real = 308,
-     Binary = 309,
-     PositiveInteger = 310,
-     PositiveHugeInteger = 311,
-     Identifier = 312,
-     IdentifierCode = 313,
-     Reference = 314,
-     InvalidCharacter = 315
-   };
+  enum yytokentype
+  {
+    t_END = 258,
+    t_COMMENT = 259,
+    t_DATE = 260,
+    t_ENDDEFINITIONS = 261,
+    t_SCOPE = 262,
+    t_TIMESCALE = 263,
+    t_UPSCOPE = 264,
+    t_VAR = 265,
+    t_VERSION = 266,
+    t_DUMPALL = 267,
+    t_DUMPOFF = 268,
+    t_DUMPON = 269,
+    t_DUMPVARS = 270,
+    s_MODULE = 271,
+    s_TASK = 272,
+    s_FUNCTION = 273,
+    s_FORK = 274,
+    s_BEGIN = 275,
+    ONE = 276,
+    B = 277,
+    Z = 278,
+    ZERO = 279,
+    HASHMARK = 280,
+    X = 281,
+    R = 282,
+    TEN = 283,
+    HUNDRET = 284,
+    PICO = 285,
+    MICRO = 286,
+    NANO = 287,
+    FEMTO = 288,
+    SECOND = 289,
+    MILLI = 290,
+    EVENT = 291,
+    INTEGER = 292,
+    PARAMETER = 293,
+    REAL = 294,
+    REG = 295,
+    SUPPLY0 = 296,
+    SUPPLY1 = 297,
+    TIME = 298,
+    TRI = 299,
+    TRIAND = 300,
+    TRIOR = 301,
+    TRIREG = 302,
+    TRI0 = 303,
+    TRI1 = 304,
+    WAND = 305,
+    WIRE = 306,
+    WOR = 307,
+    Real = 308,
+    Binary = 309,
+    PositiveInteger = 310,
+    PositiveHugeInteger = 311,
+    Identifier = 312,
+    IdentifierCode = 313,
+    Reference = 314,
+    InvalidCharacter = 315
+  };
 #endif
 /* Tokens.  */
 #define t_END 258
@@ -157,15 +165,12 @@
 #define Reference 314
 #define InvalidCharacter 315
 
-
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-
-/* Line 2068 of yacc.c  */
-#line 79 "parse_vcd.y"
+#line 79 "parse_vcd.y" /* yacc.c:1915  */
 
   char * ident;
   char * value;
@@ -179,16 +184,15 @@ typedef union YYSTYPE
   struct vcd_changeset * changeset;
   struct vcd_range * range;
 
-
-
-/* Line 2068 of yacc.c  */
-#line 186 "tokens_vcd.h"
-} YYSTYPE;
+#line 188 "tokens_vcd.h" /* yacc.c:1915  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE vcd_lval;
 
+int vcd_parse (void);
 
+#endif /* !YY_VCD_TOKENS_VCD_H_INCLUDED  */
