@@ -7,30 +7,47 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
  */
 
+/*! \file environment.h
+ * \brief The environment class definition.
+ *
+ * Contains the environment class definition.
+ */
+
+#include "equation.h"
+
 #ifndef __ENVIRONMENT_H__
 #define __ENVIRONMENT_H__
 
+namespace qucs {
+
 class variable;
 class checker;
 class solver;
 class dataset;
 template <class type_t> class ptrlist;
 
+/*! \class environment
+ * \brief Houses the settings for netlist evaluation.
+ *
+ * The environment class holds information and pointers to the
+ * classes and methods used to evaluate a netlist.
+ *
+ */
 class environment
 {
  public:
@@ -62,7 +79,7 @@ class environment
   void equationSolver (void);
 
   // subcircuit specific
-  vector getVector (char *);
+  qucs::vector getVector (char *);
   void setDoubleConstant (char *, nr_double_t);
   nr_double_t getDoubleConstant (char *);
   void setDouble (char *, nr_double_t);
@@ -90,4 +107,6 @@ class environment
   struct definition_t * defs;
 };
 
+} // namespace qucs
+
 #endif /* __ENVIRONMENT_H__ */
