@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -25,7 +25,7 @@
 #ifndef __EQNSYS_H__
 #define __EQNSYS_H__
 
-// Definition of equation system solving algorithms.
+//! Definition of equation system solving algorithms.
 enum algo_type {
   ALGO_INVERSE                    = 0x0001,
   ALGO_GAUSS                      = 0x0002,
@@ -47,7 +47,7 @@ enum algo_type {
   ALGO_QR_DECOMPOSITION_2         = 0x2000,
 };
 
-// Definition of pivoting strategies.
+//! Definition of pivoting strategies.
 enum pivot_type {
   PIVOT_NONE    = 0x01,
   PIVOT_PARTIAL = 0x02,
@@ -57,6 +57,8 @@ enum pivot_type {
 #include "tvector.h"
 #include "tmatrix.h"
 
+namespace qucs {
+
 template <class nr_type_t>
 class eqnsys
 {
@@ -130,6 +132,8 @@ class eqnsys
   void preconditioner (void);
 };
 
+} // namespace qucs
+
 #include "eqnsys.cpp"
 
 #endif /* __EQNSYS_H__ */
