@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -31,6 +31,10 @@
 #include "matrix.h"
 #include "matvec.h"
 
+struct definition_t;
+
+namespace qucs {
+
 class strlist;
 class dataset;
 class range;
@@ -84,15 +88,15 @@ public:
   int getType (void) { return type; }
   int getTag (void) { return tag; }
   void setType (int tag) { type = tag; }
-  constant * getResult (void) { return res; } 
+  constant * getResult (void) { return res; }
   nr_double_t getResultDouble (void);
   nr_complex_t getResultComplex (void);
-  vector getResultVector (void);
+  qucs::vector getResultVector (void);
   void setResult (constant *);
   char * getInstance (void);
   void setInstance (const char *);
   void applyInstance (void);
-  constant * calculate (void);    
+  constant * calculate (void);
   strlist * collectDependencies (void);
   strlist * collectDataDependencies (void);
 
@@ -105,7 +109,7 @@ public:
   virtual node * differentiate (char *) { return this; }
   virtual node * recreate (void) { return new node (*this); }
   virtual void replace (char *, char *) { }
-  
+
 public:
   int duplicate;
   int cycle;
@@ -164,7 +168,7 @@ public:
   union {
     nr_double_t d;
     nr_complex_t * c;
-    vector * v;
+    qucs::vector * v;
     matrix * m;
     matvec * mv;
     char chr;
@@ -216,7 +220,7 @@ public:
   void mul (assignment *);
   void add (assignment *);
   void mulref (assignment *);
-  
+
 public:
   char * result;
   node * body;
@@ -302,7 +306,7 @@ public:
   bool containsVariable (char *);
   nr_double_t getDouble (char *);
   void setDouble (char *, nr_double_t);
-  vector getVector (char *);
+  qucs::vector getVector (char *);
   void setDefinitions (struct definition_t * d) { defs = d; }
   struct definition_t * getDefinitions (void) { return defs; }
   node * findProperty (char *);
@@ -326,10 +330,10 @@ public:
   void setData (dataset * d) { data = d; }
   dataset * getDataset (void) { return data; }
   void evaluate (void);
-  node * addEquationData (vector *, bool ref = false);
+  node * addEquationData (qucs::vector *, bool ref = false);
   node * addEquationData (matvec *);
-  node * addGeneratedEquation (vector *, const char *);
-  vector * dataVector (node *);
+  node * addGeneratedEquation (qucs::vector *, const char *);
+  qucs::vector * dataVector (node *);
   void checkinDataset (void);
   void checkoutDataset (void);
   static int dataSize (constant *);
@@ -337,8 +341,8 @@ public:
   int getDataSize (char *);
   strlist * collectDataDependencies (node *);
   int dataSize (strlist *);
-  vector * getDataVector (char *);
-  void findMatrixVectors (vector *);
+  qucs::vector * getDataVector (char *);
+  void findMatrixVectors (qucs::vector *);
   char * isMatrixVector (char *, int&, int&);
   int findEquationResult (node *);
   int solve (dataset *);
@@ -352,6 +356,8 @@ private:
   checker * checkee;
 };
 
-} /* namespace */
+} /* namespace eqn */
+
+} // namespace qucs
 
 #endif /* __EQUATION_H__ */
