@@ -8,16 +8,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -26,6 +26,8 @@
 #ifndef __EVALUATE_H__
 #define __EVALUATE_H__
 
+namespace qucs {
+
 namespace eqn {
 
 class constant;
@@ -778,6 +780,13 @@ public:
 
   static constant * vector_x (constant *);
   static constant * matrix_x (constant *);
+
+  static constant * assert_d (constant *);
+  static constant * assert_v (constant *);
+  static constant * assert_b (constant *);
+  static constant * bugon_d (constant *);
+  static constant * bugon_v (constant *);
+  static constant * bugon_b (constant *);
 };
 
 // Type of application function.
@@ -795,6 +804,8 @@ struct application_t
 
 extern struct application_t applications[];
 
-} /* namespace */
+} /* namespace eqn */
+
+} // namespace qucs
 
 #endif /* __EVALUATE_H__ */
