@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,7 +29,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <math.h>
+#include <cmath>
 
 #include "consts.h"
 #include "object.h"
@@ -40,6 +40,8 @@
 // Helper macro.
 #define Swap(a,b) { nr_double_t t; t = a; a = b; b = t; }
 
+namespace qucs {
+
 using namespace fourier;
 
 /* The function performs a 1-dimensional fast fourier transformation.
@@ -176,7 +178,7 @@ vector fourier::fft_1d (vector var, int isign) {
   // store transformed data items in result vector
   vector res = vector (size);
   for (n = i = 0; i < size; i++, n += 2) {
-    res (i) = rect (data[n], data[n+1]);
+    res (i) = nr_complex_t (data[n], data[n+1]);
     if (isign < 0) res (i) /= size;
   }
 
@@ -215,7 +217,7 @@ vector fourier::dft_1d (vector var, int isign) {
     nr_double_t th = - isign * 2 * M_PI * n / len;
     nr_complex_t val = 0;
     for (k = 0; k < len; k++)
-      val += var (k) * polar (1.0, th * k);
+      val += var (k) * std::polar (1.0, th * k);
     res (n) = isign < 0 ? val / (nr_double_t) len : val;
   }
   return res;
@@ -241,12 +243,12 @@ void fourier::_idft_1d (nr_double_t * data, int len) {
    each dimension. */
 void fourier::_fft_nd (nr_double_t * data, int len[], int nd, int isign) {
 
- int i, i1, i2, i3, i2rev, i3rev, ip1, ip2, ip3, ifp1, ifp2; 
- int ibit, k1, k2, n, np, nr, nt; 
- 
+ int i, i1, i2, i3, i2rev, i3rev, ip1, ip2, ip3, ifp1, ifp2;
+ int ibit, k1, k2, n, np, nr, nt;
+
  // compute total number of complex values
  for (nt = 1, i = 0; i < nd; i++) nt *= len[i];
- 
+
  // main loop over the dimensions
  for (np = 1, i = nd - 1; i >= 0; i--) {
    n = len[i];
@@ -254,7 +256,7 @@ void fourier::_fft_nd (nr_double_t * data, int len[], int nd, int isign) {
    ip1 = np << 1;
    ip2 = ip1 * n;
    ip3 = ip2 * nr;
- 
+
    // bit-reversal method
    for (i2rev = 1, i2 = 1; i2 <= ip2; i2 += ip1) {
      if (i2 < i2rev) {
@@ -275,7 +277,7 @@ void fourier::_fft_nd (nr_double_t * data, int len[], int nd, int isign) {
    }
 
    // Danielson-Lanzcos algorithm
-   nr_double_t ti, tr, wt, th, wr, wi, wpi, wpr; 
+   nr_double_t ti, tr, wt, th, wr, wi, wpi, wpr;
    ifp1 = ip1;
    while (ifp1 < ip2) {
      ifp2 = ifp1 << 1;
@@ -324,3 +326,4 @@ vector fourier::fftshift (vector var) {
   return res;
 }
 
+} // namespace qucs
