@@ -8,16 +8,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -27,7 +27,7 @@
 #define __APPLICATIONS_H__
 
 // Array containing all kinds of applications.
-struct application_t eqn::applications[] = {
+struct application_t qucs::eqn::applications[] = {
   { "+", TAG_DOUBLE,  NULL, 1, { TAG_DOUBLE  } },
   { "+", TAG_COMPLEX, NULL, 1, { TAG_COMPLEX } },
   { "+", TAG_VECTOR,  NULL, 1, { TAG_VECTOR  } },
@@ -1035,6 +1035,14 @@ struct application_t eqn::applications[] = {
   { "vector", TAG_VECTOR, NULL, -1, { TAG_UNKNOWN } },
   { "matrix", TAG_MATRIX, NULL, -1, { TAG_UNKNOWN } },
 
+  { "assert",  TAG_BOOLEAN, NULL, 1,   { TAG_BOOLEAN } },
+  { "assert",  TAG_BOOLEAN, NULL, 1,   { TAG_DOUBLE } },
+  { "assert",  TAG_BOOLEAN, NULL, 1,   { TAG_VECTOR } },
+
+  { "bugon",  TAG_BOOLEAN, NULL, 1,   { TAG_BOOLEAN } },
+  { "bugon",  TAG_BOOLEAN, NULL, 1,   { TAG_DOUBLE } },
+  { "bugon",  TAG_BOOLEAN, NULL, 1,   { TAG_VECTOR } },
+
   { NULL, 0, NULL, 0, { 0 } /* end of list */ }
 };
 
