@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -28,6 +28,8 @@
 #include "ptrlist.h"
 #include "tvector.h"
 
+namespace qucs {
+
 class vector;
 class strlist;
 class circuit;
@@ -62,7 +64,7 @@ class hbsolver : public analysis
   void calcConstantCurrent (void);
   nr_complex_t excitationZ (tvector<nr_complex_t> *, circuit *, int);
   void finalSolution (void);
-  void fillMatrixNonLinear (tmatrix<nr_complex_t> *, tmatrix<nr_complex_t> *, 
+  void fillMatrixNonLinear (tmatrix<nr_complex_t> *, tmatrix<nr_complex_t> *,
 			    tvector<nr_complex_t> *, tvector<nr_complex_t> *,
 			    tvector<nr_complex_t> *, tvector<nr_complex_t> *,
 			    int);
@@ -133,4 +135,6 @@ class hbsolver : public analysis
   int nbanodes;
 };
 
+} // namespace qucs
+
 #endif /* __HBSOLVER_H__ */
