@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -29,6 +29,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+#include <cmath>
 
 #include "precision.h"
 #include "tvector.h"
@@ -36,6 +37,8 @@
 #include "spline.h"
 #include "history.h"
 
+namespace qucs {
+
 // Constructor creates an unnamed instance of the history class.
 history::history () {
   age = 0;
@@ -62,6 +65,30 @@ void history::append (nr_double_t val) {
   if (values != t) drop ();
 }
 
+/* This function drops the most recent n values in the history. */
+void history::truncate (int n)
+{
+  t->truncate (n);
+  values->truncate (n);
+}
+
+/* This function drops those values in the history which are newer
+   than the specified time. */
+void history::truncate (nr_double_t tcut)
+{
+    int i;
+    int ts = t->getSize ();
+
+    for (i = leftidx (); i < ts; i++)
+    {
+      if (t->get (i) > tcut)
+      {
+        break;
+      }
+    }
+    truncate (ts - i);
+}
+
 // Returns left-most valid index into the time value vector.
 int history::leftidx (void) {
   int ts = t->getSize ();
@@ -175,3 +202,41 @@ int history::seek (nr_double_t tval, int l, int r, nr_double_t& diff,
   }
   return idx;
 }
+
+nr_double_t history::getTfromidx (int idx)
+{
+  if (t == NULL)
+  {
+    return 0;
+  }
+  else
+  {
+    return t->get(idx);
+  }
+}
+
+nr_double_t history::getValfromidx (int idx)
+{
+  if (t == NULL)
+  {
+    return 0;
+  }
+  else
+  {
+    return values->get(idx);
+  }
+}
+
+int history::getSize (void)
+{
+  if (t == NULL)
+  {
+    return 0;
+  }
+  else
+  {
+    return t->getSize ();
+  }
+}
+
+} // namespace qucs
