@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -25,6 +25,8 @@
 #ifndef __HISTORY_H__
 #define __HISTORY_H__
 
+namespace qucs {
+
 class history
 {
  public:
@@ -35,11 +37,15 @@ class history
   ~history ();
 
   void append (nr_double_t);
+  void truncate (int);
+  void truncate (nr_double_t);
   void setAge (nr_double_t a) { age = a; }
   nr_double_t getAge (void) { return age; }
+  int getSize (void);
   nr_double_t duration (void);
   nr_double_t last (void);
   nr_double_t first (void);
+
   int leftidx (void);
   int unused (void);
   void drop (void);
@@ -50,6 +56,8 @@ class history
   nr_double_t interpol (nr_double_t, int, bool);
   nr_double_t nearest (nr_double_t, bool interpolate = true);
   int seek (nr_double_t, int, int, nr_double_t&, int);
+  nr_double_t getTfromidx (int);
+  nr_double_t getValfromidx (int);
 
  private:
   bool sign;
@@ -58,4 +66,6 @@ class history
   tvector<nr_double_t> * t;
 };
 
+} // namespace qucs
+
 #endif /* __HISTORY_H__ */
