@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -45,6 +45,8 @@
 #include "equation.h"
 #include "module.h"
 
+namespace qucs {
+
 // Global variables.
 int netlist_check = 0;
 
@@ -58,7 +60,7 @@ input::input () : object () {
 // Constructor creates an named instance of the input class.
 input::input (char * file) : object (file) {
   if ((fd = fopen (file, "r")) == NULL) {
-    logprint (LOG_ERROR, "cannot open file `%s': %s\n", 
+    logprint (LOG_ERROR, "cannot open file `%s': %s, using stdin instead\n",
 	      file, strerror (errno));
     fd = stdin;
   }
@@ -85,6 +87,7 @@ int input::netlist (net * netlist) {
   subnet = netlist;
 
   logprint (LOG_STATUS, "parsing netlist...\n");
+
   if (netlist_parse () != 0)
     return -1;
 
@@ -109,8 +112,8 @@ int input::netlist (net * netlist) {
 
 /* The little helper function creates a vector given by the list of
    values. */
-vector * input::createVector (struct value_t * values) {
-  vector * v = new vector ();
+qucs::vector * input::createVector (struct value_t * values) {
+  qucs::vector * v = new qucs::vector ();
   for (; values != NULL; values = values->next) v->add (values->value);
   return v;
 }
@@ -159,7 +162,7 @@ void input::factory (void) {
 	    if (pairs->value->var) {
 	      // add list sweeps and constants to the properties
 	      variable * v = new variable (pairs->key);
-	      constant * c = new constant (TAG_VECTOR);
+	      eqn::constant * c = new eqn::constant (eqn::TAG_VECTOR);
 	      c->v = createVector (pairs->value);
 	      v->setConstant (c);
 	      a->addProperty (pairs->key, v);
@@ -252,8 +255,8 @@ void input::factory (void) {
 	if (pairs->value == NULL) {
 	  // zero-length value lists
 	  variable * v = new variable (pairs->key);
-	  constant * c = new constant (TAG_VECTOR);
-	  c->v = new vector ();
+	  eqn::constant * c = new eqn::constant (eqn::TAG_VECTOR);
+	  c->v = new qucs::vector ();
 	  v->setConstant (c);
 	  o->addProperty (pairs->key, v);
 	}
@@ -274,7 +277,7 @@ void input::factory (void) {
 	  if (pairs->value->var) {
 	    // add value lists to the properties
 	    variable * v = new variable (pairs->key);
-	    constant * c = new constant (TAG_VECTOR);
+	    eqn::constant * c = new eqn::constant (eqn::TAG_VECTOR);
 	    c->v = createVector (pairs->value);
 	    v->setConstant (c);
 	    o->addProperty (pairs->key, v);
@@ -322,7 +325,7 @@ void input::assignDefaultProperties (object * obj, struct define_t * def) {
   }
 }
 
-// The function creates components specified by the type of component. 
+// The function creates components specified by the type of component.
 circuit * input::createCircuit (char * type) {
   module * m;
   if ((m = module::modules.get (type)) != NULL)
@@ -350,3 +353,5 @@ substrate * input::createSubstrate (char * type) {
   logprint (LOG_ERROR, "no such substrate type `%s'\n", type);
   return NULL;
 }
+
+} // namespace qucs
