@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -25,7 +25,43 @@
 #ifndef __MATVEC_H__
 #define __MATVEC_H__
 
+namespace qucs {
+
 class matrix;
+class matvec;
+
+// forward declarations
+matvec transpose (matvec);
+matvec conj      (matvec);
+vector det       (matvec);
+matvec inverse   (matvec);
+matvec sqr       (matvec);
+matvec pow       (matvec, int);
+matvec pow       (matvec, vector);
+matvec twoport   (matvec, char, char);
+matvec real      (matvec);
+matvec imag      (matvec);
+matvec abs       (matvec);
+matvec dB        (matvec);
+matvec arg       (matvec);
+matvec adjoint   (matvec);
+vector rollet    (matvec);
+vector b1        (matvec);
+matvec stos (matvec, nr_complex_t, nr_complex_t z0 = 50.0);
+matvec stos (matvec, nr_double_t, nr_double_t z0 = 50.0);
+matvec stos (matvec, vector, nr_complex_t z0 = 50.0);
+matvec stos (matvec, nr_complex_t, vector);
+matvec stos (matvec, vector, vector);
+matvec stoz (matvec, nr_complex_t z0 = 50.0);
+matvec stoz (matvec, vector);
+matvec ztos (matvec, nr_complex_t z0 = 50.0);
+matvec ztos (matvec, vector);
+matvec ztoy (matvec);
+matvec stoy (matvec, nr_complex_t z0 = 50.0);
+matvec stoy (matvec, vector);
+matvec ytos (matvec, nr_complex_t z0 = 50.0);
+matvec ytos (matvec, vector);
+matvec ytoz (matvec);
 
 class matvec
 {
@@ -39,15 +75,15 @@ class matvec
   int getRows (void) { return rows; }
   void setName (const char *);
   char * getName (void);
-  void set (vector, int, int);
+  void set (qucs::vector, int, int);
   void set (matrix, int);
-  vector get (int, int);
+  qucs::vector get (int, int);
   matrix get (int);
   static char * createMatrixString (const char *, int, int);
   static char * createMatrixString (char, int, int);
   static char * isMatrixVector (char *, int&, int&);
-  static matvec * getMatrixVector (vector *, char *);
-  static void getMatrixVectorSize (vector *, char *, int&, int&, int&);
+  static matvec * getMatrixVector (qucs::vector *, char *);
+  static void getMatrixVectorSize (qucs::vector *, char *, int&, int&, int&);
 
   // operator functions
   friend matvec operator + (matvec, matvec);
@@ -57,8 +93,8 @@ class matvec
   friend matvec operator + (nr_complex_t, matvec);
   friend matvec operator + (matvec, nr_double_t);
   friend matvec operator + (nr_double_t, matvec);
-  friend matvec operator + (matvec, vector);
-  friend matvec operator + (vector, matvec);
+  friend matvec operator + (matvec, qucs::vector);
+  friend matvec operator + (qucs::vector, matvec);
   friend matvec operator - (matvec, matvec);
   friend matvec operator - (matvec, matrix);
   friend matvec operator - (matrix, matvec);
@@ -66,13 +102,13 @@ class matvec
   friend matvec operator - (nr_complex_t, matvec);
   friend matvec operator - (matvec, nr_double_t);
   friend matvec operator - (nr_double_t, matvec);
-  friend matvec operator - (matvec, vector);
-  friend matvec operator - (vector, matvec);
+  friend matvec operator - (matvec, qucs::vector);
+  friend matvec operator - (qucs::vector, matvec);
   friend matvec operator / (matvec, nr_complex_t);
   friend matvec operator / (matvec, nr_double_t);
-  friend matvec operator / (matvec, vector);
-  friend matvec operator * (matvec, vector);
-  friend matvec operator * (vector, matvec);
+  friend matvec operator / (matvec, qucs::vector);
+  friend matvec operator * (matvec, qucs::vector);
+  friend matvec operator * (qucs::vector, matvec);
   friend matvec operator * (matvec, nr_complex_t);
   friend matvec operator * (nr_complex_t, matvec);
   friend matvec operator * (matvec, nr_double_t);
@@ -89,10 +125,11 @@ class matvec
   // other operations
   friend matvec transpose (matvec);
   friend matvec conj      (matvec);
-  friend vector det       (matvec);
+  friend qucs::vector det       (matvec);
   friend matvec inverse   (matvec);
+  friend matvec sqr       (matvec);
   friend matvec pow       (matvec, int);
-  friend matvec pow       (matvec, vector);
+  friend matvec pow       (matvec, qucs::vector);
   friend matvec twoport   (matvec, char, char);
   friend matvec real      (matvec);
   friend matvec imag      (matvec);
@@ -100,23 +137,23 @@ class matvec
   friend matvec dB        (matvec);
   friend matvec arg       (matvec);
   friend matvec adjoint   (matvec);
-  friend vector rollet    (matvec);
-  friend vector b1        (matvec);
+  friend qucs::vector rollet    (matvec);
+  friend qucs::vector b1        (matvec);
 
-  friend matvec stos (matvec, nr_complex_t, nr_complex_t z0 = 50.0);
-  friend matvec stos (matvec, nr_double_t, nr_double_t z0 = 50.0);
-  friend matvec stos (matvec, vector, nr_complex_t z0 = 50.0);
-  friend matvec stos (matvec, nr_complex_t, vector);
-  friend matvec stos (matvec, vector, vector);
-  friend matvec stoz (matvec, nr_complex_t z0 = 50.0);
-  friend matvec stoz (matvec, vector);
-  friend matvec ztos (matvec, nr_complex_t z0 = 50.0);
-  friend matvec ztos (matvec, vector);
+  friend matvec stos (matvec, nr_complex_t, nr_complex_t);
+  friend matvec stos (matvec, nr_double_t, nr_double_t);
+  friend matvec stos (matvec, qucs::vector, nr_complex_t);
+  friend matvec stos (matvec, nr_complex_t, qucs::vector);
+  friend matvec stos (matvec, qucs::vector, qucs::vector);
+  friend matvec stoz (matvec, nr_complex_t);
+  friend matvec stoz (matvec, qucs::vector);
+  friend matvec ztos (matvec, nr_complex_t);
+  friend matvec ztos (matvec, qucs::vector);
   friend matvec ztoy (matvec);
-  friend matvec stoy (matvec, nr_complex_t z0 = 50.0);
-  friend matvec stoy (matvec, vector);
-  friend matvec ytos (matvec, nr_complex_t z0 = 50.0);
-  friend matvec ytos (matvec, vector);
+  friend matvec stoy (matvec, nr_complex_t);
+  friend matvec stoy (matvec, qucs::vector);
+  friend matvec ytos (matvec, nr_complex_t);
+  friend matvec ytos (matvec, qucs::vector);
   friend matvec ytoz (matvec);
 
  private:
@@ -127,4 +164,6 @@ class matvec
   matrix * data;
 };
 
+} // namespace qucs
+
 #endif /* __MATVEC_H__ */
