@@ -25,10 +25,12 @@
 #ifndef __NASOLVER_H__
 #define __NASOLVER_H__
 
+#include "qucs_typedefs.h"
 #include "tvector.h"
 #include "tmatrix.h"
 #include "eqnsys.h"
 #include "nasolution.h"
+#include "analysis.h"
 
 // Convergence helper definitions.
 #define CONV_None            0
@@ -38,6 +40,8 @@
 #define CONV_GMinStepping    4
 #define CONV_SourceStepping  5
 
+namespace qucs {
+
 class analysis;
 class circuit;
 class nodelist;
@@ -60,7 +64,7 @@ public:
     void solve_post (void);
     void setDescription (const char * n) { desc = n; }
     const char * getDescription (void) { return desc; }
-    void saveResults (const char *, const char *, int, vector * f = NULL);
+    void saveResults (const char *, const char *, int, qucs::vector * f = NULL);
     typedef void (* calculate_func_t) (nasolver<nr_type_t> *);
     void setCalculation (calculate_func_t f) { calculate_func = f; }
     void calculate (void)
@@ -69,6 +73,12 @@ public:
     }
     const char * getHelperDescription (void);
 
+    //interface convenience functions
+    /// Returns the number of node voltages in the circuit.
+    int getN ();
+    /// Returns the number of branch currents in the circuit.
+    int getM ();
+
 protected:
     void restartNR (void);
     void savePreviousIteration (void);
@@ -85,6 +95,7 @@ protected:
     void createMatrix (void);
     void storeSolution (void);
     void recallSolution (void);
+    int  checkConvergence (void);
 
 private:
     void assignVoltageSources (void);
@@ -103,7 +114,6 @@ private:
     char * createOP (const char *, const char *);
     void saveNodeVoltages (void);
     void saveBranchCurrents (void);
-    int  checkConvergence (void);
     nr_type_t MatValX (nr_complex_t, nr_complex_t *);
     nr_type_t MatValX (nr_complex_t, nr_double_t *);
 
@@ -120,9 +130,10 @@ protected:
     int eqnAlgo;
     int updateMatrix;
     nr_double_t gMin, srcFactor;
+    const char * desc;
+    nodelist * nlist;
 
 private:
-    nodelist * nlist;
     eqnsys<nr_type_t> * eqns;
     nr_double_t reltol;
     nr_double_t abstol;
@@ -130,10 +141,12 @@ private:
     nasolution<nr_type_t> solution;
 
 private:
-    const char * desc;
+
     calculate_func_t calculate_func;
 };
 
+} // namespace qucs
+
 #include "nasolver.cpp"
 
 #endif /* __NASOLVER_H__ */
