@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -39,6 +39,8 @@
 #include "net.h"
 #include "nodelist.h"
 
+namespace qucs {
+
 // Constructor creates an instance of the nodelist class.
 nodelist::nodelist () {
   root = last = NULL;
@@ -198,16 +200,16 @@ int nodelist::length (void) {
 int nodelist::contains (char * str) {
   int res = 0;
   for (struct nodelist_t * n = root; n != NULL; n = n->next) {
-    if (n->name != NULL && str != NULL && !strcmp (n->name, str)) 
+    if (n->name != NULL && str != NULL && !strcmp (n->name, str))
       res++;
   }
   return res;
 }
 
-// Returns the node number of the give node name.
+// Returns the node number of the given node name.
 int nodelist::getNodeNr (char * str) {
   for (struct nodelist_t * n = root; n != NULL; n = n->next) {
-    if (n->name != NULL && str != NULL && !strcmp (n->name, str)) 
+    if (n->name != NULL && str != NULL && !strcmp (n->name, str))
       return n->n;
   }
   return -1;
@@ -498,3 +500,5 @@ void nodelist::print (void) {
   }
 }
 #endif /* DEBUG */
+
+} // namespace qucs
