@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -27,7 +27,9 @@
 
 #include "pair.h"
 
-class operatingpoint : public ::pair
+namespace qucs {
+
+class operatingpoint : public qucs::pair
 {
  public:
   operatingpoint ();
@@ -37,4 +39,6 @@ class operatingpoint : public ::pair
   ~operatingpoint () { }
 };
 
+} // namespace qucs
+
 #endif /* __OPERATINGPOINT_H__ */
