@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -40,6 +40,8 @@
 #include "tridiag.h"
 #include "spline.h"
 
+namespace qucs {
+
 // Constructor creates an instance of the spline class.
 spline::spline () {
   x = f0 = f1 = f2 = f3 = NULL;
@@ -320,3 +322,5 @@ spline::~spline () {
   if (f2) delete[] f2;
   if (f3) delete[] f3;
 }
+
+} // namespace qucs
