@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -25,6 +25,8 @@
 #ifndef __SWEEP_H__
 #define __SWEEP_H__
 
+namespace qucs {
+
 enum sweep_type {
   SWEEP_UNKNOWN = -1, // not yet defined
   SWEEP_CONSTANT,     // constant value
@@ -102,4 +104,6 @@ class lstsweep : public sweep
   void create (int);
 };
 
+} // namespace qucs
+
 #endif /* __SWEEP_H__ */
