@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,42 +26,50 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_NETLIST_TOKENS_NETLIST_H_INCLUDED
+# define YY_NETLIST_TOKENS_NETLIST_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int netlist_debug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     InvalidCharacter = 258,
-     Identifier = 259,
-     Assign = 260,
-     ScaleOrUnit = 261,
-     Eol = 262,
-     Eqn = 263,
-     DefSub = 264,
-     EndSub = 265,
-     REAL = 266,
-     IMAG = 267,
-     COMPLEX = 268,
-     Character = 269,
-     STRING = 270,
-     Or = 271,
-     And = 272,
-     Equal = 273,
-     NotEqual = 274,
-     GreaterOrEqual = 275,
-     LessOrEqual = 276,
-     Greater = 277,
-     Less = 278,
-     Not = 279,
-     NEG = 280,
-     POS = 281
-   };
+  enum yytokentype
+  {
+    InvalidCharacter = 258,
+    Identifier = 259,
+    Assign = 260,
+    ScaleOrUnit = 261,
+    Eol = 262,
+    Eqn = 263,
+    DefSub = 264,
+    EndSub = 265,
+    REAL = 266,
+    IMAG = 267,
+    COMPLEX = 268,
+    Character = 269,
+    STRING = 270,
+    Or = 271,
+    And = 272,
+    NotEqual = 273,
+    Equal = 274,
+    Less = 275,
+    Greater = 276,
+    LessOrEqual = 277,
+    GreaterOrEqual = 278,
+    Not = 279,
+    NEG = 280,
+    POS = 281
+  };
 #endif
 /* Tokens.  */
 #define InvalidCharacter 258
@@ -79,25 +87,22 @@
 #define STRING 270
 #define Or 271
 #define And 272
-#define Equal 273
-#define NotEqual 274
-#define GreaterOrEqual 275
-#define LessOrEqual 276
-#define Greater 277
-#define Less 278
+#define NotEqual 273
+#define Equal 274
+#define Less 275
+#define Greater 276
+#define LessOrEqual 277
+#define GreaterOrEqual 278
 #define Not 279
 #define NEG 280
 #define POS 281
 
-
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-
-/* Line 2068 of yacc.c  */
-#line 76 "parse_netlist.y"
+#line 78 "parse_netlist.y" /* yacc.c:1915  */
 
   char * ident;
   char * str;
@@ -112,22 +117,21 @@ typedef union YYSTYPE
     double r;
     double i;
   } c;
-  eqn::node * eqn;
-  eqn::constant * con;
-  eqn::reference * ref;
-  eqn::application * app;
-  eqn::assignment * assign;
+  qucs::eqn::node * eqn;
+  qucs::eqn::constant * con;
+  qucs::eqn::reference * ref;
+  qucs::eqn::application * app;
+  qucs::eqn::assignment * assign;
 
-
-
-/* Line 2068 of yacc.c  */
-#line 125 "tokens_netlist.h"
-} YYSTYPE;
+#line 127 "tokens_netlist.h" /* yacc.c:1915  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE netlist_lval;
 
+int netlist_parse (void);
 
+#endif /* !YY_NETLIST_TOKENS_NETLIST_H_INCLUDED  */
