@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.5.  */
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,22 +26,30 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_TOUCHSTONE_TOKENS_TOUCHSTONE_H_INCLUDED
+# define YY_TOUCHSTONE_TOKENS_TOUCHSTONE_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int touchstone_debug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     InvalidCharacter = 258,
-     Float = 259,
-     Option = 260,
-     Eol = 261
-   };
+  enum yytokentype
+  {
+    InvalidCharacter = 258,
+    Float = 259,
+    Option = 260,
+    Eol = 261
+  };
 #endif
 /* Tokens.  */
 #define InvalidCharacter 258
@@ -49,31 +57,27 @@
 #define Option 260
 #define Eol 261
 
-
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-
-/* Line 2068 of yacc.c  */
-#line 57 "parse_touchstone.y"
+#line 59 "parse_touchstone.y" /* yacc.c:1915  */
 
   char * ident;
   double f;
-  vector * v;
-  strlist * list;
+  qucs::vector * v;
+  qucs::strlist * list;
 
-
-
-/* Line 2068 of yacc.c  */
-#line 71 "tokens_touchstone.h"
-} YYSTYPE;
+#line 73 "tokens_touchstone.h" /* yacc.c:1915  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE touchstone_lval;
 
+int touchstone_parse (void);
 
+#endif /* !YY_TOUCHSTONE_TOKENS_TOUCHSTONE_H_INCLUDED  */
