@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -45,6 +45,8 @@
 // Defines where the equivalent admittance coefficient is going to be stored.
 #define COEFF_G 0
 
+namespace qucs {
+
 using namespace transient;
 
 /* The function calculates the integration coefficient for numerical
@@ -99,7 +101,7 @@ void transient::calcCorrectorCoeff (int Method, int order,
       // right hand side vector
       b.set (1, -1 / delta[0]);
       // first row
-      for (c = 0; c < order + 1; c++) A.set (0, c, 1); 
+      for (c = 0; c < order + 1; c++) A.set (0, c, 1);
       nr_double_t f, a;
       for (f = 0, c = 0; c < order; c++) {
 	f += delta[c];
@@ -192,7 +194,7 @@ void transient::calcPredictorCoeff (int Method, int order,
       }
       e.passEquationSys (&A, &x, &b);
       e.solve ();
-      for (r = 0; r <= order; r++) coefficients[r] = x.get (r);      
+      for (r = 0; r <= order; r++) coefficients[r] = x.get (r);
     }
     break;
   case INTEGRATOR_ADAMSBASHFORD: // ADAMS-BASHFORD order 1 to 6
@@ -432,3 +434,5 @@ nr_double_t transient::getCorrectorError (int Method, int order) {
 nr_double_t transient::getPredictorError (int Method, int order) {
   return integration_types[Method].predErrorConstant[order - 1];
 }
+
+}
