@@ -7,16 +7,16 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this package; see the file COPYING.  If not, write to
  * the Free Software Foundation, Inc., 51 Franklin Street - Fifth Floor,
- * Boston, MA 02110-1301, USA.  
+ * Boston, MA 02110-1301, USA.
  *
  * $Id$
  *
@@ -25,6 +25,8 @@
 #ifndef __TRANSIENT_H__
 #define __TRANSIENT_H__
 
+namespace qucs {
+
 enum integrator_type {
   INTEGRATOR_UNKNOWN       = -1,
   INTEGRATOR_EULER         =  0,
@@ -57,6 +59,8 @@ namespace transient {
   nr_double_t getCorrectorError (int, int);
   nr_double_t getPredictorError (int, int);
 
-} // namespace
+} // namespace transient
+
+} // namespace qucs
 
 #endif /* __TRANSIENT_H__ */
