@@ -53,6 +53,11 @@
 #define dState 0 // delta T state
 #define sState 1 // solution state
 
+// Macro for the n-th state of the solution vector history.
+#define SOL(state) (solution[(int) getState (sState, (state))])
+
+namespace qucs {
+
 using namespace transient;
 
 // Constructor creates an unnamed instance of the trsolver class.
@@ -114,10 +119,6 @@ void trsolver::initSteps (void)
     swp = createSweep ("time");
 }
 
-// Macro for the n-th state of the solution vector history.
-#define SOL(state) (solution[(int) getState (sState, (state))])
-
-
 // Performs the initial DC analysis.
 int trsolver::dcAnalysis (void)
 {
@@ -412,7 +413,10 @@ void trsolver::initHistory (nr_double_t t)
         {
             c->applyHistory (tHistory);
             saveHistory (c);
-            if (c->getHistoryAge () > age) age = c->getHistoryAge ();
+            if (c->getHistoryAge () > age)
+            {
+                age = c->getHistoryAge ();
+            }
         }
     }
     // set maximum required age for all circuits
@@ -575,7 +579,11 @@ void trsolver::nextStates (void)
 {
     circuit * root = subnet->getRoot ();
     for (circuit * c = root; c != NULL; c = (circuit *) c->getNext ())
+    {
+        // for each circuit get the next state
         c->nextState ();
+    }
+
     *SOL (0) = *x; // save current solution
     nextState ();
     statSteps++;
@@ -849,11 +857,11 @@ void trsolver::initCircuitTR (circuit * c)
    (for the given timestamp) into the output dataset. */
 void trsolver::saveAllResults (nr_double_t time)
 {
-    vector * t;
+    qucs::vector * t;
     // add current frequency to the dependency of the output dataset
     if ((t = data->findDependency ("time")) == NULL)
     {
-        t = new vector ("time");
+      t = new qucs::vector ("time");
         data->addDependency (t);
     }
     if (runs == 1) t->add (time);
@@ -889,7 +897,7 @@ nr_double_t trsolver::checkDelta (void)
         }
 
         dif = x->get (r) - SOL(0)->get (r);
-        if (finite (dif) && dif != 0)
+        if (std::isfinite (dif) && dif != 0)
         {
             // use Milne' estimate for the local truncation error
             rel = MAX (fabs (x->get (r)), fabs (SOL(0)->get (r)));
@@ -953,3 +961,5 @@ PROP_OPT [] =
 };
 struct define_t trsolver::anadef =
     { "TR", 0, PROP_ACTION, PROP_NO_SUBSTRATE, PROP_LINEAR, PROP_DEF };
+
+} // namespace qucs
