@@ -28,6 +28,8 @@
 #include "nasolver.h"
 #include "states.h"
 
+namespace qucs {
+
 class sweep;
 class circuit;
 class history;
@@ -100,4 +102,6 @@ protected:
 
 };
 
+} // namespace qucs
+
 #endif /* __TRSOLVER_H__ */
