@@ -7,7 +7,7 @@
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2, or (at your option)
  * any later version.
- * 
+ *
  * This software is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
@@ -31,6 +31,9 @@
 #include <assert.h>
 #include <string.h>
 #include <time.h>
+#include <list>
+#include <iostream>
+#include <fstream>
 
 #include "logging.h"
 #include "precision.h"
@@ -53,7 +56,9 @@ using namespace qucs;
 
 int main (int argc, char ** argv) {
 
-  char * infile = NULL, * outfile = NULL;
+  char * infile = NULL;
+  char * outfile = NULL;
+  char * projPath = NULL;
   net * subnet;
   input * in;
   circuit * gnd;
@@ -61,6 +66,9 @@ int main (int argc, char ** argv) {
   environment * root;
   int listing = 0;
   int ret = 0;
+  int dynamicLoad = 0;
+
+  std::list<std::string> vamodules;
 
   loginit ();
   precinit ();
@@ -91,6 +99,11 @@ int main (int argc, char ** argv) {
 	"  -b, --bar      enable textual progress bar\n"
 	"  -g, --gui      special progress bar used by gui\n"
 	"  -c, --check    check the input netlist and exit\n"
+#if DEBUG
+    "  -l, --listing  emit C-code for available definitions\n"
+#endif
+    "  -p, --path     project path (or location of dynamic modules)\n"
+    "  -m, --module   list of dynamic loaded modules (base names separated by space)\n"
 	"\nReport bugs to <" PACKAGE_BUGREPORT ">.\n", argv[0]);
       return 0;
     }
@@ -113,6 +126,18 @@ int main (int argc, char ** argv) {
     else if (!strcmp (argv[i], "-l") || !strcmp (argv[i], "--listing")) {
       listing = 1;
     }
+    // \todo remove command arguments
+    else if (!strcmp (argv[i], "-p") || !strcmp (argv[i], "--path")) {
+      projPath = argv[++i];
+    }
+    else if (!strcmp (argv[i], "-m") || !strcmp (argv[i], "--module")) {
+      dynamicLoad = 1;
+    }
+    else {
+      if (dynamicLoad) {
+        vamodules.push_back(argv[i]);
+      }
+    }
   }
 
   // create static modules
@@ -126,6 +151,68 @@ int main (int argc, char ** argv) {
   }
 #endif /* DEBUG */
 
+  // look for dynamic libs, load and register them
+  // \todo, keep this way of loading or keep only annotated netlist?
+  if (dynamicLoad) {
+    module::registerDynamicModules (projPath, vamodules);
+  }
+
+  else { //no argument, look into netlist
+
+    std::string sLine = "";
+    std::ifstream file;
+
+    std::string projPathNet ="";
+    std::string projVaMoules = "";
+
+    file.open(infile);
+
+    while (!file.eof()) {
+        getline(file, sLine);
+
+        if (sLine.find("--path") != std::string::npos) {
+            std::cout << sLine << std::endl;
+
+            size_t pos = 0;
+            pos = sLine.find("=");
+            sLine.erase(0, pos + 1);
+            std::cout << sLine << std::endl;
+
+//            projPath =  const_cast<char*>(sLine.c_str());
+//            projPath = (char*)sLine.c_str();
+
+//            std::cout << "inside" << projPath << std::endl;
+
+            projPathNet = sLine;
+
+        }
+
+        if (sLine.find("--module") != std::string::npos) {
+            std::cout << sLine << std::endl;
+
+            size_t pos = 0;
+            pos = sLine.find("=");
+            sLine.erase(0, pos + 1);
+            //std::cout << sLine << std::endl;
+            projVaMoules = sLine;
+
+            // put module names into list
+            std::istringstream ss(sLine);
+            std::string token;
+
+            while(std::getline(ss, token, ' ')) {
+                std::cout << token << '\n';
+
+                vamodules.push_back(token);
+            }
+        }
+    }
+
+    module::registerDynamicModules ((char*)projPathNet.c_str(), vamodules);
+    file.close();
+  }
+
+
   // create root environment
   root = new environment ("root");
 
@@ -136,7 +223,7 @@ int main (int argc, char ** argv) {
   // pass root environment to netlist object and input
   subnet->setEnv (root);
   in->setEnv (root);
-  
+
   // get input netlist
   if (in->netlist (subnet) != 0) {
     if (netlist_check) {
@@ -172,9 +259,12 @@ int main (int argc, char ** argv) {
   delete out;
   delete root;
 
-  // delete modules
+  // delete static modules and dynamic modules
   module::unregisterModules ();
 
+  // close all the dynamic libs if any opened
+  module::closeDynamicLibs();
+
   netlist_destroy_env ();
   return ret;
 }
