@@ -21,16 +21,17 @@
 
 #include "helpdialog.h"
 
-#include <qlayout.h>
-#include <qhbox.h>
-#include <qpushbutton.h>
-#include <qtextedit.h>
+
+#include <QPushButton>
+#include <QVBoxLayout>
+#include <QHBoxLayout>
+#include <QTextEdit>
 
 
 HelpDialog::HelpDialog(QWidget *parent)
-                     : QDialog(parent, 0, false, Qt::WDestructiveClose)
+                     : QDialog(parent) //, 0, false, Qt::WDestructiveClose)
 {
-  setCaption("Qucs Filter Help");
+  setWindowTitle("Qucs Filter Help");
 
 
   // --------  set help text into dialog  ------------
@@ -49,25 +50,28 @@ HelpDialog::HelpDialog(QWidget *parent)
   // --------  create dialog widgets  ------------
   resize(250, 230);
 
-  vLayout = new QVBoxLayout(this);
+  vLayout = new QVBoxLayout();
 
-  Text = new QTextEdit(s, QString::null, this);
-  Text->setTextFormat(Qt::PlainText);
+  Text = new QTextEdit(s, this);
+  //Text->setTextFormat(Qt::PlainText);
   Text->setReadOnly(true);
-//  Text->setWordWrap(QTextEdit::NoWrap);
+  //Text->setWordWrap(QTextEdit::NoWrap);
   Text->setMinimumSize(200,200);
   vLayout->addWidget(Text);
 
-  QHBox *h = new QHBox(this);
-  vLayout->addWidget(h);
+  QHBoxLayout *h = new QHBoxLayout();
+  h->addLayout(vLayout);
 
-  h->setStretchFactor(new QWidget(h),5); // stretchable placeholder
+  h->addStretch(5);
 
-  QPushButton *ButtonClose = new QPushButton(tr("Close"), h);
+  QPushButton *ButtonClose = new QPushButton(tr("Close"));
+  h->addWidget(ButtonClose);
   connect(ButtonClose, SIGNAL(clicked()), SLOT(slotClose()));
   ButtonClose->setFocus();
 
-  h->setStretchFactor(new QWidget(h),5); // stretchable placeholder
+  h->addStretch(5);
+
+  setLayout(h);
 }
 
 HelpDialog::~HelpDialog()
