@@ -18,11 +18,9 @@
  ***************************************************************************/
 
 #include "htmldatafetcher.h"
-#include <qmime.h>
-#include <q3dragobject.h>
-//Added by qt3to4:
-#include <Q3TextStream>
-#include <Q3MimeSourceFactory>
+#include <QMimeData>
+#include <QTextStream>
+#include <QDebug>
 
 HtmlDataFetcher::HtmlDataFetcher()
 {
@@ -323,13 +321,12 @@ QStringList HtmlDataFetcher::fetchChapterTexts(const QString &indexFile)
     return retVal;
   }
 
-  const QMimeSource *source = Q3MimeSourceFactory::defaultFactory()->data(indexFile);
-  Q_ASSERT(source);
-  QString sourceText;
-  bool status = Q3TextDrag::decode(source,sourceText);
-  Q_ASSERT(status);
+  QTextCodec::setCodecForLocale(QTextCodec::codecForName("utf-8"));
+
+  QFile index(indexFile);
+  index.open(QIODevice::ReadOnly);
+  QTextStream str(&index);
 
-  Q3TextStream str(&sourceText,QIODevice::ReadOnly);
   QString txt;
   bool inText = false;//spans multiple lines
   while ( !str.atEnd() )
@@ -377,6 +374,7 @@ QStringList HtmlDataFetcher::fetchChapterTexts(const QString &indexFile)
       }
     }
   }
+  index.close();
   return retVal;
 }
 
@@ -390,7 +388,7 @@ QStringList HtmlDataFetcher::fetchLinksToFiles(const QString &indexFile)
     qWarning("HtmlDataFetcher::fetchLinksToFiles() : File open error");
     return QStringList();
   }
-  Q3TextStream str(&file);
+  QTextStream str(&file);
   QString line,link;
   int index = -1;
   int end = -1;
