@@ -21,19 +21,24 @@
 
 #include <stdlib.h>
 
-#include <qapplication.h>
-#include <qstring.h>
-#include <qtextcodec.h>
-#include <qtranslator.h>
-#include <qfile.h>
-#include <q3textstream.h>
-#include <qmessagebox.h>
-#include <qdir.h>
-#include <qfont.h>
-#include <qtextcodec.h>
+#include <QApplication>
+#include <QString>
+#include <QTextCodec>
+#include <QTranslator>
+#include <QFile>
+#include <QTextStream>
+#include <QMessageBox>
+#include <QDir>
+#include <QFont>
+#include <QTextCodec>
+#include <QDebug>
 
 #include "qucshelp.h"
 
+#ifdef _WIN32
+#include <Windows.h>  //for OutputDebugString
+#endif
+
 QDir QucsHelpDir; // directory to find helps files
 tQucsSettings QucsSettings; // application settings
 
@@ -47,7 +52,7 @@ bool loadSettings()
   if(!file.open(QIODevice::ReadOnly))
     result = false; // settings file doesn't exist
   else {
-    Q3TextStream stream(&file);
+    QTextStream stream(&file);
     QString Line, Setting;
     while(!stream.atEnd()) {
       Line = stream.readLine();
@@ -67,7 +72,7 @@ bool loadSettings()
   if(!file.open(QIODevice::ReadOnly))
     result = true; // qucs settings not necessary
   else {
-    Q3TextStream stream(&file);
+    QTextStream stream(&file);
     QString Line, Setting;
     while(!stream.atEnd()) {
       Line = stream.readLine();
@@ -102,7 +107,7 @@ bool saveApplSettings(QucsHelp *qucs)
   }
 
   QString Line;
-  Q3TextStream stream(&file);
+  QTextStream stream(&file);
 
   stream << "Settings file, Qucs Help System " PACKAGE_VERSION "\n"
 	 << "HelpWindow=" << qucs->x() << ',' << qucs->y() << ','
@@ -112,6 +117,39 @@ bool saveApplSettings(QucsHelp *qucs)
   return true;
 }
 
+/*!
+ * \brief qucsMessageOutput handles qDebug, qWarning, qCritical, qFatal.
+ * \param type Message type (Qt enum)
+ * \param msg Message
+ *
+ * The message handler is used to get control of the messages.
+ * Particulary on Windows, as the messages are sent to the debugger and do not
+ * show on the terminal. The handler could aslo be extended to create a log
+ * mechanism.
+ * <http://qt-project.org/doc/qt-4.8/debug.html#warning-and-debugging-messages>
+ * <http://qt-project.org/doc/qt-4.8/qtglobal.html#qInstallMsgHandler>
+ */
+void qucsMessageOutput(QtMsgType type, const char *msg)
+{
+  switch (type) {
+  case QtDebugMsg:
+    fprintf(stderr, "Debug: %s\n", msg);
+    break;
+  case QtWarningMsg:
+    fprintf(stderr, "Warning: %s\n", msg);
+    break;
+  case QtCriticalMsg:
+    fprintf(stderr, "Critical: %s\n", msg);
+    break;
+  case QtFatalMsg:
+    fprintf(stderr, "Fatal: %s\n", msg);
+    abort();
+  }
+
+#ifdef _WIN32
+  OutputDebugStringA(msg);
+#endif
+}
 
 // #########################################################################
 // ##########                                                     ##########
@@ -135,13 +173,10 @@ int main(int argc, char *argv[])
     QString QucsDirStr = QucsDir.canonicalPath ();
     QucsSettings.DocDir =
       QDir::convertSeparators (QucsDirStr + "/share/qucs/docs/");
-    QucsSettings.BitmapDir =
-      QDir::convertSeparators (QucsDirStr + "/share/qucs/bitmaps/");
     QucsSettings.LangDir =
       QDir::convertSeparators (QucsDirStr + "/share/qucs/lang/");
   } else {
     QucsSettings.DocDir = DOCDIR;
-    QucsSettings.BitmapDir = BITMAPDIR;
     QucsSettings.LangDir = LANGUAGEDIR;
   }
 
@@ -154,6 +189,7 @@ int main(int argc, char *argv[])
   QString locale = QucsSettings.Language;
   if(locale.isEmpty())
     locale = QTextCodec::locale();
+
   tor.load( QString("qucs_") + locale, QucsSettings.LangDir);
   a.installTranslator( &tor );
 
@@ -172,6 +208,8 @@ int main(int argc, char *argv[])
   QString Page;
   if(argc > 1) Page = argv[1];
 
+  qInstallMsgHandler(qucsMessageOutput);
+
   QucsHelp *qucs = new QucsHelp(Page);
   a.setMainWidget(qucs);
   qucs->resize(QucsSettings.dx, QucsSettings.dy); // size and position ...
