@@ -18,11 +18,12 @@
 #ifndef SEARCHDIALOG_H
 #define SEARCHDIALOG_H
 
-#include <qdialog.h>
+#include <QDialog>
+#include <QVBoxLayout>
+#include <QLineEdit>
+
+#include "qucslib.h"
 
-class QVBoxLayout;
-class QLineEdit;
-class QucsLib;
 
 
 class SearchDialog : public QDialog  {
