@@ -19,18 +19,17 @@
 # include <config.h>
 #endif
 
-#include <qlayout.h>
-#include <qhbox.h>
-#include <qpushbutton.h>
-#include <qtextedit.h>
+#include <QPushButton>
+#include <QTextEdit>
+#include <QVBoxLayout>
 
 #include "helpdialog.h"
 
 
 HelpDialog::HelpDialog(QWidget *parent)
-                     : QDialog(parent, 0, false, Qt::WDestructiveClose)
+                     : QDialog(parent) //, 0, false, Qt::WDestructiveClose)
 {
-  setCaption("QucsTranscalc "+tr("Help"));
+  setWindowTitle("QucsTranscalc "+tr("Help"));
 
   // --------  set help text into dialog  ------------
   QString s(tr("QucsTranscalc is an analysis and synthesis tool for "
@@ -50,8 +49,8 @@ HelpDialog::HelpDialog(QWidget *parent)
   vLayout->setMargin(3);
   vLayout->setSpacing(3);
 
-  Text = new QTextEdit(s, QString::null, this);
-  Text->setTextFormat(Qt::PlainText);
+  Text = new QTextEdit(s, this);
+  //Text->setTextFormat(Qt::PlainText);
   Text->setReadOnly(true);
   Text->setMinimumSize(300,200);
   vLayout->addWidget(Text);
