@@ -64,8 +64,6 @@
 #include "rectwaveguide.h"
 #include "c_microstrip.h"
 
-QDir QucsWorkDir;
-
 // Defines maximum number of entries in each property category.
 static const int TransMaxBox[MAX_TRANS_BOXES] = { 9, 1, 4, 3 };
 
@@ -257,7 +255,7 @@ QucsTranscalc::QucsTranscalc() {
   setCentralWidget(centralWidget);
   
   // set application icon
-  setWindowIcon(QPixmap(QucsSettings.BitmapDir + "big.qucs.xpm"));
+  setWindowIcon(QPixmap(":/bitmaps/big.qucs.xpm"));
   setWindowTitle("Qucs Transcalc " PACKAGE_VERSION);
 
   // create file menu
@@ -338,7 +336,7 @@ QucsTranscalc::QucsTranscalc() {
   connect(tranType, SIGNAL(activated(int)), SLOT(slotSelectType(int)));
   // setup transmission line picture
   pix = new QLabel (lineGroup);
-  pix->setPixmap(QPixmap(QucsSettings.BitmapDir+"microstrip.png"));
+  pix->setPixmap(QPixmap(":/bitmaps/microstrip.png"));
 
   QVBoxLayout *vfig = new QVBoxLayout();
   vfig->addWidget(tranType);
@@ -971,7 +969,7 @@ void QucsTranscalc::closeEvent(QCloseEvent *Event)
 
 void QucsTranscalc::slotSelectType (int Type)
 {
-  pix->setPixmap(QPixmap(QucsSettings.BitmapDir + QString(TransLineTypes[Type].bitmap)));
+  pix->setPixmap(QPixmap(":/bitmaps/" + QString(TransLineTypes[Type].bitmap)));
   setMode (Type);
   statusBar()->showMessage(tr("Ready."));
 }
@@ -1113,10 +1111,10 @@ void QucsTranscalc::slotFileLoad()
   statusBar()->showMessage(tr("Loading file..."));
   int _mode = 0;
   QString s = QFileDialog::getOpenFileName(this, tr("Enter a Filename"),
-                           QucsWorkDir.path(),
+                           QucsSettings.QucsWorkDir.path(),
                            tr("Transcalc File") + " (*.trc)");
   if (!s.isEmpty())  {
-    QucsWorkDir.setPath(QDir::cleanPath(s));
+    QucsSettings.QucsWorkDir.setPath(QDir::cleanPath(s));
     if (!loadFile (s, &_mode)) {
       QMessageBox::critical (this, tr("Error"),
                  tr("Cannot load file:")+" '"+s+"'!");
@@ -1132,10 +1130,10 @@ void QucsTranscalc::slotFileSave()
   statusBar()->showMessage(tr("Saving file..."));
 
   QString s = QFileDialog::getSaveFileName(this, tr("Enter a Filename"),
-                           QucsWorkDir.path(),
+                           QucsSettings.QucsWorkDir.path(),
                            tr("Transcalc File") + " (*.trc)");
   if (!s.isEmpty())  {
-    QucsWorkDir.setPath(QDir::cleanPath(s));
+    QucsSettings.QucsWorkDir.setPath(QDir::cleanPath(s));
     if (!saveFile (s)) {
       QMessageBox::critical (this, tr("Error"),
                  tr("Cannot save file:")+" '"+s+"'!");
@@ -1164,7 +1162,7 @@ void QucsTranscalc::setMode (QString _mode) {
 
 // Updates the combobox and pixmap for the current mode.
 void QucsTranscalc::updatePixmap (int _mode) {
-  pix->setPixmap(QPixmap(QucsSettings.BitmapDir + QString(TransLineTypes[_mode].bitmap)));
+  pix->setPixmap(QPixmap(":/bitmaps/" + QString(TransLineTypes[_mode].bitmap)));
   tranType->setCurrentIndex(_mode);
 }
 
