@@ -27,7 +27,7 @@
 #include <QLabel>
 #include <QCloseEvent>
 #include <QMainWindow>
-
+#include <QDir>
 
 class QComboBox;
 class QLineEdit;
@@ -64,7 +64,6 @@ class transline;
 struct tQucsSettings {
   int x, y, dx, dy;    // position and size of main window
   QFont font;          // font
-  QString BitmapDir;   // pixmap directory
   QString LangDir;     // translation directory
   QString Language;
   int length_unit;     // default length unit
@@ -72,6 +71,8 @@ struct tQucsSettings {
   int res_unit;        // default resistance unit
   int ang_unit;        // default angle unit
   QString Mode;        // current mode
+  QDir QucsWorkDir;
+  QDir QucsHomeDir;
 };
 
 extern tQucsSettings QucsSettings;
