@@ -22,27 +22,27 @@ CCCS::CCCS()
 {
   Description = QObject::tr("current controlled current source");
 
-  Arcs.append(new Arc(0,-11, 22, 22,  0, 16*360,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 11, -7, 11,  7,QPen(QPen::darkBlue,3)));
-  Lines.append(new Line( 11,  6, 15,  1,QPen(QPen::darkBlue,3)));
-  Lines.append(new Line( 11,  6,  7,  1,QPen(QPen::darkBlue,3)));
+  Arcs.append(new Arc(0,-11, 22, 22,  0, 16*360,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 11, -7, 11,  7,QPen(Qt::darkBlue,3)));
+  Lines.append(new Line( 11,  6, 15,  1,QPen(Qt::darkBlue,3)));
+  Lines.append(new Line( 11,  6,  7,  1,QPen(Qt::darkBlue,3)));
 
-  Lines.append(new Line(-30,-30,-12,-30,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-30, 30,-12, 30,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 11,-30, 30,-30,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 11, 30, 30, 30,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-30,-30,-12,-30,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-30, 30,-12, 30,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 11,-30, 30,-30,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 11, 30, 30, 30,QPen(Qt::darkBlue,2)));
 
-  Lines.append(new Line(-12,-30,-12, 30,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 11,-30, 11,-11,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 11, 30, 11, 11,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-12,-30,-12, 30,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 11,-30, 11,-11,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 11, 30, 11, 11,QPen(Qt::darkBlue,2)));
 
-  Lines.append(new Line(-12, 20,-17, 11,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-12, 20, -8, 11,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-12, 20,-17, 11,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-12, 20, -8, 11,QPen(Qt::darkBlue,2)));
 
-  Lines.append(new Line(-25,-27, 25,-27,QPen(QPen::darkGray,1)));
-  Lines.append(new Line( 25,-27, 25, 27,QPen(QPen::darkGray,1)));
-  Lines.append(new Line( 25, 27,-25, 27,QPen(QPen::darkGray,1)));
-  Lines.append(new Line(-25, 27,-25,-27,QPen(QPen::darkGray,1)));
+  Lines.append(new Line(-25,-27, 25,-27,QPen(Qt::darkGray,1)));
+  Lines.append(new Line( 25,-27, 25, 27,QPen(Qt::darkGray,1)));
+  Lines.append(new Line( 25, 27,-25, 27,QPen(Qt::darkGray,1)));
+  Lines.append(new Line(-25, 27,-25,-27,QPen(Qt::darkGray,1)));
 
   Ports.append(new Port(-30,-30));
   Ports.append(new Port( 30,-30));
