@@ -17,15 +17,15 @@
 #include <QtGui>
 #include <stdlib.h>
 
-#include <qdir.h>
-#include <qpen.h>
-#include <qpoint.h>
-#include <qstring.h>
-#include <qpainter.h>
-#include <qtabwidget.h>
-#include <qmessagebox.h>
-#include <qdom.h>
-#include <q3dict.h>
+#include <QDir>
+#include <QPen>
+#include <QPoint>
+#include <QString>
+#include <QPainter>
+#include <QTabWidget>
+#include <QMessageBox>
+#include <QtXml>
+#include <Q3Dict>
 
 #include "components.h"
 #include "node.h"
@@ -62,6 +62,8 @@ Component::Component()
   Ports.setAutoDelete(true);
   Texts.setAutoDelete(true);
   Props.setAutoDelete(true);
+
+  containingSchematic = NULL;
 }
 
 // -------------------------------------------------------
@@ -249,6 +251,10 @@ void Component::paint(ViewPainter *p)
     p->Painter->setBrush(Qt::NoBrush);
 
     newFont.setWeight(QFont::Light);
+
+    // keep track of painter state
+    p->Painter->save();
+
     QMatrix wm = p->Painter->worldMatrix();
     // write all text
     for(pt = Texts.first(); pt != 0; pt = Texts.next()) {
@@ -270,6 +276,9 @@ void Component::paint(ViewPainter *p)
     }
     p->Painter->setWorldMatrix(wm);
     p->Painter->setWorldXForm(false);
+
+    // restore painter state
+    p->Painter->restore();
   }
 
   // restore old font
@@ -298,6 +307,7 @@ void Component::paint(ViewPainter *p)
     p->drawLine(cx+x1, cy+y2, cx+x2, cy+y1);
   }
 
+  // draw component bounding box
   if(isSelected) {
     p->Painter->setPen(QPen(Qt::darkGray,3));
     p->drawRoundRect(cx+x1, cy+y1, x2-x1, y2-y1);
@@ -308,6 +318,7 @@ void Component::paint(ViewPainter *p)
 // Paints the component when moved with the mouse.
 void Component::paintScheme(Schematic *p)
 {
+  // qDebug() << "paintScheme" << Model;
   if(Model.at(0) == '.') {   // is simulation component (dc, ac, ...)
     Text *pt;
     int a, b, xb, yb;
@@ -378,7 +389,9 @@ void Component::print(ViewPainter *p, float FontScale)
 // Rotates the component 90 counter-clockwise around its center
 void Component::rotate()
 {
-  if(Ports.count() < 1) return;  // do not rotate components without ports
+  // Port count only available after recreate, createSymbol
+  if ((Model != "Sub") && (Model !="VHDL") && (Model != "Verilog")) // skip port count
+    if(Ports.count() < 1) return;  // do not rotate components without ports
   int tmp, dx, dy;
 
   // rotate all lines
@@ -476,7 +489,9 @@ void Component::rotate()
 // Mirrors the component about the x-axis.
 void Component::mirrorX()
 {
-  if(Ports.count() < 1) return;  // do not rotate components without ports
+  // Port count only available after recreate, createSymbol
+  if ((Model != "Sub") && (Model !="VHDL") && (Model != "Verilog")) // skip port count
+    if(Ports.count() < 1) return;  // do not rotate components without ports
 
   // mirror all lines
   for(Line *p1 = Lines.first(); p1 != 0; p1 = Lines.next()) {
@@ -536,7 +551,9 @@ void Component::mirrorX()
 // Mirrors the component about the y-axis.
 void Component::mirrorY()
 {
-  if(Ports.count() < 1) return;  // do not rotate components without ports
+  // Port count only available after recreate, createSymbol
+  if ((Model != "Sub") && (Model !="VHDL") && (Model != "Verilog")) // skip port count
+    if(Ports.count() < 1) return;  // do not rotate components without ports
 
   // mirror all lines
   for(Line *p1 = Lines.first(); p1 != 0; p1 = Lines.next()) {
@@ -1083,7 +1100,7 @@ int Component::analyseLine(const QString& Row, int numProps)
     if(i2 < y1)  y1 = i2;
     if(i1 > x2)  x2 = i1;
     if(i2 > y2)  y2 = i2;
-    
+
     if(i3 < x1)  x1 = i3;
     if(i4 < y1)  y1 = i4;
     if(i3 > x2)  x2 = i3;
@@ -1244,11 +1261,17 @@ void MultiViewComponent::recreate(Schematic *Doc)
   Rects.clear();
   Arcs.clear();
   createSymbol();
-  
+
   bool mmir = mirroredX;
   int  rrot = rotated;
-  if(mmir)  mirrorX();   // mirror
-  for(int z=0; z<rrot; z++)  rotate(); // rotate
+  if (mmir && rrot==2) // mirrorX and rotate 180 = mirrorY
+    mirrorY();
+  else  {
+    if(mmir)
+      mirrorX();   // mirror
+    if (rrot)
+      for(int z=0; z<rrot; z++)  rotate(); // rotate
+  }
 
   rotated = rrot;   // restore properties (were changed by rotate/mirror)
   mirroredX = mmir;
@@ -1390,7 +1413,7 @@ QString GateComponent::verilogCode(int NumPorts)
   }
   else {
     s = "  " + Model.lower();
- 
+
     if(NumPorts <= 0) { // no truth table simulation ?
       QString td = Props.at(2)->Value;        // delay time
       if(!Verilog_Delay(td, Name)) return td;
@@ -1500,13 +1523,13 @@ void GateComponent::createSymbol()
 
 // ***********************************************************************
 // ********                                                       ********
-// ******** The following function does not below to any class.   ********
+// ******** The following function does not belong to any class.  ********
 // ******** It creates a component by getting the identification  ********
 // ******** string used in the schematic file and for copy/paste. ********
 // ********                                                       ********
 // ***********************************************************************
 
-Component* getComponentFromName(QString& Line)
+Component* getComponentFromName(QString& Line, Schematic* p)
 {
   Component *c = 0;
 
@@ -1531,8 +1554,11 @@ Component* getComponentFromName(QString& Line)
     c = Module::getComponent (cstr);
 
   if(!c) {
+    /// \todo enable user to load partial schematic, skip unknown components
     QMessageBox::critical(0, QObject::tr("Error"),
-	QObject::tr("Format Error:\nUnknown component!"));
+	QObject::tr("Format Error:\nUnknown component!\n"
+                "%1\n\n"
+                "Do you make use of loadable components?").arg(cstr));
     return 0;
   }
 
@@ -1545,6 +1571,7 @@ Component* getComponentFromName(QString& Line)
 
   cstr = c->Name;   // is perhaps changed in "recreate" (e.g. subcircuit)
   int x = c->tx, y = c->ty;
+  c->setSchematic (p);
   c->recreate(0);
   c->Name = cstr;
   c->tx = x;  c->ty = y;
