@@ -19,19 +19,19 @@
 #include "main.h"
 #include "qucs.h"
 //Added by qt3to4:
-#include <q3button.h>
+#include <Q3Button>
 #include <QLabel>
 #include <Q3GridLayout>
 #include <Q3VBoxLayout>
 #include "schematic.h"
 
-#include <q3hbox.h>
-#include <q3vbox.h>
-#include <qlayout.h>
-#include <q3hgroupbox.h>
-#include <qvalidator.h>
-#include <qtabwidget.h>
-#include <q3filedialog.h>
+#include <Q3HBox>
+#include <Q3VBox>
+#include <QLayout>
+#include <Q3HGroupBox>
+#include <QValidator>
+#include <QTabWidget>
+#include <QFileDialog>
 
 #include <math.h>
 
@@ -65,7 +65,7 @@ ComponentDialog::ComponentDialog(Component *c, Schematic *d)
   // if simulation component
   if((Comp->Model[0] == '.') &&
      (Comp->Model != ".DC") && (Comp->Model != ".HB") &&
-     (Comp->Model != ".Digi")) {
+     (Comp->Model != ".Digi") && (Comp->Model != ".ETR")) {
     QTabWidget *t = new QTabWidget(this);
     all->addWidget(t);
 
@@ -751,18 +751,22 @@ void ComponentDialog::slotApplyInput()
 // -------------------------------------------------------------------------
 void ComponentDialog::slotBrowseFile()
 {
-  QString s = Q3FileDialog::getOpenFileName(QucsWorkDir.path(),
-          tr("All Files")+" (*.*);;"+tr("Touchstone files")+" (*.s?p);;"+
-          tr("CSV files")+" (*.csv);;"+
-          tr("SPICE files")+" (*.cir *.spi);;"+
-          tr("VHDL files")+" (*.vhdl *.vhd);;"+
-          tr("Verilog files")+" (*.v)",
-          this, "", tr("Select a file"));
+  QString s = QFileDialog::getOpenFileName (
+          this,
+          tr("Select a file"),
+          QucsSettings.QucsWorkDir.path(),
+          tr("All Files")+" (*.*);;"
+            + tr("Touchstone files") + " (*.s?p);;"
+            + tr("CSV files") + " (*.csv);;"
+            + tr("SPICE files") + " (*.cir *.spi);;"
+            + tr("VHDL files") + " (*.vhdl *.vhd);;"
+            + tr("Verilog files")+" (*.v)"  );
+
   if(!s.isEmpty()) {
     // snip path if file in current directory
     QFileInfo file(s);
-    if(QucsWorkDir.exists(file.fileName()) &&
-       QucsWorkDir.absPath() == file.dirPath(true)) s = file.fileName();
+    if(QucsSettings.QucsWorkDir.exists(file.fileName()) &&
+       QucsSettings.QucsWorkDir.absPath() == file.dirPath(true)) s = file.fileName();
     edit->setText(s);
   }
   prop->currentItem()->setText(1, s);
@@ -771,7 +775,7 @@ void ComponentDialog::slotBrowseFile()
 // -------------------------------------------------------------------------
 void ComponentDialog::slotEditFile()
 {
-  Doc->App->editFile(QucsWorkDir.filePath(edit->text()));
+  Doc->App->editFile(QucsSettings.QucsWorkDir.filePath(edit->text()));
 }
 
 // -------------------------------------------------------------------------
@@ -879,7 +883,7 @@ void ComponentDialog::slotSimTypeChange(int Type)
 void ComponentDialog::slotNumberChanged(const QString&)
 {
   QString Unit, tmp;
-  double x, y, Factor, ftmp;
+  double x, y, Factor;
   if(comboType->currentItem() == 1) {   // logarithmic ?
     str2num(editStop->text(), x, Unit, Factor);
     x *= Factor;
@@ -898,13 +902,13 @@ void ComponentDialog::slotNumberChanged(const QString&)
     y *= Factor;
     x = (x - y) / (editNumber->text().toDouble() - 1.0);
 
-    str2num(editStep->text(), y, tmp, ftmp);
-    if(ftmp != 1.0) {
-      Unit = tmp;
-      Factor = ftmp;
-    }
+    QString step = num2str(x);
 
-    Unit = QString::number(x/Factor) + " " + Unit;
+    str2num(step, x, Unit, Factor);
+    if(Factor == 1.0)
+        Unit = "";
+
+    Unit = QString::number(x) + " " + Unit;
   }
 
   editStep->blockSignals(true);  // do not calculate step again
