@@ -156,10 +156,11 @@
 #include "hicumL0V1p3.h"
 #include "hicumL2V2p23.h"
 #include "hicumL2V2p24.h"
-#include "hicumL2V2p31n.h" 
+#include "hicumL2V2p31n.h"
 #include "photodiode.h"
 #include "phototransistor.h"
 #include "nigbt.h"
+#include "vcresistor.h"
 
 #include "dff_SR.h"
 #include "tff_SR.h"
@@ -191,4 +192,11 @@
 #include "comp_4bit.h"
 #include "hpribin4bit.h"
 
+// external simulation components
+#include "etr_sim.h"
+#include "ecvs.h"
+
+// Verilog-A dynamicaly loaded component
+#include "vacomponent.h"
+
 #endif
