@@ -14,7 +14,7 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-
+#include <QtGui>
 #include "equation.h"
 #include "main.h"
 
@@ -32,8 +32,8 @@ Equation::Equation()
   int xb = r.width()  >> 1;
   int yb = r.height() >> 1;
 
-  Lines.append(new Line(-xb, -yb, -xb,  yb,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-xb,  yb,  xb+3,yb,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(-xb, -yb, -xb,  yb,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-xb,  yb,  xb+3,yb,QPen(Qt::darkBlue,2)));
   Texts.append(new Text(-xb+4,  -yb-3, QObject::tr("Equation"),
 			QColor(0,0,0), 12.0));
 
