@@ -22,11 +22,16 @@
 
 
 class Equation : public Component  {
+
 public:
   Equation();
   ~Equation();
   Component* newOne();
   static Element* info(QString&, char* &, bool getNewOne=false);
+
+protected:
+  QString vhdlCode(int);
+  QString verilogCode(int);
 };
 
 #endif
