@@ -22,26 +22,26 @@ Source_ac::Source_ac()
 {
   Description = QObject::tr("ac power source");
 
-  Lines.append(new Line(-22,-11, 22,-11,QPen(QPen::darkGray,0)));
-  Lines.append(new Line(-22, 11, 22, 11,QPen(QPen::darkGray,0)));
-  Lines.append(new Line(-22,-11,-22, 11,QPen(QPen::darkGray,0)));
-  Lines.append(new Line( 22,-11, 22, 11,QPen(QPen::darkGray,0)));
+  Lines.append(new Line(-22,-11, 22,-11,QPen(Qt::darkGray,0)));
+  Lines.append(new Line(-22, 11, 22, 11,QPen(Qt::darkGray,0)));
+  Lines.append(new Line(-22,-11,-22, 11,QPen(Qt::darkGray,0)));
+  Lines.append(new Line( 22,-11, 22, 11,QPen(Qt::darkGray,0)));
 
-  Arcs.append(new Arc(-19, -9, 18, 18,     0, 16*360,QPen(QPen::darkBlue,2)));
-  Arcs.append(new Arc(-13, -6,  6,  6,16*270, 16*180,QPen(QPen::darkBlue,2)));
-  Arcs.append(new Arc(-13,  0,  6,  6, 16*90, 16*180,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(-30,  0,-19,  0,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 30,  0, 19,  0,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( -1,  0,  3,  0,QPen(QPen::darkBlue,2)));
+  Arcs.append(new Arc(-19, -9, 18, 18,     0, 16*360,QPen(Qt::darkBlue,2)));
+  Arcs.append(new Arc(-13, -6,  6,  6,16*270, 16*180,QPen(Qt::darkBlue,2)));
+  Arcs.append(new Arc(-13,  0,  6,  6, 16*90, 16*180,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(-30,  0,-19,  0,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 30,  0, 19,  0,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( -1,  0,  3,  0,QPen(Qt::darkBlue,2)));
 
-  Lines.append(new Line(  3, -5, 19, -5,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(  3,  5, 19,  5,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line(  3, -5,  3,  5,QPen(QPen::darkBlue,2)));
-  Lines.append(new Line( 19, -5, 19,  5,QPen(QPen::darkBlue,2)));
+  Lines.append(new Line(  3, -5, 19, -5,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(  3,  5, 19,  5,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line(  3, -5,  3,  5,QPen(Qt::darkBlue,2)));
+  Lines.append(new Line( 19, -5, 19,  5,QPen(Qt::darkBlue,2)));
 
-  Lines.append(new Line( 25,  5, 25, 11,QPen(QPen::red,1)));
-  Lines.append(new Line( 28,  8, 22,  8,QPen(QPen::red,1)));
-  Lines.append(new Line(-25,  5,-25, 11,QPen(QPen::black,1)));
+  Lines.append(new Line( 25,  5, 25, 11,QPen(Qt::red,1)));
+  Lines.append(new Line( 28,  8, 22,  8,QPen(Qt::red,1)));
+  Lines.append(new Line(-25,  5,-25, 11,QPen(Qt::black,1)));
 
   Ports.append(new Port( 30,  0));
   Ports.append(new Port(-30,  0));
