@@ -19,9 +19,8 @@
 #include "main.h"
 #include "schematic.h"
 
-#include <qfileinfo.h>
+#include <QFileInfo>
 
-extern QDir QucsWorkDir;
 
 
 SParamFile::SParamFile()
