@@ -18,11 +18,11 @@
 #ifndef SPICEDIALOG_H
 #define SPICEDIALOG_H
 
-#include <qdialog.h>
-#include <qregexp.h>
-#include <qdir.h>
+#include <QDialog>
+#include <QRegExp>
+#include <QDir>
 //Added by qt3to4:
-#include <Q3TextStream>
+#include <QTextStream>
 #include <Q3VBoxLayout>
 
 class Schematic;
@@ -33,18 +33,17 @@ class Q3ListBox;
 class Q3ListBoxItem;
 class QCheckBox;
 class Q3VBoxLayout;
-class Q3Process;
+class QProcess;
 class QRegExpValidator;
 class QComboBox;
+class QucsApp;
 
 
-extern QDir QucsWorkDir;
-
 
 class SpiceDialog : public QDialog {
    Q_OBJECT
 public:
-  SpiceDialog(SpiceFile*, Schematic*);
+  SpiceDialog(QucsApp*, SpiceFile*, Schematic*);
  ~SpiceDialog();
 
 private slots:
@@ -87,10 +86,12 @@ private:
   bool        changed;
   int         currentPrep;
 
-  Q3TextStream *prestream;
-  Q3Process *QucsConv, *SpicePrep;
+  QTextStream *prestream;
+  QProcess *QucsConv, *SpicePrep;
   QString Line, Error;  // to store the text read from QucsConv
   int textStatus; // to store with text data QucsConv will sent next
+
+  QucsApp* App;
 };
 
 #endif
