@@ -23,15 +23,15 @@
 # include <unistd.h>
 #endif
 #include <QtGui>
-#include <qregexp.h>
-#include <q3process.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qmessagebox.h>
-#include <q3textstream.h>
-#include <qfile.h>
-#include <qdir.h>
-#include <qfileinfo.h>
+#include <QRegExp>
+#include <QProcess>
+#include <QString>
+#include <QStringList>
+#include <QMessageBox>
+#include <QTextStream>
+#include <QFile>
+#include <QDir>
+#include <QFileInfo>
 
 #include "spicefile.h"
 #include "schematic.h"
@@ -162,7 +162,85 @@ QString SpiceFile::getSubcircuitFile()
 {
   // construct full filename
   QString FileName = Props.getFirst()->Value;
-  return properAbsFileName(FileName);
+
+  if (FileName.isEmpty())
+  {
+      return properAbsFileName(FileName);
+  }
+
+  QFileInfo FileInfo(FileName);
+
+  if (FileInfo.exists())
+  {
+      // the file must be an absolute path to a schematic file
+     return FileInfo.absoluteFilePath();
+  }
+  else
+  {
+    // get the complete base name (everything except the last '.'
+    // and whatever follows
+    QString baseName = FileInfo.completeBaseName();
+
+    // if only a file name is supplied, first check if it is in the
+    // same directory as the schematic file it is a part of
+    if (FileInfo.fileName () == FileName)
+    {
+        // the file has no path information, just the file name
+        if (containingSchematic)
+        {
+            // check if a file of the same name is in the same directory
+            // as the schematic file, if we have a pointer to it, in
+            // which case we use this one
+            QFileInfo schematicFileInfo = containingSchematic->getFileInfo ();
+
+            for (int i = 0; i < QucsMain->spiceExtensions.count (); i++)
+            {
+                QFileInfo localFIleInfo (schematicFileInfo.canonicalPath ()
+                                         + "/" + baseName + QucsMain->spiceExtensions[i]);
+                if (localFIleInfo.exists ())
+                {
+                    // return the subcircuit saved in the same directory
+                    // as the schematic file
+                    return localFIleInfo.absoluteFilePath();
+                }
+            }
+        }
+    }
+
+    // look up the hash table for the schematic file as
+    // it does not seem to be an absolute path, this will also
+    // search the home directory which is always hashed
+    QMutex mutex;
+    mutex.lock();
+    QString hashsearchresult = QucsMain->spiceNameHash.value(baseName);
+    mutex.unlock();
+
+    if (hashsearchresult.isEmpty())
+    {
+        // the schematic was not found in the hash table, return
+        // what would always have been returned in this case
+        return properAbsFileName(FileName);
+    }
+    else
+    {
+        // we found an entry in the hash table, check it actually still exists
+        FileInfo.setFile(hashsearchresult);
+
+        if (FileInfo.exists())
+        {
+            // it does exist so return the absolute file path
+            return FileInfo.absoluteFilePath();
+        }
+        else
+        {
+            // the schematic file does not actually exist, return
+            // what would always have been returned in this case
+            return properAbsFileName(FileName);
+        }
+    }
+
+  }
+
 }
 
 // -------------------------------------------------------------------------
@@ -194,9 +272,8 @@ bool SpiceFile::createSubNetlist(QTextStream *stream)
   if(changed || !ConvFile.exists() ||
      (lastLoaded.isValid() && lastLoaded < Info.lastModified())) {
     if(!ConvFile.open(QIODevice::WriteOnly)) {
-      ErrText +=
-	QObject::tr("ERROR: Cannot save converted SPICE file \"%1\".").
-	arg(FileName + ".lst");
+      ErrText += QObject::tr("ERROR: Cannot save converted SPICE file \"%1\".").
+                          arg(FileName + ".lst");
       return false;
     }
     outstream = stream;
@@ -210,9 +287,8 @@ bool SpiceFile::createSubNetlist(QTextStream *stream)
 
   // load old file and stuff into stream
   if(!ConvFile.open(QIODevice::ReadOnly)) {
-    ErrText +=
-      QObject::tr("ERROR: Cannot open converted SPICE file \"%1\".").
-      arg(FileName + ".lst");
+    ErrText += QObject::tr("ERROR: Cannot open converted SPICE file \"%1\".").
+                        arg(FileName + ".lst");
     return false;
   }
   QByteArray FileContent = ConvFile.readAll();
@@ -245,36 +321,35 @@ bool SpiceFile::recreateSubNetlist(QString *SpiceFile, QString *FileName)
   QString preprocessor = Props.at(3)->Value;
   if (preprocessor != "none") {
     bool piping = true;
-    QString script;
+    QStringList script;
 #ifdef __MINGW32__
     QString interpreter = "tinyperl.exe";
 #else
     QString interpreter = "perl";
 #endif
     if (preprocessor == "ps2sp") {
-      script = "ps2sp";
+      script << "ps2sp";
     } else if (preprocessor == "spicepp") {
-      script = "spicepp.pl";
+      script << "spicepp.pl";
     } else if (preprocessor == "spiceprm") {
-      script = "spiceprm";
+      script << "spiceprm";
       piping = false;
     }
-    script = QucsSettings.BinDir + script;
-    SpicePrep = new Q3Process(this);
-    SpicePrep->addArgument(interpreter);
-    SpicePrep->addArgument(script);
-    SpicePrep->addArgument(*SpiceFile);
+    SpicePrep = new QProcess(this);
+    script << interpreter;
+    script << script;
+    script << *SpiceFile;
 
     QFile PrepFile;
     QString PrepName = *SpiceFile + ".pre";
 
     if (!piping) {
-      SpicePrep->addArgument(PrepName);
-      connect(SpicePrep, SIGNAL(readyReadStdout()), SLOT(slotSkipOut()));
-      connect(SpicePrep, SIGNAL(readyReadStderr()), SLOT(slotGetPrepErr()));
+      script << PrepName;
+      connect(SpicePrep, SIGNAL(readyReadStandardOutput()), SLOT(slotSkipOut()));
+      connect(SpicePrep, SIGNAL(readyReadStandardError()), SLOT(slotGetPrepErr()));
     } else {
-      connect(SpicePrep, SIGNAL(readyReadStdout()), SLOT(slotGetPrepOut()));
-      connect(SpicePrep, SIGNAL(readyReadStderr()), SLOT(slotGetPrepErr()));
+      connect(SpicePrep, SIGNAL(readyReadStandardOutput()), SLOT(slotGetPrepOut()));
+      connect(SpicePrep, SIGNAL(readyReadStandardError()), SLOT(slotGetPrepErr()));
     }
 
     QMessageBox *MBox = new QMessageBox(QObject::tr("Info"),
@@ -282,7 +357,7 @@ bool SpiceFile::recreateSubNetlist(QString *SpiceFile, QString *FileName)
                QMessageBox::NoIcon, QMessageBox::Abort,
                QMessageBox::NoButton, QMessageBox::NoButton, 0, 0, true,
 	       Qt::WStyle_DialogBorder |  Qt::WDestructiveClose);
-    connect(SpicePrep, SIGNAL(processExited()), MBox, SLOT(close()));
+    connect(SpicePrep, SIGNAL(finished(int)), MBox, SLOT(close()));
 
     if (piping) {
       PrepFile.setName(PrepName);
@@ -295,16 +370,23 @@ bool SpiceFile::recreateSubNetlist(QString *SpiceFile, QString *FileName)
       prestream = new QTextStream(&PrepFile);
     }
 
-    if(!SpicePrep->start()) {
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    env.insert("PATH", env.value("PATH") );
+    SpicePrep->setProcessEnvironment(env);
+    SpicePrep->start(script.join(" "));
+    //QucsHelp->setCommunication(0);
+
+    if(SpicePrep->state()!=QProcess::Running&&
+            SpicePrep->state()!=QProcess::Starting) {
       ErrText += QObject::tr("ERROR: Cannot execute \"%1\".").
-	arg(interpreter + " " + script + "\".");
+              arg(interpreter + " " + script.join(" ") + "\".");
       if (piping) {
 	PrepFile.close();
 	delete prestream;
       }
       return false;
     }
-    SpicePrep->closeStdin();
+    //SpicePrep->closeStdin();
 
     MBox->exec();
     delete SpicePrep;
@@ -315,9 +397,16 @@ bool SpiceFile::recreateSubNetlist(QString *SpiceFile, QString *FileName)
     *SpiceFile = PrepName;
   }
 
+  QString executableSuffix = "";
+#ifdef __MINGW32__
+  executableSuffix = ".exe";
+#endif
+
   // begin command line construction
+  QString prog;
   QStringList com;
-  com << (QucsSettings.BinDir + "qucsconv");
+  prog =  QucsSettings.BinDir + "qucsconv"  + executableSuffix;
+
   if(makeSubcircuit) com << "-g" << "_ref";
   com << "-if" << "spice" << "-of" << "qucs";
   com << "-i" << *SpiceFile;
@@ -334,18 +423,27 @@ bool SpiceFile::recreateSubNetlist(QString *SpiceFile, QString *FileName)
   NetText += "\n";
 
   // startup SPICE conversion process
-  QucsConv = new Q3Process(this);
-  QucsConv->setArguments(com);
-  connect(QucsConv, SIGNAL(readyReadStdout()), SLOT(slotGetNetlist()));
-  connect(QucsConv, SIGNAL(readyReadStderr()), SLOT(slotGetError()));
-  connect(QucsConv, SIGNAL(processExited()), SLOT(slotExited()));
-  if(!QucsConv->start()) {
-    ErrText += QObject::tr("ERROR: Cannot start QucsConv!");
+  QucsConv = new QProcess(this);
+  QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+  env.insert("PATH", env.value("PATH") );
+  QucsConv->setProcessEnvironment(env);
+
+  qDebug() << "Command:" << prog << com.join(" ");
+//  QucsConv->start(com.join(" "));
+  QucsConv->start(prog, com);
+
+  /// these slots might write into NetText, ErrText, outstream, filstream
+  connect(QucsConv, SIGNAL(readyReadStandardOutput()), SLOT(slotGetNetlist()));
+  connect(QucsConv, SIGNAL(readyReadStandardError()), SLOT(slotGetError()));
+  connect(QucsConv, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(slotExited()));
+
+  if(QucsConv->state()!=QProcess::Running&&
+          QucsConv->state()!=QProcess::Starting) {
+    ErrText += QObject::tr("COMP ERROR: Cannot start QucsConv!");
     return false;
   }
   (*outstream) << NetText;
   (*filstream) << NetText;
-  QucsConv->closeStdin();
 
   // waiting info dialog box
   QMessageBox *MBox = new QMessageBox(QObject::tr("Info"),
@@ -353,7 +451,7 @@ bool SpiceFile::recreateSubNetlist(QString *SpiceFile, QString *FileName)
                QMessageBox::NoIcon, QMessageBox::Abort,
                QMessageBox::NoButton, QMessageBox::NoButton, 0, 0, true,
 	       Qt::WStyle_DialogBorder | Qt::WDestructiveClose);
-  connect(QucsConv, SIGNAL(processExited()), MBox, SLOT(close()));
+  connect(QucsConv, SIGNAL(finished(int)), MBox, SLOT(close()));
   MBox->exec();
 
   // finish
@@ -365,31 +463,31 @@ bool SpiceFile::recreateSubNetlist(QString *SpiceFile, QString *FileName)
 // -------------------------------------------------------------------------
 void SpiceFile::slotSkipErr()
 {
-  SpicePrep->readStderr();
+  SpicePrep->readAllStandardError();
 }
 
 // -------------------------------------------------------------------------
 void SpiceFile::slotSkipOut()
 {
-  SpicePrep->readStdout();
+    SpicePrep->readAllStandardOutput();
 }
 
 // -------------------------------------------------------------------------
 void SpiceFile::slotGetPrepErr()
 {
-  ErrText += QString(SpicePrep->readStderr());
+  ErrText += QString(SpicePrep->readAllStandardError());
 }
 
 // -------------------------------------------------------------------------
 void SpiceFile::slotGetPrepOut()
 {
-  (*prestream) << QString(SpicePrep->readStdout());
+  (*prestream) << QString(SpicePrep->readAllStandardOutput());
 }
 
 // -------------------------------------------------------------------------
 void SpiceFile::slotGetError()
 {
-  ErrText += QString(QucsConv->readStderr());
+  ErrText += QString(QucsConv->readAllStandardError());
 }
 
 // -------------------------------------------------------------------------
@@ -397,7 +495,7 @@ void SpiceFile::slotGetNetlist()
 {
   int i;
   QString s;
-  NetLine += QString(QucsConv->readStdout());
+  NetLine += QString(QucsConv->readAllStandardOutput());
 
   while((i = NetLine.find('\n')) >= 0) {
     s = NetLine.left(i);
@@ -425,7 +523,7 @@ void SpiceFile::slotGetNetlist()
 // -------------------------------------------------------------------------
 void SpiceFile::slotExited()
 {
-  if (!QucsConv->normalExit()) {
+  if (QucsConv->exitStatus() != QProcess::NormalExit) {
     NetText = "";
   }
   else {
