@@ -20,13 +20,13 @@
 #include <QtGui>
 #include "component.h"
 
-#include <qobject.h>
-#include <qdatetime.h>
+#include <QObject>
+#include <QDateTime>
 //Added by qt3to4:
-#include <Q3TextStream>
+#include <QTextStream>
 
-class Q3Process;
-class Q3TextStream;
+class QProcess;
+class QTextStream;
 class QString;
 
 class SpiceFile : public QObject, public MultiViewComponent  {
@@ -46,7 +46,7 @@ private:
   bool makeSubcircuit;
   bool insertSim;
   bool changed;
-  Q3Process *QucsConv, *SpicePrep;
+  QProcess *QucsConv, *SpicePrep;
   QString NetText, ErrText, NetLine, SimText;
   QTextStream *outstream, *filstream, *prestream;
   QDateTime lastLoaded;
