@@ -18,13 +18,13 @@
 #include "verilogfile.h"
 #include "qucs.h"
 //Added by qt3to4:
-#include <Q3TextStream>
+#include <QTextStream>
 #include "main.h"
 #include "schematic.h"
 
-#include <qregexp.h>
-#include <qdir.h>
-#include <qfileinfo.h>
+#include <QRegExp>
+#include <QDir>
+#include <QFileInfo>
 
 
 Verilog_File::Verilog_File()
@@ -91,13 +91,13 @@ QString Verilog_File::loadFile()
   QString s, File(Props.getFirst()->Value);
   QFileInfo Info(File);
   if(Info.isRelative())
-    File = QucsWorkDir.filePath(File);
+    File = QucsSettings.QucsWorkDir.filePath(File);
 
   QFile f(File);
   if(!f.open(QIODevice::ReadOnly))
     return QString("");
 
-  Q3TextStream stream(&f);
+  QTextStream stream(&f);
   File = stream.read();   // QString is better for "find" function
   f.close();
 
