@@ -21,14 +21,11 @@
 #include <QtGui>
 #include <math.h>
 #include <float.h>
-#ifdef __MINGW32__
-# define finite(x) _finite(x)
-#endif
 #if HAVE_IEEEFP_H
 # include <ieeefp.h>
 #endif
 
-#include <qmessagebox.h>
+#include <QMessageBox>
 
 #include "curvediagram.h"
 #include "main.h"
@@ -66,8 +63,8 @@ void CurveDiagram::calcCoordinate(double* &, double* &yD, double* &,
 		*double(y2));
   else  *py = float((yi-pa->low)/(pa->up-pa->low)*double(y2));
 
-  if(finite(*px))
-    if(finite(*py))
+  if(isfinite(*px))
+    if(isfinite(*py))
       return;
 
   *px = *py = 0.0;
