@@ -27,12 +27,10 @@
 #endif
 #include <locale.h>
 
-#include <q3textstream.h>
-#include <qmessagebox.h>
-#include <qregexp.h>
-#include <qdatetime.h>
-//Added by qt3to4:
-#include <Q3CString>
+#include <QTextStream>
+#include <QMessageBox>
+#include <QRegExp>
+#include <QDateTime>
 
 #include "diagram.h"
 #include "qucs.h"
@@ -42,27 +40,6 @@
 
 #include "rect3ddiagram.h"
 
-#ifdef __MINGW32__
-# define finite(x) _finite(x)
-#endif
-
-#if defined (__MINGW32__)
-// strtod() appears to be so sloooooooo under Win32...
-static double strtod_faster (char * pPos, char ** pEnd) {
-  *pEnd = pPos;
-  while ((**pEnd) && (**pEnd > ' ') && (**pEnd != 'j') && (**pEnd != 'i'))
-    (*pEnd)++;
-  if ((**pEnd == 'j') || (**pEnd == 'i'))
-    (*pEnd)--;
-  Q3CString str = Q3CString (pPos, *pEnd - pPos + 1);
-  bool ok;
-  double x = str.toDouble (&ok);
-  if (!ok) *pEnd = pPos;
-  return x;
-}
-#define strtod(a,b) strtod_faster(a,b)
-#endif /* __MINGW32__ */
-
 using namespace std;
 
 Diagram::Diagram(int _cx, int _cy)
@@ -126,6 +103,8 @@ void Diagram::paint(ViewPainter *p)
   for(pg = Graphs.first(); pg != 0; pg = Graphs.next())
     pg->paint(p, cx, cy);
 
+  // keep track of painter state
+  p->Painter->save();
 
   // write whole text (axis label inclusively)
   QMatrix wm = p->Painter->worldMatrix();
@@ -141,6 +120,9 @@ void Diagram::paint(ViewPainter *p)
   p->Painter->setWorldMatrix(wm);
   p->Painter->setWorldXForm(false);
 
+  // restore painter state
+  p->Painter->restore();
+
   // draw markers last, so they are at the top of painting layers
   for(pg = Graphs.first(); pg != 0; pg = Graphs.next())
     for(Marker *pm = pg->Markers.first(); pm != 0; pm = pg->Markers.next())
@@ -687,7 +669,7 @@ void Diagram::getAxisLimits(Graph *pg)
     p = pD->Points;
     for(z=pD->count; z>0; z--) { // check x coordinates (1. dimension)
       x = *(p++);
-      if(finite(x)) {
+      if(isfinite(x)) {
 	if(x > xAxis.max) xAxis.max = x;
 	if(x < xAxis.min) xAxis.min = x;
       }
@@ -700,7 +682,7 @@ void Diagram::getAxisLimits(Graph *pg)
       p = pDy->Points;
       for(z=pDy->count; z>0; z--) { // check y coordinates (2. dimension)
 	y = *(p++);
-	if(finite(y)) {
+	if(isfinite(y)) {
 	  if(y > yAxis.max) yAxis.max = y;
 	  if(y < yAxis.min) yAxis.min = y;
 	}
@@ -720,17 +702,17 @@ void Diagram::getAxisLimits(Graph *pg)
 
     if(Name[0] != 'C') {
       if(fabs(y) >= 1e-250) x = sqrt(x*x+y*y);
-      if(finite(x)) {
+      if(isfinite(x)) {
 	if(x > pa->max) pa->max = x;
 	if(x < pa->min) pa->min = x;
       }
     }
     else {   // location curve needs different treatment
-      if(finite(x)) {
+      if(isfinite(x)) {
 	if(x > xAxis.max) xAxis.max = x;
 	if(x < xAxis.min) xAxis.min = x;
       }
-      if(finite(y)) {
+      if(isfinite(y)) {
 	if(y > pa->max) pa->max = y;
 	if(y < pa->min) pa->min = y;
       }
@@ -1012,17 +994,17 @@ if(Variable.right(3) != ".X ")
     *(p++) = y;
     if(Name[0] != 'C') {
       if(fabs(y) >= 1e-250) x = sqrt(x*x+y*y);
-      if(finite(x)) {
+      if(isfinite(x)) {
         if(x > pa->max) pa->max = x;
         if(x < pa->min) pa->min = x;
       }
     }
     else {   // location curve needs different treatment
-      if(finite(x)) {
+      if(isfinite(x)) {
         if(x > xAxis.max) xAxis.max = x;
         if(x < xAxis.min) xAxis.min = x;
       }
-      if(finite(y)) {
+      if(isfinite(y)) {
         if(y > pa->max) pa->max = y;
         if(y < pa->min) pa->min = y;
       }
@@ -1137,7 +1119,7 @@ int Diagram::loadIndepVarData(const QString& Variable,
     
     *(p++) = x;
     if(Name[0] != 'C')   // not for location curves
-      if(finite(x)) {
+      if(isfinite(x)) {
         if(x > pa->max) pa->max = x;
         if(x < pa->min) pa->min = x;
       }
@@ -1258,7 +1240,7 @@ QString Diagram::save()
 }
 
 // ------------------------------------------------------------
-bool Diagram::load(const QString& Line, Q3TextStream *stream)
+bool Diagram::load(const QString& Line, QTextStream *stream)
 {
   bool ok;
   QString s = Line;
