@@ -18,10 +18,10 @@
 #ifndef MARKERDIALOG_H
 #define MARKERDIALOG_H
 #include "marker.h"
-#include <qdialog.h>
-#include <qlineedit.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
+#include <QDialog>
+#include <QLineEdit>
+#include <QComboBox>
+#include <QCheckBox>
 
 
 
