@@ -22,9 +22,6 @@
 #include <stdlib.h>
 #include <math.h>
 #include <float.h>
-#ifdef __MINGW32__
-# define finite(x) _finite(x)
-#endif
 #include <limits.h>
 #if HAVE_IEEEFP_H
 # include <ieeefp.h>
@@ -177,8 +174,8 @@ void Rect3DDiagram::calcCoordinate(double* &xD, double* &zD, double* &yD,
   *px = float(calcX_2D(x3D, y3D, z3D)) + xorig;
   *py = float(calcY_2D(x3D, y3D, z3D)) + yorig;
 
-  if(finite(*px))
-    if(finite(*py))
+  if(isfinite(*px))
+    if(isfinite(*py))
       return;
 
   *px = float(xorig);
