@@ -21,14 +21,11 @@
 #include <QtGui>
 #include <math.h>
 #include <float.h>
-#ifdef __MINGW32__
-# define finite(x) _finite(x)
-#endif
 #if HAVE_IEEEFP_H
 # include <ieeefp.h>
 #endif
 
-#include <qmessagebox.h>
+#include <QMessageBox>
 
 #include "rectdiagram.h"
 #include "main.h"
@@ -78,8 +75,8 @@ void RectDiagram::calcCoordinate(double* &xD, double* &yD, double* &,
     *py = float((yr-pa->low)/(pa->up-pa->low)*double(y2));
   }
 
-  if(!finite(*px))  *px = 0.0;
-  if(!finite(*py))  *py = 0.0;
+  if(!isfinite(*px))  *px = 0.0;
+  if(!isfinite(*py))  *py = 0.0;
 }
 
 // --------------------------------------------------------------
