@@ -32,6 +32,7 @@ using namespace std;
 
 #include "simmessage.h"
 #include "main.h"
+#include "module.h"
 #include "qucs.h"
 #include "textdoc.h"
 #include "schematic.h"
@@ -39,9 +40,9 @@ using namespace std;
 #include "components/vhdlfile.h"
 
 #ifdef __MINGW32__
-#define executablePostfix ".exe"
+#define executableSuffix ".exe"
 #else
-#define executablePostfix ""
+#define executableSuffix ""
 #endif
 
 
@@ -117,11 +118,12 @@ SimMessage::SimMessage(QWidget *w, QWidget *parent)
   Abort = new QPushButton(tr("Abort simulation"));
   Butts->addWidget(Abort);
   connect(Abort,SIGNAL(clicked()),SLOT(reject()));
+  connect(Abort,SIGNAL(clicked()),SLOT(AbortSim()));
 }
 
 SimMessage::~SimMessage()
 {
-  if(SimProcess.Running)  SimProcess.kill();
+  if(SimProcess.state()==QProcess::Running)  SimProcess.kill();
   delete all;
 }
 
@@ -133,21 +135,21 @@ bool SimMessage::startProcess()
 
   QString txt = tr("Starting new simulation on %1 at %2").
     arg(QDate::currentDate().toString("ddd dd. MMM yyyy")).
-    arg(QTime::currentTime().toString("hh:mm:ss"));
+    arg(QTime::currentTime().toString("hh:mm:ss:zzz"));
   ProgText->insert(txt + "\n\n");
-  
+
   SimProcess.blockSignals(false);
- /* On Qt4 it shows as running even before we .start it. FIXME
-  if(SimProcess.Running) {
-    qDebug() << "running!";  
+ /* On Qt4 it shows as running even before we .start it. FIXME*/
+  if(SimProcess.state()==QProcess::Running ||SimProcess.state()==QProcess::Starting) {
+    qDebug() << "running!";
     ErrText->insert(tr("ERROR: Simulator is still running!"));
     FinishSimulation(-1);
     return false;
   }
-*/
+
   Collect.clear();  // clear list for NodeSets, SPICE components etc.
   ProgText->insert(tr("creating netlist... "));
-  NetlistFile.setName(QucsHomeDir.filePath("netlist.txt"));
+  NetlistFile.setName(QucsSettings.QucsHomeDir.filePath("netlist.txt"));
    if(!NetlistFile.open(QIODevice::WriteOnly)) {
     ErrText->insert(tr("ERROR: Cannot write netlist file!"));
     FinishSimulation(-1);
@@ -175,17 +177,17 @@ bool SimMessage::startProcess()
                        SLOT(slotReadSpiceNetlist()));
   connect(&SimProcess, SIGNAL(finished(int)),
                        SLOT(slotFinishSpiceNetlist(int)));
- 
+
   nextSPICE();
   return true;
   // Since now, the Doc pointer may be obsolete, as the user could have
   // closed the schematic !!!
 }
-  
+
 // ---------------------------------------------------
 // Converts a spice netlist into Qucs format and outputs it.
 void SimMessage::nextSPICE()
-{ 
+{
   QString Line;
   for(;;) {  // search for next SPICE component
     Line = *(Collect.begin());
@@ -194,7 +196,7 @@ void SimMessage::nextSPICE()
       startSimulator(); // <<<<<================== go on ===
       return;
     }
-#warning SPICE section below not being covered?
+// FIXME #warning SPICE section below not being covered?
     qDebug() << "goin thru SPICE branch on simmmessage.cpp";
     if(Line.left(5) == "SPICE") {
       if(Line.at(5) != 'o') insertSim = true;
@@ -212,14 +214,14 @@ void SimMessage::nextSPICE()
 
   QString prog;
   QStringList com;
-  prog = QucsSettings.BinDir + "qucsconv";
+  prog = QucsSettings.BinDir + "qucsconv" + executableSuffix;
   if(makeSubcircuit)
     com << "-g" << "_ref";
   com << "-if" << "spice" << "-of" << "qucs";
 
   QFile SpiceFile;
   if(FileName.find(QDir::separator()) < 0)  // add path ?
-    SpiceFile.setName(QucsWorkDir.path() + QDir::separator() + FileName);
+    SpiceFile.setName(QucsSettings.QucsWorkDir.path() + QDir::separator() + FileName);
   else
     SpiceFile.setName(FileName);
   if(!SpiceFile.open(QIODevice::ReadOnly)) {
@@ -230,7 +232,7 @@ void SimMessage::nextSPICE()
 
   if(makeSubcircuit) {
     Stream << "\n.Def:" << properName(FileName) << " ";
-  
+
     Line.replace(',', ' ');
     Stream << Line;
     if(!Line.isEmpty()) Stream << " _ref";
@@ -238,12 +240,12 @@ void SimMessage::nextSPICE()
   Stream << "\n";
 
   ProgressText = "";
-  
+
   qDebug() << "start QucsConv" << prog << com.join(" ");
   SimProcess.start(prog, com);
-  
+
   if(!SimProcess.Running) {
-    ErrText->insert(tr("ERROR: Cannot start QucsConv!"));
+    ErrText->insert(tr("SIM ERROR: Cannot start QucsConv!"));
     FinishSimulation(-1);
     return;
   }
@@ -312,7 +314,10 @@ static QString pathName(QString longpath) {
 }
 #endif
 
-// ------------------------------------------------------------------------
+
+/*!
+ * \brief SimMessage::startSimulator simulates the document in view.
+ */
 void SimMessage::startSimulator()
 {
   // Using the Doc pointer here is risky as the user may have closed
@@ -322,7 +327,7 @@ void SimMessage::startSimulator()
   QString SimTime;
   QString Program;
   QStringList Arguments;
-  QString SimPath = QDir::convertSeparators (QucsHomeDir.absPath());
+  QString SimPath = QDir::convertSeparators (QucsSettings.QucsHomeDir.absPath());
 #ifdef __MINGW32__
   QString QucsDigiLib = "qucsdigilib.bat";
   QString QucsDigi = "qucsdigi.bat";
@@ -341,41 +346,45 @@ void SimMessage::startSimulator()
     TextDoc * Doc = (TextDoc*)DocWidget;
 
     // Take VHDL file in memory as it could contain unsaved changes.
-    Stream << Doc->text();
+    Stream << Doc->toPlainText();
     NetlistFile.close();
-    ProgText->insert(tr("done.")+"\n");  // of "creating netlist... 
+    ProgText->insert(tr("done.")+"\n");  // of "creating netlist...
 
     // Simulation.
     if (Doc->simulation) {
       SimTime = Doc->SimTime;
       QString libs = Doc->Libraries.lower();
+      /// \todo \bug error: unrecognized command line option '-Wl'
 #ifdef __MINGW32__
       if(libs.isEmpty()) {
-	libs = "-Wl";
-      } else {
-	libs.replace(" ",",-l");
-	libs = "-Wl,-l" + libs;
+        libs = "";
+      }
+      else {
+        libs.replace(" ",",-l");
+        libs = "-Wl,-l" + libs;
       }
 #else
       if(libs.isEmpty()) {
-	libs = "-c";
-      } else {
-	libs.replace(" ",",-l");
-	libs = "-c,-l" + libs;
+        libs = "-c";
+      }
+      else {
+        libs.replace(" ",",-l");
+        libs = "-c,-l" + libs;
       }
 #endif
       Program = pathName(QucsSettings.BinDir + QucsDigi);
-	  Arguments  << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
-		  << pathName(QucsSettings.BinDir) << libs;
+      Arguments  << QucsSettings.QucsHomeDir.filePath("netlist.txt")
+                 << DataSet << SimTime << pathName(SimPath)
+                 << pathName(QucsSettings.BinDir) << libs;
     }
     // Module.
     else {
-      QString text = Doc->text();
+      QString text = Doc->toPlainText();
       VHDL_File_Info VInfo (text);
       QString entity = VInfo.EntityName.lower();
       QString lib = Doc->Library.lower();
       if (lib.isEmpty()) lib = "work";
-      QString dir = QDir::convertSeparators (QucsHomeDir.path());
+      QString dir = QDir::convertSeparators (QucsSettings.QucsHomeDir.path());
       QDir vhdlDir(dir);
       if(!vhdlDir.exists("vhdl"))
 	if(!vhdlDir.mkdir("vhdl")) {
@@ -401,7 +410,10 @@ void SimMessage::startSimulator()
       destFile.writeBlock(text.ascii(), text.length());
       destFile.close();
       Program = pathName(QucsSettings.BinDir + QucsDigiLib);
-	  Arguments << "netlist.txt" << pathName(SimPath) << entity << lib;
+      Arguments << QucsSettings.QucsHomeDir.filePath("netlist.txt")
+                << pathName(SimPath)
+                << entity
+                << lib;
     }
   }
   // Simulate schematic window.
@@ -437,36 +449,99 @@ void SimMessage::startSimulator()
 	     << "endmodule // TestBench\n";
     }
     NetlistFile.close();
-    ProgText->insert(tr("done.")+"\n");  // of "creating netlist... 
+    ProgText->insert(tr("done.")+"\n");  // of "creating netlist...
 
     if(SimPorts < 0) {
+
+      // append command arguments
+      // append netlist with same arguments
+      if (! Module::vaComponents.isEmpty()) {
+
+          /*! Only pass modules to Qucsator that are indeed used on
+           * the schematic,it might be the case that the user loaded the icons,
+           * but did not compiled the module. Qucsator will not find the library.
+           *
+           * Check if used symbols have corresponing lib before running
+           * Qucsator? Need to search on the netlis.txt? Is there other data
+           * structure containig the netlist?
+           *
+          */
+          QStringList usedComponents;
+
+          if (!NetlistFile.open(QIODevice::ReadOnly))
+             QMessageBox::critical(this, tr("Error"), tr("Cannot read netlist!"));
+          else {
+             QString net = QString(NetlistFile.readAll());
+
+             QMapIterator<QString, QString> i(Module::vaComponents);
+             while (i.hasNext()) {
+                 i.next();
+                 if (net.contains(i.key()))
+                     usedComponents << i.key();
+             }
+             NetlistFile.close();
+          }
+
+          if (! usedComponents.isEmpty()) {
+
+
+            // \todo remvoe the command line arguments? use only netlist annotation?
+            //Arguments << "-p" << QucsSettings.QucsWorkDir.absolutePath()
+            //          << "-m" << usedComponents;
+            //qDebug() << "Command :" << Program << Arguments.join(" ");
+
+            /// Anotate netlist with Verilog-A dynamic path and module names
+            ///
+            if (!NetlistFile.open(QFile::Append | QFile::Text))
+               QMessageBox::critical(this, tr("Error"), tr("Cannot read netlist!"));
+            else {
+               QTextStream out(&NetlistFile);
+               out << "\n";
+               out << "# --path=" << QucsSettings.QucsWorkDir.absolutePath() << "\n";
+               out << "# --module=" << usedComponents.join(" ") << "\n";
+
+               NetlistFile.close();
+            }
+          }
+      } // vaComponents not empty
+
       if((SimOpt = findOptimization((Schematic*)DocWidget))) {
 	    ((Optimize_Sim*)SimOpt)->createASCOnetlist();
-	    Program = QucsSettings.AscoDir + "asco"+ executablePostfix; 
-        Arguments << "-qucs" << QucsHomeDir.filePath("asco_netlist.txt") 
+
+        Program = QucsSettings.AscoBinDir.canonicalPath();
+        Program = QDir::toNativeSeparators(Program+"/"+"asco"+QString(executableSuffix));
+        Arguments << "-qucs" << QucsSettings.QucsHomeDir.filePath("asco_netlist.txt")
                   << "-o" << "asco_out";
       }
       else {
-	    Program = QucsSettings.BinDir + "qucsator" + executablePostfix;
-
-        Arguments << "-b" << "-g" << "-i" 
-                  << QucsHomeDir.filePath("netlist.txt") 
+        Program = QucsSettings.BinDir + "qucsator" + executableSuffix;
+        Arguments << "-b" << "-g" << "-i"
+                  << QucsSettings.QucsHomeDir.filePath("netlist.txt")
                   << "-o" << DataSet;
       }
-    } else {
+    }
+    else {
       if (isVerilog) {
-          Program = pathName(QucsSettings.BinDir + QucsVeri);
-		  Arguments << "netlist.txt" << DataSet 
-                    << SimTime << pathName(SimPath)
-                    << pathName(QucsSettings.BinDir) << "-c";
+          Program = QDir::toNativeSeparators(QucsSettings.BinDir + QucsVeri);
+          Arguments << QDir::toNativeSeparators(QucsSettings.QucsHomeDir.filePath("netlist.txt"))
+                    << DataSet
+                    << SimTime
+                    << QDir::toNativeSeparators(SimPath)
+                    << QDir::toNativeSeparators(QucsSettings.BinDir)
+                    << "-c";
       } else {
+/// \todo \bug error: unrecognized command line option '-Wl'
 #ifdef __MINGW32__
-	Program = pathName(QucsSettings.BinDir + QucsDigi);
-	Arguments << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
-		      << pathName(QucsSettings.BinDir) << "-Wl" << "-c";
+    Program = QDir::toNativeSeparators(pathName(QucsSettings.BinDir + QucsDigi));
+    Arguments << QDir::toNativeSeparators(QucsSettings.QucsHomeDir.filePath("netlist.txt"))
+              << DataSet
+              << SimTime
+              << QDir::toNativeSeparators(SimPath)
+              << QDir::toNativeSeparators(QucsSettings.BinDir) << "-Wall" << "-c";
 #else
-	Program = pathName(QucsSettings.BinDir + QucsDigi);
-	Arguments << "netlist.txt" << DataSet << SimTime << pathName(SimPath)
+    Program = QDir::toNativeSeparators(pathName(QucsSettings.BinDir + QucsDigi));
+    Arguments << QucsSettings.QucsHomeDir.filePath("netlist.txt")
+              << DataSet << SimTime << pathName(SimPath)
 		      << pathName(QucsSettings.BinDir) << "-Wall" << "-c";
 
 #endif
@@ -483,19 +558,20 @@ void SimMessage::startSimulator()
   waitForUpdate = false;
 #endif
   wasLF = false;
-  
+
   ProgressText = "";
-  
-#ifdef __MINGW32__  
+
+#ifdef __MINGW32__
   QString sep(";"); // path separator
-#else  
+#else
   QString sep(":");
 #endif
-  
-  // append process PATH 
+
+  // append process PATH
   QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+  // insert Qucs bin dir, so ASCO can find qucsator
   env.insert("PATH", env.value("PATH") + sep + QucsSettings.BinDir );
-  SimProcess.setProcessEnvironment(env); 
+  SimProcess.setProcessEnvironment(env);
   QFile file(Program);
   if ( !file.exists() ){
     ErrText->insert(tr("ERROR: Program not found: %1").arg(Program));
@@ -504,15 +580,16 @@ void SimMessage::startSimulator()
   }
   else
     file.close();
-  
+
+  qDebug() << "Command :" << Program << Arguments.join(" ");
   SimProcess.start(Program, Arguments); // launch the program
-  
+
   if(!SimProcess.Running) {
     ErrText->insert(tr("ERROR: Cannot start simulator!"));
     FinishSimulation(-1);
     return;
   }
-	
+
 }
 
 // ------------------------------------------------------------------------
@@ -534,11 +611,6 @@ void SimMessage::slotDisplayMsg()
   ProgressText += QString(SimProcess.readAllStandardOutput());
   if(wasLF) {
     i = ProgressText.findRev('\r');
-#ifdef __MINGW32__
-    while (i > 1 && ProgressText.at(i+1) == '\n') {
-      i = ProgressText.findRev('\r', i-1);
-    }
-#endif /* __MINGW32__ */
     if(i > 1) {
 #ifdef SPEEDUP_PROGRESSBAR
       iProgress = 10*int(ProgressText.at(i-2).latin1()-'0') +
@@ -588,14 +660,14 @@ void SimMessage::slotUpdateProgressBar()
 void SimMessage::slotDisplayErr()
 {
   QTextCursor cursor = ErrText->textCursor();
-  cursor.movePosition(QTextCursor::End);  
+  cursor.movePosition(QTextCursor::End);
   ErrText->insert(QString(SimProcess.readAllStandardError()));
 }
 
 // ------------------------------------------------------------------------
 // Is called when the simulation process terminates.
 void SimMessage::slotSimEnded(int status)
-{ 
+{
   FinishSimulation(status); //0 - normal  | 1 - crash
 }
 
@@ -614,32 +686,32 @@ void SimMessage::FinishSimulation(int Status)
   if(Status == 0) {
     QString txt = tr("Simulation ended on %1 at %2").
       arg(d.toString("ddd dd. MMM yyyy")).
-      arg(t.toString("hh:mm:ss"));
+      arg(t.toString("hh:mm:ss:zzz"));
     ProgText->insert("\n" + txt + "\n" + tr("Ready.") + "\n");
   }
   else {
     QString txt = tr("Errors occurred during simulation on %1 at %2").
       arg(d.toString("ddd dd. MMM yyyy")).
-      arg(t.toString("hh:mm:ss"));
+      arg(t.toString("hh:mm:ss:zzz"));
     ProgText->insert("\n" + txt + "\n" + tr("Aborted.") + "\n");
   }
 
-  QFile file(QucsHomeDir.filePath("log.txt"));  // save simulator messages
+  QFile file(QucsSettings.QucsHomeDir.filePath("log.txt"));  // save simulator messages
   if(file.open(QIODevice::WriteOnly)) {
     int z;
     QTextStream stream(&file);
     stream << tr("Output:\n-------") << "\n\n";
-    for(z=0; z<=ProgText->document()->blockCount(); z++)
-      stream << ProgText->document()->findBlock(z).text() << "\n";
+    for(int z=0; z<ProgText->document()->blockCount(); z++)
+      stream << ProgText->document()->findBlockByNumber(z).text() << "\n";
     stream << "\n\n\n" << tr("Errors:\n-------") << "\n\n";
-    for(z=0; z<ErrText->document()->blockCount(); z++)
-      stream << ErrText->document()->findBlock(z).text() << "\n";
+    for(int z=0; z<ErrText->document()->blockCount(); z++)
+      stream << ErrText->document()->findBlockByNumber(z).text() << "\n";
     file.close();
   }
 
   if(Status == 0) {
     if(SimOpt) { // save optimization data
-      QFile ifile(QucsHomeDir.filePath("asco_out.dat"));
+      QFile ifile(QucsSettings.QucsHomeDir.filePath("asco_out.dat"));
       QFile ofile(DataSet);
       if(ifile.open(QIODevice::ReadOnly)) {
 	if(ofile.open(QIODevice::WriteOnly)) {
@@ -670,3 +742,8 @@ void SimMessage::slotDisplayButton()
   emit displayDataPage(DocName, DataDisplay);
   accept();
 }
+
+void SimMessage::AbortSim()
+{
+    SimProcess.kill();
+}
