@@ -15,12 +15,30 @@
  *                                                                         *
  ***************************************************************************/
 
+/** \file element.h
+  * \brief Defines drawing elements for schematics
+  *
+  * element.h contains definitions of various drawing elements used
+  * used to render schematics and the schematic symbols. The following
+  * structs are defined to hold information on various drawing types:
+  *
+  *    Line
+  *    Arc
+  *    Area
+  *    Port
+  *    Text
+  *    Property
+  *
+  * The Element class is also defined here which is a superclass
+  * of every component symbol.
+  *
+  */
+
 #ifndef ELEMENT_H
 #define ELEMENT_H
 
-#include <qpen.h>
-#include <qbrush.h>
-
+#include <QPen>
+#include <QBrush>
 
 class Node;
 class QPainter;
@@ -86,7 +104,7 @@ struct Property {
 // valid values for Element.Type
 // The 4 least significant bits of each value are reserved for special
 // additionals !!!
-#define isDummy           0
+#define isDummyElement    0
 #define isSpecialMask    -16
 
 #define isComponent        0x30000
@@ -116,9 +134,13 @@ struct Property {
 #define isDiagramVScroll   0x8003
 
 
-
+/** \class Element
+  * \brief Superclass of all schematic drawing elements
+  *
+  *
+  */
 class Element {
-public: 
+public:
   Element();
   virtual ~Element();
 
@@ -132,7 +154,10 @@ public:
 };
 
 
-// label for Node and Wire classes
+/** \class Conductor
+  * \brief label for Node and Wire classes
+  *
+  */
 class Conductor : public Element {
 public:
   WireLabel *Label;
