@@ -14,133 +14,202 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
+/*!
+ * \file main.cpp
+ * \brief Implementation of the main application.
+ */
 
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
+
 #include <QtGui>
 #include <stdlib.h>
 #include <ctype.h>
 #include <math.h>
 #include <locale.h>
 
-#include <qapplication.h>
-#include <qstring.h>
-#include <qstringlist.h>
-#include <qtextcodec.h>
-#include <qtranslator.h>
-#include <qfile.h>
-#include <q3textstream.h>
-#include <qmessagebox.h>
-#include <qregexp.h>
+#include <QApplication>
+#include <QString>
+#include <QStringList>
+#include <QTextCodec>
+#include <QTranslator>
+#include <QFile>
+#include <QMessageBox>
+#include <QRegExp>
 
 #include "qucs.h"
 #include "main.h"
 #include "node.h"
 
+#include "schematic.h"
+#include "module.h"
+
+#ifdef _WIN32
+#include <Windows.h>  //for OutputDebugString
+#endif
+
 tQucsSettings QucsSettings;
 
-QFont savingFont;    // to remember which font to save in "qucsrc"
-
-QucsApp *QucsMain;  // the Qucs application itself
+QucsApp *QucsMain = 0;  // the Qucs application itself
 QString lastDir;    // to remember last directory for several dialogs
+QStringList qucsPathList;
 
 // #########################################################################
 // Loads the settings file and stores the settings.
 bool loadSettings()
 {
-  QFile file(QucsHomeDir.filePath("qucsrc"));
-  if(!file.open(QIODevice::ReadOnly)) return false; // settings file doesn't exist
+    QSettings settings("qucs","qucs");
 
-  Q3TextStream stream(&file);
-  QString Line, Setting;
+    if(settings.contains("x"))QucsSettings.x=settings.value("x").toInt();
+    if(settings.contains("y"))QucsSettings.y=settings.value("y").toInt();
+    if(settings.contains("dx"))QucsSettings.dx=settings.value("dx").toInt();
+    if(settings.contains("dy"))QucsSettings.dy=settings.value("dy").toInt();
+    if(settings.contains("font"))QucsSettings.font.fromString(settings.value("font").toString());
+    if(settings.contains("largeFontSize"))QucsSettings.largeFontSize=settings.value("largeFontSize").toDouble();
+    if(settings.contains("maxUndo"))QucsSettings.maxUndo=settings.value("maxUndo").toInt();
+    if(settings.contains("NodeWiring"))QucsSettings.NodeWiring=settings.value("NodeWiring").toInt();
+    if(settings.contains("BGColor"))QucsSettings.BGColor.setNamedColor(settings.value("BGColor").toString());
+    if(settings.contains("Editor"))QucsSettings.Editor=settings.value("Editor").toString();
+    if(settings.contains("FileTypes"))QucsSettings.FileTypes=settings.value("FileTypes").toStringList();
+    if(settings.contains("Language"))QucsSettings.Language=settings.value("Language").toString();
+    if(settings.contains("Comment"))QucsSettings.Comment.setNamedColor(settings.value("Comment").toString());
+    if(settings.contains("String"))QucsSettings.String.setNamedColor(settings.value("String").toString());
+    if(settings.contains("Integer"))QucsSettings.Integer.setNamedColor(settings.value("Integer").toString());
+    if(settings.contains("Real"))QucsSettings.Real.setNamedColor(settings.value("Real").toString());
+    if(settings.contains("Character"))QucsSettings.Character.setNamedColor(settings.value("Character").toString());
+    if(settings.contains("Type"))QucsSettings.Type.setNamedColor(settings.value("Type").toString());
+    if(settings.contains("Attribute"))QucsSettings.Attribute.setNamedColor(settings.value("Attribute").toString());
+    if(settings.contains("Directive"))QucsSettings.Directive.setNamedColor(settings.value("Directive").toString());
+    if(settings.contains("Task"))QucsSettings.Comment.setNamedColor(settings.value("Task").toString());
 
-  bool ok;
-  while(!stream.atEnd()) {
-    Line = stream.readLine();
-    Setting = Line.section('=',0,0);
-    Line    = Line.section('=',1).stripWhiteSpace();
-    if(Setting == "Position") {
-	QucsSettings.x = Line.section(",",0,0).toInt(&ok);
-	QucsSettings.y = Line.section(",",1,1).toInt(&ok); }
-    else if(Setting == "Size") {
-	QucsSettings.dx = Line.section(",",0,0).toInt(&ok);
-	QucsSettings.dy = Line.section(",",1,1).toInt(&ok); }
-    else if(Setting == "Font") {
-	QucsSettings.font.fromString(Line);
-	savingFont = QucsSettings.font;
+    if(settings.contains("Editor"))QucsSettings.Editor = settings.value("Editor").toString();
+    //if(settings.contains("BinDir"))QucsSettings.BinDir = settings.value("BinDir").toString();
+    //if(settings.contains("LangDir"))QucsSettings.LangDir = settings.value("LangDir").toString();
+    //if(settings.contains("LibDir"))QucsSettings.LibDir = settings.value("LibDir").toString();
+    if(settings.contains("AdmsXmlBinDir"))QucsSettings.AdmsXmlBinDir = settings.value("AdmsXmlBinDir").toString();
+    if(settings.contains("AscoBinDir"))QucsSettings.AscoBinDir = settings.value("AscoBinDir").toString();
+    //if(settings.contains("OctaveDir"))QucsSettings.OctaveDir = settings.value("OctaveDir").toString();
+    //if(settings.contains("ExamplesDir"))QucsSettings.ExamplesDir = settings.value("ExamplesDir").toString();
+    //if(settings.contains("DocDir"))QucsSettings.DocDir = settings.value("DocDir").toString();
+    if(settings.contains("OctaveBinDir"))QucsSettings.OctaveBinDir.setPath(settings.value("OctaveBinDir").toString());
+    if(settings.contains("QucsHomeDir"))
+      if(settings.value("QucsHomeDir").toString() != "")
+         QucsSettings.QucsHomeDir.setPath(settings.value("QucsHomeDir").toString());
+    QucsSettings.QucsWorkDir = QucsSettings.QucsHomeDir;
 
-	QucsSettings.largeFontSize
-		= floor(4.0/3.0 * QucsSettings.font.pointSize());
-	}
-    else if(Setting == "BGColor") {
-	QucsSettings.BGColor.setNamedColor(Line); }
-    else if(Setting == "maxUndo") {
-	QucsSettings.maxUndo = Line.toInt(&ok); }
-    else if(Setting == "Editor") {
-	QucsSettings.Editor = Line; }
-    else if(Setting == "FileType") {
-	QucsSettings.FileTypes.append(Line); }
-    else if(Setting == "Language") {
-	QucsSettings.Language = Line; }
-    else if(Setting == "SyntaxColor") {
-	QucsSettings.Comment.setNamedColor(Line.section(",", 0,0));
-	QucsSettings.String.setNamedColor(Line.section(",", 1,1));
-	QucsSettings.Integer.setNamedColor(Line.section(",", 2,2));
-	QucsSettings.Real.setNamedColor(Line.section(",", 3,3));
-	QucsSettings.Character.setNamedColor(Line.section(",", 4,4));
-	QucsSettings.Type.setNamedColor(Line.section(",", 5,5));
-	QucsSettings.Attribute.setNamedColor(Line.section(",", 6,6));
-	QucsSettings.Directive.setNamedColor(Line.section(",", 7,7));
-	QucsSettings.Task.setNamedColor(Line.section(",", 8,8));
+    if (settings.contains("IngnoreVersion")) QucsSettings.IgnoreFutureVersion = settings.value("IngnoreVersion").toBool();
+    else QucsSettings.IgnoreFutureVersion = false;
+
+
+    QucsSettings.RecentDocs = settings.value("RecentDocs").toString().split("*",QString::SkipEmptyParts);
+    QucsSettings.numRecentDocs = QucsSettings.RecentDocs.count();
+
+
+    // If present read in the list of directory paths in which Qucs should
+    // search for subcircuit schematics
+    int npaths = settings.beginReadArray("Paths");
+    for (int i = 0; i < npaths; ++i)
+    {
+        settings.setArrayIndex(i);
+        QString apath = settings.value("path").toString();
+        qucsPathList.append(apath);
     }
-    else if(Setting == "NodeWiring") {
-	QucsSettings.NodeWiring = Line.toInt(&ok); }
-  }
+    settings.endArray();
 
-  file.close();
-  return true;
+    QucsSettings.numRecentDocs = 0;
+
+    return true;
 }
 
 // #########################################################################
 // Saves the settings in the settings file.
 bool saveApplSettings(QucsApp *qucs)
 {
-  QFile file(QucsHomeDir.filePath("qucsrc"));
-  if(!file.open(QIODevice::WriteOnly)) {    // settings file cannot be created
-    QMessageBox::warning(0, QObject::tr("Warning"),
-			QObject::tr("Cannot save settings !"));
-    return false;
+    QSettings settings ("qucs","qucs");
+
+    settings.setValue("x", QucsSettings.x);
+    settings.setValue("y", QucsSettings.y);
+    settings.setValue("dx", QucsSettings.dx);
+    settings.setValue("dy", QucsSettings.dy);
+    settings.setValue("font", QucsSettings.font.toString());
+    settings.setValue("largeFontSize", QucsSettings.largeFontSize);
+    settings.setValue("maxUndo", QucsSettings.maxUndo);
+    settings.setValue("NodeWiring", QucsSettings.NodeWiring);
+    settings.setValue("BGColor", QucsSettings.BGColor.name());
+    settings.setValue("Editor", QucsSettings.Editor);
+    settings.setValue("FileTypes", QucsSettings.FileTypes);
+    settings.setValue("Language", QucsSettings.Language);
+    settings.setValue("Comment", QucsSettings.Comment.name());
+    settings.setValue("String", QucsSettings.String.name());
+    settings.setValue("Integer", QucsSettings.Integer.name());
+    settings.setValue("Real", QucsSettings.Real.name());
+    settings.setValue("Character", QucsSettings.Character.name());
+    settings.setValue("Type", QucsSettings.Type.name());
+    settings.setValue("Attribute", QucsSettings.Attribute.name());
+    settings.setValue("Directive", QucsSettings.Directive.name());
+    settings.setValue("Task", QucsSettings.Comment.name());
+    settings.setValue("Editor", QucsSettings.Editor);
+    //settings.setValue("BinDir", QucsSettings.BinDir);
+    //settings.setValue("LangDir", QucsSettings.LangDir);
+    //settings.setValue("LibDir", QucsSettings.LibDir);
+    settings.setValue("AdmsXmlBinDir", QucsSettings.AdmsXmlBinDir.canonicalPath());
+    settings.setValue("AscoBinDir", QucsSettings.AscoBinDir.canonicalPath());
+    //settings.setValue("OctaveDir", QucsSettings.OctaveDir);
+    //settings.setValue("ExamplesDir", QucsSettings.ExamplesDir);
+    //settings.setValue("DocDir", QucsSettings.DocDir);
+    settings.setValue("OctaveBinDir", QucsSettings.OctaveBinDir.canonicalPath());
+    settings.setValue("QucsHomeDir", QucsSettings.QucsHomeDir.canonicalPath());
+    settings.setValue("IngnoreVersion",QucsSettings.IgnoreFutureVersion);
+
+    // Copy the list of directory paths in which Qucs should
+    // search for subcircuit schematics from qucsPathList
+    settings.remove("Paths");
+    settings.beginWriteArray("Paths");
+    int i = 0;
+    foreach(QString path, qucsPathList) {
+         settings.setArrayIndex(i);
+         settings.setValue("path", path);
+         i++;
+     }
+     settings.endArray();
+
+  return true;
+
+}
+
+/*!
+ * \brief qucsMessageOutput handles qDebug, qWarning, qCritical, qFatal.
+ * \param type Message type (Qt enum)
+ * \param msg Message
+ *
+ * The message handler is used to get control of the messages.
+ * Particulary on Windows, as the messages are sent to the debugger and do not
+ * show on the terminal. The handler could aslo be extended to create a log
+ * mechanism.
+ * <http://qt-project.org/doc/qt-4.8/debug.html#warning-and-debugging-messages>
+ * <http://qt-project.org/doc/qt-4.8/qtglobal.html#qInstallMsgHandler>
+ */
+void qucsMessageOutput(QtMsgType type, const char *msg)
+{
+  switch (type) {
+  case QtDebugMsg:
+    fprintf(stderr, "Debug: %s\n", msg);
+    break;
+  case QtWarningMsg:
+    fprintf(stderr, "Warning: %s\n", msg);
+    break;
+  case QtCriticalMsg:
+    fprintf(stderr, "Critical: %s\n", msg);
+    break;
+  case QtFatalMsg:
+    fprintf(stderr, "Fatal: %s\n", msg);
+    abort();
   }
 
-  Q3TextStream stream(&file);
-
-  stream << "Settings file, Qucs " PACKAGE_VERSION "\n"
-    << "Position=" << qucs->x() << "," << qucs->y() << "\n"
-    << "Size=" << qucs->width() << "," << qucs->height() << "\n"
-    << "Font=" << savingFont.toString() << "\n"
-    << "Language=" << QucsSettings.Language << "\n"
-    << "BGColor=" << QucsSettings.BGColor.name() << "\n"
-    << "maxUndo=" << QucsSettings.maxUndo << "\n"
-    << "Editor=" << QucsSettings.Editor << "\n"
-    << "SyntaxColor="
-    << QucsSettings.Comment.name() << ","
-    << QucsSettings.String.name() << ","
-    << QucsSettings.Integer.name() << ","
-    << QucsSettings.Real.name() << ","
-    << QucsSettings.Character.name() << ","
-    << QucsSettings.Type.name() << ","
-    << QucsSettings.Attribute.name() << ","
-    << QucsSettings.Directive.name() << ","
-    << QucsSettings.Task.name() << "\n"
-    << "NodeWiring=" << QucsSettings.NodeWiring << "\n";
-
-  QStringList::Iterator it = QucsSettings.FileTypes.begin();
-  while(it != QucsSettings.FileTypes.end())
-    stream << "FileType=" << (*(it++)) << "\n";
-
-  file.close();
-  return true;
+#ifdef _WIN32
+  OutputDebugStringA(msg);
+#endif
 }
 
 // #########################################################################
@@ -339,7 +408,7 @@ QString num2str(double Num)
 
   QString Str = QString::number(Num);
   if(c)  Str += c;
-  
+
   return Str;
 }
 
@@ -378,12 +447,21 @@ void convert2ASCII(QString& Text)
 }
 
 // #########################################################################
+// Converts a path to an absolute path and resolves paths relative to the
+// Qucs home directory
 QString properAbsFileName(const QString& Name)
 {
   QString s = Name;
   QFileInfo Info(s);
-  if(Info.isRelative()) s = QucsWorkDir.filePath(s);
-  return QDir::cleanDirPath(s);
+
+  if(Info.isRelative())
+  {
+      // if it's a relative file, look for it relative to the
+      // working directory (the qucs home directory)
+      s = QucsSettings.QucsWorkDir.filePath(s);
+  }
+  // return the clean path
+  return QDir::cleanPath(s);
 }
 
 // #########################################################################
@@ -539,7 +617,77 @@ bool checkVersion(QString& Line)
 // ##########                                                     ##########
 // #########################################################################
 
+int doNetlist(QString schematic, QString netlist)
+{
+  qDebug() << "*** try to load schematic :" << schematic;
 
+  QFile file(schematic);  // save simulator messages
+  if(file.open(QIODevice::ReadOnly)) {
+    file.close();
+  }
+  else {
+    fprintf(stderr, "Error: Could not load schematic %s\n", schematic.ascii());
+    return 1;
+  }
+
+  // populate Modules list
+  Module::registerModules ();
+
+  // new schematic from file
+  Schematic *sch = new Schematic(0, schematic);
+
+  // load schematic file if possible
+  if(!sch->loadDocument()) {
+    fprintf(stderr, "Error: Could not load schematic %s\n", schematic.ascii());
+    delete sch;
+    return 1;
+  }
+
+  qDebug() << "*** try to write netlist  :" << netlist;
+
+  QStringList Collect;
+
+  QTextEdit *ErrText = new QTextEdit();  //dummy
+  QFile NetlistFile;
+  QTextStream   Stream;
+
+  Collect.clear();  // clear list for NodeSets, SPICE components etc.
+
+  NetlistFile.setName(netlist);
+  if(!NetlistFile.open(QIODevice::WriteOnly)) {
+    fprintf(stderr, "Error: Could not load netlist %s\n", netlist.ascii());
+    return -1;
+  }
+
+  Stream.setDevice(&NetlistFile);
+  int SimPorts = sch->prepareNetlist(Stream, Collect, ErrText);
+
+  if(SimPorts < -5) {
+    NetlistFile.close();
+    fprintf(stderr, "Error: Could not prepare the netlist...\n");
+    return 1;
+  }
+
+  // output NodeSets, SPICE simulations etc.
+  for(QStringList::Iterator it = Collect.begin();
+  it != Collect.end(); ++it) {
+    // don't put library includes into netlist...
+    if ((*it).right(4) != ".lst" &&
+    (*it).right(5) != ".vhdl" &&
+    (*it).right(4) != ".vhd" &&
+    (*it).right(2) != ".v") {
+      Stream << *it << '\n';
+    }
+  }
+
+  Stream << '\n';
+
+  QString SimTime = sch->createNetlist(Stream, SimPorts);
+
+  NetlistFile.close();
+
+  return 0;
+}
 
 
 // #########################################################################
@@ -547,7 +695,6 @@ bool checkVersion(QString& Line)
 // ##########                  Program Start                      ##########
 // ##########                                                     ##########
 // #########################################################################
-
 int main(int argc, char *argv[])
 {
   // apply default settings
@@ -566,37 +713,85 @@ int main(int argc, char *argv[])
   QucsSettings.dx = w*3/4;
   QucsSettings.dy = h*3/4;
 
-  // is application relocated?
-  char * var = getenv ("QUCSDIR");
-  if (var != NULL) {
-    QDir QucsDir = QDir (var);
-    QString QucsDirStr = QucsDir.canonicalPath ();
-    QucsSettings.BinDir =
-      QDir::convertSeparators (QucsDirStr + "/bin/");
-    QucsSettings.BitmapDir =
-      QDir::convertSeparators (QucsDirStr + "/share/qucs/bitmaps/");
-    QucsSettings.LangDir =
-      QDir::convertSeparators (QucsDirStr + "/share/qucs/lang/");
-    QucsSettings.LibDir =
-      QDir::convertSeparators (QucsDirStr + "/share/qucs/library/");
-    QucsSettings.OctaveDir =
-      QDir::convertSeparators (QucsDirStr + "/share/qucs/octave/");
-    QucsSettings.ExamplesDir = 
-      QDir::convertSeparators (QucsDirStr + "/share/qucs/docs/examples/");
-    QucsSettings.DocDir = 
-      QDir::convertSeparators (QucsDirStr + "/share/qucs/docs/");
-  } else {
-    QucsSettings.BinDir = BINARYDIR;
-    QucsSettings.BitmapDir = BITMAPDIR;
-    QucsSettings.LangDir = LANGUAGEDIR;
-    QucsSettings.LibDir = LIBRARYDIR;
-    QucsSettings.OctaveDir = OCTAVEDIR;
-    QucsSettings.ExamplesDir = QDir(DOCDIR).canonicalPath()+"/examples/";
-    QucsSettings.DocDir = DOCDIR;
+  // check for relocation env variable
+  char* var = getenv("QUCSDIR");
+  QDir QucsDir;
+  if (var!= NULL)
+  {
+      QucsDir = QDir(QString(var));
+      qDebug() << "QUCSDIR set: " << QucsDir.absolutePath();
+  }
+  else
+  {
+     QString QucsApplicationPath = QCoreApplication::applicationDirPath();
+     #ifdef __APPLE__
+     QucsDir = QDir(QucsApplicationPath.section("/bin",0,0));
+     #else
+     QucsDir = QDir(QucsApplicationPath.replace("/bin",""));
+     #endif
+
+  }
+
+  QucsSettings.BinDir =      QucsDir.absolutePath() + "/bin/";
+  QucsSettings.LangDir =     QucsDir.canonicalPath() + "/share/qucs/lang/";
+  QucsSettings.LibDir =      QucsDir.canonicalPath() + "/share/qucs/library/";
+  QucsSettings.OctaveDir =   QucsDir.canonicalPath() + "/share/qucs/octave/";
+  QucsSettings.ExamplesDir = QucsDir.canonicalPath() + "/share/qucs/docs/examples/";
+  QucsSettings.DocDir =      QucsDir.canonicalPath() + "/share/qucs/docs/";
+
+  QucsSettings.Editor = "qucs";
+  QucsSettings.QucsHomeDir.setPath(QDir::homeDirPath()+QDir::convertSeparators ("/.qucs"));
+  QucsSettings.QucsWorkDir.setPath(QucsSettings.QucsHomeDir.canonicalPath());
+
+
+  var = getenv("ADMSXMLBINDIR");
+  if(var != NULL) {
+      QucsSettings.AdmsXmlBinDir.setPath(QString(var));
+  }
+  else {
+      // default admsXml bindir same as Qucs
+      QString admsExec;
+#ifdef __MINGW32__
+      admsExec = QDir::toNativeSeparators(QucsSettings.BinDir+"/"+"admsXml.exe");
+#else
+      admsExec = QDir::toNativeSeparators(QucsSettings.BinDir+"/"+"admsXml");
+#endif
+      QFile adms(admsExec);
+      if(adms.exists())
+        QucsSettings.AdmsXmlBinDir.setPath(QucsSettings.BinDir);
+  }
+
+  var = getenv("ASCOBINDIR");
+  if(var != NULL)  {
+      QucsSettings.AscoBinDir.setPath(QString(var));
+  }
+  else  {
+      // default ASCO bindir same as Qucs
+      QString ascoExec;
+#ifdef __MINGW32__
+      ascoExec = QDir::toNativeSeparators(QucsSettings.BinDir+"/"+"asco.exe");
+#else
+      ascoExec = QDir::toNativeSeparators(QucsSettings.BinDir+"/"+"asco");
+#endif
+      QFile asco(ascoExec);
+      if(asco.exists())
+        QucsSettings.AscoBinDir.setPath(QucsSettings.BinDir);
+  }
+
+  var = getenv("OCTAVEBINDIR");
+  if(var != NULL)  {
+      QucsSettings.OctaveBinDir.setPath(QString(var));
+  }
+  else  {
+#ifdef __MINGW32__
+      QucsSettings.OctaveBinDir.setPath(QString("C:/Software/Octave-3.6.4/bin/"));
+#else
+      QFile octaveExec("/usr/bin/octave");
+      if(octaveExec.exists())QucsSettings.OctaveBinDir.setPath(QString("/usr/bin/"));
+      QFile octaveExec1("/usr/local/bin/octave");
+      if(octaveExec1.exists()) QucsSettings.OctaveBinDir.setPath(QString("/usr/local/bin/"));
+#endif
   }
-  QucsSettings.Editor = QucsSettings.BinDir + "qucsedit";
-  QucsWorkDir.setPath(QDir::homeDirPath()+QDir::convertSeparators ("/.qucs"));
-  QucsHomeDir.setPath(QDir::homeDirPath()+QDir::convertSeparators ("/.qucs"));
   loadSettings();
 
   if(!QucsSettings.BGColor.isValid())
@@ -622,26 +817,13 @@ int main(int argc, char *argv[])
   if(!QucsSettings.Task.isValid())
     QucsSettings.Task = Qt::darkRed;
 
-  var = getenv ("ASCODIR");
-  if (var != NULL) {
-    QDir AscoDir = QDir (var);
-    QString AscoDirStr = AscoDir.canonicalPath ();
-    QucsSettings.AscoDir =
-      QDir::convertSeparators (AscoDirStr + "/bin/");
-  } 
-  else {
-    QFile file("/usr/local/bin/asco");
-    if ( file.exists() ){
-      QucsSettings.AscoDir =
-          QDir::convertSeparators ("/usr/local/bin/");
-      file.close();
-    }
-    else
-      QucsSettings.AscoDir = "";
-  }
 
   a.setFont(QucsSettings.font);
 
+  // set codecs
+  QTextCodec::setCodecForLocale(QTextCodec::codecForName("UTF-8"));
+  QTextCodec::setCodecForTr(QTextCodec::codecForName("UTF-8"));
+
   QTranslator tor( 0 );
   QString lang = QucsSettings.Language;
   if(lang.isEmpty())
@@ -653,10 +835,62 @@ int main(int argc, char *argv[])
   // work properly !???!
   setlocale (LC_NUMERIC, "C");
 
+  QString schematic;
+  QString netlist;
+
+  QString operation;
+
+  // simple command line parser
+  for (int i = 1; i < argc; ++i) {
+    if (!strcmp(argv[i], "-h") || !strcmp(argv[i], "--help")) {
+      fprintf(stdout,
+  "Usage: %s [OPTION]...\n\n"
+  "  -h, --help     display this help and exit\n"
+  "  -v, --version  display version information and exit\n"
+  "  -n, --netlist  convert Qucs schematic into netlist\n"
+  "  -i FILENAME    use file as input schematic\n"
+  "  -o FILENAME    use file as output netlist\n"
+  , argv[0]);
+      return 0;
+    }
+    else if (!strcmp(argv[i], "-v") || !strcmp(argv[i], "--version")) {
+      fprintf(stdout, "Qucs " PACKAGE_VERSION "\n");
+      return 0;
+    }
+    else if (!strcmp(argv[i], "-n") || !strcmp(argv[i], "--netlist")) {
+      operation = "netlist";
+    }
+    else if (!strcmp(argv[i], "-i")) {
+      schematic = argv[++i];
+    }
+    else if (!strcmp(argv[i], "-o")) {
+      netlist = argv[++i];
+    }
+    else {
+      fprintf(stderr, "Error: Unknown option: %s\n", argv[i]);
+      return -1;
+    }
+  }
+
+  // check operation and its required arguments
+  if (operation == "netlist") {
+    if (schematic.isEmpty()) {
+      fprintf(stderr, "Error: Expected input schematic file.\n");
+      return -1;
+    }
+    if (netlist.isEmpty()) {
+      fprintf(stderr, "Error: Expected output netlist file.\n");
+      return -1;
+    }
+    // create netlist from schematic
+    return doNetlist(schematic, netlist);
+  }
+
   QucsMain = new QucsApp();
   a.setMainWidget(QucsMain);
+  qInstallMsgHandler(qucsMessageOutput);
   QucsMain->show();
   int result = a.exec();
-  saveApplSettings(QucsMain);
+  //saveApplSettings(QucsMain);
   return result;
 }
