@@ -18,7 +18,7 @@
 #ifndef MNEMO_H
 #define MNEMO_H
 
-#include <qstring.h>
+#include <QString>
 
 void encode_String(const QString&, QString&);
 void decode_String(QString&);
