@@ -15,9 +15,9 @@
  *                                                                         *
  ***************************************************************************/
 #include <QtGui>
-#include <q3dict.h>
-#include <qstring.h>
-#include <qstringlist.h>
+#include <Q3Dict>
+#include <QString>
+#include <QStringList>
 //Added by qt3to4:
 #include <Q3PtrList>
 
@@ -32,6 +32,8 @@
 Q3Dict<Module> Module::Modules;
 Q3PtrList<Category> Category::Categories;
 
+QMap<QString, QString> Module::vaComponents;
+
 // Constructor creates instance of module object.
 Module::Module () {
   info = 0;
@@ -79,11 +81,61 @@ Component * Module::getComponent (QString Model) {
   if (m) {
     QString Name;
     char * File;
-    return (Component *) m->info (Name, File, true);
+    QString vaBitmap;
+    if (vaComponents.contains(Model))
+      return (Component *)
+              vacomponent::info (Name, vaBitmap, true, vaComponents[Model]);
+    else
+      return (Component *) m->info (Name, File, true);
   }
   return 0;
 }
 
+void Module::registerDynamicComponents()
+{
+    qDebug() << "Module::registerDynamicComponents()";
+
+
+  // vaComponents is populated in QucsApp::slotLoadModule
+
+  // register modules symbol and properties out of in vaComponents
+  QMapIterator<QString, QString> i(vaComponents);
+   while (i.hasNext()) {
+     i.next();
+
+//     qDebug() << i.key() << ": " << i.value() << endl;
+
+     Module * m = new Module ();
+
+     // what now? pointer to info?
+
+     // the typedef needs to be different
+     //passes the pointer, but it has no idea how to call the JSON
+     m->infoVA = &vacomponent::info;
+
+     // TODO maybe allow user load into custom category?
+     m->category = QObject::tr("verilog-a user devices");
+
+     // instantiation of the component once in order
+     // to obtain "Model" property of the component
+     //QString Name, Model;
+     //char * File;
+     QString Name, Model, vaBitmap;
+//     char * File;
+     Component * c = (Component *)
+             vacomponent::info (Name, vaBitmap, true, vaComponents[i.key()]);
+     Model = c->Model;
+     delete c;
+
+     // put into category and the component hash
+     intoCategory (m);
+
+     if (!Modules.find (Model))
+         Modules.insert (Model, m);
+
+   } // while
+}
+
 // The function appends the given module to the appropriate category.
 // If there is no such category yet, then the category gets created.
 void Module::intoCategory (Module * m) {
@@ -162,6 +214,8 @@ void Module::intoCategory (Module * m) {
   REGISTER_MOD_1 (QObject::tr("paintings"),val)
 #define REGISTER_PAINT_2(val,inf1,inf2) \
   REGISTER_MOD_2 (QObject::tr("paintings"),val,inf1,inf2)
+#define REGISTER_EXTERNAL_1(val) \
+  REGISTER_COMP_1 (QObject::tr("external sim components"),val)
 
 // This function has to be called once at application startup.  It
 // registers every component available in the application.  Put here
@@ -287,10 +341,11 @@ void Module::registerModules (void) {
   REGISTER_VERILOGA_2 (hicumL0V1p3, info, info_pnp);
   REGISTER_VERILOGA_1 (hicumL2V2p23);
   REGISTER_VERILOGA_1 (hicumL2V2p24);
-  REGISTER_VERILOGA_1 (hicumL2V2p31n); 
+  REGISTER_VERILOGA_1 (hicumL2V2p31n);
   REGISTER_VERILOGA_1 (photodiode);
   REGISTER_VERILOGA_1 (phototransistor);
   REGISTER_VERILOGA_1 (nigbt);
+  REGISTER_VERILOGA_1 (vcresistor);
 
   // digital components
   REGISTER_DIGITAL_1 (Digi_Source);
@@ -364,6 +419,10 @@ void Module::registerModules (void) {
   REGISTER_DIAGRAM_1 (TimingDiagram);
   REGISTER_DIAGRAM_1 (TruthDiagram);
 
+  // external simulation
+  REGISTER_EXTERNAL_1 (ETR_Sim);
+  REGISTER_EXTERNAL_1 (ecvs);
+
   // paintings
   REGISTER_PAINT_1 (GraphicLine);
   REGISTER_PAINT_1 (Arrow);
@@ -371,6 +430,7 @@ void Module::registerModules (void) {
   REGISTER_PAINT_2 (Ellipse, info, info_filled);
   REGISTER_PAINT_2 (Rectangle, info, info_filled);
   REGISTER_PAINT_1 (EllipseArc);
+
 }
 
 // This function has to be called once at application end.  It removes
