@@ -1,6 +1,7 @@
 //Added by qt3to4:
 #include <Q3PtrList>
 #include <Q3Dict>
+#include <QMap>
 /***************************************************************************
                                module.h
                               ----------
@@ -23,6 +24,7 @@
 
 // function typedefs for circuits and analyses
 typedef Element * (* pInfoFunc) (QString&, char * &, bool);
+typedef Element * (* pInfoVAFunc) (QString&, QString&, bool, QString);
 typedef Component * (* pCreatorFunc) ();
 
 class Module
@@ -34,9 +36,11 @@ class Module
   static void registerComponent (QString, pInfoFunc);
   static void intoCategory (Module *);
   static Component * getComponent (QString);
+  static void registerDynamicComponents(void);
 
  public:
   static Q3Dict<Module> Modules;
+  static QMap<QString, QString> vaComponents;
 
  public:
   static void registerModules (void);
@@ -44,6 +48,7 @@ class Module
 
  public:
   pInfoFunc info;
+  pInfoVAFunc infoVA;
   QString category;
 };
 
