@@ -6,18 +6,13 @@
 #ifndef OCTAVE_WINDOW_H
 #define OCTAVE_WINDOW_H
 
-#include <qwidget.h>
-#include <q3process.h>
-#include <qstringlist.h>
-//Added by qt3to4:
+#include <QWidget>
+#include <QProcess>
+#include <QStringList>
 #include <QKeyEvent>
-#include <Q3VBoxLayout>
 #include <QDockWidget>
-
-class QLineEdit;
-class Q3TextEdit;
-class Q3VBoxLayout;
-class Q3DockWindow;
+#include <QTextEdit>
+#include <QLineEdit>
 
 
 class OctaveWindow : public QWidget {
@@ -35,21 +30,18 @@ public:
 private slots:
   void slotDisplayMsg();
   void slotDisplayErr();
-  void slotOctaveEnded();
+  void slotOctaveEnded(int status);
   void slotSendCommand();
 
 protected:
-  void keyPressEvent(QKeyEvent*);
+  bool eventFilter(QObject *obj, QEvent *event);
 
 private:
-  Q3VBoxLayout *vBox;
-  Q3TextEdit *output;
+  QTextEdit *output;
+  QProcess octProcess;
   QLineEdit *input;
-
-  Q3Process octProcess;
-
   QStringList cmdHistory;
-  QStringList::Iterator histIterator;
+  int histPosition;
 };
 
 #endif
