@@ -18,10 +18,10 @@
 #include "ellipse.h"
 #include "filldialog.h"
 #include "schematic.h"
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
+#include <QPushButton>
+#include <QLineEdit>
+#include <QComboBox>
+#include <QCheckBox>
 
 
 Ellipse::Ellipse(bool _filled)
@@ -184,7 +184,7 @@ QString Ellipse::saveCpp()
   QString b = filled ?
     QString (", QBrush (QColor (\"%1\"), %2)").
     arg(Brush.color().name()).arg(toBrushString(Brush.style())) : "";
-  QString s = 
+  QString s =
     QString ("new Area (%1, %2, %3, %4, "
 	     "QPen (QColor (\"%5\"), %6, %7)%8)").
     arg(cx).arg(cy).arg(x2).arg(y2).
@@ -194,6 +194,21 @@ QString Ellipse::saveCpp()
   return s;
 }
 
+QString Ellipse::saveJSON()
+{
+  QString b = filled ?
+    QString ("\"colorfill\" : \"%1\", \"stylefill\" : \"%2\"").
+    arg(Brush.color().name()).arg(toBrushString(Brush.style())) : "";
+  QString s =
+    QString("{\"type\" : \"ellipse\", "
+    "\"x\" : %1, \"y\" : %2, \"w\" : %3, \"h\" : %4,"
+    "\"color\" : \"%5\", \"thick\" : %6, \"style\" : \"%7\", %8},").
+    arg(cx).arg(cy).arg(x2).arg(y2).
+    arg(Pen.color().name()).arg(Pen.width()).arg(toPenString(Pen.style())).
+    arg(b);
+  return s;
+}
+
 // --------------------------------------------------------------------------
 // Checks if the resize area was clicked.
 bool Ellipse::resizeTouched(float fX, float fY, float len)
@@ -246,16 +261,15 @@ void Ellipse::MouseMoving(
 {
   if(State > 0) {
     if(State > 1)
-      paintScale->PostPaintEvent(_Ellipse, x1, y1, x2-x1, y2-y1); // erase old painting
+      // _Ellipse hang/crash application, using _Arc solved, see bug 141 (closed)
+      paintScale->PostPaintEvent(_Arc, x1, y1, x2-x1, y2-y1, 0, 16*360); // erase old painting
     State++;
     x2 = gx;
     y2 = gy;
-    paintScale->PostPaintEvent(_Ellipse, x1, y1, x2-x1, y2-y1);  // paint new painting
+    paintScale->PostPaintEvent(_Arc, x1, y1, x2-x1, y2-y1, 0, 16*360);
   }
   else { x2 = gx; y2 = gy; }
 
-
-  #warning p->setPen(Qt::SolidLine);
   if(drawn) {
     p->PostPaintEvent(_Ellipse, cx+13, cy, 18, 12,0,0,true);  // erase old cursor symbol
     if(filled) {
