@@ -18,9 +18,9 @@
 #include "graphicline.h"
 #include "filldialog.h"
 #include "schematic.h"
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <qcombobox.h>
+#include <QPushButton>
+#include <QLineEdit>
+#include <QComboBox>
 
 #include <math.h>
 
@@ -148,7 +148,7 @@ QString GraphicLine::save()
 // --------------------------------------------------------------------------
 QString GraphicLine::saveCpp()
 {
-  QString s = 
+  QString s =
     QString ("new Line (%1, %2, %3, %4, QPen (QColor (\"%5\"), %6, %7))").
     arg(cx+x1).arg(cy+y1).arg(cx+x2).arg(cy+y2).
     arg(Pen.color().name()).arg(Pen.width()).arg(toPenString(Pen.style()));
@@ -156,6 +156,17 @@ QString GraphicLine::saveCpp()
   return s;
 }
 
+QString GraphicLine::saveJSON()
+{
+  QString s =
+    QString ("{\"type\" : \"line\", "
+      "\"x1\" : %1, \"y1\" : %2, \"x2\" : %3, \"y2\" : %4, "
+      "\"color\" : \"%5\", \"thick\" : %6, \"style\" : \"%7\"},").
+      arg(cx+x1).arg(cy+y1).arg(cx+x2).arg(cy+y2).
+      arg(Pen.color().name()).arg(Pen.width()).arg(toPenString(Pen.style()));
+  return s;
+}
+
 // --------------------------------------------------------------------------
 // Checks if the resize area was clicked.
 bool GraphicLine::resizeTouched(float fX, float fY, float len)
@@ -207,7 +218,7 @@ void GraphicLine::MouseMoving(
   else { cx = gx; cy = gy; }
 
 
-  #warning p->setPen(Qt::SolidLine);
+  // FIXME #warning p->setPen(Qt::SolidLine);
   if(drawn) {
     p->PostPaintEvent(_Line, x1+27, y1, x1+15, y1+12,0,0,true);  // erase old cursor symbol
     p->PostPaintEvent(_Line, x1+25, y1-2, x1+29, y1+2,0,0,true);
