@@ -18,10 +18,10 @@
 #include "rectangle.h"
 #include "filldialog.h"
 
-#include <qpushbutton.h>
-#include <qlineedit.h>
-#include <qcombobox.h>
-#include <qcheckbox.h>
+#include <QPushButton>
+#include <QLineEdit>
+#include <QComboBox>
+#include <QCheckBox>
 #include "schematic.h"
 
 Rectangle::Rectangle(bool _filled)
@@ -184,7 +184,7 @@ QString Rectangle::saveCpp()
   QString b = filled ?
     QString (", QBrush (QColor (\"%1\"), %2)").
     arg(Brush.color().name()).arg(toBrushString(Brush.style())) : "";
-  QString s = 
+  QString s =
     QString ("new Area (%1, %2, %3, %4, "
 	     "QPen (QColor (\"%5\"), %6, %7)%8)").
     arg(cx).arg(cy).arg(x2).arg(y2).
@@ -194,6 +194,22 @@ QString Rectangle::saveCpp()
   return s;
 }
 
+QString Rectangle::saveJSON()
+{
+  QString b = filled ?
+    QString ("\"colorfill\" : \"%1\", \"stylefill\" : \"%2\"").
+    arg(Brush.color().name()).arg(toBrushString(Brush.style())) : "";
+
+  QString s =
+    QString("{\"type\" : \"rectangle\", "
+      "\"x\" : %1, \"y\" : %2, \"w\" : %3, \"h\" : %4, "
+      "\"color\" : \"%5\", \"thick\" : %6, \"style\" : \"%7\", %8},").
+      arg(cx).arg(cy).arg(x2).arg(y2).
+      arg(Pen.color().name()).arg(Pen.width()).arg(toPenString(Pen.style())).
+      arg(b);
+  return s;
+}
+
 // --------------------------------------------------------------------------
 // Checks if the resize area was clicked.
 bool Rectangle::resizeTouched(float fX, float fY, float len)
@@ -255,7 +271,7 @@ void Rectangle::MouseMoving(
   else { x2 = gx; y2 = gy; }
 
 
-  #warning p->setPen(Qt::SolidLine);
+  // FIXME #warning p->setPen(Qt::SolidLine);
   if(drawn) {
     p->PostPaintEvent(_Rect, cx+13, cy, 18, 12,0,0,true);  // erase old cursor symbol
     if(filled) {   // hatched ?
