@@ -19,10 +19,10 @@
 #define QUCS_H
 
 #include <QtGui>
-//#include <q3mainwindow.h>
+//#include <Q3MainWindow>
 #include <QMainWindow>
-#include <qstring.h>
-#include <qdir.h>
+#include <QString>
+#include <QDir>
 //Added by qt3to4:
 #include <QLabel>
 #include <Q3PtrList>
@@ -36,6 +36,7 @@
 #include <QTabWidget>
 #include <QDockWidget>
 //#include <QListWidget>
+#include <QSettings>
 
 class QucsDoc;
 class Schematic;
@@ -45,35 +46,24 @@ class SearchDialog;
 class QLabel;
 class QAction;
 class QPrinter;
-//class Q3ToolBar;
 class QLineEdit;
 class QComboBox;
 class QTabWidget;
-//class Q3PopupMenu;
-//class Q3ListBox;
-//class Q3ListBoxItem;
 class Q3ListView;
 class Q3ListViewItem;
-//class Q3IconView;
-//class Q3IconViewItem;
-//class VTabbedDockWidget;
-//class VTabWidget;
 class OctaveWindow;
+class MessageDock;
 
 typedef bool (Schematic::*pToggleFunc) ();
 typedef void (MouseActions::*pMouseFunc) (Schematic*, QMouseEvent*);
 typedef void (MouseActions::*pMouseFunc2) (Schematic*, QMouseEvent*, float, float);
 
-extern QDir QucsWorkDir;
-extern QDir QucsHomeDir;
-
-
 class QucsApp : public QMainWindow {
   Q_OBJECT
 public:
   QucsApp();
  ~QucsApp();
-
+  QSettings *qucsSettings;
   bool closeAllFiles();
   static int testFile(const QString&);
   bool gotoPage(const QString&);   // to load a document
@@ -82,6 +72,11 @@ public:
   QString fileType (const QString&);
 
   QString ProjName;   // name of the project, that is open
+  //QList<QString> qucsPathList; // the qucs path list for subcircuits and spice files
+  QHash<QString,QString> schNameHash; // QHash for the schematic files lookup
+  QStringList spiceExtensions; // List of extensions used for spice files
+  QString getSpiceFileFilter (void); // generate file filter string for spice files
+  QHash<QString,QString> spiceNameHash; // QHash for the spice files lookup
 
   QLineEdit *editText;  // for edit component properties on schematic
   SearchDialog *SearchDia;  // global in order to keep values
@@ -116,6 +111,7 @@ public slots:
   void slotEditCut();     // put marked object into clipboard and delete it
   void slotEditCopy();    // put the marked object into the clipboard
   void slotApplSettings();// open dialog to change application settings
+  void slotRefreshSchPath(); // refresh the schematic path hash
 
   void slotIntoHierarchy();
   void slotPopHierarchy();
@@ -135,6 +131,7 @@ public slots:
   void slotShowContentMenu(const QPoint &);
   //void slotShowContentMenu(Q3ListViewItem*, const QPoint&, int);
   void slotCMenuOpen();
+  void slotCMenuCopy();
   void slotCMenuRename();
   void slotCMenuDelete();
   void slotCMenuDelGroup();
@@ -145,6 +142,7 @@ private slots:
   void slotOpenProject(QListWidgetItem*);
   void slotMenuCloseProject();
   void slotSelectSubcircuit(QTreeWidgetItem*);
+  void slotSelectLibComponent(QTreeWidgetItem*);
   void slotOpenContent(QTreeWidgetItem*);
   void slotSetCompView(int);
   void slotProjNewButt();
@@ -158,50 +156,48 @@ private slots:
   void slotChangePage(QString&, QString&);
   void slotNextTab();
   void slotHideEdit();
-
 signals:
   void signalKillEmAll();
 
 public:
   MouseActions *view;
   QTabWidget *DocumentTab;
-  //Q3IconView  *CompComps;
   QListWidget *CompComps;
+  QTreeWidget *libTreeWidget;
 
   // menu appearing by right mouse button click on content listview
   QMenu *ContentMenu;
 
   // corresponding actions
-  QAction *ActionCMenuOpen, *ActionCMenuRename, *ActionCMenuDelete, *ActionCMenuDelGroup, *ActionCMenuInsert;
+  QAction *ActionCMenuOpen, *ActionCMenuCopy, *ActionCMenuRename, *ActionCMenuDelete, *ActionCMenuDelGroup, *ActionCMenuInsert;
 
   QAction *fileNew, *textNew, *fileNewDpl, *fileOpen, *fileSave, *fileSaveAs,
           *fileSaveAll, *fileClose, *fileExamples, *fileSettings, *filePrint, *fileQuit,
-          *projNew, *projOpen, *projDel, *projClose, *applSettings,
+          *projNew, *projOpen, *projDel, *projClose, *applSettings, *refreshSchPath,
           *editCut, *editCopy, *magAll, *magOne, *magMinus, *filePrintFit,
           *symEdit, *intoH, *popH, *simulate, *dpl_sch, *undo, *redo, *dcbias;
 
+  QAction *exportAsImage;
+
   QAction *activeAction;    // pointer to the action selected by the user
 
 private:
   QPrinter  *Printer; // printer is global (to remember the user settings)
 
 // ********* Widgets on the main area **********************************
-  //VTabbedDockWidget   *dock;
-  QDockWidget *dock;
-  QTabWidget *TabView;
-  QDockWidget *octDock;
-  OctaveWindow  *octave;
+  QDockWidget     *dock;
+  QTabWidget      *TabView;
+  QDockWidget     *octDock;
+  OctaveWindow    *octave;
+  MessageDock     *messageDock;
 
-  QListWidget      *Projects;
-  //Q3ListView     *Content;
-  QTreeWidget *Content;
-  //Q3ListViewItem *ConSchematics, *ConSources, *ConDisplays, *ConDatasets,
-  //              *ConOthers, *ConVerilog, *ConVerilogA, *ConOctave;
+  QListWidget     *Projects;
+  QTreeWidget     *Content;
   QTreeWidgetItem *ConSchematics, *ConSources, *ConDisplays, *ConDatasets,
-                *ConOthers, *ConVerilog, *ConVerilogA, *ConOctave;
+                  *ConOthers, *ConVerilog, *ConVerilogA, *ConOctave;
 
 
-  QComboBox     *CompChoose;
+  QComboBox       *CompChoose;
 
 // ********** Properties ************************************************
   Q3PtrList<QString> HierarchyHistory; // keeps track of "go into subcircuit"
@@ -215,8 +211,6 @@ private:
   void printCurrentDocument(bool);
   bool saveFile(QucsDoc *Doc=0);
   bool saveAs();
-  void readProjects();
-  void readProjectFiles();
   void openProject(const QString&, const QString&);
   bool deleteProject(const QString&, const QString&);
   void updatePortNumber(QucsDoc*, int);
@@ -228,6 +222,18 @@ private:
   bool isTextDocument(QWidget *);
   void closeFile(int);
 
+  void updateRecentFilesList(QString s);
+  void successExportMessages(bool ok);
+  void fillLibrariesTreeView (void);
+
+public:
+
+  void readProjects();
+  void readProjectFiles();
+  void updatePathList(void); // update the list of paths, pruning non-existing paths
+  void updatePathList(QStringList);
+  void updateSchNameHash(void); // maps all schematic files in the path list
+  void updateSpiceNameHash(void); // maps all spice files in the path list
 
 /* **************************************************
    *****  The following methods are located in  *****
@@ -260,9 +266,9 @@ private:
 
   // menus contain the items of their menubar
   QMenu *fileMenu, *editMenu, *insMenu, *projMenu, *simMenu, *viewMenu,
-             *helpMenu, *alignMenu, *toolMenu;
+             *helpMenu, *alignMenu, *toolMenu, *recentfilesMenu;
 
-  // submenus for the PDF documents 
+  // submenus for the PDF documents
   QMenu *helpTechnical, *helpReport, *helpTutorial;
 
   QToolBar *fileToolbar, *editToolbar, *viewToolbar, *workToolbar;
@@ -291,7 +297,7 @@ public:
           *distrHor, *distrVert, *selectAll, *callLib, *callMatch, *changeProps,
           *addToProj, *editFind, *editFindAgain, *insEntity, *selectMarker,
           *createLib, *importData, *graph2csv, *createPkg, *extractPkg,
-          *callAtt, *centerHor, *centerVert;
+          *callAtt, *callRes, *centerHor, *centerVert, *loadModule, *buildModule;
 
 public slots:
   void slotEditRotate(bool);  // rotate the selected items
@@ -304,6 +310,7 @@ public slots:
   void slotInsertPort(bool);
   void slotInsertEntity();
   void slotSetWire(bool);
+  void slotEscape();
   void slotSelect(bool);
   void slotEditActivate(bool);
   void slotInsertLabel(bool);
@@ -333,11 +340,15 @@ public slots:
   void slotCallLibrary();
   void slotCallMatch();
   void slotCallAtt();
+  void slotCallRes();
   void slotHelpIndex();       // shows a HTML docu: Help Index
   void slotGettingStarted();  // shows a HTML docu: Getting started
   void slotChangeProps();
   void slotAddToProject();
   void slotApplyCompText();
+  void slotOpenRecent(int num);
+  void slotSaveDiagramToGraphicsFile();
+  void slotSaveSchematicToGraphicsFile(bool diagram = false);
 
 private slots:
   void slotCursorLeft();
@@ -350,10 +361,16 @@ private slots:
   void slotExportGraphAsCsv();
   void slotCreatePackage();
   void slotExtractPackage();
+  void slotUpdateRecentFiles();
+  void slotClearRecentFiles();
+  void slotLoadModule();
+  void slotBuildModule();
 
 private:
   void showHTML(const QString&);
   bool performToggleAction(bool, QAction*, pToggleFunc, pMouseFunc, pMouseFunc2);
   friend class SaveDialog;
+  QString lastExportFilename;
 };
-#endif
+
+#endif /* QUCS_H */
