@@ -6,6 +6,8 @@
     email                : michael.margraf@alumni.tu-berlin.de
  ***************************************************************************/
 
+/* Copyright (C) 2014 Guilherme Brondani Torri <guitorri@gmail.com>        */
+
 /***************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -19,9 +21,7 @@
 #include <stdlib.h>
 #include <limits.h>
 
-#include <q3process.h>
-
-//Added by qt3to4:
+#include <QProcess>
 #include <Q3PtrList>
 
 #include "main.h"
@@ -29,6 +29,7 @@
 #include "schematic.h"
 #include "textdoc.h"
 #include "mouseactions.h"
+#include "messagedock.h"
 #include "components/ground.h"
 #include "components/subcirport.h"
 #include "components/equation.h"
@@ -36,14 +37,15 @@
 #include "dialogs/changedialog.h"
 #include "dialogs/searchdialog.h"
 #include "dialogs/librarydialog.h"
+#include "dialogs/loaddialog.h"
 #include "dialogs/importdialog.h"
 #include "dialogs/packagedialog.h"
+#include "module.h"
 
 // for editing component name on schematic
 QRegExp  Expr_CompProp;
 QRegExpValidator Val_CompProp(Expr_CompProp, 0);
 
-
 // -----------------------------------------------------------------------
 // This function is called from all toggle actions.
 bool QucsApp::performToggleAction(bool on, QAction *Action,
@@ -123,6 +125,8 @@ void QucsApp::slotEditMirrorY(bool on)
 
 // -----------------------------------------------------------------------
 // Is called when the activate/deactivate toolbar button is pressed.
+// It also comments out the selected text on a text document
+// \todo update the status or tooltip message
 void QucsApp::slotEditActivate (bool on)
 {
   TextDoc * Doc = (TextDoc *) DocumentTab->currentPage ();
@@ -145,7 +149,7 @@ void QucsApp::slotEditActivate (bool on)
 void QucsApp::slotEditDelete(bool on)
 {
   TextDoc *Doc = (TextDoc*)DocumentTab->currentPage();
-  if(Doc->inherits("QTextEdit")) {
+  if(Doc->inherits("QPlainTextEdit")) {
     Doc->viewport()->setFocus();
     //Doc->del();
     Doc->textCursor().deleteChar();
@@ -194,8 +198,8 @@ void QucsApp::slotMoveText(bool on)
 void QucsApp::slotZoomIn(bool on)
 {
   TextDoc *Doc = (TextDoc*)DocumentTab->currentPage();
-  if(Doc->inherits("QTextEdit")) {
-    Doc->zoomBy(2.0f);
+  if(Doc->inherits("QPlainTextEdit")) {
+    Doc->zoomBy(1.5f);
     magPlus->blockSignals(true);
     magPlus->setOn(false);
     magPlus->blockSignals(false);
@@ -205,17 +209,22 @@ void QucsApp::slotZoomIn(bool on)
 		&MouseActions::MMoveZoomIn, &MouseActions::MPressZoomIn);
 }
 
+
+void QucsApp::slotEscape()
+{
+    select->setChecked(true);
+}
+
 // -----------------------------------------------------------------------
 // Is called when the select toolbar button is pressed.
 void QucsApp::slotSelect(bool on)
 {
   QWidget *w = DocumentTab->currentPage();
-  if(w->inherits("QTextEdit")) {
+  if(w->inherits("QPlainTextEdit")) {
     ((TextDoc*)w)->viewport()->setFocus();
-
-    select->blockSignals(true);
-    select->setOn(true);
-    select->blockSignals(false);
+      select->blockSignals(true);
+      select->setOn(true);
+      select->blockSignals(false);
     return;
   }
 
@@ -242,8 +251,13 @@ void QucsApp::slotSelect(bool on)
 // -----------------------------------------------------------------------
 void QucsApp::slotEditPaste(bool on)
 {
+  // get the current document
   Schematic *Doc = (Schematic*)DocumentTab->currentPage();
-  if(Doc->inherits("QTextEdit")) {
+
+  // if the current document is a text document paste in
+  // the contents of the clipboard as text
+  if(Doc->inherits("QPlainTextEdit"))
+  {
     ((TextDoc*)Doc)->viewport()->setFocus();
     ((TextDoc*)Doc)->paste();
 
@@ -252,10 +266,12 @@ void QucsApp::slotEditPaste(bool on)
     editPaste->blockSignals(false);
     return;
   }
-  
-  editText->setHidden(true); // disable text edit of component property
+  // if it's not a text doc, prevent the user from editing
+  // while we perform the paste operation
+  editText->setHidden(true);
 
-  if(!on) {
+  if(!on)
+  {
     MouseMoveAction = 0;
     MousePressAction = 0;
     MouseReleaseAction = 0;
@@ -265,14 +281,16 @@ void QucsApp::slotEditPaste(bool on)
     return;
   }
 
-  if(!view->pasteElements(Doc)) {
+  if(!view->pasteElements(Doc))
+  {
     editPaste->blockSignals(true); // do not call toggle slot
     editPaste->setOn(false);       // set toolbar button off
     editPaste->blockSignals(false);
     return;   // if clipboard empty
   }
 
-  if(activeAction) {
+  if(activeAction)
+  {
     activeAction->blockSignals(true); // do not call toggle slot
     activeAction->setOn(false);       // set last toolbar button off
     activeAction->blockSignals(false);
@@ -301,7 +319,7 @@ void QucsApp::slotInsertEntity ()
   //y = Doc->textCursor().columnNumber();
   Doc->slotCursorPosChanged();
 }
-  
+
 // -----------------------------------------------------------------------
 // Is called when the mouse is clicked upon the equation toolbar button.
 void QucsApp::slotInsertEquation(bool on)
@@ -406,14 +424,14 @@ void QucsApp::slotInsertPort(bool on)
 void QucsApp::slotEditUndo()
 {
   Schematic *Doc = (Schematic*)DocumentTab->currentPage();
-  if(Doc->inherits("QTextEdit")) {
+  if(Doc->inherits("QPlainTextEdit")) {
     ((TextDoc*)Doc)->viewport()->setFocus();
     ((TextDoc*)Doc)->undo();
     return;
   }
-  
+
   editText->setHidden(true); // disable text edit of component property
-  
+
   Doc->undo();
   Doc->viewport()->update();
   view->drawn = false;
@@ -424,14 +442,14 @@ void QucsApp::slotEditUndo()
 void QucsApp::slotEditRedo()
 {
   Schematic *Doc = (Schematic*)DocumentTab->currentPage();
-  if(Doc->inherits("QTextEdit")) {
+  if(Doc->inherits("QPlainTextEdit")) {
     ((TextDoc*)Doc)->viewport()->setFocus();
     ((TextDoc*)Doc)->redo();
     return;
   }
-  
+
   editText->setHidden(true); // disable text edit of component property
-  
+
   Doc->redo();
   Doc->viewport()->update();
   view->drawn = false;
@@ -552,7 +570,7 @@ void QucsApp::slotSelectAll()
   editText->setHidden(true); // disable text edit of component property
 
   QWidget *Doc = DocumentTab->currentPage();
-  if(Doc->inherits("QTextEdit")) {
+  if(Doc->inherits("QPlainTextEdit")) {
     ((TextDoc*)Doc)->viewport()->setFocus();
     //((TextDoc*)Doc)->selectAll(true);
     ((TextDoc*)Doc)->selectAll();
@@ -576,38 +594,98 @@ void QucsApp::slotSelectMarker()
   view->drawn = false;
 }
 
+
+extern QString lastDirOpenSave; // to remember last directory and file
+
 // ------------------------------------------------------------------------
 // Is called by slotShowLastMsg(), by slotShowLastNetlist() and from the
 // component edit dialog.
 void QucsApp::editFile(const QString& File)
 {
-  QStringList com;
-  com << QucsSettings.Editor;
-  if (!File.isEmpty()) com << File;
-  Q3Process *QucsEditor = new Q3Process(com);
-  QucsEditor->setCommunication(0);
-  if(!QucsEditor->start()) {
-    QMessageBox::critical(this, tr("Error"), tr("Cannot start text editor!"));
-    delete QucsEditor;
-    return;
-  }
+    if (QucsSettings.Editor.toLower() == "qucs" | QucsSettings.Editor.isEmpty())
+    {
+        // The Editor is 'qucs' or empty, open a net document tab
+        if (File.isEmpty()) {
+            QucsApp::slotTextNew();
+        }
+        else
+        {
+            editText->setHidden(true); // disable text edit of component property
 
-  // to kill it before qucs ends
-  connect(this, SIGNAL(signalKillEmAll()), QucsEditor, SLOT(kill()));
+            statusBar()->message(tr("Opening file..."));
+
+            QFileInfo finfo(File);
+
+            if(!finfo.exists())
+                statusBar()->message(tr("Opening aborted, file not found."), 2000);
+            else {
+                gotoPage(File);
+                lastDirOpenSave = File;   // remember last directory and file
+                statusBar()->message(tr("Ready."));
+            }
+        }
+    }
+    else
+    {
+      // use an external editor
+      QString prog;
+      QStringList args;
+
+      if (QucsSettings.Editor.toLower().contains("qucsedit")) {
+
+#ifdef __MINGW32__
+  prog = "qucsedit.exe";
+#elif __APPLE__
+  prog = "qucsedit.app/Contents/MacOS/qucsedit";
+#else
+  prog = "qucsedit";
+#endif
+
+        QFileInfo editor(QucsSettings.BinDir + prog);
+        prog = QDir::toNativeSeparators(editor.canonicalFilePath());
+      }
+      else { // user defined editor
+          QFileInfo editor(QucsSettings.Editor);
+          prog = QDir::toNativeSeparators(editor.canonicalFilePath());
+      }
+
+      if (!File.isEmpty()) {
+          args << File;
+      }
+
+      QProcess *QucsEditor = new QProcess();
+      QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+      env.insert("PATH", env.value("PATH") );
+      QucsEditor->setProcessEnvironment(env);
+
+      qDebug() << "Command: " << prog << args.join(" ");
+
+      QucsEditor->start(prog, args);
+
+      if( !QucsEditor->waitForStarted(1000) ) {
+        QMessageBox::critical(this, tr("Error"), tr("Cannot start text editor! \n\n%1").arg(prog));
+        delete QucsEditor;
+        return;
+      }
+      qDebug() << QucsEditor->readAllStandardError();
+
+      // to kill it before qucs ends
+      connect(this, SIGNAL(signalKillEmAll()), QucsEditor, SLOT(kill()));
+    }
 }
 
 // ------------------------------------------------------------------------
 // Is called to show the output messages of the last simulation.
 void QucsApp::slotShowLastMsg()
 {
-  editFile(QucsHomeDir.filePath("log.txt"));
+  editFile(QucsSettings.QucsHomeDir.filePath("log.txt"));
 }
 
 // ------------------------------------------------------------------------
 // Is called to show the netlist of the last simulation.
 void QucsApp::slotShowLastNetlist()
 {
-  editFile(QucsHomeDir.filePath("netlist.txt"));
+  editFile(QucsSettings.QucsHomeDir.filePath("netlist.txt"));
 }
 
 // ------------------------------------------------------------------------
@@ -621,11 +699,27 @@ void QucsApp::slotCallEditor()
 // Is called to start the filter synthesis program.
 void QucsApp::slotCallFilter()
 {
-  Q3Process *QucsFilter =
-    new Q3Process(QString(QucsSettings.BinDir + "qucsfilter"));
-  if(!QucsFilter->start()) {
+  QString prog;
+
+#ifdef __MINGW32__
+  prog = "qucsfilter.exe";
+#elif __APPLE__
+  prog = "qucsfilter.app/Contents/MacOS/qucsfilter";
+#else
+  prog = "qucsfilter";
+#endif
+
+  QProcess *QucsFilter = new QProcess();
+
+  QucsFilter->setWorkingDirectory(QucsSettings.BinDir);
+  QucsFilter->start(prog);
+
+  prog = QDir::toNativeSeparators(QucsSettings.BinDir+prog);
+  qDebug() << "Command :" << prog;
+
+  if( !QucsFilter->waitForStarted(1000) ) {
     QMessageBox::critical(this, tr("Error"),
-                          tr("Cannot start filter synthesis program!"));
+                          tr("Cannot start filter synthesis program! \n\n%1").arg(prog));
     delete QucsFilter;
     return;
   }
@@ -638,11 +732,25 @@ void QucsApp::slotCallFilter()
 // Is called to start the transmission line calculation program.
 void QucsApp::slotCallLine()
 {
-  Q3Process *QucsLine =
-    new Q3Process(QString(QucsSettings.BinDir + "qucstrans"));
-  if(!QucsLine->start()) {
+  QString prog;
+#ifdef __MINGW32__
+  prog = "qucstrans.exe";
+#elif __APPLE__
+  prog = "qucstrans.app/Contents/MacOS/qucstrans";
+#else
+  prog = "qucstrans";
+#endif
+  QProcess *QucsLine = new QProcess();
+
+  QucsLine->setWorkingDirectory(QucsSettings.BinDir);
+  QucsLine->start(prog);
+
+  prog = QDir::toNativeSeparators(QucsSettings.BinDir+prog);
+  qDebug() << "Command :" << prog;
+
+  if( !QucsLine->waitForStarted(1000) ) {
     QMessageBox::critical(this, tr("Error"),
-                          tr("Cannot start line calculation program!"));
+                          tr("Cannot start line calculation program! \n\n%1").arg(prog));
     delete QucsLine;
     return;
   }
@@ -655,11 +763,27 @@ void QucsApp::slotCallLine()
 // Is called to start the component library program.
 void QucsApp::slotCallLibrary()
 {
-  Q3Process *QucsLibrary =
-    new Q3Process(QString(QucsSettings.BinDir + "qucslib"));
-  if(!QucsLibrary->start()) {
+  QString prog;
+#ifdef __MINGW32__
+  prog = "qucslib.exe";
+#elif __APPLE__
+  prog = "qucslib.app/Contents/MacOS/qucslib";
+#else
+  prog = "qucslib";
+#endif
+
+  QProcess *QucsLibrary = new QProcess();
+
+  QucsLibrary->setWorkingDirectory(QucsSettings.BinDir);
+  QucsLibrary->start(prog);
+
+  prog = QDir::toNativeSeparators(QucsSettings.BinDir+prog);
+  qDebug() << "Command :" << prog;
+
+  if( !QucsLibrary->waitForStarted(1000) ) {
+
     QMessageBox::critical(this, tr("Error"),
-                          tr("Cannot start library program!"));
+                          tr("Cannot start library program! \n\n%1").arg(prog));
     delete QucsLibrary;
     return;
   }
@@ -680,11 +804,26 @@ void QucsApp::slotCallMatch()
 // Is called to start the attenuator calculation program.
 void QucsApp::slotCallAtt()
 {
-  Q3Process *QucsAtt =
-    new Q3Process(QString(QucsSettings.BinDir + "qucsattenuator"));
-  if(!QucsAtt->start()) {
+  QString prog;
+#ifdef __MINGW32__
+  prog = "qucsattenuator.exe";
+#elif __APPLE__
+  prog = "qucsattenuator.app/Contents/MacOS/qucsattenuator";
+#else
+  prog = "qucsattenuator";
+#endif
+
+  QProcess *QucsAtt = new QProcess();
+
+  QucsAtt->setWorkingDirectory(QucsSettings.BinDir);
+  QucsAtt->start(prog);
+
+  prog = QDir::toNativeSeparators(QucsSettings.BinDir+prog);
+  qDebug() << "Command :" << prog;
+
+  if( !QucsAtt->waitForStarted(1000) ) {
     QMessageBox::critical(this, tr("Error"),
-                          tr("Cannot start attenuator calculation program!"));
+                          tr("Cannot start attenuator calculation program! \n\n%1").arg(prog));
     delete QucsAtt;
     return;
   }
@@ -692,7 +831,37 @@ void QucsApp::slotCallAtt()
   // to kill it before qucs ends
   connect(this, SIGNAL(signalKillEmAll()), QucsAtt, SLOT(kill()));
 }
+// ------------------------------------------------------------------------
+// Is called to start the resistor color code calculation program.
+void QucsApp::slotCallRes()
+{
+  QString prog;
+#ifdef __MINGW32__
+  prog = "qucsrescodes.exe";
+#elif __APPLE__
+  prog = "qucsrescodes.app/Contents/MacOS/qucsrescodes";
+#else
+  prog = "qucrescodes";
+#endif
 
+  QProcess *QucsRes = new QProcess();
+
+  QucsRes->setWorkingDirectory(QucsSettings.BinDir);
+  QucsRes->start(prog);
+
+  prog = QDir::toNativeSeparators(QucsSettings.BinDir+prog);
+  qDebug() << "Command :" << prog;
+
+  if( !QucsRes->waitForStarted(1000) ) {
+    QMessageBox::critical(this, tr("Error"),
+                          tr("Cannot start resistor color code calculation program! \n\n%1").arg(prog));
+    delete QucsRes;
+    return;
+  }
+
+  // to kill it before qucs ends
+  connect(this, SIGNAL(signalKillEmAll()), QucsRes, SLOT(kill()));
+}
 // --------------------------------------------------------------
 void QucsApp::slotHelpIndex()
 {
@@ -708,12 +877,27 @@ void QucsApp::slotGettingStarted()
 // --------------------------------------------------------------
 void QucsApp::showHTML(const QString& Page)
 {
+
+  QString prog;
+#ifdef __MINGW32__
+  prog = "qucshelp.exe";
+#elif __APPLE__
+  prog = "qucshelp.app/Contents/MacOS/qucshelp";
+#else
+  prog = "qucshelp";
+#endif
+
   QStringList com;
-  com << QucsSettings.BinDir + "qucshelp" << Page;
-  Q3Process *QucsHelp = new Q3Process(com);
-  QucsHelp->setCommunication(0);
-  if(!QucsHelp->start()) {
-    QMessageBox::critical(this, tr("Error"), tr("Cannot start qucshelp!"));
+  com << prog << Page;
+
+  QProcess *QucsHelp = new QProcess();
+
+  QucsHelp->setWorkingDirectory(QucsSettings.BinDir);
+  QucsHelp->start(com.join(" "));
+
+  qDebug() << "Command :" << com.join(" ");
+  if( !QucsHelp->waitForStarted(1000) ) {
+    QMessageBox::critical(this, tr("Error"), tr("Cannot start qucshelp! \n\n%1").arg(com.join(" ")));
     delete QucsHelp;
     return;
   }
@@ -740,7 +924,7 @@ void QucsApp::slotEditFindAgain()
 void QucsApp::slotChangeProps()
 {
   QWidget *Doc = DocumentTab->currentPage();
-  if(Doc->inherits("QTextEdit")) {
+  if(Doc->inherits("QPlainTextEdit")) {
     ((TextDoc*)Doc)->viewport()->setFocus();
     SearchDia->initSearch(true);
   }
@@ -787,7 +971,7 @@ void QucsApp::slotAddToProject()
   while(it != FileList.end()) {
     Info.setFile(*it);
     origFile.setName(*it);
-    destFile.setName(QucsWorkDir.absPath() + 
+    destFile.setName(QucsSettings.QucsWorkDir.absPath() +
                      QDir::separator() + Info.fileName());
 
     if(!origFile.open(QIODevice::ReadOnly)) {
@@ -831,7 +1015,7 @@ void QucsApp::slotAddToProject()
     destFile.close();
     it++;
   }
-  
+
   free(Buffer);
   readProjectFiles();  // re-read the content ListView
   statusBar()->message(tr("Ready."));
@@ -1019,7 +1203,7 @@ void QucsApp::slotApplyCompText()
     if(pp->display) n++;   // is visible ?
     pp = pc->Props.next();
   }
-  
+
   pp = 0;
   if(view->MAx3 > 0)  pp = pc->Props.at(view->MAx3-1); // current property
   else s = pc->Name;
@@ -1159,7 +1343,7 @@ void QucsApp::slotExportGraphAsCsv()
      tr("CSV file")+" (*.csv);;" + tr("Any File")+" (*)",
      this, 0, tr("Enter an Output File Name"));
      */
-  QString s = QFileDialog::getSaveFileName(this, tr("Enter an Output File Name"), 
+  QString s = QFileDialog::getSaveFileName(this, tr("Enter an Output File Name"),
     lastDir.isEmpty() ? QString(".") : lastDir, tr("CSV file")+" (*.csv);;" + tr("Any File")+" (*)");
 
   if(s.isEmpty())
@@ -1229,3 +1413,252 @@ void QucsApp::slotExtractPackage()
   d->extractPackage();
   readProjects();
 }
+
+void QucsApp::slotOpenRecent(int num)
+{
+    //qDebug()<<QucsSettings.RecentDocs.at(num);
+    gotoPage(QucsSettings.RecentDocs.at(num));
+    updateRecentFilesList(QucsSettings.RecentDocs.at(num));
+    slotUpdateRecentFiles();
+}
+
+void QucsApp::slotUpdateRecentFiles()
+{
+
+
+    QSignalMapper* mapper = new QSignalMapper(this);
+    QList<QAction*> recent_docs;
+
+    QString file;
+    foreach (file,QucsSettings.RecentDocs) {
+        recent_docs.prepend(new QAction(file,this));
+        connect(recent_docs.first(),SIGNAL(triggered()),mapper,SLOT(map()));
+    }
+    recentfilesMenu->clear();
+    recentfilesMenu->addActions(recent_docs);
+
+    for (int i=0; i<recent_docs.count(); i++) {
+        mapper->setMapping(recent_docs.at(i),(recent_docs.count() - 1)-i);
+    }
+
+    connect(mapper,SIGNAL(mapped(int)),this,SLOT(slotOpenRecent(int)));
+
+    recentfilesMenu->insertSeparator();
+    recentfilesMenu->addAction(tr("Clear list"),this,SLOT(slotClearRecentFiles()));
+
+}
+
+void QucsApp::slotClearRecentFiles()
+{
+    QucsSettings.RecentDocs.clear();
+    slotUpdateRecentFiles();
+}
+
+
+/*!
+ * \brief QucsApp::slotLoadModule launches the dialog to select dynamic modueles
+ */
+void QucsApp::slotLoadModule()
+{
+    qDebug() << "slotLoadModule";
+
+    LoadDialog *ld = new LoadDialog(this);
+    ld->setApp(this);
+
+    // fech list of _symbol.json
+    // \todo fetch timestamp of VA, JSON, if VA newer, need to reload.
+
+    QDir projDir = QucsSettings.QucsWorkDir.absolutePath();
+
+    QStringList files;
+    QString fileSuffix = "*_symbol.json";
+
+    files = projDir.entryList(QStringList(fileSuffix),
+                                 QDir::Files | QDir::NoSymLinks);
+
+    // no JSON files or no a project?
+    if (!files.size()){
+        QMessageBox::critical(this, tr("Error"),
+                     tr("Symbol files not found in: %1\n\n"
+                        "Is the project open?\n"
+                        "Have you saved the Verilog-A symbols?")
+                       .arg(QString(projDir.absolutePath())));
+        return;
+    }
+
+    // initialize dialog
+
+    // pass list of potential symbol files
+    ld->symbolFiles << files;
+    ld->projDir = projDir;
+    ld->initDialog();
+
+    // \todo check what is already loaded, offer skip, reload
+
+    //pass stuff to ld dialog
+    // run, let user do the selections
+
+    if (ld->exec() == QDialog::Accepted) {
+
+      Module::vaComponents = ld->selectedComponents;
+
+      // dialog write new bitmap into JSON
+      // load, unload, reload
+      // inform if symbol changed
+      // populate Module::vaComponents
+      // vaComponents are selected with the dialog
+      // dialog should populate acording to checkboxes
+      // build vaComponents QMap
+
+      // remove all modules before registering/loaded again
+      // look for modules in the category,
+      // \todo investigate if it is leaking objects somewhere
+      QStringList remove;
+      Q3DictIterator<Module> it( Module::Modules );
+      for( ; it.current(); ++it ){
+        if (it.current()->category == QObject::tr("verilog-a user devices"))
+          remove << it.currentKey();
+      }
+      for (int i = 0; i < remove.size(); ++i){
+        Module::Modules.remove(remove.at(i));
+      }
+
+      if (! Module::vaComponents.isEmpty()) {
+        // Register whatever is in Module::vaComponents
+        Module::registerDynamicComponents();
+
+        // update the combobox, set new category in view
+        // pick up new category 'verilog-a user components' from `Module::category`
+        //set new category into view
+        QucsApp::fillComboBox(true);
+        CompChoose->setCurrentItem(CompChoose->count()-1);
+        slotSetCompView(CompChoose->count()-1);
+
+        // icons of dynamically registered components ready to be dragged
+      }
+    }
+
+    delete ld;
+
+}
+
+
+/*!
+ * \brief QucsApp::slotBuildModule runs admsXml, C++ compiler to build library
+ *
+ * Run the va2cpp
+ * Run the cpp2lib
+ *
+ * TODO
+ * - split into two actions, elaborate and compile?
+ * - collect, parse and display output of make
+ *
+ */
+void QucsApp::slotBuildModule()
+{
+    qDebug() << "slotBuildModule";
+
+    // reset message dock on entry
+    messageDock->reset();
+
+    messageDock->builderTabs->setTabIcon(0,QPixmap());
+    messageDock->builderTabs->setTabIcon(1,QPixmap());
+
+
+    QString make;
+
+#ifdef __MINGW32__
+    make = "mingw32-make.exe";    // must be on the path!
+#else
+    make = "make";                // must be on the path!
+#endif
+
+    QDir prefix = QDir(QucsSettings.BinDir+"../");
+
+    QDir include = QDir(QucsSettings.BinDir+"../include/qucs-core");
+
+    QString workDir = QucsSettings.QucsWorkDir.absolutePath();
+
+    // need to cd into project to make sure output is droped there?
+    // need to cd - into previous location?
+    QDir::setCurrent(workDir);
+
+    QProcess *builder = new QProcess();
+    builder->setProcessChannelMode(QProcess::MergedChannels);
+    // get current va document
+    QucsDoc *Doc = getDoc();
+    QString vaModule = Doc->fileBase(Doc->DocName);
+
+    QString admsXml = QucsSettings.AdmsXmlBinDir.canonicalPath();
+
+#ifdef __MINGW32__
+    admsXml = QDir::toNativeSeparators(admsXml+"/"+"admsXml.exe");
+#else
+    admsXml = QDir::toNativeSeparators(admsXml+"/"+"admsXml");
+#endif
+
+    // admsXml emmits C++
+    QStringList Arguments;
+    Arguments << "-f" <<  QDir::toNativeSeparators(include.absoluteFilePath("va2cpp.makefile"))
+              << QString("ADMSXML=%1").arg(admsXml)
+              << QString("PREFIX=%1").arg(QDir::toNativeSeparators(prefix.absolutePath()))
+              << QString("MODEL=%1").arg(vaModule);
+
+    QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+    env.insert("PATH", env.value("PATH") );
+    builder->setProcessEnvironment(env);
+
+    // prepend command to log
+    QString cmdString = QString("%1 %2\n").arg(make, Arguments.join(" "));
+    messageDock->admsOutput->appendPlainText(cmdString);
+
+    qDebug() << "Command :" << make << Arguments.join(" ");
+    builder->start(make, Arguments);
+
+    // admsXml seems to communicate all via stdout, or is it because of make?
+    QString vaStatus;
+    if (!builder->waitForFinished()) {
+        vaStatus = builder->errorString();
+        qDebug() << "Make failed:" << vaStatus;
+    }
+    else {
+        vaStatus = builder->readAll();
+        qDebug() << "Make stdout"  << vaStatus;
+    }
+
+    //build libs
+    qDebug() << "\nbuild libs\n";
+
+    Arguments.clear();
+
+    Arguments << "-f" <<  QDir::toNativeSeparators(include.absoluteFilePath("cpp2lib.makefile"))
+              << QString("PREFIX=\"%1\"").arg(QDir::toNativeSeparators(prefix.absolutePath()))
+              << QString("PROJDIR=\"%1\"").arg(QDir::toNativeSeparators(workDir))
+              << QString("MODEL=%1").arg(vaModule);
+
+    // prepend command to log
+    cmdString = QString("%1 %2\n").arg(make, Arguments.join(" "));
+    messageDock->cppOutput->appendPlainText(cmdString);
+
+    builder->start(make, Arguments);
+
+    QString cppStatus;
+
+    if (!builder->waitForFinished()) {
+        cppStatus = builder->errorString();
+        qDebug() << "Make failed:" << cppStatus;
+    }
+    else {
+        cppStatus = builder->readAll();
+        qDebug() << "Make output:" << cppStatus;
+    }
+    delete builder;
+
+    // push make output to message dock
+    messageDock->admsOutput->appendPlainText(vaStatus);
+    messageDock->cppOutput->appendPlainText(cppStatus);
+
+    // shot the message docks
+    messageDock->msgDock->show();
+
+}
