@@ -20,61 +20,41 @@
 #endif
 #include <QtGui>
 
-
-
 #include "main.h"
 #include "qucs.h"
 #include "dialogs/vtabbeddockwidget.h"
 #include "octave_window.h"
 
 
-/*
-QAction* Q3Action(QString a,QIcon b, QString c,unsigned int d, QObject* e)
-{
-	QAction* action=new QAction(b,c,e);
-	action->setShortcut((Qt::ShortcutContext)d);
-	return action;
-}
-
-QAction* Q3Action(QString a, QString c, unsigned int d, QObject* e)
-{
-	QAction* action=new QAction(c,e);
-	action->setShortcut((Qt::ShortcutContext)d);
-	return action;
-}
-*/
-
-
-
-
-// ----------------------------------------------------------
-// initializes all QActions of the application
+/**
+ * @brief QucsApp::initActions Initializes all QActions of the application
+ */
 void QucsApp::initActions()
 {
   activeAction = 0;   // no active action
 
   // note: first argument of QAction() for backward compatibility Qt < 3.2
 
-  fileNew = new QAction(QIcon((QucsSettings.BitmapDir + "filenew.png")), tr("&New"), this);
+  fileNew = new QAction(QIcon((":/bitmaps/filenew.png")), tr("&New"), this);
   fileNew->setShortcut(Qt::CTRL+Qt::Key_N);
   fileNew->setStatusTip(tr("Creates a new document"));
   fileNew->setWhatsThis(
 	        tr("New\n\nCreates a new schematic or data display document"));
   connect(fileNew, SIGNAL(activated()), SLOT(slotFileNew()));
 
-  textNew = new QAction(QIcon((QucsSettings.BitmapDir + "textnew.png")), tr("New &Text"), this);
+  textNew = new QAction(QIcon((":/bitmaps/textnew.png")), tr("New &Text"), this);
   textNew->setShortcut(Qt::CTRL+Qt::SHIFT+Qt::Key_V);
   textNew->setStatusTip(tr("Creates a new text document"));
   textNew->setWhatsThis(tr("New Text\n\nCreates a new text document"));
   connect(textNew, SIGNAL(activated()), SLOT(slotTextNew()));
 
-  fileOpen = new QAction(QIcon((QucsSettings.BitmapDir + "fileopen.png")),	tr("&Open..."), this);
+  fileOpen = new QAction(QIcon((":/bitmaps/fileopen.png")),	tr("&Open..."), this);
   fileOpen->setShortcut(Qt::CTRL+Qt::Key_O);
   fileOpen->setStatusTip(tr("Opens an existing document"));
   fileOpen->setWhatsThis(tr("Open File\n\nOpens an existing document"));
   connect(fileOpen, SIGNAL(activated()), SLOT(slotFileOpen()));
 
-  fileSave = new QAction(QIcon((QucsSettings.BitmapDir + "filesave.png")),	tr("&Save"), this);
+  fileSave = new QAction(QIcon((":/bitmaps/filesave.png")),	tr("&Save"), this);
   fileSave->setShortcut(Qt::CTRL+Qt::Key_S);
   fileSave->setStatusTip(tr("Saves the current document"));
   fileSave->setWhatsThis(tr("Save File\n\nSaves the current document"));
@@ -88,13 +68,13 @@ void QucsApp::initActions()
 	tr("Save As\n\nSaves the current document under a new filename"));
   connect(fileSaveAs, SIGNAL(activated()), SLOT(slotFileSaveAs()));
 
-  fileSaveAll = new QAction(QIcon((QucsSettings.BitmapDir + "filesaveall.png")),	tr("Save &All"), this);
+  fileSaveAll = new QAction(QIcon((":/bitmaps/filesaveall.png")),	tr("Save &All"), this);
   fileSaveAll->setShortcut(Qt::CTRL+Qt::Key_Plus);
   fileSaveAll->setStatusTip(tr("Saves all open documents"));
   fileSaveAll->setWhatsThis(tr("Save All Files\n\nSaves all open documents"));
   connect(fileSaveAll, SIGNAL(activated()), SLOT(slotFileSaveAll()));
 
-  fileClose = new QAction(QIcon((QucsSettings.BitmapDir + "fileclose.png")), tr("&Close"), this);
+  fileClose = new QAction(QIcon((":/bitmaps/fileclose.png")), tr("&Close"), this);
   fileClose->setShortcut(Qt::CTRL+Qt::Key_W);
   fileClose->setStatusTip(tr("Closes the current document"));
   fileClose->setWhatsThis(tr("Close File\n\nCloses the current document"));
@@ -120,7 +100,7 @@ void QucsApp::initActions()
   fileSettings->setWhatsThis(tr("Settings\n\nSets properties of the file"));
   connect(fileSettings, SIGNAL(activated()), SLOT(slotFileSettings()));
 
-  filePrint = new QAction(QIcon((QucsSettings.BitmapDir + "fileprint.png")), tr("&Print..."), this);
+  filePrint = new QAction(QIcon((":/bitmaps/fileprint.png")), tr("&Print..."), this);
   filePrint->setShortcut(Qt::CTRL+Qt::Key_P);
   filePrint->setStatusTip(tr("Prints the current document"));
   filePrint->setWhatsThis(tr("Print File\n\nPrints the current document"));
@@ -147,6 +127,13 @@ void QucsApp::initActions()
 	tr("Qucs Settings\n\nSets properties of the application"));
   connect(applSettings, SIGNAL(activated()), SLOT(slotApplSettings()));
 
+  refreshSchPath = new QAction(tr("Refresh Search Path..."), this);
+  //refreshSchPath->setShortcut(Qt::CTRL+Qt::Key_Comma);
+  refreshSchPath->setStatusTip(tr("Refresh Search Path"));
+  refreshSchPath->setWhatsThis(
+    tr("Refresh Path\n\nRechecks the list of paths for subcircuit files."));
+  connect(refreshSchPath, SIGNAL(activated()), SLOT(slotRefreshSchPath()));
+
   alignTop = new QAction(tr("Align top"), this);
   alignTop->setShortcut(Qt::CTRL+Qt::Key_T);
   alignTop->setStatusTip(tr("Align top selected elements"));
@@ -221,7 +208,7 @@ void QucsApp::initActions()
 	tr("Replace\n\nChange component properties\nor\ntext in VHDL code"));
   connect(changeProps, SIGNAL(activated()), SLOT(slotChangeProps()));
 
-  editCut = new QAction(QIcon((QucsSettings.BitmapDir + "editcut.png")),	tr("Cu&t"), this);
+  editCut = new QAction(QIcon((":/bitmaps/editcut.png")),	tr("Cu&t"), this);
   editCut->setShortcut(Qt::CTRL+Qt::Key_X);
   editCut->setStatusTip(
 	tr("Cuts out the selection and puts it into the clipboard"));
@@ -229,7 +216,7 @@ void QucsApp::initActions()
 	tr("Cut\n\nCuts out the selection and puts it into the clipboard"));
   connect(editCut, SIGNAL(activated()), SLOT(slotEditCut()));
 
-  editCopy = new QAction(QIcon((QucsSettings.BitmapDir + "editcopy.png")), tr("&Copy"), this);
+  editCopy = new QAction(QIcon((":/bitmaps/editcopy.png")), tr("&Copy"), this);
   editCopy->setShortcut(Qt::CTRL+Qt::Key_C);
   editCopy->setStatusTip(
 	tr("Copies the selection into the clipboard"));
@@ -237,7 +224,7 @@ void QucsApp::initActions()
 	tr("Copy\n\nCopies the selection into the clipboard"));
   connect(editCopy, SIGNAL(activated()), SLOT(slotEditCopy()));
 
-  editPaste = new QAction(QIcon((QucsSettings.BitmapDir + "editpaste.png")), tr("&Paste"), this);
+  editPaste = new QAction(QIcon((":/bitmaps/editpaste.png")), tr("&Paste"), this);
   editPaste->setShortcut(Qt::CTRL+Qt::Key_V);
   editPaste->setStatusTip(
 	tr("Pastes the clipboard contents to the cursor position"));
@@ -246,7 +233,7 @@ void QucsApp::initActions()
   editPaste->setToggleAction(true);
   connect(editPaste, SIGNAL(toggled(bool)), SLOT(slotEditPaste(bool)));
 
-  editDelete = new QAction(QIcon((QucsSettings.BitmapDir + "editdelete.png")), tr("&Delete"), this);
+  editDelete = new QAction(QIcon((":/bitmaps/editdelete.png")), tr("&Delete"), this);
   editDelete->setShortcut(Qt::Key_Delete);
   editDelete->setStatusTip(tr("Deletes the selected components"));
   editDelete->setWhatsThis(tr("Delete\n\nDeletes the selected components"));
@@ -271,6 +258,9 @@ void QucsApp::initActions()
   //mainAccel->connectItem(mainAccel->insertItem(Qt::Key_Backspace),
   //                       editDelete, SLOT(toggle()) );
 
+  exportAsImage = new QAction(tr("Export as image"),this);
+  connect(exportAsImage,SIGNAL(activated()),SLOT(slotSaveSchematicToGraphicsFile()));
+
   // cursor left/right/up/down to move marker on a graph
   cursorLeft = new QShortcut(QKeySequence(Qt::Key_Left), this);
   connect(cursorLeft, SIGNAL(activated()), SLOT(slotCursorLeft()));
@@ -298,13 +288,13 @@ void QucsApp::initActions()
 			this, SLOT(slotNextTab()));
 */
 
-  undo = new QAction(QIcon((QucsSettings.BitmapDir + "undo.png")), tr("&Undo"), this);
+  undo = new QAction(QIcon((":/bitmaps/undo.png")), tr("&Undo"), this);
   undo->setShortcut(Qt::CTRL+Qt::Key_Z);
   undo->setStatusTip(tr("Undoes the last command"));
   undo->setWhatsThis(tr("Undo\n\nMakes the last action undone"));
   connect(undo, SIGNAL(activated()), SLOT(slotEditUndo()));
 
-  redo = new QAction(QIcon((QucsSettings.BitmapDir + "redo.png")), tr("&Redo"), this);
+  redo = new QAction(QIcon((":/bitmaps/redo.png")), tr("&Redo"), this);
   redo->setShortcut(Qt::CTRL+Qt::Key_Y);
   redo->setStatusTip(tr("Redoes the last command"));
   redo->setWhatsThis(tr("Redo\n\nRepeats the last action once more"));
@@ -376,33 +366,47 @@ void QucsApp::initActions()
 	tr("Export to CSV\n\nConvert graph data to CSV file"));
   connect(graph2csv, SIGNAL(activated()), SLOT(slotExportGraphAsCsv()));
 
-  magAll = new QAction(QIcon((QucsSettings.BitmapDir + "viewmagfit.png")), tr("View All"), this);
+  buildModule = new QAction(tr("Build Verilog-A module..."), this);
+  buildModule->setStatusTip(tr("Run admsXml and C++ compiler"));
+  buildModule->setWhatsThis(tr("Build Verilog-A module\nRuns amdsXml and C++ compiler"));
+  connect(buildModule, SIGNAL(activated()), SLOT(slotBuildModule()));
+
+  loadModule = new QAction(tr("Load Verilog-A module..."), this);
+  loadModule->setStatusTip(tr("Select Verilog-A symbols to be loaded"));
+  loadModule->setWhatsThis(tr("Load Verilog-A module\nLet the user select and load symbols"));
+  connect(loadModule, SIGNAL(activated()), SLOT(slotLoadModule()));
+
+  magAll = new QAction(QIcon((":/bitmaps/viewmagfit.png")), tr("View All"), this);
   magAll->setShortcut(Qt::Key_0);
   magAll->setStatusTip(tr("Show the whole page"));
   magAll->setWhatsThis(tr("View All\n\nShows the whole page content"));
   connect(magAll, SIGNAL(activated()), SLOT(slotShowAll()));
 
-  magOne = new QAction(QIcon((QucsSettings.BitmapDir + "viewmag1.png")), tr("View 1:1"), this);
+  magOne = new QAction(QIcon((":/bitmaps/viewmag1.png")), tr("View 1:1"), this);
   magOne->setShortcut(Qt::Key_1);
   magOne->setStatusTip(tr("Views without magnification"));
   magOne->setWhatsThis(tr("View 1:1\n\nShows the page content without magnification"));
   connect(magOne, SIGNAL(activated()), SLOT(slotShowOne()));
 
-  magPlus = new QAction(QIcon((QucsSettings.BitmapDir + "viewmag+.png")),	tr("Zoom in"), this);
+  magPlus = new QAction(QIcon((":/bitmaps/viewmag+.png")),	tr("Zoom in"), this);
   magPlus->setShortcut(Qt::Key_Plus);
   magPlus->setStatusTip(tr("Zooms into the current view"));
   magPlus->setWhatsThis(tr("Zoom in\n\nZooms the current view"));
   magPlus->setToggleAction(true);
   connect(magPlus, SIGNAL(toggled(bool)), SLOT(slotZoomIn(bool)));
 
-  magMinus = new QAction(QIcon((QucsSettings.BitmapDir + "viewmag-.png")), tr("Zoom out"), this);
+  magMinus = new QAction(QIcon((":/bitmaps/viewmag-.png")), tr("Zoom out"), this);
   magMinus->setShortcut(Qt::Key_Minus);
   magMinus->setStatusTip(tr("Zooms out the current view"));
   magMinus->setWhatsThis(tr("Zoom out\n\nZooms out the current view"));
   connect(magMinus, SIGNAL(activated()), SLOT(slotZoomOut()));
 
-  select = new QAction(QIcon((QucsSettings.BitmapDir + "pointer.png")), tr("Select"), this);
-  select->setShortcut(Qt::Key_Escape);
+  QAction *escape = new QAction(this);
+  escape->setShortcut(Qt::Key_Escape);
+  connect(escape, SIGNAL(activated()), SLOT(slotEscape()));
+  this->addAction(escape);
+
+  select = new QAction(QIcon((":/bitmaps/pointer.png")), tr("Select"), this);
   select->setStatusTip(tr("Activate select mode"));
   select->setWhatsThis(tr("Select\n\nActivates select mode"));
   select->setToggleAction(true);
@@ -422,7 +426,7 @@ void QucsApp::initActions()
 	tr("Select Markers\n\nSelects all diagram markers of the document"));
   connect(selectMarker, SIGNAL(activated()), SLOT(slotSelectMarker()));
 
-  editRotate = new QAction(QIcon((QucsSettings.BitmapDir + "rotate_ccw.png")), tr("Rotate"), this);
+  editRotate = new QAction(QIcon((":/bitmaps/rotate_ccw.png")), tr("Rotate"), this);
   editRotate->setShortcut(Qt::CTRL+Qt::Key_R);
   editRotate->setStatusTip(tr("Rotates the selected component by 90\x00B0"));
   editRotate->setWhatsThis(
@@ -430,7 +434,7 @@ void QucsApp::initActions()
   editRotate->setToggleAction(true);
   connect(editRotate, SIGNAL(toggled(bool)), SLOT(slotEditRotate(bool)));
 
-  editMirror = new QAction(QIcon((QucsSettings.BitmapDir + "mirror.png")), tr("Mirror about X Axis"), this);
+  editMirror = new QAction(QIcon((":/bitmaps/mirror.png")), tr("Mirror about X Axis"), this);
   editMirror->setShortcut(Qt::CTRL+Qt::Key_J);
   editMirror->setStatusTip(tr("Mirrors the selected item about X Axis"));
   editMirror->setWhatsThis(
@@ -438,7 +442,7 @@ void QucsApp::initActions()
   editMirror->setToggleAction(true);
   connect(editMirror, SIGNAL(toggled(bool)), SLOT(slotEditMirrorX(bool)));
 
-  editMirrorY = new QAction(QIcon((QucsSettings.BitmapDir + "mirrory.png")), tr("Mirror about Y Axis"), this);
+  editMirrorY = new QAction(QIcon((":/bitmaps/mirrory.png")), tr("Mirror about Y Axis"), this);
   editMirrorY->setShortcut(Qt::CTRL+Qt::Key_M);
   editMirrorY->setStatusTip(tr("Mirrors the selected item about Y Axis"));
   editMirrorY->setWhatsThis(
@@ -446,14 +450,14 @@ void QucsApp::initActions()
   editMirrorY->setToggleAction(true);
   connect(editMirrorY, SIGNAL(toggled(bool)), SLOT(slotEditMirrorY(bool)));
 
-  intoH = new QAction(QIcon((QucsSettings.BitmapDir + "bottom.png")), tr("Go into Subcircuit"), this);
+  intoH = new QAction(QIcon((":/bitmaps/bottom.png")), tr("Go into Subcircuit"), this);
   intoH->setShortcut(Qt::CTRL+Qt::Key_I);
   intoH->setStatusTip(tr("Goes inside the selected subcircuit"));
   intoH->setWhatsThis(
 	tr("Go into Subcircuit\n\nGoes inside the selected subcircuit"));
   connect(intoH, SIGNAL(activated()), SLOT(slotIntoHierarchy()));
 
-  popH = new QAction(QIcon((QucsSettings.BitmapDir + "top.png")), tr("Pop out"), this);
+  popH = new QAction(QIcon((":/bitmaps/top.png")), tr("Pop out"), this);
   popH->setShortcut(Qt::CTRL+Qt::Key_H);
   popH->setStatusTip(tr("Pop outside subcircuit"));
   popH->setWhatsThis(
@@ -461,7 +465,7 @@ void QucsApp::initActions()
   connect(popH, SIGNAL(activated()), SLOT(slotPopHierarchy()));
   popH->setEnabled(false);  // only enabled if useful !!!!
 
-  editActivate = new QAction(QIcon((QucsSettings.BitmapDir + "deactiv.png")),	tr("Deactivate/Activate"), this);
+  editActivate = new QAction(QIcon((":/bitmaps/deactiv.png")),	tr("Deactivate/Activate"), this);
   editActivate->setShortcut(Qt::CTRL+Qt::Key_D);
   editActivate->setStatusTip(tr("Deactivate/Activate selected components"));
   editActivate->setWhatsThis(
@@ -469,7 +473,7 @@ void QucsApp::initActions()
   editActivate->setToggleAction(true);
   connect(editActivate, SIGNAL(toggled(bool)), SLOT(slotEditActivate(bool)));
 
-  insEquation = new QAction(QIcon((QucsSettings.BitmapDir + "equation.png")),	tr("Insert Equation"), this);
+  insEquation = new QAction(QIcon((":/bitmaps/equation.png")),	tr("Insert Equation"), this);
   insEquation->setShortcut(Qt::CTRL+Qt::Key_Less);
   insEquation->setStatusTip(tr("Inserts an equation"));
   insEquation->setWhatsThis(
@@ -477,27 +481,27 @@ void QucsApp::initActions()
   insEquation->setToggleAction(true);
   connect(insEquation, SIGNAL(toggled(bool)), SLOT(slotInsertEquation(bool)));
 
-  insGround = new QAction(QIcon((QucsSettings.BitmapDir + "ground.png")), tr("Insert Ground"), this);
+  insGround = new QAction(QIcon((":/bitmaps/ground.png")), tr("Insert Ground"), this);
   insGround->setShortcut(Qt::CTRL+Qt::Key_G);
   insGround->setStatusTip(tr("Inserts a ground symbol"));
   insGround->setWhatsThis(tr("Insert Ground\n\nInserts a ground symbol"));
   insGround->setToggleAction(true);
   connect(insGround, SIGNAL(toggled(bool)), SLOT(slotInsertGround(bool)));
 
-  insPort = new QAction(QIcon((QucsSettings.BitmapDir + "port.png")),	tr("Insert Port"), this);
+  insPort = new QAction(QIcon((":/bitmaps/port.png")),	tr("Insert Port"), this);
   insPort->setStatusTip(tr("Inserts a port symbol"));
   insPort->setWhatsThis(tr("Insert Port\n\nInserts a port symbol"));
   insPort->setToggleAction(true);
   connect(insPort, SIGNAL(toggled(bool)), SLOT(slotInsertPort(bool)));
 
-  insWire = new QAction(QIcon((QucsSettings.BitmapDir + "wire.png")),	tr("Wire"), this);
+  insWire = new QAction(QIcon((":/bitmaps/wire.png")),	tr("Wire"), this);
   insWire->setShortcut(Qt::CTRL+Qt::Key_E);
   insWire->setStatusTip(tr("Inserts a wire"));
   insWire->setWhatsThis(tr("Wire\n\nInserts a wire"));
   insWire->setToggleAction(true);
   connect(insWire, SIGNAL(toggled(bool)), SLOT(slotSetWire(bool)));
 
-  insLabel = new QAction(QIcon((QucsSettings.BitmapDir + "nodename.png")), tr("Wire Label"), this);
+  insLabel = new QAction(QIcon((":/bitmaps/nodename.png")), tr("Wire Label"), this);
   insLabel->setShortcut(Qt::CTRL+Qt::Key_L);
   insLabel->setStatusTip(tr("Inserts a wire or pin label"));
   insLabel->setWhatsThis(tr("Wire Label\n\nInserts a wire or pin label"));
@@ -551,13 +555,20 @@ void QucsApp::initActions()
 	tr("Attenuator synthesis\n\nStarts attenuator calculation program"));
   connect(callAtt, SIGNAL(activated()), SLOT(slotCallAtt()));
 
-  simulate = new QAction(QIcon((QucsSettings.BitmapDir + "gear.png")), tr("Simulate"), this);
+  callRes = new QAction(tr("Resistor color codes"), this);
+  callRes->setShortcut(Qt::CTRL+Qt::Key_7);
+  callRes->setStatusTip(tr("Starts Qucs resistor color codes"));
+  callRes->setWhatsThis(
+  tr("Resistor color codes\n\nStarts standard resistor color code computation program"));
+  connect(callRes, SIGNAL(activated()), SLOT(slotCallRes()));
+
+  simulate = new QAction(QIcon((":/bitmaps/gear.png")), tr("Simulate"), this);
   simulate->setShortcut(Qt::Key_F2);
   simulate->setStatusTip(tr("Simulates the current schematic"));
   simulate->setWhatsThis(tr("Simulate\n\nSimulates the current schematic"));
   connect(simulate, SIGNAL(activated()), SLOT(slotSimulate()));
 
-  dpl_sch = new QAction(QIcon((QucsSettings.BitmapDir + "rebuild.png")), tr("View Data Display/Schematic"), this);
+  dpl_sch = new QAction(QIcon((":/bitmaps/rebuild.png")), tr("View Data Display/Schematic"), this);
   dpl_sch->setShortcut(Qt::Key_F4);
   dpl_sch->setStatusTip(tr("Changes to data display or schematic page"));
   dpl_sch->setWhatsThis(
@@ -572,7 +583,7 @@ void QucsApp::initActions()
 	tr("Calculate DC bias\n\nCalculates DC bias and shows it"));
   connect(dcbias, SIGNAL(activated()), SLOT(slotDCbias()));
 
-  setMarker = new QAction(QIcon((QucsSettings.BitmapDir + "marker.png")),	tr("Set Marker on Graph"), this);
+  setMarker = new QAction(QIcon((":/bitmaps/marker.png")),	tr("Set Marker on Graph"), this);
   setMarker->setShortcut(Qt::CTRL+Qt::Key_B);
   setMarker->setStatusTip(tr("Sets a marker on a diagram's graph"));
   setMarker->setWhatsThis(
@@ -652,10 +663,16 @@ void QucsApp::initMenuBar()
   fileMenu->addAction(textNew);
   fileMenu->addAction(fileOpen);
   fileMenu->addAction(fileClose);
+
+  recentfilesMenu = new QMenu(tr("Open Recent"),fileMenu);
+  fileMenu->addMenu(recentfilesMenu);
+  slotUpdateRecentFiles();
+
   fileMenu->insertSeparator();
   fileMenu->addAction(fileSave);
   fileMenu->addAction(fileSaveAll);
   fileMenu->addAction(fileSaveAs);
+  fileMenu->addAction(exportAsImage);
   fileMenu->addAction(filePrint);
   fileMenu->addAction(filePrintFit);
   fileMenu->insertSeparator();
@@ -665,10 +682,10 @@ void QucsApp::initMenuBar()
   fileMenu->addAction(symEdit);
   fileMenu->insertSeparator();
   fileMenu->addAction(applSettings);
+  fileMenu->addAction(refreshSchPath);
   fileMenu->insertSeparator();
   fileMenu->addAction(fileQuit);
 
-
   editMenu = new QMenu(tr("&Edit"));  // menuBar entry editMenu
   editMenu->addAction(undo);
   editMenu->addAction(redo);
@@ -722,18 +739,22 @@ void QucsApp::initMenuBar()
 
 
   projMenu = new QMenu(tr("&Project"));  // menuBar entry projMenu
-  projNew->addTo(projMenu);
-  projOpen->addTo(projMenu);
-  addToProj->addTo(projMenu);
-  projClose->addTo(projMenu);
-  projDel->addTo(projMenu);
+  projMenu->addAction(projNew);
+  projMenu->addAction(projOpen);
+  projMenu->addAction(addToProj);
+  projMenu->addAction(projClose);
+  projMenu->addAction(projDel);
   projMenu->insertSeparator();
-  createLib->addTo(projMenu);
-  createPkg->addTo(projMenu);
-  extractPkg->addTo(projMenu);
+  projMenu->addAction(createLib);
+  projMenu->addAction(createPkg);
+  projMenu->addAction(extractPkg);
   projMenu->insertSeparator();
-  importData->addTo(projMenu);
-  graph2csv->addTo(projMenu);
+  projMenu->addAction(importData);
+  projMenu->addAction(graph2csv);
+  projMenu->insertSeparator();
+  // TODO only enable if document is VA file
+  projMenu->addAction(buildModule);
+  projMenu->addAction(loadModule);
 
   toolMenu = new QMenu(tr("&Tools"));  // menuBar entry toolMenu
   toolMenu->addAction(callEditor);
@@ -742,6 +763,7 @@ void QucsApp::initMenuBar()
   toolMenu->addAction(callLib);
   toolMenu->addAction(callMatch);
   toolMenu->addAction(callAtt);
+  toolMenu->addAction(callRes);
 
 
 
@@ -940,7 +962,7 @@ void QucsApp::slotShowWarnings()
 
   if(ResultState < 9)
     QTimer::singleShot(500, this, SLOT(slotShowWarnings()));
-  else 
+  else
     ResultState = 0;
 }
 
@@ -1035,6 +1057,8 @@ void QucsApp::slotHelpAbout()
     tr("Quite Universal Circuit Simulator")+"\n"+
     tr("Copyright (C)")+" 2003-2009 "+
     tr("by Michael Margraf")+"\n"+
+    tr("Copyright (C)")+" 2011-2014 "+
+    tr("Qucs Team")+"\n"+
     "\nThis is free software; see the source for copying conditions."
     "\nThere is NO warranty; not even for MERCHANTABILITY or "
     "\nFITNESS FOR A PARTICULAR PURPOSE.\n\n"+
@@ -1043,13 +1067,14 @@ void QucsApp::slotHelpAbout()
     tr("Special thanks to Jens Flucke and Raimund Jacob")+"\n"+
     tr("Many thanks to Mike Brinson for correcting the VHDL output")+"\n"+
     tr("GUI improvements by Gopala Krishna A")+"\n"+
-    tr("Verilog-AMS interface by Helene Parruitte")+"\n\n"+
+    tr("Verilog-AMS interface by Helene Parruitte")+"\n"+
+    tr("Verilog-AMS dynamic loader by Guilherme Brondani Torri")+"\n\n"+
     tr("Translations:")+"\n"+
     tr("German by Stefan Jahn")+"\n"+
     tr("Polish by Dariusz Pienkowski")+"\n"+
     tr("Romanian by Radu Circa")+"\n"+
     tr("French by Vincent Habchi, F5RCS")+"\n"+
-    tr("Portuguese by Luciano Franca and Helio de Sousa")+"\n"+
+    tr("Portuguese by Luciano Franca, Helio de Sousa, Guilherme Brondani Torri")+"\n"+
     tr("Spanish by Jose L. Redrejo Rodriguez")+"\n"+
     tr("Japanese by Toyoyuki Ishikawa")+"\n"+
     tr("Italian by Giorgio Luparia and Claudio Girardi")+"\n"+
