@@ -22,22 +22,22 @@
 #include <stdlib.h>
 #include <limits.h>
 
-#include <qimage.h>
-#include <qaction.h>
-#include <qregexp.h>
-#include <qicon.h>
-#include <qprinter.h>
-#include <qlineedit.h>
-#include <qfileinfo.h>
-#include <q3iconview.h>
-#include <qtabwidget.h>
-#include <q3dragobject.h>
-#include <q3paintdevicemetrics.h>
-#include <qdir.h>
+#include <QImage>
+#include <QAction>
+#include <QRegExp>
+#include <QIcon>
+#include <QPrinter>
+#include <QLineEdit>
+#include <QFileInfo>
+#include <Q3IconView>
+#include <QTabWidget>
+#include <Q3DragObject>
+#include <Q3PaintDeviceMetrics>
+#include <QDir>
 
 #include "qucs.h"
 //Added by qt3to4:
-#include <Q3TextStream>
+#include <QTextStream>
 #include <QDragLeaveEvent>
 #include <Q3StrList>
 #include <Q3PtrList>
@@ -99,14 +99,14 @@ Schematic::Schematic(QucsApp *App_, const QString& Name_)
 
   isVerilog = false;
   creatingLib = false;
-  QFileInfo Info(Name_);
+  FileInfo = QFileInfo (Name_);
   if(App) {
     if(Name_.isEmpty())
       App->DocumentTab->addTab(this, QPixmap(empty_xpm),
                             QObject::tr("untitled"));
     else
       App->DocumentTab->addTab(this, QPixmap(empty_xpm),
-                            Info.fileName());
+                            FileInfo.fileName());
 
     // calls indirectly "becomeCurrent"
     App->DocumentTab->setCurrentPage(App->DocumentTab->indexOf(this));
@@ -122,7 +122,7 @@ Schematic::Schematic(QucsApp *App_, const QString& Name_)
     viewport()->setPaletteBackgroundColor(QucsSettings.BGColor);
     viewport()->setMouseTracking(true);
     viewport()->setAcceptDrops(true);  // enable drag'n drop
-#warning removed those signals, crashes on it...
+// FIXME #warning removed those signals, crashes on it...
     /*connect(horizontalScrollBar(),
 		SIGNAL(prevLine()), SLOT(slotScrollLeft()));
     connect(horizontalScrollBar(),
@@ -231,7 +231,7 @@ void Schematic::becomeCurrent(bool update)
       sizeOfAll(UsedX1, UsedY1, UsedX2, UsedY2);
       setChanged(true, true);
     }
-    
+
     ps = UndoSymbol.current();
     if(ps != UndoSymbol.getFirst())  App->undo->setEnabled(true);
     else  App->undo->setEnabled(false);
@@ -354,8 +354,8 @@ void Schematic::paintFrame(ViewPainter *p)
   int xall, yall;
   if(!sizeOfFrame(xall, yall))
     return;
-
-  p->Painter->setPen(QPen(Qt::black,0));
+  p->Painter->setPen(QPen(Qt::darkGray,1));
+  //p->Painter->setPen(QPen(Qt::black,0));
   int d = p->LineSpacing + int(4.0 * p->Scale);
   int x1_, y1_, x2_, y2_;
   p->map(xall, yall, x1_, y1_);
@@ -442,6 +442,8 @@ void Schematic::drawContents(QPainter *p, int, int, int, int)
       pn->Label->paint(&Painter);  // separate because of paintSelected
   }
 
+  // FIXME disable here, issue with select box goes away
+  // also, instead of red, line turns blue
   for(Diagram *pd = Diagrams->first(); pd != 0; pd = Diagrams->next())
     pd->paint(&Painter);
 
@@ -468,17 +470,17 @@ void Schematic::drawContents(QPainter *p, int, int, int, int)
       Painter.drawText(pn->Name, x, y);
     }
   }
-  
+
   /*
    * The following events used to be drawn from mouseactions.cpp, but since Qt4
    * Paint actions can only be called from within the paint event, so they
    * are put into a QList (PostedPaintEvents) and processed here
    */
-  for(int i=0;i<PostedPaintEvents.size();i++) 
+  for(int i=0;i<PostedPaintEvents.size();i++)
   {
     PostedPaintEvent p = PostedPaintEvents[i];
     QPainter painter2(viewport());
-    
+
     switch(p.pe)
     {
       case _NotRop:
@@ -487,7 +489,7 @@ void Schematic::drawContents(QPainter *p, int, int, int, int)
         else
           Painter.Painter->setCompositionMode(QPainter::RasterOp_SourceAndNotDestination);
         break;
-      case _Rect: 
+      case _Rect:
         if(p.PaintOnViewport)
           painter2.drawRect(p.x1, p.y1, p.x2, p.y2);
         else
@@ -515,17 +517,17 @@ void Schematic::drawContents(QPainter *p, int, int, int, int)
         Painter.Painter->setPen(Qt::DotLine);
         break;
       case _Translate:
-        
+
         painter2.translate(p.x1, p.y1);
         break;
       case _Scale:
         painter2.scale(p.x1,p.y1);
         break;
     }
-    
+
   }
   PostedPaintEvents.clear();
-  
+
 }
 
 void Schematic::PostPaintEvent (PE pe, int x1, int y1, int x2, int y2, int a, int b, bool PaintOnViewport)
@@ -550,7 +552,7 @@ void Schematic::contentsMousePressEvent(QMouseEvent *Event)
   App->editText->setHidden(true); // disable text edit of component property
   if(App->MouseReleaseAction == &MouseActions::MReleasePaste)
     return;
-  
+
   float x = float(Event->pos().x())/Scale + float(ViewX1);
   float y = float(Event->pos().y())/Scale + float(ViewY1);
 
@@ -601,10 +603,21 @@ void Schematic::print(QPrinter*, QPainter *Painter, bool printAll, bool fitToPag
   int marginY = (int)(40 * printerDpiY / screenDpiY);
 
   if(fitToPage) {
-    float ScaleX = float(printerW - 2*marginX) /
-                   float((UsedX2-UsedX1) * printerDpiX) * screenDpiX;
-    float ScaleY = float(printerH - 2*marginY) /
-                   float((UsedY2-UsedY1) * printerDpiY) * screenDpiY;
+
+    float ScaleX = float((printerW - 2*marginX) /
+                   float((UsedX2-UsedX1) * printerDpiX)) * screenDpiX;
+    float ScaleY = float((printerH - 2*marginY) /
+                   float((UsedY2-UsedY1) * printerDpiY)) * screenDpiY;
+
+    if(showFrame){
+        int xall, yall;
+        sizeOfFrame(xall, yall);
+        ScaleX = ((float)(printerW - 2*marginX) /
+                       (float)(xall * printerDpiX)) * screenDpiX;
+        ScaleY = ((float)(printerH - 2*marginY) /
+                       (float)(yall * printerDpiY)) * screenDpiY;
+    }
+
     if(ScaleX > ScaleY)
       PrintScale = ScaleY;
     else
@@ -612,7 +625,7 @@ void Schematic::print(QPrinter*, QPainter *Painter, bool printAll, bool fitToPag
   }
 
 
-  bool selected;
+  //bool selected;
   ViewPainter p;
   int StartX = UsedX1;
   int StartY = UsedY1;
@@ -628,7 +641,6 @@ void Schematic::print(QPrinter*, QPainter *Painter, bool printAll, bool fitToPag
   printFont.setPointSizeF(printFont.pointSizeF()/PrintRatio);
   Painter->setFont(printFont);
 #endif
-
   p.init(Painter, PrintScale * PrintRatio,
          -StartX, -StartY, -marginX, -marginY,
 	 PrintScale, PrintRatio);
@@ -636,85 +648,97 @@ void Schematic::print(QPrinter*, QPainter *Painter, bool printAll, bool fitToPag
   if(!symbolMode)
     paintFrame(&p);
 
-  for(Component *pc = Components->first(); pc != 0; pc = Components->next())
-    if(pc->isSelected || printAll) {
-      selected = pc->isSelected;
-      pc->isSelected = false;
-      pc->print(&p, screenDpiX / printerDpiX);
-      pc->isSelected = selected;
+  paintSchToViewpainter(&p,printAll,false,screenDpiX,printerDpiX);
+
+    Painter->setFont(oldFont);
+}
+
+
+void Schematic::paintSchToViewpainter(ViewPainter *p, bool printAll, bool toImage, int screenDpiX, int printerDpiX)
+{
+    bool selected;
+
+    for(Component *pc = Components->first(); pc != 0; pc = Components->next())
+      if(pc->isSelected || printAll) {
+        selected = pc->isSelected;
+        pc->isSelected = false;
+        if (toImage) {
+            pc->paint(p);
+        } else {
+            pc->print(p, (float)screenDpiX / (float)printerDpiX);
+        }
+        pc->isSelected = selected;
+      }
+
+    for(Wire *pw = Wires->first(); pw != 0; pw = Wires->next()) {
+      if(pw->isSelected || printAll) {
+        selected = pw->isSelected;
+        pw->isSelected = false;
+        pw->paint(p);   // paint all selected wires
+        pw->isSelected = selected;
+      }
+      if(pw->Label)
+        if(pw->Label->isSelected || printAll) {
+          selected = pw->Label->isSelected;
+          pw->Label->isSelected = false;
+          pw->Label->paint(p);
+          pw->Label->isSelected = selected;
+        }
     }
 
-  for(Wire *pw = Wires->first(); pw != 0; pw = Wires->next()) {
-    if(pw->isSelected || printAll) {
-      selected = pw->isSelected;
-      pw->isSelected = false;
-      pw->paint(&p);   // paint all selected wires
-      pw->isSelected = selected;
-    }
-    if(pw->Label)
-      if(pw->Label->isSelected || printAll) {
-        selected = pw->Label->isSelected;
-        pw->Label->isSelected = false;
-        pw->Label->paint(&p);
-        pw->Label->isSelected = selected;
-      }
-  }
-
-  Element *pe;
-  for(Node *pn = Nodes->first(); pn != 0; pn = Nodes->next()) {
-    for(pe = pn->Connections.first(); pe != 0; pe = pn->Connections.next())
-      if(pe->isSelected || printAll) {
-        pn->paint(&p); // paint all nodes with selected elements
-        break;
-      }
-    if(pn->Label)
-      if(pn->Label->isSelected || printAll) {
-        selected = pn->Label->isSelected;
-        pn->Label->isSelected = false;
-        pn->Label->paint(&p);
-        pn->Label->isSelected = selected;
-      }
-  }
-
-  Graph  *pg;
-  Marker *pm;
-  for(Diagram *pd = Diagrams->first(); pd != 0; pd = Diagrams->next())
-    if(pd->isSelected || printAll) {
-      // if graph or marker is selected, deselect during printing
-      for(pg = pd->Graphs.first(); pg != 0; pg = pd->Graphs.next()) {
-	if(pg->isSelected)  pg->Type |= 1;  // remember selection
-	pg->isSelected = false;
-	for(pm = pg->Markers.first(); pm != 0; pm = pg->Markers.next()) {
-	  if(pm->isSelected)  pm->Type |= 1;  // remember selection
-	  pm->isSelected = false;
-	}
-      }
-
-      selected = pd->isSelected;
-      pd->isSelected = false;
-      pd->paint(&p);  // paint all selected diagrams with graphs and markers
-      pd->isSelected = selected;
-
-      // revert selection of graphs and markers
-      for(pg = pd->Graphs.first(); pg != 0; pg = pd->Graphs.next()) {
-	if(pg->Type & 1)  pg->isSelected = true;
-	pg->Type &= -2;
-	for(pm = pg->Markers.first(); pm != 0; pm = pg->Markers.next()) {
-	  if(pm->Type & 1)  pm->isSelected = true;
-	  pm->Type &= -2;
-	}
-      }
+    Element *pe;
+    for(Node *pn = Nodes->first(); pn != 0; pn = Nodes->next()) {
+      for(pe = pn->Connections.first(); pe != 0; pe = pn->Connections.next())
+        if(pe->isSelected || printAll) {
+          pn->paint(p); // paint all nodes with selected elements
+          break;
+        }
+      if(pn->Label)
+        if(pn->Label->isSelected || printAll) {
+          selected = pn->Label->isSelected;
+          pn->Label->isSelected = false;
+          pn->Label->paint(p);
+          pn->Label->isSelected = selected;
+        }
     }
 
-  for(Painting *pp = Paintings->first(); pp != 0; pp = Paintings->next())
-    if(pp->isSelected || printAll) {
-      selected = pp->isSelected;
-      pp->isSelected = false;
-      pp->paint(&p);   // paint all selected paintings
-      pp->isSelected = selected;
-    }
+    for(Painting *pp = Paintings->first(); pp != 0; pp = Paintings->next())
+      if(pp->isSelected || printAll) {
+        selected = pp->isSelected;
+        pp->isSelected = false;
+        pp->paint(p);   // paint all selected paintings
+        pp->isSelected = selected;
+      }
 
-  Painter->setFont(oldFont);
+    Graph  *pg;
+    Marker *pm;
+    for(Diagram *pd = Diagrams->first(); pd != 0; pd = Diagrams->next())
+      if(pd->isSelected || printAll) {
+        // if graph or marker is selected, deselect during printing
+        for(pg = pd->Graphs.first(); pg != 0; pg = pd->Graphs.next()) {
+      if(pg->isSelected)  pg->Type |= 1;  // remember selection
+      pg->isSelected = false;
+      for(pm = pg->Markers.first(); pm != 0; pm = pg->Markers.next()) {
+        if(pm->isSelected)  pm->Type |= 1;  // remember selection
+        pm->isSelected = false;
+      }
+        }
+
+        selected = pd->isSelected;
+        pd->isSelected = false;
+        pd->paint(p);  // paint all selected diagrams with graphs and markers
+        pd->isSelected = selected;
+
+        // revert selection of graphs and markers
+        for(pg = pd->Graphs.first(); pg != 0; pg = pd->Graphs.next()) {
+      if(pg->Type & 1)  pg->isSelected = true;
+      pg->Type &= -2;
+      for(pm = pg->Markers.first(); pm != 0; pm = pg->Markers.next()) {
+        if(pm->Type & 1)  pm->isSelected = true;
+        pm->Type &= -2;
+      }
+        }
+      }
 }
 
 // -----------------------------------------------------------
@@ -722,7 +746,7 @@ float Schematic::zoom(float s)
 {
   Scale *= s;
   if(Scale > 10.0) Scale = 10.0f;
-  if(Scale < 0.01) Scale = 0.01f;
+  if(Scale < 0.1) Scale = 0.1f;
 
   // "resizeContents()" performs an immediate repaint. So, set widget
   // to hidden. This causes some flicker, but it is still nicer.
@@ -1247,7 +1271,7 @@ QString Schematic::copySelected(bool cut)
 
 // ---------------------------------------------------
 // Performs paste function from clipboard
-bool Schematic::paste(Q3TextStream *stream, Q3PtrList<Element> *pe)
+bool Schematic::paste(QTextStream *stream, Q3PtrList<Element> *pe)
 {
   return pasteFromClipboard(stream, pe);
 }
@@ -1313,6 +1337,10 @@ int Schematic::save()
     ps->replace(1,1,'i');//at(1) = 'i';   // state of being unchanged
     UndoSymbol.findRef(ps);  // back to current
   }
+  // update the subcircuit file lookup hashes
+  QucsMain->updateSchNameHash();
+  QucsMain->updateSpiceNameHash();
+
   return result;
 }
 
@@ -1369,7 +1397,7 @@ int Schematic::adjustPortNumbers()
     VHDL_File_Info VInfo;
     TextDoc * d = (TextDoc*)App->findDoc (Name);
     if (d)
-      VInfo = VHDL_File_Info (d->text());
+      VInfo = VHDL_File_Info (d->document()->toPlainText());
     else
       VInfo = VHDL_File_Info (Name, true);
     Names = QStringList::split(",",VInfo.PortNames);
@@ -1425,7 +1453,7 @@ int Schematic::adjustPortNumbers()
     Verilog_File_Info VInfo;
     TextDoc * d = (TextDoc*)App->findDoc (Name);
     if (d)
-      VInfo = Verilog_File_Info (d->text());
+      VInfo = Verilog_File_Info (d->document()->toPlainText());
     else
       VInfo = Verilog_File_Info (Name, true);
     Names = QStringList::split(",",VInfo.PortNames);
@@ -1470,7 +1498,7 @@ int Schematic::adjustPortNumbers()
     VerilogA_File_Info VInfo;
     TextDoc * d = (TextDoc*)App->findDoc (Name);
     if (d)
-      VInfo = VerilogA_File_Info (d->text());
+      VInfo = VerilogA_File_Info (d->toPlainText());
     else
       VInfo = VerilogA_File_Info (Name, true);
     Names = QStringList::split(",",VInfo.PortNames);
@@ -1500,24 +1528,35 @@ int Schematic::adjustPortNumbers()
     }
   }
   // handle schematic symbol
-  else {
-    // go through all components in a schematic
-    for(Component *pc = DocComps.first(); pc!=0; pc = DocComps.next())
-      if(pc->Model == "Port") {
-	countPort++;
+  else
+  {
+      // go through all components in a schematic
+      for(Component *pc = DocComps.first(); pc!=0; pc = DocComps.next())
+      {
+         if(pc->Model == "Port")
+         {
+             countPort++;
 
-	Str = pc->Props.getFirst()->Value;
-	// search for matching port symbol
-	for(pp = SymbolPaints.first(); pp!=0; pp = SymbolPaints.next())
-	  if(pp->Name == ".PortSym ")
-	    if(((PortSymbol*)pp)->numberStr == Str) break;
+             Str = pc->Props.getFirst()->Value;
+             // search for matching port symbol
+             for(pp = SymbolPaints.first(); pp!=0; pp = SymbolPaints.next())
+             {
+                 if(pp->Name == ".PortSym ")
+                 {
+                   if(((PortSymbol*)pp)->numberStr == Str) break;
+                 }
+             }
 
-	if(pp)
-	  ((PortSymbol*)pp)->nameStr = pc->Name;
-	else {
-	  SymbolPaints.append(new PortSymbol(x1, y2, Str, pc->Name));
-	  y2 += 40;
-	}
+             if(pp)
+             {
+                 ((PortSymbol*)pp)->nameStr = pc->Name;
+             }
+             else
+             {
+                 SymbolPaints.append(new PortSymbol(x1, y2, Str, pc->Name));
+                 y2 += 40;
+             }
+          }
       }
   }
 
@@ -2112,3 +2151,145 @@ void Schematic::contentsDragMoveEvent(QDragMoveEvent *Event)
 
   Event->accept();
 }
+
+void Schematic::getSchWidthAndHeight(int &w, int &h, int& xmin_, int& ymin_)
+{
+    int xmin= INT_MAX,
+        ymin= INT_MAX,
+        xmax= INT_MIN,
+        ymax= INT_MIN;
+
+    for(Component *pc = Components->first(); pc != 0; pc = Components->next()) {
+        int x1,y1,x2,y2,d1,d2,d3,d4;
+        pc->entireBounds(x1,y1,x2,y2,this->textCorr());
+
+        d1 = std::min(x1,x2);
+        if (d1<xmin) xmin = d1;
+        d2 = std::max(x2,x1);
+        if (d2>xmax) xmax = d2;
+        d3 = std::min(y1,y2);
+        if (d3<ymin) ymin = d3;
+        d4 = std::max(y2,y1);
+        if (d4>ymax) ymax = d4;
+    }
+
+    for(Wire *pw = Wires->first(); pw != 0; pw = Wires->next()) {
+        int xc,yc;
+        pw->getCenter(xc,yc);
+
+        if (xc<xmin) xmin = xc;
+        if (xc>xmax) xmax = xc;
+        if (yc<ymin) ymin = yc;
+        if (yc>ymax) ymax = yc;
+    }
+
+    for(Diagram *pd = Diagrams->first(); pd != 0; pd = Diagrams->next()) {
+
+        int x1,y1,x2,y2,d1,d2,d3,d4;
+        pd->Bounding(x1,y1,x2,y2);
+
+        d1 = std::min(x1,x2);
+        if (d1<xmin) xmin = d1;
+        d2 = std::max(x2,x1);
+        if (d2>xmax) xmax = d2;
+        d3 = std::min(y1,y2);
+        if (d3<ymin) ymin = d3;
+        d4 = std::max(y2,y1);
+        if (d4>ymax) ymax = d4;
+    }
+
+    for(Painting *pp = Paintings->first(); pp != 0; pp = Paintings->next()) {
+       int x1,y1,x2,y2,d1,d2,d3,d4;
+       pp->Bounding(x1,y1,x2,y2);
+
+       d1 = std::min(x1,x2);
+       if (d1<xmin) xmin = d1;
+       d2 = std::max(x2,x1);
+       if (d2>xmax) xmax = d2;
+       d3 = std::min(y1,y2);
+       if (d3<ymin) ymin = d3;
+       d4 = std::max(y2,y1);
+       if (d4>ymax) ymax = d4;
+    }
+
+    w = abs(xmax - xmin);
+    h = abs(ymax - ymin);
+    xmin_ = xmin;
+    ymin_ = ymin;
+}
+
+void Schematic::getSelAreaWidthAndHeight(int &wsel, int &hsel, int& xmin_sel_, int& ymin_sel_)
+{
+    int xmin= INT_MAX,
+        ymin= INT_MAX,
+        xmax= INT_MIN,
+        ymax= INT_MIN;
+
+     for(Component *pc = Components->first(); pc != 0; pc = Components->next()) {
+         if (pc->isSelected) {
+           int x1,y1,x2,y2,d1,d2,d3,d4;
+           pc->entireBounds(x1,y1,x2,y2,this->textCorr());
+           d1 = std::min(x1,x2);
+           if (d1<xmin) xmin = d1;
+           d2 = std::max(x2,x1);
+           if (d2>xmax) xmax = d2;
+           d3 = std::min(y1,y2);
+           if (d3<ymin) ymin = d3;
+           d4 = std::max(y2,y1);
+           if (d4>ymax) ymax = d4;
+         }
+    }
+
+    for(Wire *pw = Wires->first(); pw != 0; pw = Wires->next()) {
+
+        if (pw->isSelected) {
+            int xc,yc;
+            pw->getCenter(xc,yc);
+
+            if (xc<xmin) xmin = xc;
+            if (xc>xmax) xmax = xc;
+            if (yc<ymin) ymin = yc;
+            if (yc>ymax) ymax = yc;
+        }
+    }
+
+    for(Diagram *pd = Diagrams->first(); pd != 0; pd = Diagrams->next()) {
+
+
+
+        if (pd->isSelected) {
+            int x1,y1,x2,y2,d1,d2,d3,d4;
+            pd->Bounding(x1,y1,x2,y2);
+
+            d1 = std::min(x1,x2);
+            if (d1<xmin) xmin = d1;
+            d2 = std::max(x2,x1);
+            if (d2>xmax) xmax = d2;
+            d3 = std::min(y1,y2);
+            if (d3<ymin) ymin = d3;
+            d4 = std::max(y2,y1);
+            if (d4>ymax) ymax = d4;
+        }
+    }
+
+    for(Painting *pp = Paintings->first(); pp != 0; pp = Paintings->next()) {
+
+       if (pp->isSelected) {
+           int x1,y1,x2,y2,d1,d2,d3,d4;
+           pp->Bounding(x1,y1,x2,y2);
+           d1 = std::min(x1,x2);
+           if (d1<xmin) xmin = d1;
+           d2 = std::max(x2,x1);
+           if (d2>xmax) xmax = d2;
+           d3 = std::min(y1,y2);
+           if (d3<ymin) ymin = d3;
+           d4 = std::max(y2,y1);
+           if (d4>ymax) ymax = d4;
+       }
+    }
+
+    wsel = abs(xmax - xmin);
+    hsel = abs(ymax - ymin);
+    xmin_sel_ = xmin;
+    ymin_sel_ = ymin;
+}
