@@ -19,16 +19,15 @@
 # include <config.h>
 #endif
 #include <QtGui>
-#include <qmessagebox.h>
-#include <qdir.h>
-#include <qstringlist.h>
-#include <qregexp.h>
-#include <q3process.h>
-#include <q3textedit.h>
+#include <QMessageBox>
+#include <QDir>
+#include <QStringList>
+#include <QRegExp>
+#include <Q3TextEdit>
 #include <QTextEdit>
-#include <q3ptrlist.h>
+#include <Q3PtrList>
 //Added by qt3to4:
-#include <Q3TextStream>
+#include <QTextStream>
 #include <Q3ValueList>
 
 #include "main.h"
@@ -40,10 +39,9 @@
 #include "components/vhdlfile.h"
 #include "components/verilogfile.h"
 #include "components/libcomp.h"
+#include "module.h"
 
 
-extern QDir QucsWorkDir;
-
 // Here the subcircuits, SPICE components etc are collected. It must be
 // global to also work within the subcircuits.
 SubMap FileList;
@@ -104,7 +102,7 @@ QString Schematic::createClipboardFile()
 
 // -------------------------------------------------------------
 // Only read fields without loading them.
-bool Schematic::loadIntoNothing(Q3TextStream *stream)
+bool Schematic::loadIntoNothing(QTextStream *stream)
 {
   QString Line, cstr;
   while(!stream->atEnd()) {
@@ -119,7 +117,7 @@ bool Schematic::loadIntoNothing(Q3TextStream *stream)
 
 // -------------------------------------------------------------
 // Paste from clipboard.
-bool Schematic::pasteFromClipboard(Q3TextStream *stream, Q3PtrList<Element> *pe)
+bool Schematic::pasteFromClipboard(QTextStream *stream, Q3PtrList<Element> *pe)
 {
   QString Line;
 
@@ -197,7 +195,7 @@ int Schematic::saveSymbolCpp (void)
     return -1;
   }
 
-  Q3TextStream stream (&file);
+  QTextStream stream (&file);
 
   // automatically compute boundings of drawing
   int xmin = INT_MAX;
@@ -252,6 +250,90 @@ int Schematic::saveSymbolCpp (void)
   return 0;
 }
 
+// save symbol paintings in JSON format
+int Schematic::saveSymbolJSON()
+{
+  QFileInfo info (DocName);
+  QString jsonfile = info.dirPath () + QDir::separator()
+                   + info.baseName() + "_sym.json";
+
+  qDebug() << "saveSymbolJson for " << jsonfile;
+
+  QFile file (jsonfile);
+
+  if (!file.open (QIODevice::WriteOnly)) {
+    QMessageBox::critical (0, QObject::tr("Error"),
+		   QObject::tr("Cannot save JSON symbol file \"%1\"!").arg(jsonfile));
+    return -1;
+  }
+
+  QTextStream stream (&file);
+
+  // automatically compute boundings of drawing
+  int xmin = INT_MAX;
+  int ymin = INT_MAX;
+  int xmax = INT_MIN;
+  int ymax = INT_MIN;
+  int x1, y1, x2, y2;
+  int maxNum = 0;
+  Painting * pp;
+
+  stream << "{\n";
+
+  stream << "\"paintings\" : [\n";
+
+  // symbol drawing code"
+  for (pp = SymbolPaints.first (); pp != 0; pp = SymbolPaints.next ()) {
+    if (pp->Name == ".ID ") continue;
+    if (pp->Name == ".PortSym ") {
+      if (((PortSymbol*)pp)->numberStr.toInt() > maxNum)
+	maxNum = ((PortSymbol*)pp)->numberStr.toInt();
+      x1 = ((PortSymbol*)pp)->cx;
+      y1 = ((PortSymbol*)pp)->cy;
+      if (x1 < xmin) xmin = x1;
+      if (x1 > xmax) xmax = x1;
+      if (y1 < ymin) ymin = y1;
+      if (y1 > ymax) ymax = y1;
+      continue;
+    }
+    pp->Bounding (x1, y1, x2, y2);
+    if (x1 < xmin) xmin = x1;
+    if (x2 > xmax) xmax = x2;
+    if (y1 < ymin) ymin = y1;
+    if (y2 > ymax) ymax = y2;
+    stream << "  " << pp->saveJSON() << "\n";
+  }
+
+  // terminal definitions
+  //stream << "terminal \n";
+  for (int i = 1; i <= maxNum; i++) {
+    for (pp = SymbolPaints.first (); pp != 0; pp = SymbolPaints.next ()) {
+      if (pp->Name == ".PortSym ")
+	if (((PortSymbol*)pp)->numberStr.toInt() == i)
+	  stream << "  " << pp->saveJSON () << "\n";
+    }
+  }
+
+  stream << "],\n"; //end of paintings JSON array
+
+  // symbol boundings
+  stream
+    << "  \"x1\" : " << xmin << ",\n" << "  \"y1\" : " << ymin << ",\n"
+    << "  \"x2\" : " << xmax << ",\n" << "  \"y2\" : " << ymax << ",\n";
+
+  // property text position
+  for (pp = SymbolPaints.first (); pp != 0; pp = SymbolPaints.next ())
+    if (pp->Name == ".ID ")
+      stream << "  " << pp->saveJSON () << "\n";
+
+  stream << "}\n";
+
+  file.close ();
+  return 0;
+
+
+}
+
 // -------------------------------------------------------------
 // Returns the number of subcircuit ports.
 int Schematic::saveDocument()
@@ -263,7 +345,7 @@ int Schematic::saveDocument()
     return -1;
   }
 
-  Q3TextStream stream(&file);
+  QTextStream stream(&file);
 
   stream << "<Qucs Schematic " << PACKAGE_VERSION << ">\n";
 
@@ -335,14 +417,108 @@ int Schematic::saveDocument()
   if (fileSuffix () == "sym") {
     if (fileSuffix (DataDisplay) == "va") {
       saveSymbolCpp ();
-    }
-  }
+      saveSymbolJSON ();
+
+      // TODO slit this into another method, or merge into saveSymbolJSON
+      // handle errors in separate
+      qDebug() << "  -> Run adms for symbol";
+
+      QString vaFile;
+
+//      QDir prefix = QDir(QucsSettings.BinDir);
+
+      QDir include = QDir(QucsSettings.BinDir+"../include/qucs-core");
+
+      //pick admsXml from settings
+      QString admsXml = QucsSettings.AdmsXmlBinDir.canonicalPath();
+
+#ifdef __MINGW32__
+      admsXml = QDir::toNativeSeparators(admsXml+"/"+"admsXml.exe");
+#else
+      admsXml = QDir::toNativeSeparators(admsXml+"/"+"admsXml");
+#endif
+
+      QString workDir = QucsSettings.QucsWorkDir.absolutePath();
+
+      qDebug() << "App path : " << qApp->applicationDirPath();
+      qDebug() << "workdir"  << workDir;
+      qDebug() << "homedir"  << QucsSettings.QucsHomeDir.absolutePath();
+
+      vaFile = QucsSettings.QucsWorkDir.filePath(fileBase()+".va");
+
+      QStringList Arguments;
+      Arguments << QDir::toNativeSeparators(vaFile)
+                << "-I" << QDir::toNativeSeparators(include.absolutePath())
+                << "-e" << QDir::toNativeSeparators(include.absFilePath("qucsMODULEguiJSONsymbol.xml"))
+                << "-A" << "dyload";
+
+//      QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+//      env.insert("PATH", env.value("PATH") );
+
+      QFile file(admsXml);
+      if ( !file.exists() ){
+        QMessageBox::critical(this, tr("Error"),
+                              tr("Program admsXml not found: %1\n\n"
+                                  "Set the admsXml location on the application settings.").arg(admsXml));
+        return -1;
+      }
+
+      qDebug() << "Command: " << admsXml << Arguments.join(" ");
+
+      // need to cd into project to run admsXml?
+      QDir::setCurrent(workDir);
+
+      QProcess builder;
+      builder.setProcessChannelMode(QProcess::MergedChannels);
+
+      builder.start(admsXml, Arguments);
+
+
+      // how to capture [warning]? need to modify admsXml?
+      // TODO put stdout, stderr into a dock window, not messagebox
+      if (!builder.waitForFinished()) {
+        QString cmdString = QString("%1 %2\n\n").arg(admsXml, Arguments.join(" "));
+        cmdString = cmdString + builder.errorString();
+        QMessageBox::critical(this, tr("Error"), cmdString);
+      }
+      else {
+        QString cmdString = QString("%1 %2\n\n").arg(admsXml, Arguments.join(" "));
+        cmdString = cmdString + builder.readAll();
+        QMessageBox::information(this, tr("Status"), cmdString);
+      }
+
+      // Append _sym.json into _props.json, save into _symbol.json
+      QFile f1(QucsSettings.QucsWorkDir.filePath(fileBase()+"_props.json"));
+      QFile f2(QucsSettings.QucsWorkDir.filePath(fileBase()+"_sym.json"));
+      f1.open(QIODevice::ReadOnly | QIODevice::Text);
+      f2.open(QIODevice::ReadOnly | QIODevice::Text);
+
+      QString dat1 = QString(f1.readAll());
+      QString dat2 = QString(f2.readAll());
+      QString finalJSON = dat1.append(dat2);
+
+      // remove joining point
+      finalJSON = finalJSON.replace("}{", "");
+
+      QFile f3(QucsSettings.QucsWorkDir.filePath(fileBase()+"_symbol.json"));
+      f3.open(QIODevice::WriteOnly | QIODevice::Text);
+      QTextStream out(&f3);
+      out << finalJSON;
+
+      f1.close();
+      f2.close();
+      f3.close();
+
+      // TODO choose icon, default to something or provided png
+
+    } // if DataDisplay va
+  } // if suffix .sym
 
   return 0;
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadProperties(Q3TextStream *stream)
+bool Schematic::loadProperties(QTextStream *stream)
 {
   bool ok = true;
   QString Line, cstr, nstr;
@@ -450,7 +626,7 @@ void Schematic::simpleInsertComponent(Component *c)
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadComponents(Q3TextStream *stream, Q3PtrList<Component> *List)
+bool Schematic::loadComponents(QTextStream *stream, Q3PtrList<Component> *List)
 {
   QString Line, cstr;
   Component *c;
@@ -460,7 +636,8 @@ bool Schematic::loadComponents(Q3TextStream *stream, Q3PtrList<Component> *List)
     Line = Line.stripWhiteSpace();
     if(Line.isEmpty()) continue;
 
-    c = getComponentFromName(Line);
+    /// \todo enable user to load partial schematic, skip unknown components
+    c = getComponentFromName(Line, this);
     if(!c) return false;
 
     if(List) {  // "paste" ?
@@ -519,7 +696,7 @@ void Schematic::simpleInsertWire(Wire *pw)
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadWires(Q3TextStream *stream, Q3PtrList<Element> *List)
+bool Schematic::loadWires(QTextStream *stream, Q3PtrList<Element> *List)
 {
   Wire *w;
   QString Line;
@@ -556,7 +733,7 @@ bool Schematic::loadWires(Q3TextStream *stream, Q3PtrList<Element> *List)
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadDiagrams(Q3TextStream *stream, Q3PtrList<Diagram> *List)
+bool Schematic::loadDiagrams(QTextStream *stream, Q3PtrList<Diagram> *List)
 {
   Diagram *d;
   QString Line, cstr;
@@ -599,7 +776,7 @@ bool Schematic::loadDiagrams(Q3TextStream *stream, Q3PtrList<Diagram> *List)
 }
 
 // -------------------------------------------------------------
-bool Schematic::loadPaintings(Q3TextStream *stream, Q3PtrList<Painting> *List)
+bool Schematic::loadPaintings(QTextStream *stream, Q3PtrList<Painting> *List)
 {
   Painting *p=0;
   QString Line, cstr;
@@ -656,7 +833,7 @@ bool Schematic::loadDocument()
   }
 
   QString Line;
-  Q3TextStream stream(&file);
+  QTextStream stream(&file);
 
   // read header **************************
   do {
@@ -677,10 +854,22 @@ bool Schematic::loadDocument()
 
   Line = Line.mid(16, Line.length()-17);
   if(!checkVersion(Line)) { // wrong version number ?
-    file.close();
-    QMessageBox::critical(0, QObject::tr("Error"),
-		 QObject::tr("Wrong document version: ")+Line);
-    return false;
+
+    QMessageBox::StandardButton result;
+    result = QMessageBox::warning(0,
+                                  QObject::tr("Warning"),
+                                  QObject::tr("Wrong document version \n" +
+                                              DocName + "\n"
+                                              "Try to open it anyway?"),
+                                  QMessageBox::Yes|QMessageBox::No);
+
+    if (result==QMessageBox::No) {
+        file.close();
+        return false;
+    }
+
+    //QMessageBox::critical(0, QObject::tr("Error"),
+        // QObject::tr("Wrong document version: ")+Line);
   }
 
   // read content *************************
@@ -690,6 +879,7 @@ bool Schematic::loadDocument()
     if(Line.isEmpty()) continue;
 
     if(Line == "<Symbol>") {
+      if ((Schematic*)QucsMain != 0) // GUI running, load Symbols
       if(!loadPaintings(&stream, &SymbolPaints)) {
 	file.close();
 	return false;
@@ -705,17 +895,20 @@ bool Schematic::loadDocument()
     if(Line == "<Wires>") {
       if(!loadWires(&stream)) { file.close(); return false; } }
     else
+    if ((Schematic*)QucsMain != 0) { // GUI running, load Diagrams, Paintings
     if(Line == "<Diagrams>") {
       if(!loadDiagrams(&stream, &DocDiags)) { file.close(); return false; } }
     else
     if(Line == "<Paintings>") {
       if(!loadPaintings(&stream, &DocPaints)) { file.close(); return false; } }
     else {
+        qDebug() << Line;
       QMessageBox::critical(0, QObject::tr("Error"),
 		   QObject::tr("File Format Error:\nUnknown field!"));
       file.close();
       return false;
     }
+    } // Diagrams, Paintings
   }
 
   file.close();
@@ -789,7 +982,7 @@ bool Schematic::rebuild(QString *s)
   DocPaints.clear();
 
   QString Line;
-  Q3TextStream stream(s, QIODevice::ReadOnly);
+  QTextStream stream(s, QIODevice::ReadOnly);
   Line = stream.readLine();  // skip identity byte
 
   // read content *************************
@@ -808,7 +1001,7 @@ bool Schematic::rebuildSymbol(QString *s)
   SymbolPaints.clear();	// delete whole document
 
   QString Line;
-  Q3TextStream stream(s, QIODevice::ReadOnly);
+  QTextStream stream(s, QIODevice::ReadOnly);
   Line = stream.readLine();  // skip identity byte
 
   // read content *************************
@@ -923,7 +1116,7 @@ void Schematic::propagateNode(QStringList& Collect,
 }
 
 #include <iostream>
-// --------------------------------------------------- 
+// ---------------------------------------------------
 // Goes through all schematic components and allows special component
 // handling, e.g. like subcircuit netlisting.
 bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
@@ -959,52 +1152,67 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
     }
 
     // handle subcircuits
-    if(pc->Model == "Sub") {
+    if(pc->Model == "Sub")
+    {
       int i;
+      // tell the subcircuit it belongs to this schematic
+      pc->setSchematic (this);
       QString f = pc->getSubcircuitFile();
       SubMap::Iterator it = FileList.find(f);
-      if(it != FileList.end()) {
-	if (!it.data().PortTypes.isEmpty()) {
-	  i = 0;
-	  // apply in/out signal types of subcircuit
-	  for(Port *pp = pc->Ports.first(); pp; pp = pc->Ports.next(), i++) {
-	    pp->Type = it.data().PortTypes[i];
-	    pp->Connection->DType = pp->Type;
-	  }
-	}
+      if(it != FileList.end())
+      {
+        if (!it.data().PortTypes.isEmpty())
+        {
+          i = 0;
+          // apply in/out signal types of subcircuit
+          for(Port *pp = pc->Ports.first(); pp; pp = pc->Ports.next(), i++)
+          {
+            pp->Type = it.data().PortTypes[i];
+            pp->Connection->DType = pp->Type;
+          }
+        }
         continue;   // insert each subcircuit just one time
       }
+
+      // The subcircuit has not previously been added
       SubFile sub = SubFile("SCH", f);
       FileList.insert(f, sub);
 
+
       // load subcircuit schematic
       s = pc->Props.first()->Value;
-      Schematic *d = new Schematic(0, QucsWorkDir.filePath(s));
-      if(!d->loadDocument()) {  // load document if possible
-        delete d;
-        ErrText->insert(QObject::tr("ERROR: Cannot load subcircuit \"%1\".").arg(s));
-        return false;
+      Schematic *d = new Schematic(0, pc->getSubcircuitFile());
+      if(!d->loadDocument())      // load document if possible
+      {
+          delete d;
+          ErrText->insert(QObject::tr("ERROR: Cannot load subcircuit \"%1\".").arg(s));
+          return false;
       }
       d->DocName = s;
       d->isVerilog = isVerilog;
       d->isAnalog = isAnalog;
       d->creatingLib = creatingLib;
       r = d->createSubNetlist(stream, countInit, Collect, ErrText, NumPorts);
-      if (r) {
-	      i = 0;
-	      // save in/out signal types of subcircuit
-	      for(Port *pp = pc->Ports.first(); pp; pp = pc->Ports.next(), i++) {
-          //if(i>=d->PortTypes.count())break;
-	        pp->Type = d->PortTypes[i];
-	        pp->Connection->DType = pp->Type;
-	      }
-	      sub.PortTypes = d->PortTypes;
-	      FileList.replace(f, sub);
+      if (r)
+      {
+        i = 0;
+        // save in/out signal types of subcircuit
+        for(Port *pp = pc->Ports.first(); pp; pp = pc->Ports.next(), i++)
+        {
+            //if(i>=d->PortTypes.count())break;
+            pp->Type = d->PortTypes[i];
+            pp->Connection->DType = pp->Type;
+        }
+        sub.PortTypes = d->PortTypes;
+        FileList.replace(f, sub);
       }
       delete d;
-      if(!r) return false;
+      if(!r)
+      {
+        return false;
+      }
       continue;
-    }
+    } // if(pc->Model == "Sub")
 
     // handle library symbols
     if(pc->Model == "Lib") {
@@ -1040,6 +1248,8 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
     // handle SPICE subcircuit components
     if(pc->Model == "SPICE") {
       s = pc->Props.first()->Value;
+      // tell the spice component it belongs to this schematic
+      pc->setSchematic (this);
       if(s.isEmpty()) {
         ErrText->insert(QObject::tr("ERROR: No file name in SPICE component \"%1\".").
                         arg(pc->Name));
@@ -1089,7 +1299,7 @@ bool Schematic::throughAllComps(QTextStream *stream, int& countInit,
 	r = vf->createSubNetlist(stream);
 	ErrText->insert(vf->getErrorText());
 	if(!r) return false;
-      }      
+      }
       continue;
     }
   }
