@@ -1,9 +1,9 @@
 /***************************************************************************
                                 textdoc.h
                                -----------
-    begin                : Sat Mar 11 2006
-    copyright            : (C) 2006 by Michael Margraf
-    email                : michael.margraf@alumni.tu-berlin.de
+Copyright (C) 2006 by Michael Margraf <michael.margraf@alumni.tu-berlin.de>
+Copyright (C) 2014 by Guilherme Brondani Torri <guitorri@gmail.com>
+
  ***************************************************************************/
 
 /***************************************************************************
@@ -18,13 +18,16 @@
 #ifndef TEXTDOC_H
 #define TEXTDOC_H
 
-
-#include <QTextEdit>
-#include <q3textedit.h>
-#include <qfont.h>
+#include <QPlainTextEdit>
+#include <QFont>
 
 #include "qucsdoc.h"
 
+/*!
+ * \file textdoc.h
+ * \brief Definition of the TextDoc class.
+ */
+
 class SyntaxHighlighter;
 
 extern const char *smallsave_xpm[];// icon for unsaved files (diskette)
@@ -40,9 +43,12 @@ extern const char *empty_xpm[];    // provides same height than "smallsave_xpm"
 #define DEV_MASK_TYP 0xFF00
 #define DEV_DEF      0x0200 // default value
 
-class TextDoc : public QTextEdit, public QucsDoc {
+/*!
+ * \brief The TextDoc class definition
+ */
+class TextDoc : public QPlainTextEdit, public QucsDoc {
   Q_OBJECT
-public: 
+public:
   TextDoc (QucsApp *, const QString&);
  ~TextDoc ();
 
@@ -59,6 +65,7 @@ public:
   void  setLanguage (const QString&);
   QString getModuleName (void);
 
+
   QFont TextFont;
 
   bool simulation;   // simulation or module
@@ -75,6 +82,7 @@ public:
 
   bool loadSettings (void);
   bool saveSettings (void);
+  void refreshLanguage(void);
 
   QMenu* createStandardContextMenu(const QPoint&);
 
@@ -84,6 +92,9 @@ public slots:
 
 private:
   SyntaxHighlighter * syntaxHighlight;
+
+private slots:
+   void highlightCurrentLine();
 };
 
 #endif
